* **************************************************************************** *
* Cash Is Queen                                                                *
* Local Economy Effects of Cash Transfers to Women in West Africa              *
* Replication File                                                             *		
* Appendix A: Details on Program Design and Data  						       *
* **************************************************************************** *

* Outline 
 local table_a2      0 
 local table_a3      0 
 local table_a4      0  
 local table_a5      0 
 local table_a6      1
 
*** =========================================================================***
*   Table A2. Attrition Balance Check
**  =========================================================================***
if (`table_a2' == 1) {	
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear
  
* Sample of Analysis
  keep if FNLP_treatment==0
	  
* Balance Check - EVs 
* ------------------------------------------
  gl output_name "TA2_PanelA"
  gl title       "Ultra-poor (EV) households"
  gl DS_var      attrit_w_f2 attrit_w_f3 attrit_w_f2f3
  gl covariates  d_lgacode_bl_1
 
   # d;
   iebaltab $DS_var if vulnerability_category_ward_bl==1, 
			grpvar(nct_ct_inel)  covariates($covariates)  onerow 
			stats(pair(nrmd) f(p)) 
			rowvarlabels ftest format(%12.2f) nostar
			savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
   # d cr;		

* Exporting to unique file 
* ------------------------------------------	 
   preserve 
   * Date:	
	 local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	 disp "`svdate'" 		
	
   * Import table from csv
	 import excel "$outputs_raw/Tables/$output_name.xls", clear

   * Exporting into common file 
	 export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
   restore
  
  
* Balance Check - VVs and Mls
* ------------------------------------------
	 gl output_name "TA2_PanelB"
	  gl DS_var       attrit_w_f2 attrit_w_f3 attrit_w_f2f3
	  gl covariates d_lgacode_bl_1
	 
   # d;
   iebaltab $DS_var if vulnerability_category_ward_bl!=1,
			grpvar(CTvill)  covariates($covariates)  onerow 
			stats(pair(nrmd) f(p)) 
			rowvarlabels ftest format(%12.2f) nostar
			savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
   # d cr;		
	  
* Exporting to unique file 
* ------------------------------------------	 
   preserve 
   * Date:	
	 local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	 disp "`svdate'" 		
	
   * Import table from csv
	 import excel "$outputs_raw/Tables/$output_name.xls", clear

   * Exporting into common file 
	 export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
   restore
  
}

*** =========================================================================***
*   Table A3: Attrition Regression for Extremely Vulnerable Households
**  =========================================================================***
if (`table_a3' == 1) {	
  * Load Data 
    use  "$data/Final/FNLPDataWideAnalysis.dta", clear
  
  * Sample if Analysis
    keep if FNLP_treatment==0
	  
  * Setting up globals for controls    
	  # d;
		gl out_var    attrit_f2f3
					  attrit_w_f2f3;		
		gl treat      i.spill_treatment;

		gl treat2     i.vulnerability_category_ward_bl;	
		
		gl controls1   age_hhhead_bl 	   
					   marital_status_bl    
					   literacy_hhhead_bl   
					   num_hh_members_bl 
					   w_daily_adulteq_expenses_bl
					   num_plots_bl
					   business_work_w_bl
					   weai_new_bl_w
					   lga_new_bl;   
					   
		gl controls2   i.spill_treatment##
		               (c.age_hhhead_bl
					   i.marital_status_bl    
					   i.literacy_hhhead_bl   
					   c.num_hh_members_bl    
					   c.w_daily_adulteq_expenses_bl
					   c.num_plots_bl  
					   i.business_work_w_bl
					   c.weai_new_bl_w
					   i.lga_new_bl);   	
					   
		gl controls3   i.CTvill##
		               (c.age_hhhead_bl
					   i.marital_status_bl    
					   i.literacy_hhhead_bl   
					   c.num_hh_members_bl    
					   c.w_daily_adulteq_expenses_bl
					   c.num_plots_bl  
					   i.business_work_w_bl
					   c.weai_new_bl_w
					   i.lga_new_bl);   					   
	  # d cr;			

   * Fixing labels 
	 la def spill_treatment 0 "Pure Control" 1 "CT"   2 "Non-CT" , modify
	 la val spill_treatment spill_treatment
	  
	 la def CTvill   0 "Non-Program Village"  1 "Program Villages", modify 
	 la val CTvill CTvill

 ** Regression code for EV Sample 
 ** ----------------------------------------------------------------------------
  * Settings
    gl output_name   TA3_AttritionEV
	gl title         "Attrition Regression for Extremely Vulnerable Households" 

   * Regression Code 
	 local outcome attrit_f2f3
	 eststo:  reg `outcome'  ${controls2} if vulnerability_category_ward_bl==1, ///
	           cluster(village_new_bl)
	 estadd local  RESPONDENT  "Female and Male Respondent"
	 estadd local  SAMPLE      "Extreme Vulnerables"
	 
   * Regression Code 
	 local outcome attrit_w_f2f3
	 eststo:  reg `outcome'  ${controls2} if vulnerability_category_ward_bl==1, ///
	           cluster(village_new_bl)
	 estadd local  RESPONDENT  "Female Respondent"
	 estadd local  SAMPLE      "Extreme Vulnerables"
	 
   * Output
	# d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
		  title("$title") 
		  stats(space N r2 RESPONDENT SAMPLE, fmt(0 0 2 0)       
		  labels(" " "Observations" "Adjusted R-squared" "Respondent" "Sample")) 
		  drop (0.spill_treatment* *0.marital_status_bl *0.literacy_hhhead_bl  
		   1.lga_new_bl *0.business_work_w_bl 1.spill_treatment#1.lga_new_bl
		   2.spill_treatment#1.lga_new_bl)
		  label  brackets plain  numbers depvars  
		  star(* 0.1 ** 0.05 *** 0.01)   b(%9.3f) se(%9.2f)        
		  replace;
	# d cr;		
	
** Exporting to Unique File 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 	

 * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 			   

	preserve 
 
 * Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)

 * Exporting into common file 
	 export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
	restore    
 }  
 
 
*** =========================================================================***
*   Table A4: Attrition Regression for Very Vulnerable and Market Limited HHs
**  =========================================================================*** 
if (`table_a4' == 1) {	
  * Load Data 
    use  "$data/Final/FNLPDataWideAnalysis.dta", clear
  
  * Sample if Analysis
    keep if FNLP_treatment==0
	  
  * Setting up globals for controls    
	  # d;
		gl out_var    attrit_f2f3
					  attrit_w_f2f3;		
		gl treat      i.spill_treatment;

		gl treat2     i.vulnerability_category_ward_bl;	
		
		gl controls1   age_hhhead_bl 	   
					   marital_status_bl    
					   literacy_hhhead_bl   
					   num_hh_members_bl 
					   w_daily_adulteq_expenses_bl
					   num_plots_bl
					   business_work_w_bl
					   weai_new_bl_w
					   lga_new_bl;   
					   
		gl controls2   i.spill_treatment##
		               (c.age_hhhead_bl
					   i.marital_status_bl    
					   i.literacy_hhhead_bl   
					   c.num_hh_members_bl    
					   c.w_daily_adulteq_expenses_bl
					   c.num_plots_bl  
					   i.business_work_w_bl
					   c.weai_new_bl_w
					   i.lga_new_bl);   	
					   
		gl controls3   i.CTvill##
		               (c.age_hhhead_bl
					   i.marital_status_bl    
					   i.literacy_hhhead_bl   
					   c.num_hh_members_bl    
					   c.w_daily_adulteq_expenses_bl
					   c.num_plots_bl  
					   i.business_work_w_bl
					   c.weai_new_bl_w
					   i.lga_new_bl);   					   
	  # d cr;			

   * Fixing labels 
	 la def spill_treatment 0 "Pure Control" 1 "CT"   2 "Non-CT" , modify
	 la val spill_treatment spill_treatment
	  
	 la def CTvill   0 "Non-Program Village"  1 "Program Villages", modify 
	 la val CTvill CTvill 
 
 
 
 ** Regression code for All Sample 
 ** ----------------------------------------------------------------------------
  if 1{
   * Output 
    gl output_name   TA4_AttritionVV
	gl title         "Survey Attrition Very Vulnerables and Market Limited Across Villages" 
	
	* Regression Code
     local outcome attrit_f2f3
     eststo:  reg  `outcome'  ${controls3} if d_vuln_cat_1!=1,	        ///
	               cluster(village_new_bl)
	 estadd local  RESPONDENT  "Female and Male Respondent"
	 estadd local  SAMPLE      "Very Vulnerables and Market Limited"
	 
	* Regression Code
     local outcome attrit_w_f2f3
     eststo:  reg  `outcome'  ${controls3} if d_vuln_cat_1!=1,	        ///
	               cluster(village_new_bl)
	 estadd local  RESPONDENT  "Female Respondent"
	 estadd local  SAMPLE      "Very Vulnerables and Market Limited"	 
   
   * Output
	# d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
		  title("$title") 
		  stats(space N r2 RESPONDENT SAMPLE, fmt(0 0 2 0)       
		  labels(" " "Observations" "Adjusted R-squared" "Respondent" "Sample")) 
		  label  brackets plain  numbers depvars  
		  drop (0.CTvill* *0.marital_status_bl *0.literacy_hhhead_bl  
		  1.lga_new_bl *0.business_work_w_bl 1.CTvill#1.lga_new_bl)
		  star(* 0.1 ** 0.05 *** 0.01)   b(%9.3f) se(%9.2f)        
		  replace;
	# d cr;		
	
** Exporting to Unique File 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 	

 * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 			   

	preserve 
 
 * Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)

 * Exporting into common file 
	 export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
	restore    
  }
	
 }
 
*** =========================================================================***
*   Table A5: Covariate Balance — Village-level Characteristics
**  =========================================================================*** 	
if (`table_a5' == 1) {	
 * Load Village Level Data	
   use  "$data/Raw/FNLP_VillageLevel.dta", clear	
	
 * Sample if Analysis
   keep if FNLP_treatment==0

 * Setting up globals  
   # d;
   gl dem_var   age_hhhead_bl        marital_status2_bl_2
				marital_status2_bl_3 marital_status2_bl_4
				literacy_hhhead_bl; 
				
			
   gl lfp_var   any_farm_hh_bl     any_business_bl    any_wage_hh_bl				
			    farming_work_w_bl  farming_work_h_bl 
			    business_work_w_bl business_work_h_bl;

   gl dist_var  min_distance_market min_distance_vCT min_distance_vFNLP 
                mean_distance max_distance;			
				
   gl pov_var   num_vul_village;
						   
   gl agg_ind   ppi_score  ppi_p50 num_inf_ind	num_com_ind; 
      
   gl covariates d_lgacode_bl_1;
   
   gl DS_var $lfp_var $dist_var $pov_var $agg_ind;		
   # d cr; 
   
   
 * Logit to create wegiths: 
	# d;  
	gl cov_pred any_farm_hh_bl         any_wage_hh_bl 
				 farming_work_w_bl      farming_work_h_bl 
				 business_work_h_bl     min_distance_market 
				 max_distance           num_vul_village
				 ppi_score              ppi_p50 
				 num_inf_ind	        num_com_ind;
	# d cr;   

	
	* Regression on treatment status - Pure control is base category
	probit CTvill $cov_pred

	* Predict probability of treatment (CTvill == 1)
	predict prob1

	* Compute probability of control (CTvill == 0) as 1 - prob1
	gen prob0 = 1 - prob1

	* Generating inverse probability weights
	gen     ipw_vill = 1/prob0 if CTvill == 0
	replace ipw_vill = 1/prob1 if CTvill == 1

	* Label the variable
	label var ipw_vill "Inverse Probability Weights Probit Village"

	* Drop intermediate probability variables
	drop prob0 prob1


* Regression on treatment status - Pure control is base category
	probit CTvill $cov_pred if RDD_18==1

	* Predict probability of treatment (CTvill == 1)
	predict prob1

	* Compute probability of control (CTvill == 0) as 1 - prob1
	gen prob0 = 1 - prob1

	* Generating inverse probability weights
	gen     ipw_villRDD18 = 1/prob0 if CTvill == 0
	replace ipw_villRDD18 = 1/prob1 if CTvill == 1

	* Label the variable
	label var ipw_villRDD18 "Inverse Probability Weights Probit Village (RDD18)"

	* Drop intermediate probability variables
	drop prob0 prob1
 
 
   la def CTvill   1 "Non-Program Villages" 0 "Program Villages", modify
   la val CTvill  CTvill
   
   
  * Settings 
	gl output_name "TA5_CovariateBalanceVillageFull"
	gl controls $DS_var 

  * Code for ttest table
	# d;
	iebaltab $controls  /*[pweight=ipw_vill]*/,
	         grpvar(CTvill) covariates($covariates)  onerow 
			 stats(pair(nrmd)) ftest
			 rowvarlabels format(%12.2f)
			 savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	# d cr;		

 ** Exporting to unique file 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore
   
		
  * Settings  for RDD 
     la def CTvill   1 "Non-Program Villages" 0 "Program Villages (RDD Sample)", modify
   la val CTvill  CTvill
  
  
	gl output_name  "TA5_CovariateBalanceVillageRDD"
	gl controls $DS_var 

  * Code for ttest table
	# d;
	iebaltab $controls if RDD_18==1 /*[pweight=ipw_villRDD18]*/,
	         grpvar(CTvill) covariates($covariates)  onerow 
			 stats(pair(nrmd)) ftest
			 rowvarlabels format(%12.2f)
			 savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	# d cr;		

 ** Exporting to unique file 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore
}
	
	
*** =========================================================================***
*   Table A6: Multiple Hypothesis Testing Corrections
**  =========================================================================***  
if (`table_a6' == 1) {	

local Full_sample    1
local RDD_sample     0

*  FULL SAMPLE
** ------------------------------------------------------------------------ ***  	
if `Full_sample'{
set rmsg on	
* -----------------------------------------------	
* Non-Farm Enterprise Outcomes 
* -----------------------------------------------	
if 1{
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
  
   
  * We need to drop those for which we do not have the outcome of interest
	keep if panel_sample==1
    keep if d_vuln_cat_1==1
	keep if FNLP_treatment==0
  
  * Renaming variables so coeff can be save
    ren d_ct_nct_inel_2_year2 ct_y2
	ren d_ct_nct_inel_2_year3 ct_y3
    ren d_ct_nct_inel_1_year2 nct_y2
	ren d_ct_nct_inel_1_year3 nct_y3	
	ren pet400_year2          pet_y2
	ren pet400_year3          pet_y3
	
	
	
  * Globals of controls and main variables 	
	# d;
	gl treat 	    ct_y2 ct_y3   
				    nct_y2 nct_y3; 	
	gl spill 	    pet_y2   pet_y3;  
	gl marketsize   b400pov_year2  b400pov_year3;
	gl rel_poverty  pEV400_year2   pEV400_year3;	
    gl controls     d_lgacode_bl_1; 
	gl year         d_year_2    d_year_3;	
	# d cr; 

* Code of multiple hypothesis testing regressions 
if 1{
 * Set of options that should not change across regressions
	# d;
	gl xlist  $treat $spill $rel_poverty $marketsize $controls $year;
	gl rw_var $treat $spill;
	local options1 	time(year) id(hhid_panel) lag(3)                     
					spatial latitude(gps_latitude_final)                
					longitude(gps_longitude_final) dist(300) bartlett;	
	# d cr;				

 * Set of outcomes 
	local depvar1 business_work
	local depvar2 ihs_realprofits_w 

	
 * Regression specification 	
	# d;
	rwolf2 (acreg `depvar1'  $xlist, `options1') 
		   (acreg `depvar2'  $xlist, `options1'),
		   indepvars($rw_var, $rw_var)
		   usevalid seed(123) reps(1000);
	# d cr;	
}

* Exporting to unique file 
if 1{
* Date:	
  local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
  disp "`svdate'" 	

* Output and name
  gl sheet_name "TA6_NonFarmEnterprise"

* Exporting the file 	
  putexcel set "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
	             sheet("$sheet_name") modify
				
* Export Titles and subtitle
  putexcel A1=("Romano-Wolf multiple hypothesis testing")
  putexcel A2=("Female Entrepreneurship")
  
* Exporting outcome names 
  putexcel A4=("Non Farm Enterprise")
  putexcel A10=("Real Monthly Profits(IHS)")

* Exporting column names   
  putexcel B4=("CT in CT villages Midline[A]")
  putexcel B5=("CT in CT villages Endline[B]") 
  putexcel B6=("NCT in CT villages Midline[C]")
  putexcel B7=("NCT in CT villages Endline[D]")   
  putexcel B8=("PET Midline[E]")
  putexcel B9=("PET Endline[F]")  
  

  putexcel B10=("CT in CT villages Midline[A]")
  putexcel B11=("CT in CT villages Endline[B]") 
  putexcel B12=("NCT in CT villages Midline[C]")
  putexcel B13=("NCT in CT villages Endline[D]")   
  putexcel B14=("PET Midline[E]")
  putexcel B15=("PET Endline[F]")  
  
* Setting up columns names  
  putexcel C3=("Model p-value ") D3=("Resample p-value") 
  
* Specify the starting cell for the matrix output in Excel
	* Extract the full Romano-Wolf matrix
	matrix e_RW = e(RW)

	* Get the number of rows
	local rows = rowsof(e_RW)

	* Create a new matrix with the same number of rows but only two columns
	matrix e_RW_selected = J(`rows', 2, .) // Create empty matrix with `rows` rows and 2 columns

	* Copy the first two columns (Model p-value and Resample p-value)
	forval i = 1/`rows' {
		matrix e_RW_selected[`i',1] = e_RW[`i',1]  // Model p-value
		matrix e_RW_selected[`i',2] = e_RW[`i',2]  // Resample p-value
	}

	* Round values to three decimal places
	forval i = 1/`rows' {
		forval j = 1/2 {
			matrix e_RW_selected[`i',`j'] = round(e_RW_selected[`i',`j'], 0.001)
		}
	}

	* Export only Model p-value and Resample p-value to Excel
	putexcel C4 = matrix(e_RW_selected)

	* Save the Excel file
	putexcel clear
* Clear Stored Estimates
  eststo clear	
	
	
}  
	
	
	
}	
	
* -----------------------------------------------	
* Agriculture Outcomes 
* -----------------------------------------------		
if 1{
* Load Data 
   use  "$data/Final/FNLPDataWideAnalysis.dta", clear	
	
* Sample of Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  drop if business_work_w_bl==.   
  keep if d_wavail_f2==1 & d_wavail_f3==1	
	
	
* Renaming treatment variables   
  ren d_ct_nct_inel_2   ct
  ren d_ct_nct_inel_1   nct
  ren pet400            pet  
 
* Setting up globals for controls  
  gl controls      d_lgacode_bl_1
  gl treatB 	   ct nct 					
  gl spillB 	   pet	
  gl marketsizeB   b400pov
  gl rel_povertyB  pEV400 
 
** Code of multiple hypothesis testing regressions 
** -----------------------------------------------------------------------------	
if 1{
 * Set of options that should not change across regressions
	# d;
	gl xlist $treatB $spillB $rel_povertyB $marketsizeB $controls;	
	gl rw_var	$treatB $spillB;
	local options1 	spatial latitude(gps_latitude_final) 
		            longitude(gps_longitude_final) dist(400) bartlett;	
	# d cr;		
	
 * Set of outcomes 
	local depvar1 d_posyields
	local depvar2 ihs_ragyields 
	local depvar3 ihs_ttl_realinputsha

	
	
 * Regression specification 	
	# d;
	rwolf2 (acreg `depvar1'_f3 `depvar1'_bl $xlist, `options1') 
		   (acreg `depvar2'_f3 `depvar2'_bl $xlist, `options1')
		   (acreg `depvar3'_f3 `depvar3'_bl $xlist, `options1'),
		   indepvars($rw_var, $rw_var, $rw_var)
		   usevalid seed(123) reps(1000);
	# d cr;	
}
** Exporting to unique file 
** -----------------------------------------------------------------------------	
if 1{
* Date:	
  local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
  disp "`svdate'" 	

* Output and name
  gl sheet_name "TA6_Agriculture"

* Exporting the file 	
  putexcel set "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
	             sheet("$sheet_name") modify
				 		
* Export Titles and subtitle
  putexcel A1=("Romano-Wolf multiple hypothesis testing")
  putexcel A2=("Impact on Agriculture Outcomes")
  
* Exporting outcome names 
  putexcel A4=("Positive Agricultural Yields")
  putexcel A7=("Yields(IHS)")
  putexcel A10=("Total spend on inputs in the plot/ha(IHS)") 

* Exporting column names   
  putexcel B4=("CT in CT villages[A]")
  putexcel B5=("NCT in CT villages [B]") 
  putexcel B6=("PET [C]")
 
  putexcel B7=("CT in CT villages[A]")
  putexcel B8=("NCT in CT villages [B]") 
  putexcel B9=("PET [C]")
  
  putexcel B10=("CT in CT villages[A]")
  putexcel B11=("NCT in CT villages [B]") 
  putexcel B12=("PET [C]")
  
  
* Setting up columns names  
  putexcel C3=("Model p-value ") D3=("Resample p-value") 
  
* Specify the starting cell for the matrix output in Excel
	* Extract the full Romano-Wolf matrix
	matrix e_RW = e(RW)

	* Get the number of rows
	local rows = rowsof(e_RW)

	* Create a new matrix with the same number of rows but only two columns
	matrix e_RW_selected = J(`rows', 2, .) // Create empty matrix with `rows` rows and 2 columns

	* Copy the first two columns (Model p-value and Resample p-value)
	forval i = 1/`rows' {
		matrix e_RW_selected[`i',1] = e_RW[`i',1]  // Model p-value
		matrix e_RW_selected[`i',2] = e_RW[`i',2]  // Resample p-value
	}

	* Round values to three decimal places
	forval i = 1/`rows' {
		forval j = 1/2 {
			matrix e_RW_selected[`i',`j'] = round(e_RW_selected[`i',`j'], 0.001)
		}
	}

	* Export only Model p-value and Resample p-value to Excel
	putexcel C4 = matrix(e_RW_selected)

	* Save the Excel file
	putexcel clear
* Clear Stored Estimates
  eststo clear
				
}  
}

* -----------------------------------------------	
* Food Security and Consumption  
* -----------------------------------------------		
if 1{
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
  
 * We need to drop those for which we do not have the outcome of interest
	keep if panel_sample==1
    keep if d_vuln_cat_1==1
	keep if FNLP_treatment==0
  
  * Renaming variables so coeff can be save
    ren d_ct_nct_inel_2_year2 ct_y2
	ren d_ct_nct_inel_2_year3 ct_y3
    ren d_ct_nct_inel_1_year2 nct_y2
	ren d_ct_nct_inel_1_year3 nct_y3	
	
  * Globals of controls and main variables 	
	# d;
	gl treat 	    ct_y2 ct_y3   
				    nct_y2 nct_y3; 	
	gl spill 	    pet400_year2   pet400_year3;  
	gl marketsize   b400pov_year2  b400pov_year3;
	gl rel_poverty  pEV400_year2   pEV400_year3;	
    gl controls     d_lgacode_bl_1; 
	gl year         d_year_2    d_year_3;	
	# d cr; 
	
** Code of multiple hypothesis testing regressions 
** -----------------------------------------------------------------------------	
if 1{
 * Set of options that should not change across regressions
	# d;
	gl xlist $treat $spill $rel_poverty $marketsize $controls $year;	
    gl rw_var $treat $spill;
	local options1 	time(year) id(hhid_panel) lag(3)                     
					spatial latitude(gps_latitude_final)                
					longitude(gps_longitude_final) dist(400) bartlett;	
	# d cr;				

 * Set of outcomes 
	local depvar1 foodins_index
	local depvar2 ihs_expen_7dae


 * Regression specification 	
	# d;
	rwolf2 (acreg `depvar1'  $xlist, `options1') 
		   (acreg `depvar2'  $xlist, `options1'),
		   indepvars($rw_var, $rw_var)
		   usevalid seed(123) reps(1000);
	# d cr;	
}
** Exporting to unique file 
** -----------------------------------------------------------------------------	
if 1{
* Date:	
  local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
  disp "`svdate'" 	

* Output and name
  gl sheet_name "TA6_FoodSecurityConsumption"

* Exporting the file 	
  putexcel set "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
	             sheet("$sheet_name") modify
				 
				 
* Export Titles and subtitle
  putexcel A1=("Romano-Wolf multiple hypothesis testing")
  putexcel A2=("Food Security and Consumption")
  
* Exporting outcome names 
  putexcel A4=("Household Food Security Scale (0-6)")
  putexcel A10=("Real Expenditures Adult Equivalent(IHS)")

* Exporting column names   
  putexcel B4=("CT in CT villages Midline[A]")
  putexcel B5=("CT in CT villages Endline[B]") 
  putexcel B6=("NCT in CT villages Midline[C]")
  putexcel B7=("NCT in CT villages Endline[D]")   
  putexcel B8=("PET Midline[E]")
  putexcel B9=("PET Endline[F]")  
  

  putexcel B10=("CT in CT villages Midline[A]")
  putexcel B11=("CT in CT villages Endline[B]") 
  putexcel B12=("NCT in CT villages Midline[C]")
  putexcel B13=("NCT in CT villages Endline[D]")   
  putexcel B14=("PET Midline[E]")
  putexcel B15=("PET Endline[F]") 
  
* Setting up columns names  
  putexcel C3=("Model p-value ") D3=("Resample p-value")
  
* Specify the starting cell for the matrix output in Excel
	* Extract the full Romano-Wolf matrix
	matrix e_RW = e(RW)

	* Get the number of rows
	local rows = rowsof(e_RW)

	* Create a new matrix with the same number of rows but only two columns
	matrix e_RW_selected = J(`rows', 2, .) // Create empty matrix with `rows` rows and 2 columns

	* Copy the first two columns (Model p-value and Resample p-value)
	forval i = 1/`rows' {
		matrix e_RW_selected[`i',1] = e_RW[`i',1]  // Model p-value
		matrix e_RW_selected[`i',2] = e_RW[`i',2]  // Resample p-value
	}

	* Round values to three decimal places
	forval i = 1/`rows' {
		forval j = 1/2 {
			matrix e_RW_selected[`i',`j'] = round(e_RW_selected[`i',`j'], 0.001)
		}
	}

	* Export only Model p-value and Resample p-value to Excel
	putexcel C4 = matrix(e_RW_selected)

	* Save the Excel file
	putexcel clear
* Clear Stored Estimates
  eststo clear
  
  
}  


}
		
* -----------------------------------------------	
* Women's Empowerment and Decision-Making Power
* -----------------------------------------------		
if 1{
 * Load Data 
   use  "$data/Final/FNLPDataWideAnalysis.dta", clear	
		
* Sample of Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  drop if business_work_w_bl==.   
  keep if d_wavail_f2==1 & d_wavail_f3==1
	
* Renaming treatment variables   
  ren d_ct_nct_inel_2   ct
  ren d_ct_nct_inel_1   nct
  ren pet400            pet  
  ren proweai_sum_ind_w  proweai_w
  ren dm_index_w_f3    dmind_wf3
  ren d_sharemoney4_1_w_f3 sharem_1_wf3
  ren d_sharemoney4_2_w_f3 sharem_2_wf3
  ren d_sharemoney4_3_w_f3 sharem_3_wf3  
  
* Setting up globals for controls  
  gl controls      d_lgacode_bl_1
  gl treatB 	   ct nct 					
  gl spillB 	   pet	
  gl marketsizeB   b400pov
  gl rel_povertyB  pEV400 
  
** Code of multiple hypothesis testing regressions 
** -----------------------------------------------------------------------------	
if 1{
 * Set of options that should not change across regressions
	# d;
	gl xlist $treatB $spillB $rel_povertyB $marketsizeB $controls;	
	gl rw_var	$treatB $spillB;
	local options1 	spatial latitude(gps_latitude_final) 
		            longitude(gps_longitude_final) dist(400) bartlett;	
	# d cr;		

 * Set of outcomes 
	local depvar1 proweai_w
	local depvar2 dmind_wf3
	local depvar3 sharem_1_wf3
	local depvar4 sharem_2_wf3
	local depvar5 sharem_3_wf3 
   
    local control_1 weai_new_bl_w
	local control_2 dm_index_w_bl
	
 * Regression specification 	
	# d;
	rwolf2 (acreg `depvar1'  $xlist `control_1', `options1') 
		   (acreg `depvar2'  $xlist `control_2', `options1')
		   (acreg `depvar3'  $xlist `control_2', `options1')
		   (acreg `depvar4'  $xlist `control_2', `options1')
		   (acreg `depvar5'  $xlist `control_2', `options1'),
		   indepvars($rw_var, $rw_var, $rw_var, $rw_var, $rw_var)
		   usevalid seed(123) reps(1000);
	# d cr;	
}
** Exporting to unique file 
** -----------------------------------------------------------------------------	
if 1{
* Date:	
  local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
  disp "`svdate'" 	

* Output and name
  gl sheet_name "TA6_WomenEmpowerment"

* Exporting the file 	
  putexcel set "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
	             sheet("$sheet_name") modify
				 		
* Export Titles and subtitle
  putexcel A1=("Romano-Wolf multiple hypothesis testing")
  putexcel A2=("Impact on Empowering Outcomes")
  
* Exporting outcome names 
  putexcel A4=("Pro-WEAI Empowerment Index (0-11)")
  putexcel A7=("Decision Making Index (0-7)")
  putexcel A10=("Who decides how money from a relative is shared: Self") 
  putexcel A13=("Who decides how money from a relative is shared: Spouse") 
  putexcel A16=("Who decides how money from a relative is shared: Joint") 
  
  
* Exporting column names   
  putexcel B4=("CT in CT villages[A]")
  putexcel B5=("NCT in CT villages [B]") 
  putexcel B6=("PET [C]")
 
  putexcel B7=("CT in CT villages[A]")
  putexcel B8=("NCT in CT villages [B]") 
  putexcel B9=("PET [C]")
  
  putexcel B10=("CT in CT villages[A]")
  putexcel B11=("NCT in CT villages [B]") 
  putexcel B12=("PET [C]")
  
  
  putexcel B13=("CT in CT villages[A]")
  putexcel B14=("NCT in CT villages [B]") 
  putexcel B15=("PET [C]")
  
  putexcel B16=("CT in CT villages[A]")
  putexcel B17=("NCT in CT villages [B]") 
  putexcel B18=("PET [C]")  
  
  
* Setting up columns names  
  putexcel C3=("Model p-value ") D3=("Resample p-value") 
  
* Specify the starting cell for the matrix output in Excel
	* Extract the full Romano-Wolf matrix
	matrix e_RW = e(RW)

	* Get the number of rows
	local rows = rowsof(e_RW)

	* Create a new matrix with the same number of rows but only two columns
	matrix e_RW_selected = J(`rows', 2, .) // Create empty matrix with `rows` rows and 2 columns

	* Copy the first two columns (Model p-value and Resample p-value)
	forval i = 1/`rows' {
		matrix e_RW_selected[`i',1] = e_RW[`i',1]  // Model p-value
		matrix e_RW_selected[`i',2] = e_RW[`i',2]  // Resample p-value
	}

	* Round values to three decimal places
	forval i = 1/`rows' {
		forval j = 1/2 {
			matrix e_RW_selected[`i',`j'] = round(e_RW_selected[`i',`j'], 0.001)
		}
	}

	* Export only Model p-value and Resample p-value to Excel
	putexcel C4 = matrix(e_RW_selected)

	* Save the Excel file
	putexcel clear
* Clear Stored Estimates
  eststo clear
				
}  
}
	
set rmsg off		

}	
	
	
*  RDD SAMPLE
** ------------------------------------------------------------------------ *** 
 	
if `RDD_sample'{
	
* -----------------------------------------------	
* Non-Farm Enterprise Outcomes 
* -----------------------------------------------	
if 1{
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
  
 * We need to drop those for which we do not have the outcome of interest
	keep if panel_sample==1
    keep if d_vuln_cat_1==1
	keep if FNLP_treatment==0
  	keep if RDD_18==1 
	
	
  * Renaming variables so coeff can be save
    ren d_ct_nct_inel_2_year2 ct_y2
	ren d_ct_nct_inel_2_year3 ct_y3
    ren d_ct_nct_inel_1_year2 nct_y2
	ren d_ct_nct_inel_1_year3 nct_y3	
	ren pet400_year2          pet_y2
	ren pet400_year3          pet_y3
	
	
	
  * Globals of controls and main variables 	
	# d;
	gl treat 	    ct_y2 ct_y3   
				    nct_y2 nct_y3; 	
	gl spill 	    pet_y2   pet_y3;  
	gl marketsize   b400pov_year2  b400pov_year3;
	gl rel_poverty  pEV400_year2   pEV400_year3;	
    gl controls     d_lgacode_bl_1; 
	gl year         d_year_2    d_year_3;	
	# d cr; 

* Code of multiple hypothesis testing regressions 
if 1{
 * Set of options that should not change across regressions
	# d;
	gl xlist  $treat $spill $rel_poverty $marketsize $controls $year;
	gl rw_var $treat $spill;
	local options1 	time(year) id(hhid_panel) lag(3)                     
					spatial latitude(gps_latitude_final)                
					longitude(gps_longitude_final) dist(300) bartlett;	
	# d cr;				

 * Set of outcomes 
	local depvar1 business_work
	local depvar2 ihs_realprofits_w 

	
 * Regression specification 	
	# d;
	rwolf2 (acreg `depvar1'  $xlist [pweight=ipw], `options1') 
		   (acreg `depvar2'  $xlist [pweight=ipw], `options1'),
		   indepvars($rw_var, $rw_var)
		   usevalid seed(123) reps(1000);
	# d cr;	
}

* Exporting to unique file 
if 1{
* Date:	
  local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
  disp "`svdate'" 	

* Output and name
  gl sheet_name "TA6_NonFarmEnterpriseRDD"

* Exporting the file 	
  putexcel set "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
	             sheet("$sheet_name") modify
				
* Export Titles and subtitle
  putexcel F2=("Female Entrepreneurship (RDD)")
  
* Exporting outcome names 
  putexcel A4=("Non Farm Enterprise")
  putexcel A10=("Real Monthly Profits(IHS)")

  
* Setting up columns names  
  putexcel F3=("Model p-value ") G3=("Resample p-value") 
  
* Specify the starting cell for the matrix output in Excel
	* Extract the full Romano-Wolf matrix
	matrix e_RW = e(RW)

	* Get the number of rows
	local rows = rowsof(e_RW)

	* Create a new matrix with the same number of rows but only two columns
	matrix e_RW_selected = J(`rows', 2, .) // Create empty matrix with `rows` rows and 2 columns

	* Copy the first two columns (Model p-value and Resample p-value)
	forval i = 1/`rows' {
		matrix e_RW_selected[`i',1] = e_RW[`i',1]  // Model p-value
		matrix e_RW_selected[`i',2] = e_RW[`i',2]  // Resample p-value
	}

	* Round values to three decimal places
	forval i = 1/`rows' {
		forval j = 1/2 {
			matrix e_RW_selected[`i',`j'] = round(e_RW_selected[`i',`j'], 0.001)
		}
	}

	* Export only Model p-value and Resample p-value to Excel
	putexcel F4 = matrix(e_RW_selected)

	* Save the Excel file
	putexcel clear
* Clear Stored Estimates
  eststo clear	
	
	
}  
	
	
	
}	
	
* -----------------------------------------------	
* Agriculture Outcomes 
* -----------------------------------------------		
if 1{
* Load Data 
   use  "$data/Final/FNLPDataWideAnalysis.dta", clear	
	
* Sample of Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1	
  keep if RDD_18==1 	
	
* Renaming treatment variables   
  ren d_ct_nct_inel_2   ct
  ren d_ct_nct_inel_1   nct
  ren pet400            pet  
 
* Setting up globals for controls  
  gl controls      d_lgacode_bl_1
  gl treatB 	   ct nct 					
  gl spillB 	   pet	
  gl marketsizeB   b400pov
  gl rel_povertyB  pEV400 
 
** Code of multiple hypothesis testing regressions 
** -----------------------------------------------------------------------------	
if 1{
 * Set of options that should not change across regressions
	# d;
	gl xlist $treatB $spillB $rel_povertyB $marketsizeB $controls;	
	gl rw_var	$treatB $spillB;
	local options1 	spatial latitude(gps_latitude_final) 
		            longitude(gps_longitude_final) dist(400) bartlett;	
	# d cr;		
	
 * Set of outcomes 
	local depvar1 d_posyields
	local depvar2 ihs_ragyields 
	local depvar3 ihs_ttl_realinputsha

	
	
 * Regression specification 	
	# d;
	rwolf2 (acreg `depvar1'_f3 `depvar1'_bl $xlist [pweight=ipw], `options1') 
		   (acreg `depvar2'_f3 `depvar2'_bl $xlist [pweight=ipw], `options1')
		   (acreg `depvar3'_f3 `depvar3'_bl $xlist [pweight=ipw], `options1'),
		   indepvars($rw_var, $rw_var, $rw_var)
		   usevalid seed(123) reps(1000);
	# d cr;	
}

** Exporting to unique file 
** -----------------------------------------------------------------------------	
if 1{
* Date:	
  local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
  disp "`svdate'" 	

* Output and name
  gl sheet_name "TA6_AgricultureRDD"

* Exporting the file 	
  putexcel set "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
	             sheet("$sheet_name") modify
				 		
* Export Titles and subtitle
  putexcel F2=("Impact on Agriculture Outcomes (RDD)")
  
* Exporting outcome names 
  putexcel A4=("Positive Agricultural Yields")
  putexcel A7=("Yields(IHS)")
  putexcel A10=("Total spend on inputs in the plot/ha(IHS)") 

* Setting up columns names  
  putexcel F3=("Model p-value ") G3=("Resample p-value") 
  
* Specify the starting cell for the matrix output in Excel
	* Extract the full Romano-Wolf matrix
	matrix e_RW = e(RW)

	* Get the number of rows
	local rows = rowsof(e_RW)

	* Create a new matrix with the same number of rows but only two columns
	matrix e_RW_selected = J(`rows', 2, .) // Create empty matrix with `rows` rows and 2 columns

	* Copy the first two columns (Model p-value and Resample p-value)
	forval i = 1/`rows' {
		matrix e_RW_selected[`i',1] = e_RW[`i',1]  // Model p-value
		matrix e_RW_selected[`i',2] = e_RW[`i',2]  // Resample p-value
	}

	* Round values to three decimal places
	forval i = 1/`rows' {
		forval j = 1/2 {
			matrix e_RW_selected[`i',`j'] = round(e_RW_selected[`i',`j'], 0.001)
		}
	}

	* Export only Model p-value and Resample p-value to Excel
	putexcel F4 = matrix(e_RW_selected)

	* Save the Excel file
	putexcel clear
* Clear Stored Estimates
  eststo clear
				
}  
}

* -----------------------------------------------	
* Food Security and Consumption  
* -----------------------------------------------		
if 1{
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
  
 * We need to drop those for which we do not have the outcome of interest
	keep if panel_sample==1
    keep if d_vuln_cat_1==1
	keep if FNLP_treatment==0
  	keep if RDD_18==1 
	
  * Renaming variables so coeff can be save
    ren d_ct_nct_inel_2_year2 ct_y2
	ren d_ct_nct_inel_2_year3 ct_y3
    ren d_ct_nct_inel_1_year2 nct_y2
	ren d_ct_nct_inel_1_year3 nct_y3	
	
  * Globals of controls and main variables 	
	# d;
	gl treat 	    ct_y2 ct_y3   
				    nct_y2 nct_y3; 	
	gl spill 	    pet400_year2   pet400_year3;  
	gl marketsize   b400pov_year2  b400pov_year3;
	gl rel_poverty  pEV400_year2   pEV400_year3;	
    gl controls     d_lgacode_bl_1; 
	gl year         d_year_2    d_year_3;	
	# d cr; 
	
** Code of multiple hypothesis testing regressions 
** -----------------------------------------------------------------------------	
if 1{
 * Set of options that should not change across regressions
	# d;
	gl xlist $treat $spill $rel_poverty $marketsize $controls $year;	
    gl rw_var $treat $spill;
	local options1 	time(year) id(hhid_panel) lag(3)                     
					spatial latitude(gps_latitude_final)                
					longitude(gps_longitude_final) dist(400) bartlett;	
	# d cr;				

 * Set of outcomes 
	local depvar1 foodins_index
	local depvar2 ihs_expen_7dae


 * Regression specification 	
	# d;
	rwolf2 (acreg `depvar1'  $xlist [pweight=ipw], `options1') 
		   (acreg `depvar2'  $xlist [pweight=ipw], `options1'),
		   indepvars($rw_var, $rw_var)
		   usevalid seed(123) reps(1000);
	# d cr;	
}


** Exporting to unique file 
** -----------------------------------------------------------------------------	
if 1{
* Date:	
  local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
  disp "`svdate'" 	

* Output and name
  gl sheet_name "TA6_FoodSecurityConsumptionRDD"

* Exporting the file 	
  putexcel set "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
	             sheet("$sheet_name") modify
				 
				 
* Export Titles and subtitle
  putexcel F2=("Food Security and Consumption (RDD)")
  
* Exporting outcome names 
  putexcel A4=("Household Food Security Scale (0-6)")
  putexcel A10=("Real Expenditures Adult Equivalent(IHS)")
  
* Setting up columns names  
  putexcel F3=("Model p-value ") F3=("Resample p-value")
  
* Specify the starting cell for the matrix output in Excel
	* Extract the full Romano-Wolf matrix
	matrix e_RW = e(RW)

	* Get the number of rows
	local rows = rowsof(e_RW)

	* Create a new matrix with the same number of rows but only two columns
	matrix e_RW_selected = J(`rows', 2, .) // Create empty matrix with `rows` rows and 2 columns

	* Copy the first two columns (Model p-value and Resample p-value)
	forval i = 1/`rows' {
		matrix e_RW_selected[`i',1] = e_RW[`i',1]  // Model p-value
		matrix e_RW_selected[`i',2] = e_RW[`i',2]  // Resample p-value
	}

	* Round values to three decimal places
	forval i = 1/`rows' {
		forval j = 1/2 {
			matrix e_RW_selected[`i',`j'] = round(e_RW_selected[`i',`j'], 0.001)
		}
	}

	* Export only Model p-value and Resample p-value to Excel
	putexcel F4 = matrix(e_RW_selected)

	* Save the Excel file
	putexcel clear
* Clear Stored Estimates
  eststo clear
  
  
}  


}
		
* -----------------------------------------------	
* Women's Empowerment and Decision-Making Power
* -----------------------------------------------		
if 1{
 * Load Data 
   use  "$data/Final/FNLPDataWideAnalysis.dta", clear	
		
* Sample of Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1
  keep if RDD_18==1
	
* Renaming treatment variables   
  ren d_ct_nct_inel_2   ct
  ren d_ct_nct_inel_1   nct
  ren pet400            pet  
  ren proweai_sum_ind_w  proweai_w
  ren dm_index_w_f3    dmind_wf3
  ren d_sharemoney4_1_w_f3 sharem_1_wf3
  ren d_sharemoney4_2_w_f3 sharem_2_wf3
  ren d_sharemoney4_3_w_f3 sharem_3_wf3  
  
* Setting up globals for controls  
  gl controls      d_lgacode_bl_1
  gl treatB 	   ct nct 					
  gl spillB 	   pet	
  gl marketsizeB   b400pov
  gl rel_povertyB  pEV400 
  
** Code of multiple hypothesis testing regressions 
** -----------------------------------------------------------------------------	
if 1{
 * Set of options that should not change across regressions
	# d;
	gl xlist $treatB $spillB $rel_povertyB $marketsizeB $controls;	
	gl rw_var	$treatB $spillB;
	local options1 	spatial latitude(gps_latitude_final) 
		            longitude(gps_longitude_final) dist(400) bartlett;	
	# d cr;		

 * Set of outcomes 
	local depvar1 proweai_w
	local depvar2 dmind_wf3
	local depvar3 sharem_1_wf3
	local depvar4 sharem_2_wf3
	local depvar5 sharem_3_wf3 
   
    local control_1 weai_new_bl_w
	local control_2 dm_index_w_bl
	
 * Regression specification 	
	# d;
	rwolf2 (acreg `depvar1'  $xlist `control_1' [pweight=ipw], `options1') 
		   (acreg `depvar2'  $xlist `control_2' [pweight=ipw], `options1')
		   (acreg `depvar3'  $xlist `control_2' [pweight=ipw], `options1')
		   (acreg `depvar4'  $xlist `control_2' [pweight=ipw], `options1')
		   (acreg `depvar5'  $xlist `control_2' [pweight=ipw], `options1'),
		   indepvars($rw_var, $rw_var, $rw_var, $rw_var, $rw_var)
		   usevalid seed(123) reps(1000);
	# d cr;	
}

** Exporting to unique file 
** -----------------------------------------------------------------------------	
if 1{
* Date:	
  local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
  disp "`svdate'" 	

* Output and name
  gl sheet_name "TA6_WomenEmpowermentRDD"

* Exporting the file 	
  putexcel set "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
	             sheet("$sheet_name") modify
				 		
* Export Titles and subtitle
  putexcel F2=("Impact on Empowering Outcomes (RDD)")
  
* Exporting outcome names 
  putexcel A4=("Pro-WEAI Empowerment Index (0-11)")
  putexcel A7=("Decision Making Index (0-7)")
  putexcel A10=("Who decides how money from a relative is shared: Self") 
  putexcel A13=("Who decides how money from a relative is shared: Spouse") 
  putexcel A16=("Who decides how money from a relative is shared: Joint") 
  
  
* Setting up columns names  
  putexcel F3=("Model p-value ") G3=("Resample p-value") 
  
* Specify the starting cell for the matrix output in Excel
	* Extract the full Romano-Wolf matrix
	matrix e_RW = e(RW)

	* Get the number of rows
	local rows = rowsof(e_RW)

	* Create a new matrix with the same number of rows but only two columns
	matrix e_RW_selected = J(`rows', 2, .) // Create empty matrix with `rows` rows and 2 columns

	* Copy the first two columns (Model p-value and Resample p-value)
	forval i = 1/`rows' {
		matrix e_RW_selected[`i',1] = e_RW[`i',1]  // Model p-value
		matrix e_RW_selected[`i',2] = e_RW[`i',2]  // Resample p-value
	}

	* Round values to three decimal places
	forval i = 1/`rows' {
		forval j = 1/2 {
			matrix e_RW_selected[`i',`j'] = round(e_RW_selected[`i',`j'], 0.001)
		}
	}

	* Export only Model p-value and Resample p-value to Excel
	putexcel F4 = matrix(e_RW_selected)

	* Save the Excel file
	putexcel clear
* Clear Stored Estimates
  eststo clear
				
}  
}
	
	

}	
	

	
}	
		

 
 
* ******************************************************************************
//  END DOFILE 
* ******************************************************************************


