* **************************************************************************** *
* Cash Is Queen                                                                *
* Local Economy Effects of Cash Transfers to Women in West Africa              *
* Replication File                                                             *		
* Appendix B: Further Details on Spatial Modeling of Spillovers  			   *
* **************************************************************************** *

* Outline 
local figure_b2     1
local table_b1      1
local figure_b3     1
local table_b2      1
local figure_b6     1
local table_b3      1
local table_b4      1

*** =========================================================================***
*	Figure B2: Moran's I Scatterplots                                          *
*** =========================================================================***
if (`figure_b2' == 1) {	
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear
  
* Sample if Analysis
  keep if FNLP_treatment==0   // FNLP CONTROL SITES
  keep if d_vuln_cat_1==1  	  // EVS 
  keep if CTvill==1           // Just ELIGIBLES 
  
* Generating Standarized Variables of main outcomes  
  egen std_profits_bl=std(profits_business_bl)
  egen std_profits_f3= std(w_profits_business_fup3) 
  egen std_aeconsumption_bl=std(w_daily_adulteq_expenses_bl) 
  egen std_aeconsumption_f3=std(w_daily_adulteq_expenses_f3) 
   
* Morans I Statistic:  Profits
* ------------------------------------------------------------------------------ 
if 1{
  local lat gps_latitude_final 
  local lon gps_longitude_final
  local outcome std_profits_f3
  moransi `outcome', lon(`lon') lat(`lat') swm(pow 2) dist(.) dunit(km) gen
  local m    `r(I)' 
  local morans = round(`m', .01)
  local p_value  `r(pI)' 	
	
* Morans Graph
  local title    "Moran's I Scatterplot"
  local subtitle "Business Profits (Endline)"
  # d;
	twoway  (scatter splag_`outcome'_p `outcome', 
					 ms(oh) yaxis(1 2) xaxis(1 2) color("85 0 212")) 
			(lfit    splag_`outcome'_p `outcome', 
			         lw(medium) estopts(nocons) color("255 205 0")), 
			ytitle("Spatially Lagged Values", tstyle(size(small)) axis(1)) 
			xtitle("Standardized Values", tstyle(size(small)) height(6) axis(1)) 
			ytitle("", axis(2)) 
			xtitle("", axis(2)) 
			ylabel(/*-2(2)6*/, ang(h) labsize(small) format(%2.0f) nogrid axis(1)) 
			xlabel(/*-2(2)6*/, labsize(small) format(%2.0f) nogrid axis(1)) 
			ylabel(/*-2(2)6*/, ang(h) labsize(small) format(%2.0f) nogrid axis(2)) 
			xlabel(/*-2(2)6*/, labsize(small) format(%2.0f) nogrid axis(2))
			ysize(3) xsize(4) 
			yline(0, lwidth(thin) lcolor(gray) lpattern(dash)) 
			xline(0, lwidth(thin) lcolor(gray) lpattern(dash)) 
			/*title("`title'", justification(left) color(black) span pos(11) size(medium))*/ 
			subtitle("`subtitle'", justification(left) color(black) span pos(11) size(small))
			legend(off)
			graphregion(color(white) fcolor(white))
			note("Moran's I statistic=`morans'" 
			     "P-value of I=0.00"
				 "Size of spatial weight matrix: 1156*1156", size(vsmall));
  # d cr; 
  
* Graph export 
  graph export "$outputs_final/Figures/FB2_MoranI_Profits.png", ///
                as(png) width(1600) height(1200) replace

}			
			
* Morans I Statistic:  Expenditures
* ------------------------------------------------------------------------------ 
if 1{
  local lat gps_latitude_final 
  local lon gps_longitude_final
  local outcome std_aeconsumption_f3
  moransi `outcome', lon(`lon') lat(`lat') swm(pow 2) dist(.) dunit(km) gen
  local m    `r(I)' 
  local morans = round(`m', .01)
  local p_value  `r(pI)' 	
	
* Morans Graph
  local title    "Moran's I Scatterplot"
  local subtitle "Daily Adult Equivalent Expentitures (Endline)"
  # d;
	twoway  (scatter splag_`outcome'_p `outcome', 
					 ms(oh) yaxis(1 2) xaxis(1 2) color("85 0 212")) 
			(lfit    splag_`outcome'_p `outcome', 
			         lw(medium) estopts(nocons) color("255 205 0")), 
			ytitle("Spatially Lagged Values", tstyle(size(small)) axis(1)) 
			xtitle("Standardized Values", tstyle(size(small)) height(6) axis(1)) 
			ytitle("", axis(2)) 
			xtitle("", axis(2)) 
			ylabel(/*-2(2)6*/, ang(h) labsize(small) format(%2.0f) nogrid axis(1)) 
			xlabel(/*-2(2)6*/, labsize(small) format(%2.0f) nogrid axis(1)) 
			ylabel(/*-2(2)6*/, ang(h) labsize(small) format(%2.0f) nogrid axis(2)) 
			xlabel(/*-2(2)6*/, labsize(small) format(%2.0f) nogrid axis(2))
			ysize(3) xsize(4) 
			yline(0, lwidth(thin) lcolor(gray) lpattern(dash)) 
			xline(0, lwidth(thin) lcolor(gray) lpattern(dash)) 
			/*title("`title'", justification(left) color(black) span pos(11) size(medium))*/ 
			subtitle("`subtitle'", justification(left) color(black) span pos(11) size(small))
			legend(off)
			graphregion(color(white) fcolor(white))
			note("Moran's I statistic=`morans'" 
			     "P-value of I=0.00" 
				 "Size of spatial weight matrix:1239*1239", size(vsmall));
  # d cr; 
  
 * Graph export 
  graph export "$outputs_final/Figures/FB2_MoranI_Expenditures.png", ///
                as(png) width(1600) height(1200) replace 
}			
		
		

 }

*** =========================================================================***
*   Table B1: Descriptive Statistics of Distance Variables between 
*   Households in Same Village
**  =========================================================================***
if (`table_b1' == 1) {	
	
* Load the dataset 
  use "$data/Raw/VillageDistancesHH.dta", clear    

* Adding labels to improve output
  la var min_distance "Shortest (Meters)"
  la var mean_distance "Mean (Kilometers)"
  la var max_distance  "Maximum (Kilometers)" 
  la var mean_dist_villmark "Distance to Market"
* Define global for variables  
  gl ds_var min_distance mean_distance max_distance mean_dist_villmark

* Clear stored estimates  
  eststo clear  

* Generate descriptive statistics  
  estpost tabstat $ds_var, statistics(count mean sd p50 min max) columns(statistics)  

* Export table in LaTeX format
  esttab using "$outputs_raw/Tables/TB1_DS_VillageDistance.tex", ///
    cells("mean(fmt(%9.2f)label (Mean))" ///
          "sd(fmt(%9.2f)label (SD))" ///
          "p50(fmt(%9.2f)label (Median))" ///  // Fix label for Median
          "min(fmt(%9.2f)label (Min))" ///
          "max(fmt(%9.2f)label (Max))") ///
    title("Table B1: Descriptive Statistics of Distance Variables between Households in Same Village") ///
    label unstack nonumbers nogaps nonote plain replace ///
    stats(N, fmt(%9.0g) labels("Observations"))  // Add row for Observations
} 

** ========================================================================== **
*  Figure B3: Average Distance between Household (km) per Village
** ===========================================================================**
if (`figure_b3' == 1){
* Load the dataset 
  use "$data/Raw/VillageDistancesHH.dta", clear    
  
* Code to graph  
  graph set window fontface "Times New Roman"  
  
  gl title    "Mean distance between two households (Kms)"	   
  gl subtitle "Within village"
  local group village_group	   

  gl outcome1 mean_distance
  sum $outcome1 
  local 	mean_1 =round(r(mean), .01) 
  
  # d ; 
	graph bar  $outcome1,
			over(`group', gap(*.3)  label(labsize(tiny) angle(90))
			sort (1))
			bar(1,  color(lavender%40) lcolor(gold)) 
			stack 
			 title($title, size(small) 
					 color(black) span pos(11))
			 subtitle($subtitle, size(vsmall)
						justification(left) pos(11))
			 ytitle(Kilometers, size(vsmall))
			 ylabel(,labsize (small))
			 graphregion(color(white))
			 bargap(3) blabe(total, format(%9.2f) size(tiny))
			 note("Mean Distance `mean_1' Kms", size(vsmall))
			 name(mygraph, replace); 
	# d cr; 
  
  
* Export the graph as a PNG file
  local graph_output FB3_HistogramDistVillage
  graph export "$outputs_final/Figures/`graph_output'.png", as(png) replace name(mygraph)
	
	
	
	
}

** ========================================================================== **
*  Table B2: Local Neighborhood Statistics by radius 100m–1,000m
** ===========================================================================**
if (`table_b2' == 1) {	
 * Load dataset 	
   use "$data/Raw/HHSpatialLongData.dta", clear	
   
*  Extra cleaning so output is cleared   
   replace pet=0    if 	village_ineligible_ct==1
   replace bpov=bpov*100
   replace pet=pet*100
   replace pEV=pEV*100
  
 * Adding labels 
   la var pet   "Proportion of neighbors that are cash transfers recipients (PET)" 
   la var pEV	"Proportion of neighbors that are extremely vulnerable (PEV)" 
   la var bpov  "Number of households in neighborhood (#HHs)" 

* DS Table  CT Villages
* ------------------------------------------------------------------------------
   gl output_name TB2_DSRadius_PanelA
   gl ds_var pet pEV bpov
   # d; 
	eststo  clear; 
	estpost tabstat $ds_var if village_ineligible_ct==0,  
	         by(meters)				              
			 statistics(mean sd min max) columns(statistics); 
		
	 esttab using  "$outputs_raw/Tables/$output_name.csv",	 
	 cells("mean(fmt(%9.2f)label (Mean))" "sd(fmt(%9.2f)label (SD))" 
	       "min(fmt(%9.2f)label (Min))" "max(fmt(%9.2f)label (Max))")
	 title("Table: Descriptive Statistics across country ") label 	
	 unstack  nonumbers nogaps nonote plain replace; 
  # d cr; 
   
 * Drop store values	 
  eststo clear	 
  
*  Exporting to unique file 
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
  preserve 
  * Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore	
	

* DS Table NonProgram Villages 
* ------------------------------------------------------------------------------
   gl output_name TB2_DSRadius_PanelB
   gl ds_var pEV bpov
   # d; 
	eststo  clear; 
	estpost tabstat $ds_var if village_ineligible_ct==1,  
	         by(meters)				              
			 statistics(mean sd min max) columns(statistics); 
		
	 esttab using  "$outputs_raw/Tables/$output_name.csv",	 
	 cells("mean(fmt(%9.2f)label (Mean))" "sd(fmt(%9.2f)label (SD))" 
	       "min(fmt(%9.2f)label (Min))" "max(fmt(%9.2f)label (Max))")
	 title("Table: Descriptive Statistics across country ") label 	
	 unstack  nonumbers nogaps nonote plain replace; 
  # d cr; 
   
 * Drop store values	 
  eststo clear	 
  
*  Exporting to unique file 
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
  preserve 
  * Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore	
		


 }
 
*** =========================================================================***	
*   Figure B4-B6 Density of main Variables 	
*** =========================================================================***
/// These set of figures are produce in Rscript: AppendiB_RScript

*** =========================================================================***	
*   Figure B6: Proportion of Cash Transfers across Local Neighborhood	
*** =========================================================================***
if (`figure_b6' == 1) {	
 * Activating Each Graph 
   local NonfarmEnterprise    1
   local BusinessProfits      1
	
 * NonFarm Enterprise 
 * ----------------------------------------------------------------------	
if `NonfarmEnterprise'{	
 * Load Data 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear
   
 * Selecting Sample for Analysis 
   keep if panel_sample==1
   keep if d_vuln_cat_1==1
   keep if FNLP_treatment==0

	
  * Defining right hand side variables
    # d ;
	gl controls    d_lgacode_bl_1; 
					
	gl treat 	    d_ct_nct_inel_2_year2 d_ct_nct_inel_2_year3   
				    d_ct_nct_inel_1_year2 d_ct_nct_inel_1_year3;
	gl treat2 	    d_ct_nct_inel_2_year2 d_ct_nct_inel_2_year3;					
	gl controls     d_lgacode_bl_1; 
	gl year         d_year_2    d_year_3;	
	# d cr;

   	 
** NonFarm Enterprise as Output
** -----------------------------------------------------------------------------	 
   gl title "NonAgricultural business Outcomes"	
   gl output_name  FB6_NonFarmEnterprise
   gl panel_out    business_work
  
 * Midline Storing Values 
 * -------------------------
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl xlist  $treat $controls $year
   foreach outcome of varlist $panel_out{   
  foreach mts in 100 200 300 400  500 600 700 800 900 1000{ 
   # d;
   eststo: acreg `outcome'  $xlist  
				  pet`mts'_year2   pet`mts'_year3  
				  b`mts'pov_year2  b`mts'pov_year3  pEV`mts'_year2        
				  pEV`mts'_year3,
				  time(`Timevar') id(`Panelvar') lag(3)
				  spatial latitude(gps_latitude_final) 
				  longitude(gps_longitude_final) dist(`mts') bartlett;
   # d cr; 		   
   
 * Saving estimates 
   estimates store model1_rat`mts'
	
   } 
   }
 
 
 * Endline Storing Values 
 * -------------------------
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl xlist $treat $controls $year
   foreach outcome of varlist $panel_out{   
  foreach mts in 100 200 300 400  500 600 700 800 900 1000{ 
   # d;
   eststo: acreg `outcome'  $xlist  pet`mts'_year2   pet`mts'_year3  
           b`mts'pov_year2  b`mts'pov_year3  pEV`mts'_year2        
		   pEV`mts'_year3 ,
		   time(`Timevar') id(`Panelvar') lag(3)
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`mts') bartlett;
   # d cr; 		   
 
   	lincomest pet`mts'_year3
	estimates save model2_rat`mts', replace
	estimates use  model2_rat`mts'	
 	estimates store model2_rat`mts'		
   } 
   }   
				
** Code to Export Graph 
** -----------------------------------------------------------------------------
if 1{
 * Variables to keep 
  gl drop $xlist b*pov_year2  b*pov_year3  pEV*_year2  pEV*_year3 	            ///
		  _cons pet*_year3
	
 * Output of the graph 
   gl output_name   FB6_NonFarmEnterprise
   graph set window fontface "Times New Roman"  
   local title     "Non-Farm Enterprise"
   local subtitle  "Proportion of Cash Transfers (PET)"
   local ytitle    "Local neighborhood radius in meters"
   local xtitle    "Probability that the household has a Non-Farm Enterprise"
   
 *  Graph look  
   grstyle clear
   grstyle init 
   grstyle linepattern major_grid dot
   grstyle linewidth major_grid medium
   grstyle color major_grid gs10
   
  * Coefplot look  
  # d ;
	coefplot (model1_rat100, rename(pet100_year2  = "100 mts")
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7)  
							 mlabsize(vsmall)  msize(small) msymbol(D))       
			 (model1_rat200, rename(pet200_year2  = "200 mts") 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
	         (model1_rat300, rename(pet300_year2  = "300 mts" ) 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model1_rat400, rename(pet400_year2  = "400 mts" ) 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
	         (model1_rat500, rename(pet500_year2  = "500 mts" ) 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey)  
			 (model1_rat600, rename(pet600_year2  = "600 mts")
	                         mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7)
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model1_rat700, rename(pet700_year2  = "700 mts") 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model1_rat800, rename(pet800_year2  = "800 mts")
	                         mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model1_rat900, rename(pet900_year2  = "900 mts")
	                         mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model1_rat1000, rename(pet1000_year2  = "1000 mts") 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat100, rename((1)= "100 mts")
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey)       
			 (model2_rat200, rename((1)= "200 mts") 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2)
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
	         (model2_rat300, rename((1)= "300 mts" ) 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey)  
			 (model2_rat400, rename((1)= "400 mts" ) 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
	         (model2_rat500, rename((1)= "500 mts" ) 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat600, rename((1)= "600 mts")
	                         mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat700, rename((1)= "700 mts") 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2)
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat800, rename((1)= "800 mts")
	                         mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat900, rename((1)= "900 mts")
	                         mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2)
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat1000, rename((1)= "1000 mts") 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2)
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey),
			  title ("`title'", size(medium)  justification(left) pos(11)) 
			  subtitle ("`subtitle'", size(small) justification(left) pos(11))
			  ytitle("`ytitle'") ytitle(,size(vsmall))
			  xtitle("`xtitle'") xtitle(,size(vsmall))
	   	      xline(0, lcolor(gs10) lwidth(medium)) 
			  xlabel(,grid)   xlabel(,labsize(vsmall))
			  mlabel format(%9.1g)  mlabgap(*0.1) 
			  /*byopts (xrescale) */
			  coeflabel(, labs(vsmall)) 
			  legend(order(2 "Midline" 24 "Endline")  row(1) ring(0.2) pos(6)
			        size(vsmall)  region(lstyle(none)))
			  drop ($drop)
			  lcolor(bluishgray) graphregion(fcolor(white)) 			  
			  note("2SLS Specification Panel Data with Conley Standard Errors"
			       "Sample: 1,166 Extreme Vulnerable Households (Over 3 waves)", 
				    size(vsmall));		   
		# d cr; 	 

	* Export Graph 
	  graph save   "$outputs_raw/Figures/coefplot_PET.gph", replace
	  graph use    "$outputs_raw/Figures/coefplot_PET.gph"
	  graph export "$outputs_final/Figures/$output_name.pdf", ///
	                replace

		}
		
		
}			 
			  	
 * Business Profits 
 * ----------------------------------------------------------------------	
if `BusinessProfits'{	
 * Load Data 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear
   
 * Selecting Sample for Analysis 
   keep if panel_sample==1
   keep if d_vuln_cat_1==1
   keep if FNLP_treatment==0

	
  * Defining right hand side variables
    # d ;
	gl controls    d_lgacode_bl_1; 
					
	gl treat 	    d_ct_nct_inel_2_year2 d_ct_nct_inel_2_year3   
				    d_ct_nct_inel_1_year2 d_ct_nct_inel_1_year3;
	gl treat2 	    d_ct_nct_inel_2_year2 d_ct_nct_inel_2_year3;					
	gl controls     d_lgacode_bl_1; 
	gl year         d_year_2    d_year_3;	
	# d cr;

   	 
** Business Profits as Output
** -----------------------------------------------------------------------------	 
   gl title "Business Profits"	
   gl output_name  FB6_BusinessProfits
   gl panel_out    ihs_profits_business
  
 * Midline Storing Values 
 * -------------------------
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl xlist  $treat $controls $year
   foreach outcome of varlist $panel_out{   
  foreach mts in 100 200 300 400  500 600 700 800 900 1000{ 
   # d;
   eststo: acreg `outcome'  $xlist  
				  pet`mts'_year2   pet`mts'_year3  
				  b`mts'pov_year2  b`mts'pov_year3  pEV`mts'_year2        
				  pEV`mts'_year3,
				  time(`Timevar') id(`Panelvar') lag(3)
				  spatial latitude(gps_latitude_final) 
				  longitude(gps_longitude_final) dist(`mts') bartlett;
   # d cr; 		   
   
 * Saving estimates 
   estimates store model1_rat`mts'
	
   } 
   }
 
 
 * Endline Storing Values 
 * -------------------------
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl xlist $treat $controls $year
   foreach outcome of varlist $panel_out{   
  foreach mts in 100 200 300 400  500 600 700 800 900 1000{ 
   # d;
   eststo: acreg `outcome'  $xlist  pet`mts'_year2   pet`mts'_year3  
           b`mts'pov_year2  b`mts'pov_year3  pEV`mts'_year2        
		   pEV`mts'_year3 ,
		   time(`Timevar') id(`Panelvar') lag(3)
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`mts') bartlett;
   # d cr; 		   
 
   	lincomest pet`mts'_year3
	estimates save model2_rat`mts', replace
	estimates use  model2_rat`mts'	
 	estimates store model2_rat`mts'		
   } 
   }   
				
** Code to Export Graph 
** -----------------------------------------------------------------------------
if 1{
 * Variables to keep 
  gl drop $xlist b*pov_year2  b*pov_year3  pEV*_year2  pEV*_year3 	            ///
		  _cons pet*_year3
	
 * Output of the graph 
   graph set window fontface "Times New Roman"  
   local title     "Business Profits"	
   local subtitle  "Proportion of Cash Transfers (PET)"
   local ytitle    "Local neighborhood radius in meters"
   local xtitle    "Probability that the household has a Non-Farm Enterprise"
   
 *  Graph look  
   grstyle clear
   grstyle init 
   grstyle linepattern major_grid dot
   grstyle linewidth major_grid medium
   grstyle color major_grid gs10
   
  * Coefplot look  
  # d ;
	coefplot (model1_rat100, rename(pet100_year2  = "100 mts")
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7)  
							 mlabsize(vsmall)  msize(small) msymbol(D))       
			 (model1_rat200, rename(pet200_year2  = "200 mts") 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
	         (model1_rat300, rename(pet300_year2  = "300 mts" ) 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model1_rat400, rename(pet400_year2  = "400 mts" ) 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
	         (model1_rat500, rename(pet500_year2  = "500 mts" ) 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey)  
			 (model1_rat600, rename(pet600_year2  = "600 mts")
	                         mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7)
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model1_rat700, rename(pet700_year2  = "700 mts") 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model1_rat800, rename(pet800_year2  = "800 mts")
	                         mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model1_rat900, rename(pet900_year2  = "900 mts")
	                         mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model1_rat1000, rename(pet1000_year2  = "1000 mts") 
							 mcolor("255 205 0") ciopts(color("255 241 179"))
							 mlabcolor(black) mlabposition(7) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat100, rename((1)= "100 mts")
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey)       
			 (model2_rat200, rename((1)= "200 mts") 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2)
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
	         (model2_rat300, rename((1)= "300 mts" ) 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey)  
			 (model2_rat400, rename((1)= "400 mts" ) 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
	         (model2_rat500, rename((1)= "500 mts" ) 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat600, rename((1)= "600 mts")
	                         mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat700, rename((1)= "700 mts") 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2)
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat800, rename((1)= "800 mts")
	                         mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2) 
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat900, rename((1)= "900 mts")
	                         mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2)
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey) 
			 (model2_rat1000, rename((1)= "1000 mts") 
							 mcolor("85 0 212") ciopts(color("204 204 255"))
							 mlabcolor(black) mlabposition(2)
							 mlabsize(vsmall)  msize(small) msymbol(D) nokey),
			  title ("`title'", size(medium)  justification(left) pos(11)) 
			  subtitle ("`subtitle'", size(small) justification(left) pos(11))
			  ytitle("`ytitle'") ytitle(,size(vsmall))
			  xtitle("`xtitle'") xtitle(,size(vsmall))
	   	      xline(0, lcolor(gs10) lwidth(medium)) 
			  xlabel(,grid)   xlabel(,labsize(vsmall))
			  mlabel format(%9.1g)  mlabgap(*0.1) 
			  /*byopts (xrescale) */
			  coeflabel(, labs(vsmall)) 
			  legend(order(2 "Midline" 24 "Endline")  row(1) ring(0.2) pos(6)
			        size(vsmall)  region(lstyle(none)))
			  drop ($drop)
			  lcolor(bluishgray) graphregion(fcolor(white)) 			  
			  note("2SLS Specification Panel Data with Conley Standard Errors"
			       "Sample: 1,166 Extreme Vulnerable Households (Over 3 waves)", 
				    size(vsmall));		   
		# d cr; 	 

	* Export Graph 
	  graph save   "$outputs_raw/Figures/coefplot_PET.gph", replace
	  graph use    "$outputs_raw/Figures/coefplot_PET.gph"
	  graph export "$outputs_final/Figures/$output_name.pdf", ///
	                replace

		}
		
		


			  
			
		
		
}

}	


*** =========================================================================***
*   Table B3: Non-Farm Enterprise across Local Neighborhood Radius
**  =========================================================================***	
if (`table_b3' == 1) {	
  * Load Data 
    use  "$data/Final/FNLPDataLongAnalysis.dta", clear

  * Sample of Analyis 
	keep if panel_sample==1
    keep if d_vuln_cat_1==1
	keep if FNLP_treatment==0
	 
 	
  * Defining right hand side variables
    # d ;
	gl treat 	    d_ct_nct_inel_2_year2 d_ct_nct_inel_2_year3   
				    d_ct_nct_inel_1_year2 d_ct_nct_inel_1_year3; 
	gl spill 	    pet_year2   pet_year3;     	
	gl marketsize   bpov_year2  bpov_year3;
	gl rel_poverty  pEV_year2   pEV_year3;
	gl controls    d_lgacode_bl_1; 
	gl year         d_year_2    d_year_3;
	# d cr;
  	 
   gl title "NonFarm Enterprise across Local Neighborhood Radius"	
   gl output_name "TB3_Business_Panel_Radius"
   gl panel_out      business_work ihs_profits_business
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl     distance    200 300 400 500 600 800 1000
   
** FULL MODEL INTERACTED 
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local space " "
 
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
 
  * Output
  # d;
   esttab using "$outputs_raw/Tables/$output_name.csv", replace 
   title(${title})	depvars  label nogaps  
   coeflabels(d_ct_nct_inel_2_year2 "CT in CT villages Midline[A]"
              d_ct_nct_inel_2_year3 "CT in CT villages Endline[B]"
			  d_ct_nct_inel_1_year2 "NCT in CT villages Midline[C]"
              d_ct_nct_inel_1_year3 "NCT in CT villages Endline[D]"
              pet_year2    "PET Midline[E]"
			  pet_year3    "PET Endline[F]"			  
			  pEV_year2    "PEV Midline[G]"
			  pEV_year3    "PEV Endline[H]"
			  bpov_year2   "#HH Midline[I]"
			  bpov_year3   "#HH Endline[J]"
			  d_year_2    "Midline[K]"   
			  d_year_3    "Endline[L]")
	order (d_ct_nct_inel_2_year2
              d_ct_nct_inel_2_year3
			  d_ct_nct_inel_1_year2 
              d_ct_nct_inel_1_year3
              pet_year2    
			  pet_year3    		  
			  pEV_year2   
			  pEV_year3    
			  bpov_year2   
			  bpov_year3   
			  d_year_2   
			  d_year_3 )		   
        drop ($controls)  
        stats(space N  meters 
              mean_bl mean_f2 mean_f3 
			  pet_mean pev_mean bpov_mean, 
			  fmt(0 0 0 2 2 2 2 2 2 2 2 3 3 3 3 3)       
			  labels(" " "Observations"  "Meters" 
			  "Mean pure control BL"
			  "Mean pure control Midline"
			  "Mean pure control Endline"
			  "CT recepients around (%)" 
			  "EVs around (%)" 
			  "HH around(#)")) 
     brackets plain  numbers 
     star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f);
   # d cr;
   
 * Drop store values	 
   eststo clear	 
  
*  Exporting to unique file 
*  ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
 
 
 * Drop store values	 
   eststo clear	  
 
 
 } 
 	

*** =========================================================================***
*   Table B4: Stable Unit Treatment Value Assumption Regressions
**  =========================================================================***	
if (`table_b4' == 1) {	
	
 local household_level   1
 local village_level     1
	
** -----------------------------------------------
*  Household Level Regressions 
** -----------------------------------------------
if `household_level'{
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear
 
* Keeping Sample of Analysis 
  keep if FNLP_treatment==0

* Defining main outcomes 
   gl output_name  "TB4_SUVTA_PanelA"
   gl out_var   business_work_w_f2 business_work_w_f3
   gl controls2 business_work_w_bl d_lgacode_bl_1
   
   gl xlist1 min_distance_vFNLP
   gl xlist2 min_distance_vFNLP min_distance_vFNLP_vCT CTvill
   gl xlist3 min_distance_vCT

   
** Effect FNLP 
** -----------------------------------------------
  foreach outcome in $out_var{ 

** Effect FNLP 
** -----------------------------------------------	
	
  gl controls ${xlist2}
	 eststo:  reg `outcome' ${controls} ${controls2} if d_vuln_cat_1==1,	    ///
	           cluster(village_new_bl)  robust
	 estadd local  SAMPLE  "ALL EV"
	
** Effect CT just Ineligibles 
** -----------------------------------------------	
  gl controls ${xlist3}
	 eststo:  reg `outcome' ${controls} ${controls2} if d_vuln_cat_1==1        ///
	           & village_ineligible_ct==1, cluster(village_new_bl)  robust
	 estadd local  SAMPLE  "Pure Control"
	}
	
 * Output 
   # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
		  title("$title") drop($controls2)
		  stats(space N r2 SAMPLE, fmt(0 0 2 0)       
		  labels(" " "Observations" "Adjusted R-squared" "Sample")) 
		  label  brackets plain  numbers depvars  
		  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
		  replace;
	# d cr;		  
   

 * Drop store values	 
  eststo clear	 
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
    
}  
   
** -----------------------------------------------
*  Village level 
** -----------------------------------------------   
if `village_level'{  

 * Load Data
   use "$data/Raw/SUVTADistancesVillages.dta", clear 
 
 * Keeping sample of analysis 
   keep if FNLP_treatment==0
 
 * Defining main outcomes 
   gl output_name  "TB4_SUVTA_PanelB"
   gl out_var     business_growthEV_bl_fup2  business_growthEV_fup2_fup3	
	
   gl controls2 d_lga_new_bl_1
   
   gl xlist1 min_distance_vFNLP
   gl xlist2 min_distance_vFNLP min_distance_vFNLP_vCT CTvill
   gl xlist3 min_distance_vCT	
   
   
   
** Effect FNLP 
** -----------------------------------------------
  foreach outcome in $out_var{ 
  gl controls ${xlist2}
	 eststo:  reg `outcome' ${controls} ${controls2},	    ///
	           cluster(village_new_bl)  robust
	 estadd local  SAMPLE  "ALL EV"
	
** Effect CT just Ineligibles 
** -----------------------------------------------	
  gl controls ${xlist3}
	 eststo:  reg `outcome' ${controls} ${controls2} if ///
	               village_ineligible_ct==1, cluster(village_new_bl)  robust
	 estadd local  SAMPLE  "Pure Control"
	}
	
	
   * Output 
	# d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
		  title("$title") drop($controls2)
		  stats(space N r2 SAMPLE, fmt(0 0 2 0)       
		  labels(" " "Observations" "Adjusted R-squared" "Sample")) 
		  label  brackets plain  numbers depvars  
		  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
		  replace;
	# d cr;		  
   
** EXPORTING ALL 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
    
}  
   	
	
	
	
}	


* ******************************************************************************
//  END DOFILE 
* ******************************************************************************
