* **************************************************************************** *
* Cash Is Queen                                                                *
* Local Economy Effects of Cash Transfers to Women in West Africa              *
* Replication File                                                             *		
* Appendix C: Details on Business Activities and Financial Access 			   *
* **************************************************************************** *

local table_c1     1
local table_c2     1
local table_c3     1
local table_c4     1
local table_c5     1


*** =========================================================================***
*   Table C1: Characteristics of Businesses at Midline and Endline
*** =========================================================================***
if (`table_c1' == 1) {
 * Load Dataset 	
   use  "$data/Final/FNLPDataWideAnalysis.dta", clear	

 * Keeping sample 			
	keep if d_vuln_cat_1==1 
	keep if FNLP_treatment==0  
	keep if d_wavail_f2==1 & d_wavail_f3==1  

 * Defining variables 	
  # d;  
    gl buss_w_f2  	 
				  w_rawmats_business_w_f2
				  d_primary_act_f2_c1             
				  d_primary_act_f2_c2		
				  d_primary_act_f2_c3               
				  d_primary_act_f2_c4 		
				  d_primary_act_f2_c5
				  d_locationbuss_?_fup2_w_unc  
				  d_sourcemonbuss_?_w_f2
				  bus_years_f2_w;
			   
	gl buss_w_f3  	 
			      w_rawmats_business_w_f3
			      d_primary_act_f3_c1                 
			      d_primary_act_f3_c2 		
			      d_primary_act_f3_c3               
			      d_primary_act_f3_c4		
			      d_primary_act_f3_c5   
			      d_locationbuss_*_fup3_w_unc
				  d_sourcemonbuss_?_w_f3
			      bus_years_f3_w;		  
			   
	# d cr; 	 
  
* Making sure we are looking at conditional Characteristics 
	foreach var of varlist $buss_w_f2{
	replace `var'=. if business_work_w_f2==0
	}
	foreach var of varlist $buss_w_f3{
	replace `var'=. if business_work_w_f3==0
	replace `var'=. if business_work_w_f3==.
	}		  
 

  
  * Exporting Ttest : Midline
  * --------------------------------------------------------------------
  * Code Export 
	gl output_name "TC1_DSBusinessMid_Ttest"
	gl covariates d_lgacode_bl_1
	gl DS_var  $buss_w_f2

   # d;
   iebaltab $DS_var, grpvar(nct_ct_inel)  covariates($covariates)
			stats(pair(diff))
			rowvarlabels format(%12.2f)
			savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	# d cr;			
  
 ** Exporting to unique file 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore
  
  
  
  * Exporting Normal Diff: Midline
  * --------------------------------------------------------------------
  * Code Export 
	gl output_name "TC1_DSBusinessMid_Norm"
	gl covariates d_lgacode_bl_1
	gl DS_var  $buss_w_f2

   # d;
   iebaltab $DS_var, grpvar(nct_ct_inel)  covariates($covariates)
			stats(pair(nrmd))
			rowvarlabels format(%12.2f)
			savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	# d cr;			
  
 ** Exporting to unique file 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore  
  
		 
  * Exporting Ttest : Endline
  * --------------------------------------------------------------------
  * Code Export 
	gl output_name "TC1_DSBusinessEnd_Ttest"
	gl covariates d_lgacode_bl_1
	gl DS_var  business_work_w_f3 $buss_w_f3 	

   # d;
   iebaltab $DS_var, grpvar(nct_ct_inel)  covariates($covariates)
			stats(pair(diff))
			rowvarlabels format(%12.2f)
			savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	# d cr;			
  
 ** Exporting to unique file 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore
   
   
  * Exporting Normal Diff: Endline
  * --------------------------------------------------------------------
  * Code Export 
	gl output_name "TC1_DSBusinessEnd_Norm"
	gl covariates d_lgacode_bl_1
	gl DS_var  business_work_w_f3 $buss_w_f3 	

   # d;
   iebaltab $DS_var, grpvar(nct_ct_inel)  covariates($covariates)
			stats(pair(nrmd))
			rowvarlabels format(%12.2f)
			savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	# d cr;			
  
 ** Exporting to unique file 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore
      
   
   
   
   
   
  
}
	
*** =========================================================================***
*   Table C2: Business Dynamics
*** =========================================================================***
if (`table_c2' == 1) {
 * Load Dataset 	
   use  "$data/Final/FNLPDataWideAnalysis.dta", clear	

 * Keeping sample 			
	keep if d_vuln_cat_1==1 
	keep if FNLP_treatment==0  
	keep if d_wavail_f2==1 & d_wavail_f3==1  

 * T TEST TABLE
 * ------------------------------------------
  gl DS_var d_mul_bus_bme_?   
  gl output_name  "TC2_BusinessDynamicsTtest"
  gl covariates   d_lgacode_bl_1	
	
  # d;
   iebaltab $DS_var, grpvar(nct_ct_inel)  covariates($covariates)
			stats(pair(diff))
			rowvarlabels format(%12.2f)
			savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
  # d cr;			
  
 ** Exporting to unique file 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore
   	
	
	
 * T TEST TABLE
 * ------------------------------------------
  gl output_name  "TC2_BusinessDynamicsNorm"
  gl covariates   d_lgacode_bl_1	
	
  # d;
   iebaltab $DS_var, grpvar(nct_ct_inel)  covariates($covariates)
			stats(pair(nrmd))
			rowvarlabels format(%12.2f)
			savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
  # d cr;			
  
 ** Exporting to unique file 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore	
	
	
	
	
	
	
	
	
	 
	
	
}	

*** =========================================================================***
*   Table C3: Business Agglomeration
*** =========================================================================***
if (`table_c3' == 1) {
 * Load Dataset 	
   use  "$data/Final/FNLPDataWideAnalysis.dta", clear	

* Sample if Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1
  ren business_work_w_f2 business_work_fup2
  ren business_work_w_f3 business_work_fup3
  ren business_work_w_bl business_work_bl
  
* Globals variables 
  # d;  
	gl treatB 	     d_ct_nct_inel_2   d_ct_nct_inel_1; 	
	gl spillB 	     pet;     	
	gl rel_povertyB  pEV;
	gl marketsizeB   bpov;	
	gl specnumbusf2  bpa2 ;
	gl bus_out_f2    business_work ihs_profits_business;  
	gl bus_out_f3    business_work ihs_profits_business;
  # d cr; 	

* Format 	
	gl title "Table Business Agglomeration" 
	gl output_name "TC3_Agglomeration" 
	local meters  400 
	local met_cut 0.4

** -----------------------------------------------------------------------------
*  Outcomes Midline - Midline
** -----------------------------------------------------------------------------
   gl outcomes_f3 $bus_out_f3
   local time  d_wavail_f2
if 1{

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB  $spillB $rel_povertyB $marketsizeB 
foreach outcome in $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
	ren  b`number'pa2        bpa2
	ren  b`number'pa3        bpa3	
 
 * Regression 	 
   # d;
   eststo: acreg `outcome'_fup3 ${xlist1} ${controls} `outcome'_bl if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'_fup3   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
	sum    bpa2   if e(sample) & d_ct_nct_inel_3!=1
	estadd scalar  bpa2_mean=r(mean)	
		
  	estadd scalar meters=`number'  
	estadd local space " "
   
 * Renaming 
 	ren  bpa2            b`number'pa2    
	ren  bpa3            b`number'pa3   
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	


** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB  ${specnumbusf2} $spillB $rel_povertyB $marketsizeB 
foreach outcome in $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
	ren  b`number'pa2        bpa2
	ren  b`number'pa3        bpa3	
 
 * Regression 	 
   # d;
   eststo: acreg `outcome'_fup3 ${xlist1} ${controls} `outcome'_bl if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'_fup3   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
	sum    bpa2   if e(sample) & d_ct_nct_inel_3!=1
	estadd scalar  bpa2_mean=r(mean)	
		
  	estadd scalar meters=`number'  
	estadd local space " "
   
 * Renaming 
 	ren  bpa2            b`number'pa2    
	ren  bpa3            b`number'pa3   
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	



}



  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(d_ct_nct_inel_2 "Cash Transfer [A]" 
	          d_ct_nct_inel_1 "No Cash Transfer [B]" 
			  bpa2   "#Business(Midline)"
			  bpa3   "#Business(Endline)"
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]") 
			  drop(${controls} *_bl) 
			   stats(space N r2 meters mean
			   pet_mean pev_mean bpov_mean bpa2_mean, 
			  fmt(0 0 2 0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels(" " "Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "CT recepients around (%)" 
			  "EVs around (%)" 
			  "Households around(#)"
			  "Business Midline(#)")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	

*** =========================================================================***
*   Table C4: Type of business
*** =========================================================================***
if (`table_c4' == 1) {
* Load Dataset 	
   use  "$data/Final/FNLPDataWideAnalysis.dta", clear
   
* Sample if Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1
  drop if d_ct_nct_inel_3==1
  
* Renaming Variables for easy output   
  ren business_work_w_f2 business_work_fup2
  ren business_work_w_f3 business_work_fup3
  ren business_work_w_bl   business_work_bl
    
* Format 	
   gl title "Table C4: Type of business" 
   gl output_name "TC4_TypeBusiness"
   
   # d; 
   
    gl spillB 	     pet;     	
	gl marketsizeB   bpov;
	gl rel_povertyB  pEV;
	
   gl type_bus_f2  d_primary_act_f2_c1 d_primary_act_f2_c1               
				   d_primary_act_f2_c2 d_primary_act_f2_c3                  
				   d_primary_act_f2_c4 d_primary_act_f2_c5
				   d_primary_act_f2_c6;
				   
   gl type_bus_f3  d_primary_act_f3_c1                  						
				   d_primary_act_f3_c2 d_primary_act_f3_c3                  
				   d_primary_act_f3_c4 d_primary_act_f3_c5
				   d_primary_act_f3_c6; 
				   
	gl specnumbusf2  bpa2;
	gl specnumbusf3  bpa3;	
	gl spectypbusf2  bpa2_c1      bpa2_c2   bpa2_c3            
					 bpa2_c4      bpa2_c5   bpa2_c6;
	gl spectypbusf3  bpa3_c1      bpa3_c2   bpa3_c3            
					 bpa3_c4      bpa3_c5   bpa3_c6;					   
	gl controls      d_lgacode_bl_1; 				   
  # d cr;   
   
   la var  d_ct_nct_inel_2 "Cash Transfer [A]"
   
   
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4

** -----------------------------------------------------------------------------
*  Outcomes Midline - endline
** -----------------------------------------------------------------------------
   gl outcomes_f3   $type_bus_f3
   gl controls2
   local time       d_wavail_f2
   local condition  business_work_fup2
if 1{
** Spillovers+ Market Size 
** -----------------------------------------------------------------------------
gl xlist1 d_ct_nct_inel_2   $spillB $rel_povertyB $marketsizeB   ${spectypbusf2}
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
	ren  b`number'pa2        bpa2
	ren  b`number'pa3        bpa3
    forval categorie=1/6{
	ren  b`number'pa2_c`categorie' bpa2_c`categorie'
	ren  b`number'pa3_c`categorie' bpa3_c`categorie'	
     }
	 		
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if `time'==1 & `condition'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_1==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local space " "
   
 * Renaming 
    forval categorie=1/6{
	ren  bpa2_c`categorie'  b`number'pa2_c`categorie' 
	ren  bpa3_c`categorie'	b`number'pa3_c`categorie'
     }	 
	ren  bpa2            b`number'pa2    
	ren  bpa3            b`number'pa3    
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	
}


* Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(d_ct_nct_inel_2 "Cash Transfer [A]" 
			  pet    "PET[B]" 
	          pEV    "PEV[C]" 
	          bpov   "#HH[D]"
              bpa2_c1 "Cook(Midline)"
			  bpa2_c2 "Oil Processing(Midline)"
			  bpa2_c3 "Crop Processing(Midline)"
			  bpa2_c4 "Trading(Midline)" 
			  bpa2_c5 "Services(Midline)" 
			  bpa2_c6 "Other(Midline)") 
			  order(d_ct_nct_inel_2 pet pEV bpov)
			  drop(d_lgacode_bl_1) 
			  stats(space N r2 meters mean
			  pet_mean pev_mean bpov_mean, 
			  fmt(0 0 2 0 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels(" " "Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "CT recepients around (%)" 
			  "EVs around (%)" 
			  "HH around(#)")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.3f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	


** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}
    

*** =========================================================================***
*   Table C5: Access to Finance DS
*** =========================================================================***
if (`table_c5' == 1) {
* Load Dataset 	
   use  "$data/Final/FNLPDataWideAnalysis.dta", clear

* Sample of Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1
   	  
* Replacing by missing since we focus on specific sample 
  foreach var of varlist amt_chop_money_w chop_money_rs_*  chop_money_rs_dum_other_w{
  replace `var'=. if 	marital_status2_bl_3==1 | marital_status2_bl_4==1 	
  } 
 	
* Setting up globals 	
  # d;
  gl loans_sav d_any_loan_bl     
               d_any_account_bl
               w_ttl_loan_bl 
			   d_loan_f2         
			   d_anycash_f2    
			   w_cash_savings_?_f2 
	           d_loan_f3         
			   d_anycash_f3       
			   w_cash_savings_?_f3
			   d_chop_money_w    
			   amt_chop_money_w
			   chop_money_rs_dum_1_w 
			   chop_money_rs_dum_2_w 
			   chop_money_rs_dum_3_w 
			   chop_money_rs_dum_4_w 
			   chop_money_rs_dum_5_w 
			   chop_money_rs_dum_8_w;
   # d cr; 
   
	
 * Setting up  
   gl DS_var       $loans_sav  
   gl output_name  "TC5_AccessFinanceTtest"
   gl covariates    d_lgacode_bl_1	
   local groupvar   nct_ct_inel  
	
  # d;
   iebaltab $DS_var, grpvar(`groupvar') covariates($covariates)
			stats(pair(diff))
			rowvarlabels format(%12.2f)
			savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
  # d cr;			
  
 ** Exporting to unique file 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore
   		
	
	
	
	
	
	
}
 
	
	
