* **************************************************************************** *
* Cash Is Queen                                                                *
* Local Economy Effects of Cash Transfers to Women in West Africa              *
* Replication File                                                             *		
* Appendix D: Regression Discontinuity Design (RDD) Details 	        	   *
* **************************************************************************** *

local figure_d1       1
local table_d1        1
local table_d2        1
local figure_d2       1

*** =========================================================================***	
*   Figure D1: Balance Test for Different Windows around 18 EV Cutoff
*** =========================================================================***
if (`figure_d1' == 1) {
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear
  	
* Keep only control villages and EVs
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0	
	
* Window selection around the 18 EV cutoff - Graph
* ============================================================================== 
	graph set window fontface "Times New Roman"  
    # d;
    gl resp_char   business_work_w_bl econ_fem_activity_bl 
				   foodins_index_bl   dietdiv_score_bl wardcode_bl;  
    # d cr;  				 
	
	
   gl DS_var      $resp_char 
   local outcome  num_evs_village_ 
   local title    "Local Randomization around 18 EVs cutoff"	
   
   # d;
	rdwinselect `outcome' $resp_char, 
				c(18) wmin(14) wstep(1) reps(100) 
				nwindows(40) stat(hotelling) approximate plot 
				graph_options(title(`title', size(medium))
							  xtitle(Window Length/2, size(small))
							  ytitle(P-value, size(small))
							  graphregion(color(white))
							  color(blue%40)
							  xline(36, lwidth(thin) lcolor(gray) lpattern(dash)));
   # d cr;	
  
	* Export Graph 
	local title  "FD1_LocalRandomizationGraph"	
	//graph save   "$outputs_final/Figures/`title'.gph", replace
	//graph use    "$outputs_final/Figures/`title'.gph"
	graph export "$outputs_final/Figures/`title'.pdf", replace


}

	
*** =========================================================================***	
*   Table D1: Randomization Balance Check
*** =========================================================================***
if (`table_d1' == 1) {
 * Load Data 
   use   "$data/Final/FNLPDataWideAnalysis.dta", clear
   
 * Sample if Analysis
   keep if FNLP_treatment==0
	  
 * Globals of variables   
    # d;
			gl controls    age_hhhead_bl  
						   marital_status2_bl_2  
						   marital_status2_bl_3
						   marital_status2_bl_4
						   literacy_hhhead_bl 
						   num_hh_members_bl   
						   num_hh_members_15_bl       
						   num_plots_bl
						   d_farm_size_bl_1
						   w_daily_adulteq_expenses_bl
						   povertylinebelow_190_bl
						   foodins_index_bl
						   num_enterprises_bl
						   any_farm_hh_bl
						   weai_new_bl_w
						   empowered_new_bl    
						   dm_index_w_bl
						   business_work_w_bl
						   econ_fem_activity_bl;  
               # d cr;			   
			   
			   

 * Covariate Balance Normal Difference - RDD Sample 
 * -----------------------------------------------------------------------------
  * Settings 
	gl output_name "TD1_CovariateBalanceRDDTtest"
	gl controls $controls
	gl covariates d_lgacode_bl_1
  
   * Code for ttest table
	# d;
	iebaltab $controls  if d_vuln_cat_1==1  & (d_wavail_f2==1 | d_wavail_f3==1) 
	         & RDD_18==1 [pweight=ipw],
	         grpvar(nct_ct_inel) covariates($covariates)  onerow 
			 stats(pair(diff) f(p))
			 rowvarlabels  format(%12.2f)
			 savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	# d cr;		

 ** Exporting to unique file 	 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore 
 
 
 * Covariate Balance Normal Difference - RDD Sample 
 * -----------------------------------------------------------------------------
  * Settings 
	gl output_name "TD1_CovariateBalanceRDDNorm"
	gl controls $controls
	gl covariates d_lgacode_bl_1
  
   * Code for ttest table
	# d;
	iebaltab $controls  if d_vuln_cat_1==1  & (d_wavail_f2==1 | d_wavail_f3==1) 
	         & RDD_18==1 [pweight=ipw],
	         grpvar(nct_ct_inel) covariates($covariates)  onerow 
			 stats(pair(nrmd) f(p))
			 rowvarlabels ftest format(%12.2f)
			 savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	# d cr;		

 ** Exporting to unique file 	 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore  
 
 
 
 
 
	
}  


*** =========================================================================***	
*   Table D2: Multinomial Probit over Treatment Status
*** =========================================================================***
if (`table_d2' == 1) {
	
 * Load 
   use   "$data/Final/FNLPDataWideAnalysis.dta", clear

* Setting up globals 
  # d;
   gl cov_pred    age_hhhead_bl
                  marital_status2_bl_2 marital_status2_bl_3 marital_status2_bl_4
				  num_plots_bl       
				  num_hh_members_bl  
				  num_plots_bl  
				  num_enterprises_bl
				  weai_new_bl_w
				  d_lgacode_bl_1; 
  eststo clear;				  
  # d cr; 				  
   
 * Regression Code 
    # d;
   mprobit spill_treatment ${cov_pred} if d_vuln_cat_1==1 
						   & FNLP_treatment==0	& RDD_18==1, 
						   cluster(village_new_bl) baseoutcome(0) robust; 
	est sto m;
  # d cr; 				  
	  
  * Estimate average marginal effects
	forval i = 0/2 {
	est res  m
	margins, dydx(*) predict(outcome(`i')) post
	est store m`i'
	}

 * Exporting Coefficientes 
   gl output_name TD2_MultinomialCoeff
  # d; 
    esttab m  using "$outputs_raw/Tables/$output_name.csv", replace 
    equations(1) eqlabels(none) nonumber obs ar2
    mlabel("Coeff.", lhs("Multinomial Probit Over Treatment Status"))   
	keep   (${cov_pred})								
	se star(* 0.10 ** 0.05 *** 0.01) b(%9.3f) se(%9.2f) alignment(3);
  # d cr; 
	
	
 * Exporting Marginal Effects 
   gl output_name TD2_Multinomial
   # d; 
    esttab m0 m1 m2 using "$outputs_raw/Tables/$output_name.csv", replace 
    mlabel("Pure Control" "Cash Transfer" "Non-Cash Transfer", 
	lhs("Multinomial Probit Over Treatment Status")) 
	coeflab(age_hhhead_bl 	    "Age (Years)"
	   		marital_status_bl   "Marital Status (Married=1)" 
            literacy_hhhead_bl  "Literacy (Can you read or write in any language=1)"        
			num_hh_members_bl   "Number of household members"
            num_enterprises_bl  "Number of enterprises own by the household (0-5)"
			d_lgacode_bl_1      "Birnin Kebbi")
	 keep   (${cov_pred})	
	        nogaps 	obs	
				  depvars  label nogaps  
			  brackets plain  numbers 
     star(* 0.1 ** 0.05 *** 0.01)   b(%9.3f) se(%9.2f);    
  # d cr;	


 * Exporting to unique file 
 * ------------------------------------------
    gl output_name TD2_Multinomial
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
  preserve 
  * Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore	

   




}

*** =========================================================================***	
*   Figure D2: Balance Improvements across Multiple Treatments
*** =========================================================================***
 // From R Script


