* **************************************************************************** *
* Cash Is Queen                                                                *
* Local Economy Effects of Cash Transfers to Women in West Africa              *
* Replication File                                                             *		
* Appendix E: Main Results Extended                          	        	   *
* **************************************************************************** *
local table_E1    1
local table_E2    1
local table_E3    1
local table_E4    1



*** =========================================================================***	
*   Table E1: Inclusion of Other Vulnerable Households (VVs and MLs) in the Village
*** =========================================================================***	
if 	`table_E1'{
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
  
 * We need to drop those for which we do not have the outcome of interest
   keep if panel_sample==1
   drop if d_vuln_cat_1==1 
   keep if FNLP_treatment==0

   
 * Setting up globals 
    # d ;
    gl business_out   business_work                      ihs_realprofits_w;  
	gl controls    d_lgacode_bl_1; 
					
	gl treat 	    d_ct_nct_inel_2_year2 d_ct_nct_inel_2_year3   
				    d_ct_nct_inel_1_year2 d_ct_nct_inel_1_year3; 
	gl treat_vill	CTvill_year2 CTvill_year3;
	gl spill 	    pet_year2   pet_year3;     	
	gl marketsize   bpov_year2  bpov_year3;
	gl rel_poverty  pEV_year2   pEV_year3;			
	gl year         d_year_2    d_year_3;
    gl treat_villB	CTvill; 					
    gl spillB 	    pet;     	
	gl marketsizeB  bpov;
	gl rel_povertyB pEV;	
	# d cr;
 
 * Generating temp variables for mean 
   gen business_work_m= business_work    
   gen ihs_realprofits_w_m=w_realprofits_w
 
 
 * Setting for outputs    
   gl title "NonAgricultural business Outcomes"	
   gl output_name "TE1_BusinessPanel"
   gl panel_out   $business_out
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl     distance    400
   
 
 ** FULL MODEL INTERACTED 
** ------------------------------------- 
 gl xlist  $treat_vill $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local space " "
 
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
  
  
 ** FULL MODEL INTERACTED  inter 
** ------------------------------------- 
  gl xlist $treat_vill $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
	ren VVML_PET`DISTcutoff'_year2   VVML_PET_year2	
	ren VVML_PET`DISTcutoff'_year3   VVML_PET_year3	
		
   
   # d;
   eststo: acreg `outcome' $xlist,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local space " "
 
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
   ren VVML_PET_year2	VVML_PET`DISTcutoff'_year2
   ren VVML_PET_year3	VVML_PET`DISTcutoff'_year3   
   } 
   }
 

 
  * Output
  # d;
   esttab using "$outputs_raw/Tables/$output_name.csv", replace 
   title(${title})	depvars  label nogaps  
   coeflabels(CTvill_year2     "VVML in CT villages at Midline[A]"
			  CTvill_year3     "VVML in CT villages at Endline[B]"
              pet_year2        "PET Midline[C]"
			  pet_year3        "PET Endline[D]"			  
			  pEV_year2        "PEV Midline[E]"
			  pEV_year3        "PEV Endline[F]"
			  bpov_year2       "#HH Midline[G]"
			  bpov_year3       "#HH Endline[H]")	  
        drop ($controls)   
		order (CTvill_year2  CTvill_year3
		      pet_year2   pet_year3
			  pEV_year2   pEV_year3
		      bpov_year2  bpov_year3
			  d_year_2    d_year_3)
        stats(space N  meters 
              mean_bl mean_f2 mean_f3 
			  pet_mean pev_mean bpov_mean, 
			  fmt(0 0 0 2 2 2 2 2 2 2 2 3 3 3 3 3)       
			  labels(" " "Observations"  "Meters" 
			  "Mean pure control BL"
			  "Mean pure control Midline"
			  "Mean pure control Endline"
			  "CT recepients around (%)" 
			  "EVs around (%)" 
			  "HH around(#)")) 
     brackets plain  numbers 
     star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f);
   # d cr;
   
 
** EXPORTING ALL 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
 
 } 
	
*** =========================================================================***	
*   Table E2: Fiscal Multiplier Estimates
*** =========================================================================***
if 	`table_E2'{
  * Load Data 
    use  "$data/Final/FNLPDataWideAnalysis.dta", clear
  
  * Sample if Analysis
	keep if FNLP_treatment==0	

 * Generating number of enterprise in each category and by village status 
   gl business_var business_work_w_bl business_work_w_f2 business_work_w_f3
 
 
 * Collapsing te data at the vulnerable level and type of village
   collapse (sum) $business_var, by (d_EV village_ineligible_ct)
 
 * Adding labels so is clearer
   la def d_EV   1 "EV" 0 "VV & ML", modify 
   la val d_EV d_EV 
   
   la def village_ineligible_ct 0 "Program villages" 1 "Comparison villages", modify 
   la val village_ineligible_ct village_ineligible_ct
   
   
 * Input some values from Census data to compute rates over whole population of study 
   gen ttl_pop_ct_census=8987
   gen ttl_pop_nct_census=1499
   gen frac_ev=0.16
   gen frac_vvml=0.7
   
   gen ttl_ev_ct=ttl_pop_ct_census*frac_ev
   gen ttl_ev_nct=ttl_pop_nct_census*frac_ev
   
   gen ttl_vvml_ct=ttl_pop_ct_census*frac_vvml
   gen ttl_vvml_nct=ttl_pop_nct_census*frac_vvml   
 
*  Generating Rate of business
   gen     rate_bus_bl=. 
   replace rate_bus_bl=business_work_w_bl/ttl_ev_ct  if d_EV==1 & village_ineligible_ct==0
   replace rate_bus_bl=business_work_w_bl/ttl_ev_nct if d_EV==1 & village_ineligible_ct==1
   replace rate_bus_bl=business_work_w_bl/ttl_vvml_ct  if d_EV==0 & village_ineligible_ct==0
   replace rate_bus_bl=business_work_w_bl/ttl_vvml_nct if d_EV==0 & village_ineligible_ct==1   
   
   
   gen     rate_bus_f2=. 
   replace rate_bus_f2=business_work_w_f2/ttl_ev_ct  if d_EV==1 & village_ineligible_ct==0
   replace rate_bus_f2=business_work_w_f2/ttl_ev_nct if d_EV==1 & village_ineligible_ct==1
   replace rate_bus_f2=business_work_w_f2/ttl_vvml_ct  if d_EV==0 & village_ineligible_ct==0
   replace rate_bus_f2=business_work_w_f2/ttl_vvml_nct if d_EV==0 & village_ineligible_ct==1      
   
  
   gen     rate_bus_f3=. 
   replace rate_bus_f3=business_work_w_f3/ttl_ev_ct  if d_EV==1 &village_ineligible_ct==0
   replace rate_bus_f3=business_work_w_f3/ttl_ev_nct if d_EV==1 &village_ineligible_ct==1  
   replace rate_bus_f3=business_work_w_f3/ttl_vvml_ct  if d_EV==0 & village_ineligible_ct==0
   replace rate_bus_f3=business_work_w_f3/ttl_vvml_nct if d_EV==0 & village_ineligible_ct==1      
   
 
* Sorting out properly for output 
   gsort -d_EV
   
* Keeping just variables we need 
  keep  village_ineligible_ct d_EV rate_bus_*
 
 * Exporting data 
   gl output_name  TE2_Multiplier
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   			  
  
  

 * Exporting into common file 
   export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 firstrow(variables) sheet("$output_name", modify) 
 
 
}

*** =========================================================================***	
*   Table E3: Conditional Profits Estimates
*** =========================================================================***	
if 	`table_E3'{
	
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
  
 * We need to drop those for which we do not have the outcome of interest
   keep if panel_sample==1
   keep if FNLP_treatment==0	
	
 * Labels to improve output 
   la var w90_conrealprofits_w	"Real Profits Conditional (W/90)"
	
   gl title "Profits conditional on female micro-enterprise - ev and vvml"	
   gl output_name "TE3_CondProfits"
   gl panel_out   w90_conrealprofits_w
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl     distance    400

** Effect no spillovers - EVs
** -----------------------------------------------
 gl xlist CTvill_year2 CTvill_year3 $controls $year
 foreach outcome of varlist $panel_out{   
   # d;
   eststo: reg `outcome' $xlist if d_vuln_cat_1==1, cluster (village_new_bl);
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
**# Bookmark #2
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	estadd local sample "EVS"

   } 
  
  
** Effect no spillovers - VVs
** -----------------------------------------------
 gl xlist CTvill_year2 CTvill_year3 $controls $year
 foreach outcome of varlist $panel_out{   
   # d;
   eststo: reg `outcome' $xlist if d_vuln_cat_1!=1, cluster (village_new_bl);
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
**# Bookmark #2
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	estadd local sample "VVML"

   } 
  
    
 ** Output
  # d;
   esttab using "$outputs_raw/Tables/$output_name.csv", replace 
   title(${title})	depvars  label nogaps  
   coeflabels(CTvill_year2 "CT villages x Midline[A]"
              CTvill_year3 "CT villages x Endline[B]"
			  d_year_2    "Midline[C]"   
			  d_year_3    "Endline[D]")
	order (CTvill_year2 CTvill_year3  
		   d_year_2     d_year_3 )		   
        drop ($controls)  
        stats(N  
              mean_bl mean_f2 mean_f3 
			  sample, 
			  fmt(0 2 2 2 0)       
			  labels("Observations"  
			  "Mean pure control BL"
			  "Mean pure control Midline"
			  "Mean pure control Endline"
			  "Sample")) 
     brackets plain  numbers 
     star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f);
   # d cr;
   
 
** EXPORTING ALL 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
 
 
 } 	
	
*** =========================================================================***	
*   Table E4: Local Prices
*** =========================================================================***	
if 	`table_E4'{
  * Load Data 
    use  "$data/Final/FNLPDataWideAnalysis.dta", clear
  
  * Sample if Analysis
	keep if FNLP_treatment==0	

  * Set of variables 
    # d;
	gl DS_var w_goat_price_f2 w_chicken_price_f2 w_sheep_price_f2 
	          w_ttl_food_exp_f2 
			  w_goat_price_f3 w_chicken_price_f3 w_sheep_price_f3 
	          w_ttl_food_exp_f3;
    # d cr;			  
  
 * BALANCE TABLE - Entire Sample 
 * ------------------------------------------
	  gl output_name "TE4_LocalPrices_Ttest"
	  gl covariates d_lgacode_bl_1
	 
	   # d;
	   iebaltab $DS_var,
	            grpvar(CTvill)  covariates($covariates) 
                stats(pair(diff)) 
			    rowvarlabels ftest format(%12.2f) nostar
			    savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	   # d cr;		

 * Exporting to unique file 
 * ------------------------------------------	 
	  preserve 
	   * Date:	
		local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
		disp "`svdate'" 		
		
	  * Import table from csv
		import excel "$outputs_raw/Tables/$output_name.xls", clear

	  * Exporting into common file 
		export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
					 sheet("$output_name", modify) 
	  restore
  
 * BALANCE TABLE - Entire Sample 
 * ------------------------------------------
	  gl output_name "TE2_LocalPrices_Norm"
	  gl covariates d_lgacode_bl_1
	 
	   # d;
	   iebaltab $DS_var,
	            grpvar(CTvill)  covariates($covariates) 
                stats(pair(nrmd)) 
			    rowvarlabels ftest format(%12.2f) nostar
			    savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	   # d cr;		

 * Exporting to unique file 
 * ------------------------------------------	 
	  preserve 
	   * Date:	
		local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
		disp "`svdate'" 		
		
	  * Import table from csv
		import excel "$outputs_raw/Tables/$output_name.xls", clear

	  * Exporting into common file 
		export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx",   ///
					 sheet("$output_name", modify) 
	  restore
  	
	
	
	
	
	
	
	
}

