* **************************************************************************** *
* Cash Is Queen                                                                *
* Local Economy Effects of Cash Transfers to Women in West Africa              *
* Replication File                                                             *		
* Appendix F: Results on Secondary Outcomes                    	        	   *
* **************************************************************************** *

*** ========================================================================= ***
*   MAIN SETTINGS 
*** ========================================================================= ***
if 1 {	

    * Defining right-hand side variables
    global controls       d_lgacode_bl_1
    global treat          d_ct_nct_inel_2_year2 d_ct_nct_inel_2_year3 ///
                          d_ct_nct_inel_1_year2 d_ct_nct_inel_1_year3
    global treat_vill     CTvill_year2 CTvill_year3
    global treatVV        d_vvml_CT_year2 d_vvml_CT_year3 ///
                          d_vvml_year1 d_vvml_year2 d_vvml_year3
    global spill_ct       bct_year2 bct_year3  
    global spill          pet_year2 pet_year3
    global marketsize     bpov_year2 bpov_year3
    global rel_poverty    pEV_year2 pEV_year3
    global interactions   CT_PET_year2 CT_PET_year3
    global treatB         d_ct_nct_inel_2 d_ct_nct_inel_1
    global spillB         pet
    global marketsizeB    bpov
    global rel_povertyB   pEV
    global interactionsB  CT_PET
    global year           d_year_2 d_year_3

    *** ===================================================================== ***
    *   Defining Outcomes 
    *** ===================================================================== ***

    global business_out   w_realprofits_w w_conrealprofits_w ///
                          w_rawmats_business w_conrawmats_bus

    global lfp_w          d_work_w farming_work_w business_work ///
                          d_lab_dyn_w_2 d_lab_dyn_w_3 d_lab_dyn_w_4

    global lfp_h          d_work_h farming_work_h business_work_h ///
                          d_lab_dyn_h_2 d_lab_dyn_h_3 d_lab_dyn_h_4

    global husb_panel     farming_work_h business_work_h ///
                          ihs_realprofits_h w_realprofits_h ///
                          ihs_rawmats_business_h w_rawmats_business_h

    global ag_out_cs      w_ragyields w_conragyields w_ttl_realinputsha

    global ag_inp_cs      w_ttl_area_cult_f3 w_ttl_laborplots_ha ///
                          d_any_ext_f3 ihs_ttl_spend_orgfert_ha_f3 ///
                          ihs_ttl_spend_infert_ha_f3 ihs_ttl_spend_seeds_ha_f3 ///
                          ihs_ttl_wagehlabor_ha_f3

    global ag_lab_cs      anyfamlab anyhirelab ///
                          w_ttl_daysseas_hhmem_ha_f3 w_ttl_daymen_hired_ha_f3 ///
                          w_ttl_daywomen_hired_ha_f3 w_ttl_daychild_hired_ha_f3

    global ag_use_cs      w_ttl_solharv_f3 w_ttl_consharv_f3 w_ttl_paymharv_f3 ///
                          w_ttl_storharv_f3 w_ttl_postharv_f3

    global cons_out_panel ihs_r_exp_ttlnonfood_7dae ihs_rexp_allfood ///
                          w_r_exp_ttlnonfood_7dae w_rexp_allfood

    global assets_f2      ihs_value_animals_fup2_w ihs_value_farmassets_fup2_w ///
                          ihs_value_hhassets_fup2_w w_value_animals_fup2_w ///
                          w_value_farmassets_fup2_w w_value_hhassets_fup2_w

    global assets_f3      ihs_value_animals_fup3_w ihs_value_farmassets_fup3_w ///
                          ihs_value_hhassets_fup3_w w_value_animals_fup3_w ///
                          w_value_farmassets_fup3_w w_value_hhassets_fup3_w

    global health_f3      haz waz MUAC_z

    global educ_f3        num_gmem_attsch_616_f3 share_gmem_attsch_616_f3 ///
                          num_bmem_attsch_616_f3 share_bmem_attsch_616_f3

    global norms_f3_w     ge_index_w w_norms_women_not_go_work ///
                          w_comm_norm_woman_fields w_comm_norm_male_bad_provider ///
                          w_comm_norm_woman_travelsout

    global norms_f3_h     ge_index_h h_norms_women_not_go_work ///
                          h_comm_norm_woman_fields h_comm_norm_male_bad_provider ///
                          h_comm_norm_woman_travelsout

    global timeuse_f3_w   time_2 time_3 time_4 time_5 time_6 time_leisu
}

*** =========================================================================***	
*   Table F1: Non-farm Enterprise Outcomes Profits and Raw Materials (levels)
*** =========================================================================***	
if 1{
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
  	
  * We need to drop those for which we do not have the outcome of interest
	keep if panel_sample==1
    keep if d_vuln_cat_1==1
	keep if FNLP_treatment==0
	 
   	 
   gl title "Impact on Non-Farm Enterprise Outcomes"	
   gl output_name "TF1_Business_Panel"
   gl panel_out  $business_out
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl     distance    400
   
** FULL MODEL INTERACTED 
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 

  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
 
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
** FULL MODEL INTERACTED 
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist if RDD_18==1 [pweight=ipw],
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
 ** Output
  # d;
   esttab using "$outputs_raw/Tables/$output_name.csv", replace 
   title(${title})	depvars  label nogaps  
   coeflabels(d_ct_nct_inel_2_year2 "CT in CT villages Midline[A]"
              d_ct_nct_inel_2_year3 "CT in CT villages Endline[B]"
			  d_ct_nct_inel_1_year2 "NCT in CT villages Midline[C]"
              d_ct_nct_inel_1_year3 "NCT in CT villages Endline[D]"
              pet_year2    "PET Midline[E]"
			  pet_year3    "PET Endline[F]"			  
			  pEV_year2    "PEV Midline[G]"
			  pEV_year3    "PEV Endline[H]"
			  bpov_year2   "#HH Midline[I]"
			  bpov_year3   "#HH Endline[J]"
			  d_year_2    "Midline[K]"   
			  d_year_3    "Endline[L]")
	order (d_ct_nct_inel_2_year2
              d_ct_nct_inel_2_year3
			  d_ct_nct_inel_1_year2 
              d_ct_nct_inel_1_year3
              pet_year2    
			  pet_year3    		  
			  pEV_year2   
			  pEV_year3    
			  bpov_year2   
			  bpov_year3   
			  d_year_2   
			  d_year_3 )		   
        drop ($controls)  
        stats(N  meters 
              mean_bl mean_f2 mean_f3 
			  pet_mean pev_mean bpov_mean sample, 
			  fmt(0 0 2 2 2 2 2 2 2 2 2 3 3 3 3 3)       
			  labels("Observations"  "Meters" 
			  "Mean pure control BL"
			  "Mean pure control Midline"
			  "Mean pure control Endline"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "Sample")) 
     brackets plain  numbers 
     star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f);
   # d cr;
   
 
** EXPORTING ALL 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
 
 
 } 
	
*** =========================================================================***	
*   Table F2: Female Labor Supply (Past Month) 
*** =========================================================================***	
if 1{
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 

 * We need to drop those for which we do not have the outcome of interest
   keep if panel_sample==1
   keep if d_vuln_cat_1==1
   keep if FNLP_treatment==0

   gl title "Table F2:Female Labor Supply (Past Month)"	
   gl output_name "TF2_LFPWife"
   gl panel_out      $lfp_w
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl     distance    400

** FULL MODEL FULL SAMPLE 
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
 
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
** FULL MODEL RDD
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist if RDD_18==1,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
 ** Output
  # d;
   esttab using "$outputs_raw/Tables/$output_name.csv", replace 
   title(${title})	depvars  label nogaps  
   coeflabels(d_ct_nct_inel_2_year2 "CT in CT villages Midline[A]"
              d_ct_nct_inel_2_year3 "CT in CT villages Endline[B]"
			  d_ct_nct_inel_1_year2 "NCT in CT villages Midline[C]"
              d_ct_nct_inel_1_year3 "NCT in CT villages Endline[D]"
              pet_year2    "PET Midline[E]"
			  pet_year3    "PET Endline[F]"			  
			  pEV_year2    "PEV Midline[G]"
			  pEV_year3    "PEV Endline[H]"
			  bpov_year2   "#HH Midline[I]"
			  bpov_year3   "#HH Endline[J]"
			  d_year_2    "Midline[K]"   
			  d_year_3    "Endline[L]")
	order (d_ct_nct_inel_2_year2
              d_ct_nct_inel_2_year3
			  d_ct_nct_inel_1_year2 
              d_ct_nct_inel_1_year3
              pet_year2    
			  pet_year3    		  
			  pEV_year2   
			  pEV_year3    
			  bpov_year2   
			  bpov_year3   
			  d_year_2   
			  d_year_3 )		   
        drop ($controls)  
        stats(N  meters 
              mean_bl mean_f2 mean_f3 
			  pet_mean pev_mean bpov_mean sample, 
			  fmt(0 0 2 2 2 2 2 2 2 2 2 3 3 3 3 3)       
			  labels("Observations"  "Meters" 
			  "Mean pure control BL"
			  "Mean pure control Midline"
			  "Mean pure control Endline"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "Sample")) 
     brackets plain  numbers 
     star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f);
   # d cr;
   
 
** EXPORTING ALL 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
 
 
 } 
 	
*** =========================================================================***	
*   Table F3: Husband's Labor Supply (Past Month) 
*** =========================================================================***	
if 1{
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 

  * We need to drop those for which we do not have the outcome of interest
	keep if panel_sample==1
    keep if d_vuln_cat_1==1
	keep if FNLP_treatment==0

   gl title "Table F3: Husband's Labor Supply (Past Month)"	
   gl output_name "TF3_LFPHusband"
   gl panel_out      $lfp_h
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl     distance    400

   
** FULL MODEL FULL SAMPLE 
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
 
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
** FULL MODEL RDD
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist if RDD_18==1,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
 ** Output
  # d;
   esttab using "$outputs_raw/Tables/$output_name.csv", replace 
   title(${title})	depvars  label nogaps  
   coeflabels(d_ct_nct_inel_2_year2 "CT in CT villages Midline[A]"
              d_ct_nct_inel_2_year3 "CT in CT villages Endline[B]"
			  d_ct_nct_inel_1_year2 "NCT in CT villages Midline[C]"
              d_ct_nct_inel_1_year3 "NCT in CT villages Endline[D]"
              pet_year2    "PET Midline[E]"
			  pet_year3    "PET Endline[F]"			  
			  pEV_year2    "PEV Midline[G]"
			  pEV_year3    "PEV Endline[H]"
			  bpov_year2   "#HH Midline[I]"
			  bpov_year3   "#HH Endline[J]"
			  d_year_2    "Midline[K]"   
			  d_year_3    "Endline[L]")
	order (d_ct_nct_inel_2_year2
              d_ct_nct_inel_2_year3
			  d_ct_nct_inel_1_year2 
              d_ct_nct_inel_1_year3
              pet_year2    
			  pet_year3    		  
			  pEV_year2   
			  pEV_year3    
			  bpov_year2   
			  bpov_year3   
			  d_year_2   
			  d_year_3 )		   
        drop ($controls)  
        stats(N  meters 
              mean_bl mean_f2 mean_f3 
			  pet_mean pev_mean bpov_mean sample, 
			  fmt(0 0 2 2 2 2 2 2 2 2 2 3 3 3 3 3)       
			  labels("Observations"  "Meters" 
			  "Mean pure control BL"
			  "Mean pure control Midline"
			  "Mean pure control Endline"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "Sample")) 
     brackets plain  numbers 
     star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f);
   # d cr;
   
 
** EXPORTING ALL 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
 
 
 } 
 

*** =========================================================================***	
*   Table F4: Wage Employment // Missing
*** =========================================================================***	
if 1{
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear 	

* Sample if Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1
  
* Format 	
  gl title "F4 Wage Employment"	
  gl output_name "TF4_WageEmployment"

** -----------------------------------------------------------------------------
*  Outcomes Midline
** ----------------------------------------------------------------------------- 
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4
  gl outcomes_f2  wage_emp_fup2_w  wage_emp_fup2_h

** Full Model  
   gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f2{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

** RDD Model 
   gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
 local condition RDD_18
foreach outcome of varlist $outcomes_f2{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if  `condition'==1 
           [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	


** -----------------------------------------------------------------------------
*  Outcomes Endline
** ----------------------------------------------------------------------------- 
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4
  gl outcomes_f2  wage_emp_fup3_w  wage_emp_fup3_h 

** Full Model  
   gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f2{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

** RDD Model 
   gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
 local condition RDD_18
foreach outcome of varlist $outcomes_f2{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if  `condition'==1 
           [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	




  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
			  d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]")
			  order (d_ct_nct_inel_2 d_ct_nct_inel_1 pet pEV bpov)
			  drop(${controls} ${controls2}) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "SAMPLE")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	

*** =========================================================================***	
*   Table F5: Agricultural Outcomes (Levels)
*** =========================================================================***	
if 1{
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear	

* Sample of Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1
 
* Format 	
  gl title "Agriculture Outcomes (Levels)"	
  gl output_name "TF5_AgOutcomes"
  gl outcomes_f3 $ag_out_cs
 
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4

** -----------------------------------------------------------------------------
*  Outcomes Endline
** -----------------------------------------------------------------------------
local time d_wavail_f3

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome in $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome'_f3 ${xlist1} ${controls}
           `outcome'_bl  if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'_f3  if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

** Spillovers+ Market Size + Interactions -RDD
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome in $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome'_f3 ${xlist1} ${controls}
           `outcome'_bl  if `time'==1 & RDD_18==1 [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'_f3  if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
	          d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]") 
			  drop(${controls}) 
			  order(d_ct_nct_inel_2 d_ct_nct_inel_1 pet pEV bpov)
			  stats(N r2 meters mean
			  pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "Sample")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}



*** =========================================================================***	
*   Table F6: Agricultural Non-labor Inputs
*** =========================================================================***	
if 1{
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear	
	
* Sample of Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0 
  keep if d_wavail_f2==1 & d_wavail_f3==1
  
 * Format 	
   gl title "Agricultural Non-labor Inputs"	
   gl output_name "TF6_AgNonLabInp"
   gl outcomes_f3 $ag_inp_cs 
   gl controls2   num_crops_cult_bl

   
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4

** -----------------------------------------------------------------------------
*  Outcomes Endline
** -----------------------------------------------------------------------------
local time d_wavail_f3
if 1{

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}
           ${controls2}  if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	


** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}
           ${controls2}  if `time'==1 & RDD_18==1 [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	


	
}
  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
	          d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]") 
			  drop(${controls} ${controls2} ) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "CT recipients around (%)" 
			  "Average EVs around (%)" 
			  "Households around(#)"
			  "Sample")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	
	


*** =========================================================================***	
*   Table F7: Agricultural Labor Inputs
*** =========================================================================***	
if 1{
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear 	
	
* Sample of Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0  
  keep if d_wavail_f2==1 & d_wavail_f3==1
  
 * Format 	
   gl title "Agricultural Labor Inputs"	
   gl output_name "TF7_AgLabInp"
   gl outcomes_f3 $ag_lab_cs 
   gl controls2   num_crops_cult_bl

   
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4

** -----------------------------------------------------------------------------
*  Outcomes Endline
** -----------------------------------------------------------------------------
** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}
           ${controls2}  if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	
	
	
** Spillovers+ Market Size + Interactions RDD
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}
           ${controls2}  if `time'==1 & RDD_18==1 [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	
		
	
	
  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
	          d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]") 
			  drop(${controls} ${controls2} ) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean, 
			  fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" 
			  "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "CT recipients around (%)" 
			  "Average EVs around (%)" 
			  "Households around(#)"
			  "Sample")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	
		

*** =========================================================================***	
*   Table F8: Use of Agricultural Value Harvested 
*** =========================================================================***	
if 1{
 * Load Data 
    use  "$data/Final/FNLPDataWideAnalysis.dta", clear 	
 * Sample of Analysis
   keep if d_vuln_cat_1==1 
   keep if FNLP_treatment==0  
   keep if d_wavail_f2==1 & d_wavail_f3==1
  
 * Format 	
   gl title "Use of Agricultural Value Harvested"	
   gl output_name "TF8_AgUse"
   gl outcomes_f3 $ag_use_cs 
   gl controls2  w_agyields_bl

   
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4

** -----------------------------------------------------------------------------
*  Outcomes Endline
** -----------------------------------------------------------------------------
** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}
           ${controls2}, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	
	
	
** Spillovers+ Market Size + Interactions RDD
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}
           ${controls2}  if RDD_18==1 [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	
		
	
	
  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
	          d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]") 
			  drop(${controls} ${controls2} ) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean, 
			  fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" 
			  "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "CT recipients around (%)" 
			  "Average EVs around (%)" 
			  "Households around(#)"
			  "Sample")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	
		

*** =========================================================================***	
*   Table F9: Consumption - Breakdown Non-Food and Food
*** =========================================================================***	
if 1{
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
   
  * We need to drop those for which we do not have the outcome of interest
	keep if panel_sample==1
    keep if d_vuln_cat_1==1
	keep if FNLP_treatment==0
	 	
   * Format 	
   gl title "Consumption - Breakdown Non-Food and Food"	
   gl output_name "TF9_Consump_Panel"
   gl panel_out  $cons_out_panel
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl     distance    400
   
** FULL MODEL INTERACTED 
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
 
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
** FULL MODEL INTERACTED 
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist if RDD_18==1 [pweight=ipw],
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
 ** Output
  # d;
   esttab using "$outputs_raw/Tables/$output_name.csv", replace 
   title(${title})	depvars  label nogaps  
   coeflabels(d_ct_nct_inel_2_year2 "CT in CT villages Midline[A]"
              d_ct_nct_inel_2_year3 "CT in CT villages Endline[B]"
			  d_ct_nct_inel_1_year2 "NCT in CT villages Midline[C]"
              d_ct_nct_inel_1_year3 "NCT in CT villages Endline[D]"
              pet_year2    "PET Midline[E]"
			  pet_year3    "PET Endline[F]"			  
			  pEV_year2    "PEV Midline[G]"
			  pEV_year3    "PEV Endline[H]"
			  bpov_year2   "#HH Midline[I]"
			  bpov_year3   "#HH Endline[J]"
			  d_year_2    "Midline[K]"   
			  d_year_3    "Endline[L]")
	order (d_ct_nct_inel_2_year2
              d_ct_nct_inel_2_year3
			  d_ct_nct_inel_1_year2 
              d_ct_nct_inel_1_year3
              pet_year2    
			  pet_year3    		  
			  pEV_year2   
			  pEV_year3    
			  bpov_year2   
			  bpov_year3   
			  d_year_2   
			  d_year_3 )		   
        drop ($controls)  
        stats(N  meters 
              mean_bl mean_f2 mean_f3 
			  pet_mean pev_mean bpov_mean sample, 
			  fmt(0 0 2 2 2 2 2 2 2 2 2 3 3 3 3 3)       
			  labels("Observations"  "Meters" 
			  "Mean pure control BL"
			  "Mean pure control Midline"
			  "Mean pure control Endline"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "Sample")) 
     brackets plain  numbers 
     star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f);
   # d cr;
   
 
** EXPORTING ALL 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
 
   
   
   
   
   
   
   
   
   
   
  	
}

*** =========================================================================***	
*   Table F10: Impact on Investments in Assets, Health, and Education
*** =========================================================================***	
if 1{
  * Load Data 
    use  "$data/Final/FNLPDataWideAnalysis.dta", clear 	

 * Sample if Analysis
	keep if d_vuln_cat_1==1 
	keep if FNLP_treatment==0  
	keep if d_wavail_f2==1 & d_wavail_f3==1

	
	la var ihsassetsind_f2  "Assets Index"
	la var ihsassetsind_f3  "Assets Index"
	
	# d;  
	gl assets_f2      ihsassetsind_f2  
					  ihs_ttl_healthv2_exp_hh_f2
					  ihs_ttl_educ_exp_hh_f2;

	gl assets_f3      ihsassetsind_f3 
					  ihs_ttl_healthv2_exp_hh_f3
					  ihs_ttl_educ_exp_hh_f3;  
	# d cr;

  
** -----------------------------------------------------------------------------
*  Outcomes Midline
** ----------------------------------------------------------------------------- 
if 1{  
* Format 	
  gl title "Impact on household assets, health and education (Panel A)"	
  gl output_name "TF10a_InvestmentsAppendix"
   
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4

   gl outcomes_f2 $assets_f2 
   gl controls2
   local time  d_wavail_f2
if 1{

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f2{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
 local condition RDD_18
foreach outcome of varlist $outcomes_f2{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if `time'==1 & `condition'==1 
           [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	



}

  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
			  d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]")
			  order (d_ct_nct_inel_2 d_ct_nct_inel_1 pet pEV bpov)
			  drop(${controls} ${controls2}) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "SAMPLE")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	



** -----------------------------------------------------------------------------
*  Outcomes Endline
** -----------------------------------------------------------------------------
if 1{
* Format 	
  gl title "Impact on household assets, health and education (Panel B)"	
  gl output_name "F10b_InvestmentsAppendix"
  
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4

   gl outcomes_f3  $assets_f3 
   gl controls2 
   local time d_wavail_f3

if 1{

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
 local condition RDD_18
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if `time'==1 & `condition'==1
           [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

}

  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
			  d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]")
			  order (d_ct_nct_inel_2 d_ct_nct_inel_1 pet pEV bpov)
			  drop(${controls} ${controls2}) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "SAMPLE")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	

   
   
   
}

*** =========================================================================***	
*   Table F11: Assets
*** =========================================================================***	
if 1{
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear 	

* Sample if Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0 
  keep if d_wavail_f2==1 & d_wavail_f3==1
  
  
    global assets_f2      ihs_value_animals_fup2_w ihs_value_farmassets_fup2_w ///
                          ihs_value_hhassets_fup2_w w_value_animals_fup2_w ///
                          w_value_farmassets_fup2_w w_value_hhassets_fup2_w

    global assets_f3      ihs_value_animals_fup3_w ihs_value_farmassets_fup3_w ///
                          ihs_value_hhassets_fup3_w w_value_animals_fup3_w ///
                          w_value_farmassets_fup3_w w_value_hhassets_fup3_w  
  
** -----------------------------------------------------------------------------
*  Outcomes Midline
** ----------------------------------------------------------------------------- 
* Format 	
  gl title "Assets Breakdown (Panel A)"	
  gl output_name "TF11a_Assets"
if 1{    
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4
  gl outcomes_f2 $assets_f2 
  gl controls2
  local time     d_wavail_f2

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f2{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
 local condition RDD_18
foreach outcome of varlist $outcomes_f2{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if `time'==1 & `condition'==1 
           [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
			  d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]")
			  order (d_ct_nct_inel_2 d_ct_nct_inel_1 pet pEV bpov)
			  drop(${controls} ${controls2}) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "SAMPLE")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	
	
	
** -----------------------------------------------------------------------------
*  Outcomes Endline
** -----------------------------------------------------------------------------
* Format 	
  gl title "Assets Breakdown (Panel B)"	
  gl output_name "TF11b_Assets"
   
if 1{   
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4
  gl outcomes_f3  $assets_f3 
  gl controls2 
  local time d_wavail_f3

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
 local condition RDD_18
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} if `time'==1 & `condition'==1
           [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

 * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
			  d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]")
			  order (d_ct_nct_inel_2 d_ct_nct_inel_1 pet pEV bpov)
			  drop(${controls} ${controls2}) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "SAMPLE")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	

}
		
*** =========================================================================***	
*   Table F12: Time Use 
*** =========================================================================***	
if 1{
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear 	

  * Sample if Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1
  
 * Format 	
  gl title "Time Use"	
  gl output_name "TF12_TimeUse"
   
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4
   
** -----------------------------------------------------------------------------
*  Outcomes Endline set 1 Wife
** ------------------------------------------------------------------------------ 
 gl    outcomes_f3   $timeuse_f3_w 
 local time          d_wavail_f3
if 1{
** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome in $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome'_f3_w ${xlist1} ${controls} `outcome'_bl_w 
           if  `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'_f3_w   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	


** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
 local condition RDD_18
foreach outcome in $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome'_f3_w ${xlist1} ${controls} `outcome'_bl_w 
           if  `time'==1 & `condition'==1 [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'_f3_w   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages" 
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

}	
 	
* Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
			  d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]") 
			  drop(${controls} *_bl_w ) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "CT recipients around (%)" 
			  "Average EVs around (%)" 
			  "Households around(#)"
			  "Sample")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	
	
		

*** =========================================================================***	
*   Table F13: Gender Attitudes and Norms Reported by Female Respondents
*** =========================================================================***	
if 1{
  * Load Data 
    use  "$data/Final/FNLPDataWideAnalysis.dta", clear 	
	
* Sample if Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1

  
** -----------------------------------------------------------------------------
*  Outcomes Endline set 1 Wife
** -----------------------------------------------------------------------------  
* Format 	
  gl title "Gender Attitudes and Norms Reported by Female Respondents"	
  gl output_name "TF13_NormsFemale"

* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4

  gl    outcomes_f3   $norms_f3_w
  gl    controls2     
  local time          d_wavail_f3

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}  ${controls2} 
           if  `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
 local condition RDD_18
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}  ${controls2} 
           if  `time'==1  & `condition'==1 [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	


  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
			  d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]"
			  CT_PET "CT*PET[F]") 
			  drop(${controls} ${controls2}) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels(
			  "Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "CT recipients around (%)" 
			  "Average EVs around (%)" 
			  "Households around(#)"
			  "Sample")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore

}	
 	
	
*** =========================================================================***	
*   Table F14: Gender Attitudes and Norms Reported by Husbands
*** =========================================================================***	
if 1{
* Load Data 
    use  "$data/Final/FNLPDataWideAnalysis.dta", clear 	
	
* Sample if Analysis
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1

** -----------------------------------------------------------------------------
*  Outcomes Endline set 2 Husband
** -----------------------------------------------------------------------------
* Format 	
  gl title "Gender Attitudes and Norms Reported by Male Respondents"	
  gl output_name "FT14_NormsMale"

* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4 
  
 gl    outcomes_f3   $norms_f3_h
 gl    controls2     
 local time          d_mavail_f3
if 1{

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}  ${controls2} 
           if  `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

** Spillovers+ Market Size + Interactions
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}  ${controls2} 
           if  `time'==1 & `condition'==1 [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages" 
   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	


	
  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
			  d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]"
			  CT_PET "CT*PET[F]") 
			  drop(${controls}) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels(
			  "Observations" "Adjusted R-squared" 
			  "Meters" 
              "Outcome Mean Pure Control"
			  "CT recipients around (%)" 
			  "EVs around (%)" 
			  "Households around(#)"
			  "Sample")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_AppendixTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
}	
}	









