* **************************************************************** *
*	Cash is Queen 						                           *
*   Main Analysis: RandomizationBalanceAndAttrition                *    		
*   2025        												   *
* **************************************************************** *

local table_1a 1   // Covariate Balance Table Household Level Full sample
local table_1b 1   // Covariate Balance Table Household Level RDD sample

*** =========================================================================***
*        Table 1: Covariate Balance - Household Level Characteristics
**  =========================================================================***
 * Load Data 
   use   "$data/Final/FNLPDataWideAnalysis.dta", clear
   
 * Sample if Analysis
   keep if FNLP_treatment==0
	  
 * Globals of variables   
    # d;
			gl controls    age_hhhead_bl  
						   marital_status2_bl_2  
						   marital_status2_bl_3
						   marital_status2_bl_4
						   literacy_hhhead_bl 
						   num_hh_members_bl   
						   num_hh_members_15_bl       
						   num_plots_bl
						   d_farm_size_bl_1
						   w_daily_adulteq_expenses_bl
						   povertylinebelow_190_bl
						   foodins_index_bl
						   num_enterprises_bl
						   any_farm_hh_bl
						   weai_new_bl_w
						   empowered_new_bl    
						   dm_index_w_bl
						   business_work_w_bl
						   econ_fem_activity_bl;  
               # d cr;			   
			   
* Covariate Balance Normal Difference Full Sample 
* -----------------------------------------------------------------------------
if `table_1a'{
  * Settings 
	gl output_name "T1_CovariateBalanceFull"
	gl controls $controls
	gl covariates d_lgacode_bl_1
  
   * Code for ttest table
	# d;
	iebaltab $controls  if d_vuln_cat_1==1 ,
	         grpvar(nct_ct_inel) covariates($covariates)  onerow 
			  stats(pair(nrmd) f(p))
			 rowvarlabels ftest format(%12.2f)
			 savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	# d cr;		

 ** Exporting to unique file 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_MainTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore
}


 * Covariate Balance Normal Difference - RDD Sample 
 * -----------------------------------------------------------------------------
if `table_1b'{ 
  * Settings 
	gl output_name "T1_CovariateBalanceRDD"
	gl controls $controls
	gl covariates d_lgacode_bl_1
  
   * Code for ttest table
	# d;
	iebaltab $controls  if d_vuln_cat_1==1  & (d_wavail_f2==1 | d_wavail_f3==1) 
	         & RDD_18==1 [pweight=ipw],
	         grpvar(nct_ct_inel) covariates($covariates)  onerow 
			 stats(pair(nrmd) f(p))
			 rowvarlabels ftest format(%12.2f)
			 savexlsx("$outputs_raw/Tables/$output_name.xls")  replace;
	# d cr;		

 ** Exporting to unique file 	 
  preserve 
   * Date:	
	local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
	disp "`svdate'" 		
	
  * Import table from csv
	import excel "$outputs_raw/Tables/$output_name.xls", clear

  * Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_MainTables_`svdate'.xlsx",   ///
				 sheet("$output_name", modify) 
  restore 
 
 
 
	
}  



** =========================================================================***
// END DOFILE 
** =========================================================================***
