* **************************************************************************** *
* Cash Is Queen                                                                *
* Local Economy Effects of Cash Transfers to Women in West Africa              *
* Replication File                                                             *		
* Regression Analysis 														   *
* **************************************************************************** *
*** =========================================================================***
*   Setting up globals for outcomes and covariates
*** =========================================================================***

** Defining right-hand side variables
** ----------------------------------------------------------------------------
    # d ;
	gl controls    d_lgacode_bl_1; 
					
	gl treat 	    d_ct_nct_inel_2_year2 d_ct_nct_inel_2_year3   
				    d_ct_nct_inel_1_year2 d_ct_nct_inel_1_year3; 
	gl treat_vill	CTvill_year2 CTvill_year3;
	gl treatVV      d_vvml_CT_year2 d_vvml_CT_year3  
					d_vvml_year1    d_vvml_year2 d_vvml_year3;
	gl spill_ct	    bct_year2   bct_year3;  
	gl spill 	    pet_year2   pet_year3;     	
	gl marketsize   bpov_year2  bpov_year3;
	gl rel_poverty  pEV_year2   pEV_year3;
	gl interactions CT_PET_year2   CT_PET_year3;
	gl treatB 	     d_ct_nct_inel_2   d_ct_nct_inel_1; 					
    gl spillB 	     pet;     	
	gl marketsizeB   bpov;
	gl rel_povertyB  pEV;
	gl interactionsB CT_PET;					
	gl year         d_year_2    d_year_3;
	# d cr;
	
** Defining outcomes
** ----------------------------------------------------------------------------
    # d;
    gl business_out   business_work ihs_realprofits_w;  
	
	gl ag_out_cs      d_posyields  ihs_ragyields  ihs_ttl_realinputsha;
					  
	gl cons_out       foodaindex ihs_expen_7dae;
					  
	gl dm_var_w       dm2_aindex_w_f3
					  d_sharemoney4_1_w_f3      d_sharemoney4_2_w_f3
					  d_sharemoney4_3_w_f3; 
				  
	# d cr;

*** =========================================================================***
*   Table Specification and Result Storage
*** =========================================================================***
  local table_2      1  /*Non-Farm Enterprise Outcomes*/
  local table_3      1  /*Agriculture Outcomes*/
  local table_4      1  /*Food Security and Consumption*/
  local table_5      1  /*Women's Empowerment and Decision-Making Power*/
		
	
*** =========================================================================***
*   Table 2: Non-Farm Enterprise Outcomes 
*** =========================================================================***
if (`table_2' == 1) {	
* ------------------------------------------------------------------------------	
* Main Regression Results 
* ------------------------------------------------------------------------------	
if 1{	
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
  
 * Selecting Sample 
   keep if panel_sample==1
   keep if d_vuln_cat_1==1
   keep if FNLP_treatment==0
   	 
	 
 * Generating temporary dataset to produce sum at bottom of the table 	 
   gen business_work_m=business_work  
   gen ihs_realprofits_w_m=w_realprofits_w	 
	 
	 
 * Selecting Main Settings for table 	 
   gl title "Impact on Non-Farm Enterprise Outcomes"	
   gl output_name "T2_NonFarmEnterprise"
   gl panel_out   $business_out
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl     distance    400
   
* Basic Treatment Effect
* -----------------------------------------------
 gl xlist $treat $controls $year
 foreach condition in ct_control nct_control{
 foreach outcome of varlist $panel_out{   
   # d;
   eststo: reg `outcome' $xlist if `condition'==1, cluster (village_new_bl);
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	estadd local sample "HHs in Program Villages"

   } 
}
    
* Adding Spillover Impact and market size
* -----------------------------------------------
 gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach condition in ct_control nct_control{	
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'          pet
	ren b`DISTcutoff'pov         bpov
	ren pet`DISTcutoff'_year2    pet_year2 
    ren pet`DISTcutoff'_year3    pet_year3
    ren b`DISTcutoff'pov_year2   bpov_year2 
    ren b`DISTcutoff'pov_year3   bpov_year3
	ren pEV`DISTcutoff'          pEV
    ren pEV`DISTcutoff'_year2    pEV_year2 
    ren pEV`DISTcutoff'_year3    pEV_year3
   
   # d;
   eststo: acreg `outcome' $xlist if `condition'==1,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar     mean_bl=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar     mean_f2=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "HHs in Program Villages"
 
 ** Rename variables so they align in output
   ren bpov        b`DISTcutoff'pov 
   ren pet         pet`DISTcutoff'
   ren pet_year2   pet`DISTcutoff'_year2 
   ren pet_year3   pet`DISTcutoff'_year3
   ren bpov_year2  b`DISTcutoff'pov_year2
   ren bpov_year3  b`DISTcutoff'pov_year3
 
   ren pEV         pEV`DISTcutoff'
   ren pEV_year2   pEV`DISTcutoff'_year2
   ren pEV_year3   pEV`DISTcutoff'_year3
 
   } 
   }
 }
 
* Full Model for Full Sample
* -----------------------------------------------
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar     mean_bl=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar     mean_f2=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
 
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
* Full Model for RDD Sample
* -----------------------------------------------
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist if RDD_18==1 [pweight=ipw],
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
 ** Output
  # d;
   esttab using "$outputs_raw/Tables/$output_name.csv", replace 
   title(${title})	depvars  label nogaps  
   coeflabels(d_ct_nct_inel_2_year2 "CT in CT villages Midline[A]"
              d_ct_nct_inel_2_year3 "CT in CT villages Endline[B]"
			  d_ct_nct_inel_1_year2 "NCT in CT villages Midline[C]"
              d_ct_nct_inel_1_year3 "NCT in CT villages Endline[D]"
              pet_year2    "PET Midline[E]"
			  pet_year3    "PET Endline[F]"			  
			  pEV_year2    "PEV Midline[G]"
			  pEV_year3    "PEV Endline[H]"
			  bpov_year2   "#HH Midline[I]"
			  bpov_year3   "#HH Endline[J]"
			  d_year_2    "Midline[K]"   
			  d_year_3    "Endline[L]")
	order (d_ct_nct_inel_2_year2
              d_ct_nct_inel_2_year3
			  d_ct_nct_inel_1_year2 
              d_ct_nct_inel_1_year3
              pet_year2    
			  pet_year3    		  
			  pEV_year2   
			  pEV_year3    
			  bpov_year2   
			  bpov_year3   
			  d_year_2   
			  d_year_3 )		   
        drop ($controls)  
        stats(N  meters 
              mean_bl mean_f2 mean_f3 
			  pet_mean pev_mean bpov_mean sample, 
			  fmt(0 0 2 2 2 2 2 2 2 2 2 3 3 3 3 3)       
			  labels("Observations"  "Meters" 
			  "Mean pure control BL"
			  "Mean pure control Midline"
			  "Mean pure control Endline"
			  "CT recepients around (%)" 
			  "EVs around (%)" 
			  "Households around(#)"
			  "Sample")) 
     brackets plain  numbers 
     star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f);
   # d cr;
   
 
** EXPORTING ALL 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_MainTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
 
* Clear Stored Estimates
  eststo clear
 } 
 
* ------------------------------------------------------------------------------	
* Elasticities  - Output second spreadsheet
* ------------------------------------------------------------------------------ 
if 1{
 * Load the Panel dataset 
   use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
  
 * Selecting Sample 
   keep if panel_sample==1
   keep if d_vuln_cat_1==1
   keep if FNLP_treatment==0
   	 

 * Globals of controls and main variables 	
  # d;
	gl treat_2v     d_ct_nct_inel_2_year2 
	                d_ct_nct_inel_2_year3   
				    d_ct_nct_inel_1_year2  
					d_ct_nct_inel_1_year3; 	
	gl spill_2v 	    pet400_year2   pet400_year3;  
	gl marketsize_2v   b400pov_year2  b400pov_year3;
	gl rel_poverty_2v  pEV400_year2   pEV400_year3;	
    gl controls_2v     d_lgacode_bl_1; 
	gl year_2v         d_year_2    d_year_3;	

  # d cr; 

gl outcome_1    1

** Outcome 1 
********************************************************************************
if $outcome_1{  
* Coefficients to compute  elasticity
  local elas_coeff1      d_ct_nct_inel_2_year2  
  local elas_coeff2      d_ct_nct_inel_2_year3  
  local elas_coeff3      d_ct_nct_inel_1_year2  
  local elas_coeff4      d_ct_nct_inel_1_year3   
  local elas_coeff5      pet400_year2  
  local elas_coeff6      pet400_year3     
  
  local outcome  ihs_realprofits_w
   
**  JUST TREATMENTS : Just CT
*** =========================================================================***
  gl xlist        $treat_2v  $controls_2v $year_2v
  local spec_num  1
  local condition ct_control
if 1{ 
** Regression code
   # d;
   eststo: reg `outcome' $xlist if `condition'==1, cluster (village_new_bl);
   # d cr; 		   
 
  * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
 
 ** Estimating elasticities
  * Coefficient 1
	disp ("/* Elasticity Coeff 1*/")  
	nlcom  exp(_b[`elas_coeff1'] - 0.5 * ((_se[`elas_coeff1'])^2)) - 1, post
	local elast_c1_out1= _b[_nl_1]
    local elast_c1_out1S`spec_num'=round(`elast_c1_out1', 0.01)
	 	 
  * Coefficient 2 
    estimates restore _temp_reg	 
	disp ("/* Elasticity Coeff 2*/")  
	nlcom  exp(_b[`elas_coeff2'] - 0.5 * ((_se[`elas_coeff2'])^2)) - 1, post
	local elast_c2_out1= _b[_nl_1]
    local elast_c2_out1S`spec_num'=round(`elast_c2_out1', 0.01)	
			

  }
	  
**  JUST TREATMENTS : Just NCT
*** =========================================================================***
  gl xlist        $treat_2v  $controls_2v $year_2v
  local spec_num  2
  local condition nct_control
if 1{ 
** Regression code
   # d;
   eststo: reg `outcome' $xlist if `condition'==1, cluster (village_new_bl);
   # d cr; 		   
 
  * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
 
 ** Estimating elasticities
  * Coefficient 3 
    estimates restore _temp_reg	 	
	disp ("/* Elasticity Coeff 3*/")  
	nlcom  exp(_b[`elas_coeff3'] - 0.5 * ((_se[`elas_coeff3'])^2)) - 1, post
	local elast_c3_out1= _b[_nl_1]
    local elast_c3_out1S`spec_num'=round(`elast_c3_out1', 0.01)
	 
  * Coefficient 4
    estimates restore _temp_reg	 	 
	disp ("/* Elasticity Coeff 4*/")  
	nlcom  exp(_b[`elas_coeff4'] - 0.5 * ((_se[`elas_coeff4'])^2)) - 1, post
	local elast_c4_out1= _b[_nl_1]
    local elast_c4_out1S`spec_num'=round(`elast_c4_out1', 0.01)		

  }
	  
**  FULL MODEL  : Just CT
*** =========================================================================***
  gl xlist        $treat_2v $spill_2v $rel_poverty_2v $marketsize_2v $controls_2v $year_2v
  local spec_num  3
  local condition ct_control
if 1{ 
** Regression code
   # d;
   eststo: acreg `outcome' $xlist if `condition'==1,
		   time(year) id(hhid_panel) lag(3)
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(400) bartlett;
   # d cr; 		   
 
  * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
 
 ** Estimating elasticities
  * Coefficient 1
	disp ("/* Elasticity Coeff 1*/")  
	nlcom  exp(_b[`elas_coeff1'] - 0.5 * ((_se[`elas_coeff1'])^2)) - 1, post
	local elast_c1_out1= _b[_nl_1]
    local elast_c1_out1S`spec_num'=round(`elast_c1_out1', 0.01)
	 	 
  * Coefficient 2 
    estimates restore _temp_reg	 
	disp ("/* Elasticity Coeff 2*/")  
	nlcom  exp(_b[`elas_coeff2'] - 0.5 * ((_se[`elas_coeff2'])^2)) - 1, post
	local elast_c2_out1= _b[_nl_1]
    local elast_c2_out1S`spec_num'=round(`elast_c2_out1', 0.01)	
	
  * Coefficient 5
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 5*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff5'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff5']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_5= _b[_nl_1]		
	local elast_c5_out1= _b[_nl_1]
    local elast_c5_out1S`spec_num'=round(`elast_c5_out1', 0.01)		
	
  * Coefficient 6
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 6*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff6'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff6']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_6= _b[_nl_1]		
	local elast_c6_out1= _b[_nl_1]
    local elast_c6_out1S`spec_num'=round(`elast_c6_out1', 0.01)		

  }
	    
  
**  FULL MODEL  : Just NCT
*** =========================================================================***
  gl xlist        $treat_2v $spill_2v $rel_poverty_2v $marketsize_2v $controls_2v $year_2v
  local spec_num  4
  local condition nct_control
if 1{ 
** Regression code
   # d;
   eststo: acreg `outcome' $xlist if `condition'==1,
		   time(year) id(hhid_panel) lag(3)
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(400) bartlett;
   # d cr; 		   
 
  * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
 
 ** Estimating elasticities
  * Coefficient 3 
    estimates restore _temp_reg	 	
	disp ("/* Elasticity Coeff 3*/")  
	nlcom  exp(_b[`elas_coeff3'] - 0.5 * ((_se[`elas_coeff3'])^2)) - 1, post
	local elast_c3_out1= _b[_nl_1]
    local elast_c3_out1S`spec_num'=round(`elast_c3_out1', 0.01)
	 
  * Coefficient 4
    estimates restore _temp_reg	 	 
	disp ("/* Elasticity Coeff 4*/")  
	nlcom  exp(_b[`elas_coeff4'] - 0.5 * ((_se[`elas_coeff4'])^2)) - 1, post
	local elast_c4_out1= _b[_nl_1]
    local elast_c4_out1S`spec_num'=round(`elast_c4_out1', 0.01)		
	
	
  * Coefficient 5
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 5*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff5'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff5']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_5= _b[_nl_1]		
	local elast_c5_out1= _b[_nl_1]
    local elast_c5_out1S`spec_num'=round(`elast_c5_out1', 0.01)		
	
  * Coefficient 6
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 6*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff6'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff6']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_6= _b[_nl_1]		
	local elast_c6_out1= _b[_nl_1]
    local elast_c6_out1S`spec_num'=round(`elast_c6_out1', 0.01)		

  }
	    
**  FULL MODEL 
*** =========================================================================***
  gl xlist        $treat_2v $spill_2v $rel_poverty_2v $marketsize_2v $controls_2v $year_2v
  local spec_num  5
if 1{ 
** Regression code
   # d;
   eststo: acreg `outcome' $xlist,
		   time(year) id(hhid_panel) lag(3)
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(400) bartlett;
   # d cr; 		   
 
  * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
 
 ** Estimating elasticities
  * Coefficient 1
	disp ("/* Elasticity Coeff 1*/")  
	nlcom  exp(_b[`elas_coeff1'] - 0.5 * ((_se[`elas_coeff1'])^2)) - 1, post
	local elast_c1_out1= _b[_nl_1]
    local elast_c1_out1S`spec_num'=round(`elast_c1_out1', 0.01)
	 	 
  * Coefficient 2 
    estimates restore _temp_reg	 
	disp ("/* Elasticity Coeff 2*/")  
	nlcom  exp(_b[`elas_coeff2'] - 0.5 * ((_se[`elas_coeff2'])^2)) - 1, post
	local elast_c2_out1= _b[_nl_1]
    local elast_c2_out1S`spec_num'=round(`elast_c2_out1', 0.01)	
	
  * Coefficient 3 
    estimates restore _temp_reg	 	
	disp ("/* Elasticity Coeff 3*/")  
	nlcom  exp(_b[`elas_coeff3'] - 0.5 * ((_se[`elas_coeff3'])^2)) - 1, post
	local elast_c3_out1= _b[_nl_1]
    local elast_c3_out1S`spec_num'=round(`elast_c3_out1', 0.01)
	 
  * Coefficient 4
    estimates restore _temp_reg	 	 
	disp ("/* Elasticity Coeff 4*/")  
	nlcom  exp(_b[`elas_coeff4'] - 0.5 * ((_se[`elas_coeff4'])^2)) - 1, post
	local elast_c4_out1= _b[_nl_1]
    local elast_c4_out1S`spec_num'=round(`elast_c4_out1', 0.01)		
	
	
  * Coefficient 5
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 5*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff5'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff5']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_5= _b[_nl_1]		
	local elast_c5_out1= _b[_nl_1]
    local elast_c5_out1S`spec_num'=round(`elast_c5_out1', 0.01)		
	
  * Coefficient 6
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 6*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff6'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff6']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_6= _b[_nl_1]		
	local elast_c6_out1= _b[_nl_1]
    local elast_c6_out1S`spec_num'=round(`elast_c6_out1', 0.01)		

  }
	
**  RDD MODEL 
*** =========================================================================***
  gl xlist        $treat_2v $spill_2v $rel_poverty_2v $marketsize_2v $controls_2v $year_2v
  local spec_num  6  
** Regression code
if 1{ 
   # d;
   eststo: acreg `outcome' $xlist if RDD_18==1 [pweight=ipw],
		   time(year) id(hhid_panel) lag(3)
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(400) bartlett;
   # d cr; 		   
 
 * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
	
 ** Estimating elasticities
  * Coefficient 1
	disp ("/* Elasticity Coeff 1*/")  
	nlcom  exp(_b[`elas_coeff1'] - 0.5 * ((_se[`elas_coeff1'])^2)) - 1, post
	local elast_c1_out1= _b[_nl_1]
    local elast_c1_out1S`spec_num'=round(`elast_c1_out1', 0.01)
	 
  * Coefficient 2 
    estimates restore _temp_reg	 	 
	disp ("/* Elasticity Coeff 2*/")  
	nlcom  exp(_b[`elas_coeff2'] - 0.5 * ((_se[`elas_coeff2'])^2)) - 1, post
	local elast_c2_out1= _b[_nl_1]
    local elast_c2_out1S`spec_num'=round(`elast_c2_out1', 0.01)	
	
  * Coefficient 3 
    estimates restore _temp_reg	 	
	disp ("/* Elasticity Coeff 3*/")  
	nlcom  exp(_b[`elas_coeff3'] - 0.5 * ((_se[`elas_coeff3'])^2)) - 1, post
	local elast_c3_out1= _b[_nl_1]
    local elast_c3_out1S`spec_num'=round(`elast_c3_out1', 0.01)
	 
  * Coefficient 4 
    estimates restore _temp_reg	 	 
	disp ("/* Elasticity Coeff 4*/")  
	nlcom  exp(_b[`elas_coeff4'] - 0.5 * ((_se[`elas_coeff4'])^2)) - 1, post
	local elast_c4_out1= _b[_nl_1]
    local elast_c4_out1S`spec_num'=round(`elast_c4_out1', 0.01)		
	
  * Coefficient 5
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 5*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff5'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff5']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_5= _b[_nl_1]		
	local elast_c5_out1= _b[_nl_1]
    local elast_c5_out1S`spec_num'=round(`elast_c5_out1', 0.01)		
	
  * Coefficient 6
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 6*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff6'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff6']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_6= _b[_nl_1]		
	local elast_c6_out1= _b[_nl_1]
    local elast_c6_out1S`spec_num'=round(`elast_c6_out1', 0.01)		
	
	
	
	
	
  }
	
}	
	
** Exporting to unique file 
** -----------------------------------------------------------------------------	
if 1{
 * Date:	
   local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
   disp "`svdate'" 	

  * Output and name
    gl sheet_name "T2_NonFarmEnterprise_Elast"
	
	

  * Exporting the file 	
  # d;
    putexcel set "$outputs_final/CashIsQueen_MainTables_`svdate'.xlsx", 
	             sheet("$sheet_name") modify;
				 
	putexcel A1=("Elasticities - Adjustment following Bellemare and Wichman (2020)")
            
			 A4=("CT in CT villages Midline[A]")
             A5=("CT in CT villages Endline[B]") 
             A6=("NCT in CT villages Midline[C]")
             A7=("NCT in CT villages Endline[D]")   
             A8=("PET Midline[E]")
             A9=("PET Endline[F]")   			 
			 
			 B2=("Business Profits")
			 C3=("Just CT")
			 E3=("Just NCT")
			 G3=("CT Full")
			 I3=("NCT Full")			 
			 K3=("Full")
			 M3=("RDD 18");
			 
	putexcel C4=(`elast_c1_out1S1')  
	         C5=(`elast_c2_out1S1')                   
 
			 
                 
	         E6=(`elast_c3_out1S2')  
			 E7=(`elast_c4_out1S2')

			 
             G4=(`elast_c1_out1S3')  
	         G5=(`elast_c2_out1S3')                   

	         G8=(`elast_c5_out1S3')  
			 G9=(`elast_c6_out1S3')			 
			                
	         I6=(`elast_c3_out1S4')  
			 I7=(`elast_c4_out1S4')
	         I8=(`elast_c5_out1S4')  
			 I9=(`elast_c6_out1S4')				 
			 
             K4=(`elast_c1_out1S5')  
	         K5=(`elast_c2_out1S5')                   
	         K6=(`elast_c3_out1S5')  
			 K7=(`elast_c4_out1S5')
	         K8=(`elast_c5_out1S5')  
			 K9=(`elast_c6_out1S5')			 
			 
             M4=(`elast_c1_out1S6')  
	         M5=(`elast_c2_out1S6')                   
	         M6=(`elast_c3_out1S6')  
			 M7=(`elast_c4_out1S6')
	         M8=(`elast_c5_out1S6')  
			 M9=(`elast_c6_out1S6');  
			 
* Merge cells B2 and C2 and center the text "Business Profits"
  putexcel B2:C2=matrix(1), merge;			 
  
  putexcel clear;
   # d cr;		
	
} 


* Clear Stored Estimates
  eststo clear
}

} 
 
*** =========================================================================***
*   Table 3: Agriculture Outcomes 
*** =========================================================================***
if (`table_3' == 1) {
	
* ------------------------------------------------------------------------------	
* Main Regression Results 
* ------------------------------------------------------------------------------	
if 1{	
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear

* Sample of Analysis
  keep if d_vuln_cat_1==1                 // Keeping just EV sample
  keep if FNLP_treatment==0               // Keeping  FNLP control sites
  keep if d_wavail_f2==1 & d_wavail_f3==1 // Keeping sample in both rounds 
  
  
 * Format 	
   gl title "Impact on Agriculture Outcomes"	
   gl output_name "T3_AgricultureOutcomes"
   gl outcomes_f3 $ag_out_cs
 
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4
  local time d_wavail_f3
  
** Full Model 
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome in $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome'_f3 ${xlist1} ${controls}
           `outcome'_bl  if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'_f3  if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

** Full Model -RDD
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome in $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome'_f3 ${xlist1} ${controls}
           `outcome'_bl  if `time'==1 & RDD_18==1  [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'_f3  if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	
  

  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
	          d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]") 
			  drop(${controls} d_posyields_bl  ihs_ragyields_bl  ihs_ttl_realinputsha_bl) 
			  order(d_ct_nct_inel_2 d_ct_nct_inel_1 pet pEV bpov)
			  stats(N r2 meters mean
			  pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "Sample")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_MainTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
	
* Clear Stored Estimates
  eststo clear	
	
}	


* ------------------------------------------------------------------------------	
* Elasticities
* ------------------------------------------------------------------------------
if 1{
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear

* Sample of Analysis
  keep if d_vuln_cat_1==1                 // Keeping just EV sample
  keep if FNLP_treatment==0               // Keeping  FNLP control sites
  keep if d_wavail_f2==1 & d_wavail_f3==1 // Keeping sample in both rounds 
  drop if business_work_w_bl==.   
 	
* Setting up globals for regression   
  gl controls_2v      d_lgacode_bl_1
  gl treatB_2v 	      d_ct_nct_inel_2 d_ct_nct_inel_1					
  gl spillB_2v 	      pet400	
  gl marketsizeB_2v   b400pov
  gl rel_povertyB_2v  pEV400
  

  
  gl outcome_1    1
  gl outcome_2    1
  
** Outcome 1 
********************************************************************************
if $outcome_1{ 
  local outcome          ihs_ragyields
  local elas_coeff1      d_ct_nct_inel_2  
  local elas_coeff2      d_ct_nct_inel_1  
  local elas_coeff3       pet400

      
**  FULL MODEL 
*** =========================================================================***
  gl xlist       $treatB_2v $spillB_2v $rel_povertyB_2v $marketsizeB_2v
  local spec_num  3
if 1{ 
** Regression code
   # d;
   eststo: acreg `outcome'_f3 ${xlist} ${controls} `outcome'_bl,
		   spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(400) bartlett;
   # d cr; 		   
   
 
  * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
 
 ** Estimating elasticities
  * Coefficient 1
	disp ("/* Elasticity Coeff 1*/")  
	nlcom  exp(_b[`elas_coeff1'] - 0.5 * ((_se[`elas_coeff1'])^2)) - 1, post
	local elast_c1_out1= _b[_nl_1]
    local elast_c1_out1S`spec_num'=round(`elast_c1_out1', 0.01)
	 	 
  * Coefficient 2 
    estimates restore _temp_reg	 
	disp ("/* Elasticity Coeff 2*/")  
	nlcom  exp(_b[`elas_coeff2'] - 0.5 * ((_se[`elas_coeff2'])^2)) - 1, post
	local elast_c2_out1= _b[_nl_1]
    local elast_c2_out1S`spec_num'=round(`elast_c2_out1', 0.01)	
	
  * Coefficient 3
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 3*/")  
    // Outcome mean 
	sum `outcome'_f3 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff3'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff3']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 				
	local elast_c3_out1= _b[_nl_1]
    local elast_c3_out1S`spec_num'=round(`elast_c3_out1', 0.01)		
		
	
  }
	
**  RDD MODEL 
*** =========================================================================***
  gl xlist       $treatB_2v $spillB_2v $rel_povertyB_2v $marketsizeB_2v
  local spec_num  4
** Regression code
if 1{ 
   # d;
   eststo: acreg `outcome'_f3 ${xlist} ${controls} `outcome'_bl
           if RDD_18==1  [pweight=ipw],
		   spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(400) bartlett;
   # d cr; 		   

 * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
	
 ** Estimating elasticities
  * Coefficient 1
	disp ("/* Elasticity Coeff 1*/")  
	nlcom  exp(_b[`elas_coeff1'] - 0.5 * ((_se[`elas_coeff1'])^2)) - 1, post
	local elast_c1_out1= _b[_nl_1]
    local elast_c1_out1S`spec_num'=round(`elast_c1_out1', 0.01)
	 
  * Coefficient 2 
    estimates restore _temp_reg	 	 
	disp ("/* Elasticity Coeff 2*/")  
	nlcom  exp(_b[`elas_coeff2'] - 0.5 * ((_se[`elas_coeff2'])^2)) - 1, post
	local elast_c2_out1= _b[_nl_1]
    local elast_c2_out1S`spec_num'=round(`elast_c2_out1', 0.01)	
	
  * Coefficient 3
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 3*/")  
    // Outcome mean 
	sum `outcome'_f3 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff3'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff3']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 			
	local elast_c3_out1= _b[_nl_1]
    local elast_c3_out1S`spec_num'=round(`elast_c3_out1', 0.01)		 	
	
  }
}

** Outcome 2
********************************************************************************
if $outcome_2{ 
  local outcome          ihs_ttl_realinputsha
  local elas_coeff1      d_ct_nct_inel_2  
  local elas_coeff2      d_ct_nct_inel_1  
  local elas_coeff3      pet400

      
**  FULL MODEL 
*** =========================================================================***
  gl xlist       $treatB_2v $spillB_2v $rel_povertyB_2v $marketsizeB_2v
  local spec_num  3
if 1{ 
** Regression code
   # d;
   eststo: acreg `outcome'_f3 ${xlist} ${controls} `outcome'_bl,
		   spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(400) bartlett;
   # d cr; 		   
   
 
  * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
 
 ** Estimating elasticities
  * Coefficient 1
	disp ("/* Elasticity Coeff 1*/")  
	nlcom  exp(_b[`elas_coeff1'] - 0.5 * ((_se[`elas_coeff1'])^2)) - 1, post
	local elast_c1_out2= _b[_nl_1]
    local elast_c1_out2S`spec_num'=round(`elast_c1_out2', 0.01)
	 	 
  * Coefficient 2 
    estimates restore _temp_reg	 
	disp ("/* Elasticity Coeff 2*/")  
	nlcom  exp(_b[`elas_coeff2'] - 0.5 * ((_se[`elas_coeff2'])^2)) - 1, post
	local elast_c2_out2= _b[_nl_1]
    local elast_c2_out2S`spec_num'=round(`elast_c2_out2', 0.01)	
	
  * Coefficient 3
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 3*/")  
    // Outcome mean 
	sum `outcome'_f3 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff3'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff3']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_3= _b[_nl_1]		
	local elast_c3_out2= _b[_nl_1]
    local elast_c3_out2S`spec_num'=round(`elast_c3_out2', 0.01)		
		
	
  }
	
**  RDD MODEL 
*** =========================================================================***
  gl xlist       $treatB_2v $spillB_2v $rel_povertyB_2v $marketsizeB_2v
  local spec_num  4
** Regression code
if 1{ 
   # d;
   eststo: acreg `outcome'_f3 ${xlist} ${controls} `outcome'_bl
           if RDD_18==1  [pweight=ipw],
		   spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(400) bartlett;
   # d cr; 		   

 * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
	
 ** Estimating elasticities
  * Coefficient 1
	disp ("/* Elasticity Coeff 1*/")  
	nlcom  exp(_b[`elas_coeff1'] - 0.5 * ((_se[`elas_coeff1'])^2)) - 1, post
	local elast_c1_out2= _b[_nl_1]
    local elast_c1_out2S`spec_num'=round(`elast_c1_out2', 0.01)
	 
  * Coefficient 2 
    estimates restore _temp_reg	 	 
	disp ("/* Elasticity Coeff 2*/")  
	nlcom  exp(_b[`elas_coeff2'] - 0.5 * ((_se[`elas_coeff2'])^2)) - 1, post
	local elast_c2_out2= _b[_nl_1]
    local elast_c2_out2S`spec_num'=round(`elast_c2_out2', 0.01)	
	
  * Coefficient 3
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 3*/")  
    // Outcome mean 
	sum `outcome'_f3 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff3'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff3']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_3= _b[_nl_1]		
	local elast_c3_out2= _b[_nl_1]
    local elast_c3_out2S`spec_num'=round(`elast_c3_out2', 0.01)		 	
	
  }
}

 
** Exporting to unique file 
** -----------------------------------------------------------------------------	
if 1{
 * Date:	
   local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
   disp "`svdate'" 	

  * Output and name
    gl sheet_name "T3_AgricultureOutcomes_Elast"

  * Exporting the file 	
  # d;
    putexcel set "$outputs_final/CashIsQueen_MainTables_`svdate'.xlsx", 
	             sheet("$sheet_name") modify;
				 
	putexcel A1=("Elasticities - Adjustment following Bellemare and Wichman (2020)")
            
			 A4=("CT in CT villages [A]")
             A5=("NCT in CT villages [B]")  
             A6=("PET[C]")
			 
			 C2=("Yields")
			 D2=("Total spend on inputs in the plot")
			 
			 F2=("Yields")
			 G2=("Total spend on inputs in the plot")			 
			 
			 C3=("Full")
			 F3=("RDD");
			 
	putexcel 
             C4=(`elast_c1_out1S3')  
			 C5=(`elast_c2_out1S3') 
			 C6=(`elast_c3_out1S3') 
             D4=(`elast_c1_out2S3')  
			 D5=(`elast_c2_out2S3') 
			 D6=(`elast_c3_out2S3') 
			 
             F4=(`elast_c1_out1S4')  
			 F5=(`elast_c2_out1S4') 
			 F6=(`elast_c3_out1S4') 
             G4=(`elast_c1_out2S4')  
			 G5=(`elast_c2_out2S4') 
			 G6=(`elast_c3_out2S4') ;  

	putexcel clear;
   # d cr;		
	
} 


* Clear Stored Estimates
  eststo clear	
	
}

}

*** =========================================================================***
*   Table 4: Food Security and Consumption 
*** =========================================================================***
if (`table_4' == 1) {
	
* ------------------------------------------------------------------------------	
* Main Regression Results 
* ------------------------------------------------------------------------------	
if 1{	
  * Load the Panel dataset 
    use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
  
  * Generating temp variables for exporting means 
    gen foodaindex_m=foodaindex 
	gen ihs_expen_7dae_m=w_expen_7dae
  
  * We need to drop those for which we do not have the outcome of interest
	keep if panel_sample==1
    keep if d_vuln_cat_1==1
	keep if FNLP_treatment==0
	 	
  * Format 	
   gl title "Impact on Food Security and Consumption"	
   gl output_name "T4_FoodSecurityConsump"
   gl panel_out  $cons_out
   local  LAGcutoff   3
   local  Timevar     year
   local  Panelvar    hhid_panel	
   gl     distance    400
   
** FULL MODEL INTERACTED 
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist ,
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"
 
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
** FULL MODEL INTERACTED - RDD
** ------------------------------------- 
  gl xlist $treat $spill $rel_poverty $marketsize $controls $year
 foreach outcome of varlist $panel_out{   
  foreach DISTcutoff in $distance{
  * Renaming  variables so they align in output
    ren pet`DISTcutoff'            pet
	ren pEV`DISTcutoff'            pEV	
	ren b`DISTcutoff'pov           bpov
	ren pet`DISTcutoff'_year2      pet_year2 
    ren pet`DISTcutoff'_year3      pet_year3
    ren b`DISTcutoff'pov_year2     bpov_year2 
    ren b`DISTcutoff'pov_year3     bpov_year3
    ren pEV`DISTcutoff'_year2      pEV_year2 
    ren pEV`DISTcutoff'_year3      pEV_year3
	ren CT_PET`DISTcutoff'_year2   CT_PET_year2
	ren CT_HH`DISTcutoff'_year2    CT_HH_year2
	ren CT_PEV`DISTcutoff'_year2   CT_PEV_year2
	ren CT_PET`DISTcutoff'_year3   CT_PET_year3
	ren CT_HH`DISTcutoff'_year3    CT_HH_year3
	ren CT_PEV`DISTcutoff'_year3   CT_PEV_year3	
   
   # d;
   eststo: acreg `outcome' $xlist if RDD_18==1  [pweight=ipw],
		   time(`Timevar') id(`Panelvar') lag(`LAGcutoff')
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`DISTcutoff') bartlett;
   # d cr; 		   
 
 
  * Stats 
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_1==1
	estadd scalar  mean_bl=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_2==1
	estadd scalar  mean_f2=r(mean)
	sum `outcome'_m   if e(sample) & d_ct_nct_inel_3==1 & d_year_3==1
	estadd scalar  mean_f3=r(mean)
	
	sum    pet if e(sample)
	local  pet_mean=r(mean)
	estadd scalar  pet_mean=r(mean)
	
	sum    pEV if e(sample)
	local  pev_mean=r(mean)
	estadd scalar  pev_mean=r(mean)
	
    sum    bpov if e(sample)
	local  bpov_mean=r(mean)
	estadd scalar  bpov_mean=r(mean)
 
	estadd scalar meters=`DISTcutoff'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 ** Rename variables so they align in output
   ren pet 				pet`DISTcutoff' 
   ren pEV				pEV`DISTcutoff'       
   ren bpov  			b`DISTcutoff'pov    
   ren CT_PET_year2     CT_PET`DISTcutoff'_year2
   ren CT_HH_year2      CT_HH`DISTcutoff'_year2  
   ren CT_PEV_year2	    CT_PEV`DISTcutoff'_year2
   ren CT_PET_year3     CT_PET`DISTcutoff'_year3
   ren CT_HH_year3      CT_HH`DISTcutoff'_year3 
   ren CT_PEV_year3	    CT_PEV`DISTcutoff'_year3
   ren pet_year2  		pet`DISTcutoff'_year2 
   ren pet_year3   		pet`DISTcutoff'_year3
   ren bpov_year2  		b`DISTcutoff'pov_year2
   ren bpov_year3  		b`DISTcutoff'pov_year3
   ren pEV_year2  		pEV`DISTcutoff'_year2
   ren pEV_year3   		pEV`DISTcutoff'_year3
 
   } 
   }
 
 ** Output
  # d;
   esttab using "$outputs_raw/Tables/$output_name.csv", replace 
   title(${title})	depvars  label nogaps  
   coeflabels(d_ct_nct_inel_2_year2 "CT in CT villages Midline[A]"
              d_ct_nct_inel_2_year3 "CT in CT villages Endline[B]"
			  d_ct_nct_inel_1_year2 "NCT in CT villages Midline[C]"
              d_ct_nct_inel_1_year3 "NCT in CT villages Endline[D]"
              pet_year2    "PET Midline[E]"
			  pet_year3    "PET Endline[F]"			  
			  pEV_year2    "PEV Midline[G]"
			  pEV_year3    "PEV Endline[H]"
			  bpov_year2   "#HH Midline[I]"
			  bpov_year3   "#HH Endline[J]"
			  d_year_2    "Midline[K]"   
			  d_year_3    "Endline[L]")
	order (d_ct_nct_inel_2_year2
              d_ct_nct_inel_2_year3
			  d_ct_nct_inel_1_year2 
              d_ct_nct_inel_1_year3
              pet_year2    
			  pet_year3    		  
			  pEV_year2   
			  pEV_year3    
			  bpov_year2   
			  bpov_year3   
			  d_year_2   
			  d_year_3 )		   
        drop ($controls)  
        stats(N  meters 
              mean_bl mean_f2 mean_f3 
			  pet_mean pev_mean bpov_mean sample, 
			  fmt(0 0 1 1 1 2 2 2 2 2 2 3 3 3 3 3)       
			  labels("Observations"  "Meters" 
			  "Mean pure control BL"
			  "Mean pure control Midline"
			  "Mean pure control Endline"
			  "CT recepients around (%)" 
			  "EVs around (%)" 
			  "HH around (#)"
			  "Sample")) 
     brackets plain  numbers 
     star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f);
   # d cr;
   
 
** EXPORTING ALL 
** -----------------------------------------------------------------------------
 * Drop store values	 
  eststo clear	 
  
** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_MainTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
 
* Clear Stored Estimates
  eststo clear 
 
 } 
 		
	
* ------------------------------------------------------------------------------	
* Elasticities
* ------------------------------------------------------------------------------		
if 1{
  * Load the Panel dataset 
    use  "$data/Final/FNLPDataLongAnalysis.dta", clear 
   
  * We need to drop those for which we do not have the outcome of interest
	keep if panel_sample==1
    keep if d_vuln_cat_1==1
	keep if FNLP_treatment==0	

 * Globals of controls and main variables 	
  # d;
	gl treat_2v	    d_ct_nct_inel_2_year2 
	                d_ct_nct_inel_2_year3   
				    d_ct_nct_inel_1_year2  
					d_ct_nct_inel_1_year3; 	
	gl spill_2v 	    pet400_year2   pet400_year3;  
	gl marketsize_2v   b400pov_year2  b400pov_year3;
	gl rel_poverty_2v  pEV400_year2   pEV400_year3;	
    gl controls_2v     d_lgacode_bl_1; 
	gl year_2v         d_year_2    d_year_3;	

  # d cr; 


    gl outcome_1    1
** Outcome 1 
********************************************************************************
if $outcome_1{  
* Coefficients to compute  elasticity
  local elas_coeff1      d_ct_nct_inel_2_year2  
  local elas_coeff2      d_ct_nct_inel_2_year3  
  local elas_coeff3      d_ct_nct_inel_1_year2  
  local elas_coeff4      d_ct_nct_inel_1_year3   
  local elas_coeff5      pet400_year2  
  local elas_coeff6      pet400_year3     
  
  local outcome  ihs_expen_7dae
   

**  FULL MODEL 
*** =========================================================================***
  gl xlist        $treat_2v $spill_2v $rel_poverty_2v $marketsize_2v $controls_2v $year_2v
  local spec_num  5
if 1{ 
** Regression code
   # d;
   eststo: acreg `outcome' $xlist,
		   time(year) id(hhid_panel) lag(3)
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(400) bartlett;
   # d cr; 		   
 
  * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
 
 ** Estimating elasticities
  * Coefficient 1
	disp ("/* Elasticity Coeff 1*/")  
	nlcom  exp(_b[`elas_coeff1'] - 0.5 * ((_se[`elas_coeff1'])^2)) - 1, post
	local elast_c1_out1= _b[_nl_1]
    local elast_c1_out1S`spec_num'=round(`elast_c1_out1', 0.01)
	 	 
  * Coefficient 2 
    estimates restore _temp_reg	 
	disp ("/* Elasticity Coeff 2*/")  
	nlcom  exp(_b[`elas_coeff2'] - 0.5 * ((_se[`elas_coeff2'])^2)) - 1, post
	local elast_c2_out1= _b[_nl_1]
    local elast_c2_out1S`spec_num'=round(`elast_c2_out1', 0.01)	
	
  * Coefficient 3 
    estimates restore _temp_reg	 	
	disp ("/* Elasticity Coeff 3*/")  
	nlcom  exp(_b[`elas_coeff3'] - 0.5 * ((_se[`elas_coeff3'])^2)) - 1, post
	local elast_c3_out1= _b[_nl_1]
    local elast_c3_out1S`spec_num'=round(`elast_c3_out1', 0.01)
	 
  * Coefficient 4
    estimates restore _temp_reg	 	 
	disp ("/* Elasticity Coeff 4*/")  
	nlcom  exp(_b[`elas_coeff4'] - 0.5 * ((_se[`elas_coeff4'])^2)) - 1, post
	local elast_c4_out1= _b[_nl_1]
    local elast_c4_out1S`spec_num'=round(`elast_c4_out1', 0.01)		
	
	
  * Coefficient 5
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 5*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff5'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff5']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_5= _b[_nl_1]		
	local elast_c5_out1= _b[_nl_1]
    local elast_c5_out1S`spec_num'=round(`elast_c5_out1', 0.01)		
	
  * Coefficient 6
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 6*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff6'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff6']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_6= _b[_nl_1]		
	local elast_c6_out1= _b[_nl_1]
    local elast_c6_out1S`spec_num'=round(`elast_c6_out1', 0.01)		

  }
	
**  RDD MODEL 
*** =========================================================================***
  gl xlist        $treat_2v $spill_2v $rel_poverty_2v $marketsize_2v $controls_2v $year_2v
  local spec_num  6  
** Regression code
if 1{ 
   # d;
   eststo: acreg `outcome' $xlist if RDD_18==1 [pweight=ipw],
		   time(year) id(hhid_panel) lag(3)
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(400) bartlett;
   # d cr; 		   
 
 * Saving estimates so we can compute nonlinear coefficients 
    estimates store _temp_reg
	
 ** Estimating elasticities
  * Coefficient 1
	disp ("/* Elasticity Coeff 1*/")  
	nlcom  exp(_b[`elas_coeff1'] - 0.5 * ((_se[`elas_coeff1'])^2)) - 1, post
	local elast_c1_out1= _b[_nl_1]
    local elast_c1_out1S`spec_num'=round(`elast_c1_out1', 0.01)
	 
  * Coefficient 2 
    estimates restore _temp_reg	 	 
	disp ("/* Elasticity Coeff 2*/")  
	nlcom  exp(_b[`elas_coeff2'] - 0.5 * ((_se[`elas_coeff2'])^2)) - 1, post
	local elast_c2_out1= _b[_nl_1]
    local elast_c2_out1S`spec_num'=round(`elast_c2_out1', 0.01)	
	
  * Coefficient 3 
    estimates restore _temp_reg	 	
	disp ("/* Elasticity Coeff 3*/")  
	nlcom  exp(_b[`elas_coeff3'] - 0.5 * ((_se[`elas_coeff3'])^2)) - 1, post
	local elast_c3_out1= _b[_nl_1]
    local elast_c3_out1S`spec_num'=round(`elast_c3_out1', 0.01)
	 
  * Coefficient 4 
    estimates restore _temp_reg	 	 
	disp ("/* Elasticity Coeff 4*/")  
	nlcom  exp(_b[`elas_coeff4'] - 0.5 * ((_se[`elas_coeff4'])^2)) - 1, post
	local elast_c4_out1= _b[_nl_1]
    local elast_c4_out1S`spec_num'=round(`elast_c4_out1', 0.01)		
	
  * Coefficient 5
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 5*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff5'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff5']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_5= _b[_nl_1]		
	local elast_c5_out1= _b[_nl_1]
    local elast_c5_out1S`spec_num'=round(`elast_c5_out1', 0.01)		
	
  * Coefficient 6
    estimates restore _temp_reg	 	   
	disp ("/* Elasticity Coeff 6*/")  
    // Outcome mean 
	sum `outcome' 
	local ybar=r(mean)	
	// X variables mean  	
	sum   `elas_coeff6'
	local  xbar1=r(mean)	
	// Perform the nlcom estimation	
    nlcom _b[ `elas_coeff6']*`xbar1'*((sqrt(`ybar'^2 + 1))/`ybar'), post 		
	local elast_6= _b[_nl_1]		
	local elast_c6_out1= _b[_nl_1]
    local elast_c6_out1S`spec_num'=round(`elast_c6_out1', 0.01)		
	
	
	
	
	
  }
	
}	
	
** Exporting to unique file 
** -----------------------------------------------------------------------------	
if 1{
 * Date:	
   local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
   disp "`svdate'" 	

  * Output and name
    gl sheet_name "T4_FoodSecurityConsump_Elast"
	
  * Exporting the file 	
  # d;
    putexcel set "$outputs_final/CashIsQueen_MainTables_`svdate'.xlsx", 
	             sheet("$sheet_name") modify;
				 
	putexcel A1=("Elasticities - Adjustment following Bellemare and Wichman (2020)")
            
			 A4=("CT in CT villages Midline[A]")
             A5=("CT in CT villages Endline[B]") 
             A6=("NCT in CT villages Midline[C]")
             A7=("NCT in CT villages Endline[D]")   
             A8=("PET Midline[E]")
             A9=("PET Endline[F]")   			 
			 		 
			 C3=("Full")
			 E3=("RDD 18");
			 
	putexcel
			 
             C4=(`elast_c1_out1S5')  
	         C5=(`elast_c2_out1S5')                   
	         C6=(`elast_c3_out1S5')  
			 C7=(`elast_c4_out1S5')
	         C8=(`elast_c5_out1S5')  
			 C9=(`elast_c6_out1S5')			 
			 
             E4=(`elast_c1_out1S6')  
	         E5=(`elast_c2_out1S6')                   
	         E6=(`elast_c3_out1S6')  
			 E7=(`elast_c4_out1S6')
	         E8=(`elast_c5_out1S6')  
			 E9=(`elast_c6_out1S6');  
			 
* Merge cells B2 and C2 and center the text "Business Profits"
  putexcel B2:C2=matrix(1), merge;			 
			 
	putexcel clear;
   # d cr;		

* Clear Stored Estimates
  eststo clear   
   
   
} 


	
	
	
	
	
	
}	
	
	
}	
	
*** =========================================================================***
*   Table 5: Women's Empowerment and Decision-Making Power
*** =========================================================================***
if (`table_5' == 1) {
	
* ------------------------------------------------------------------------------	
* Main Regression Results 
* ------------------------------------------------------------------------------	
if 1{	
* Load Data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", clear

* Sample if Analysis (Extreme vulnerables, NonFNLP Panel Sample)
  keep if d_vuln_cat_1==1 
  keep if FNLP_treatment==0
  keep if d_wavail_f2==1 & d_wavail_f3==1
  
 * Format 	
  gl title " Impact on economic empowerment and decision making"	
  gl output_name "T5_WomenEmpowermentDM"
   
* Setting up locals for distances  
  local meters  400 
  local met_cut 0.4
   
** -----------------------------------------------------------------------------
*  Outcomes Endline PRO- WEIA 
** ------------------------------------------------------------------------------ 
 gl    outcomes_f3   proweia2_aindex_w_f3
 gl    controls2     weai_new_bl_w 
 local time          d_wavail_f3
if 1{
** Spillovers+ Market Size 
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls}  ${controls2}  if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

}

** -----------------------------------------------------------------------------
*  Outcomes Endline Decision Making 
** ------------------------------------------------------------------------------ 
 gl outcomes_f3   $dm_var_w
 gl controls2     dm_index_w_bl
 local time       d_wavail_f3
if 1{

** Spillovers+ Market Size 
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} ${controls2}  if `time'==1, 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "Full Sample (CTs and NCTs) in Program Villages"   
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

}


  
** -----------------------------------------------------------------------------
*  Outcomes Endline PRO- WEIA RDD
** ------------------------------------------------------------------------------ 
 gl    outcomes_f3   proweia2_aindex_w_f3
 gl    controls2     weai_new_bl_w 
 local time          d_wavail_f3
if 1{

** Spillovers+ Market Size +RDD
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
 local condition RDD_18
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} ${controls2}  if `time'==1 
           & `condition'==1 [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

}
  
  
** -----------------------------------------------------------------------------
*  Outcomes Endline Decision Making 
** ------------------------------------------------------------------------------ 
 gl outcomes_f3   $dm_var_w
 gl controls2     dm_index_w_bl
 local time       d_wavail_f3
if 1{


** Spillovers+ Market Size + RDD
** -----------------------------------------------------------------------------
 gl xlist1 $treatB $spillB $rel_povertyB $marketsizeB
 local condition RDD_18
foreach outcome of varlist $outcomes_f3{ 
	foreach i in 1{
	local   number: word `i' of `meters'
	local   distcut: word `i' of `met_cut' 
	
 * Renaming variables so output looks better	  
    ren  d_ct_nct_inel_2_m`number' d_ct_nct_inel_2_m
    ren pet`number'          pet
    ren pEV`number'          pEV
	ren b`number'pov         bpov	
	ren CT_PET`number'       CT_PET
	ren CT_HH`number'        CT_HH
	ren CT_PEV`number'       CT_PEV		
 
 * Regression 	 
   # d;
   eststo: acreg `outcome' ${xlist1} ${controls} ${controls2}  if `time'==1
           & `condition'==1 [pweight=ipw], 
           spatial latitude(gps_latitude_final) 
		   longitude(gps_longitude_final) dist(`distcut') bartlett;
   # d cr; 		   
  
	
 * Stats 
	sum `outcome'   if e(sample) & d_ct_nct_inel_3==1
	estadd scalar  mean=r(mean)
	sum    pet if e(sample)
	estadd scalar  pet_mean=r(mean)
	sum    pEV if e(sample)
	estadd scalar  pev_mean=r(mean)	
	sum    bpov if e(sample)
	estadd scalar  bpov_mean=r(mean)
	
  	estadd scalar meters=`number'  
	estadd local sample "RDD 18 (CTs and NCTs) in Program Villages"
	
 * Renaming 	
 	ren  CT_PET             CT_PET`number' 
	ren  CT_HH              CT_HH`number' 
	ren  CT_PEV		        CT_PEV`number' 
    ren  pet 				pet`number'  
    ren  pEV 				pEV`number' 
	ren  bpov				b`number'pov   
	ren  d_ct_nct_inel_2_m  d_ct_nct_inel_2_m`number'
	}

	
	
}	

}
  
  
  
  
  
  * Output 
  # d
	esttab using "$outputs_raw/Tables/$output_name.csv",                             
			  title("$title") 
			  coeflabels(
			  d_ct_nct_inel_2 "CT in CT villages [A]"
			  d_ct_nct_inel_1 "NCT in CT villages [B]" 
	          pet    "PET[C]" 
	          pEV    "PEV[D]" 
	          bpov   "#HH[E]")
			  order (d_ct_nct_inel_2 d_ct_nct_inel_1 pet pEV bpov)
			  drop(${controls} weai_new_bl_w  dm_index_w_bl) 
			   stats(N r2 meters mean
			   pet_mean pev_mean bpov_mean sample, 
			  fmt(0 2 0 2 2 2 2 2 2 2 2 2 2 2 2 2 2 2)       
			  labels("Observations" "Adjusted R-squared" "Meters" 
              "Outcome Mean Pure Control"
			  "Average CT recepients around (%)" 
			  "Average EVs around (%)" 
			  "Average HH around(#)"
			  "SAMPLE")) 
			  label  brackets plain  numbers depvars  
			  star(* 0.1 ** 0.05 *** 0.01)   b(%9.2f) se(%9.2f)        
			  replace;
  # d cr;			  
* Drop store values	 
  eststo clear	

** Exporting to unique file 
** ------------------------------------------
 * Date:	
    local svdate: di %tdCCYYNNDD daily("$S_DATE", "DMY")
    disp "`svdate'" 
   				   
	preserve 
	* Import table from csv
	import delimited "$outputs_raw/Tables/$output_name.csv", ///
	clear delimiter(comma)
	

	* Exporting into common file 
	export excel using "$outputs_final/CashIsQueen_MainTables_`svdate'.xlsx", ///
				 sheet("$output_name", modify) 
	restore
	
* Clear Stored Estimates
  eststo clear	
	
}	
		

}			
	
	
	
	
***=============================================================================
/// END OF DOFILE 