* ******************************************************************************
* NIGERIA Feed the Future - ENDLINE 2025
* Data Cleaning and Construction: Part A
* ******************************************************************************
local part_A1 1    // Household Dataset Preparation
local part_A2 1    // Main Variables from Project


** =============================================================================
*  A1. HOUSEHOLD DATASET PREPARATION 
** =============================================================================
if `part_A1'{
* 1. Load Household-Level Dataset
* -----------------------------------------------------------------------------*
  use "$data/Raw/FNLP_HouseholdFullData.dta", clear

* 2. Process Individual_Sections
* -----------------------------------------------------------------------------*

	* 2.1 Household Roster Variables
	do "$dofiles/Intermediate/Individual_Sections/Roster_Core.do" 

	* 2.2 Social Norms and Livestock
	do "$dofiles/Intermediate/Individual_Sections/Norms_LivestockVars.do"

	* 2.3 Business, Savings, and Income
	do "$dofiles/Intermediate/Individual_Sections/Business_IncSav.do"

	* 2.4 Food Security and Consumption
	do "$dofiles/Intermediate/Individual_Sections/FoodSecurity_Consumption.do"

	* 2.5 Agricultural Outcomes
	do "$dofiles/Intermediate/Individual_Sections/Plot_Roster.do"
	do "$dofiles/Intermediate/Individual_Sections/Input_and_labor_use.do"
	do "$dofiles/Intermediate/Individual_Sections/Extension_services.do"
	do "$dofiles/Intermediate/Individual_Sections/Crop_Roster.do"

	* 2.6 Child Health Outcomes
	do "$dofiles/Intermediate/Individual_Sections/ChildNutrition.do"

	* 2.7 Savings and Loans
	do "$dofiles/Intermediate/Individual_Sections/Saving_and_loans.do"
	
* 3. Additional Variable Cleaning
* -----------------------------------------------------------------------------*
if 1{
    recode  gen_9 gen_10 gen_11 gen_12 gen_13 gen_14 (3=.d) (2=0)
	gen     just_viol_pub=(gen_10==1 | gen_11==1)
    replace just_viol_pub=. if gen_10>=. | gen_11>=.
	la var  just_viol_pub "Justify violence public goods"
	
	gen     just_viol_priv=(gen_9==1 | gen_13==1 | gen_14==1)
    replace just_viol_priv=. if gen_9>=. | gen_13>=.	| gen_14>=.
	la var  just_viol_priv "Justify violence private goods"
	
	foreach number in 9 10 11 12 13 14{
	clonevar jviol_`number'=gen_`number'
	}
	
  * Aspirations
    do "$dofiles\Intermediate\Individual_Sections/CodingAspirations.do"
    gen asp_daug=. 
    replace asp_daug=1 if gen_16==1
    replace asp_daug=2 if gen_16==2
    replace asp_daug=3 if gen_16>=3 & gen_16<=6
	replace asp_daug=4 if gen_16==7
	replace asp_daug=5 if gen_16==9
	replace asp_daug=6 if gen_16==8	

    gen asp_son=. 
    replace asp_son=1 if gen_17==1
    replace asp_son=2 if gen_17==2
    replace asp_son=3 if gen_17>=3 & gen_17<=6
	replace asp_son=4 if gen_17==7
	replace asp_son=5 if gen_17==9
	replace asp_son=6 if gen_17==8	
	
	la def  asp   1 "Family farming" 2 "Run family business" ///
					3 "Professional Job(government,private sector)" ///
					4 "Dont work outside home" 5 "Married" 6 "Other", modify 
	la val  asp_daug asp_son asp 
	tab asp_daug, gen (d_asp_daug_)
	tab asp_son, gen (d_asp_son_)	
	
	
	
  * Gender eq norms 
    clonevar shame_husbhhwork=gen_32
	//recode   shame_husbhhwork  (5=1) (4=2) (3=3) (2=4)  (1=5)
	clonevar tol_viol=gen_33
	//recode   tol_viol  (5=1) (4=2) (3=3) (2=4)  (1=5)
	clonevar obey_husb=gen_34
	//recode   obey_husb (5=1) (4=2) (3=3) (2=4)  (1=5)	
	clonevar menwom_rights=gen_35
	//recode   menwom_rights (5=1) (4=2) (3=3) (2=4)  (1=5)
	clonevar womreso=gen_36
	//recode   womreso (5=1) (4=2) (3=3) (2=4)  (1=5)
	clonevar viol_priv=gen_37
	//recode   viol_priv (5=1) (4=2) (3=3) (2=4)  (1=5)	
	clonevar womenleaves=gen_38
	//recode   womenleaves (5=1) (4=2) (3=3) (2=4)  (1=5)		
	la def   agreement 1 "Strongly disagree" 2 "Disagree" 3 "Neither" ///
					 4 "Agree" 5"Strongly agree", modify 
	la val shame_husbhhwork-womenleaves agreement
	
   * Life satisfaction & happiness
	 recode happ_12_1 happ_12_2 (4=1) (3=2) (2=3) (1=4)
	 foreach num in 7 8 9 10 14 16 17{
	 recode   happ_12_`num' (5=1) (4=2) (3=3) (2=4)  (1=5)	
	 }
	 
	 
	* Decision Making 
	recode share_money_2 (4=6) (5=6)
	recode share_money_4 (4=6) (5=6)
    tab    share_money_2, gen (d_sharemoney2_)
	tab    share_money_4, gen (d_sharemoney4_)
	gl ds_var adequate_prod_5 adequate_income_5 adequate_income_1 ///
	          female_plotown fem_borrow adequate_prod_6 fem_assetsale 
	recode $ds_var (.=0)
	
  # d;	
   gl share_var  
			  share_myself_ngo share_spouse_ngo 
			  share_children_ngo share_friends_in_ngo 
			  share_friends_out_ngo share_myself_relative 
			  share_spouse_relative share_children_relative
			  share_friends_in_relative share_friends_out_relative;
   # d cr; 			  
	
   foreach var of varlist $share_var{
   clonevar  `var'_w=`var'  if  inf_1_5==1 & time==2 
   clonevar  `var'_h=`var'  if  inf_1_5==2 & time==2 
   }		
   
  
	
	
	# d;
	gl dm_indicators fem_plotdecisions       fem_earningsdecisions 
	                 fem_enterprisedecisions fem_landrentdecisions 
					 fem_borrowdecisions     fem_cropusedecisions 
					 fem_assetsale; 

    gl proweia_ind adequacy_input_prod adequacy_input_income adequacy_own_assets 
	               fem_assetsale fem_borrow groupmember_any adequacy_workload
				   adequacy_inc_satisfaction adequacy_attitude_viol 
				   adequacy_autonomy_inc adequacy_selfeff adequacy_respect;
	# d cr;
	
	foreach var in  $dm_indicators{
	gen `var'_w_bl=`var'_bl  if time==2 & inf_1_5==1
	}
	
	foreach var of varlist $proweia_ind{
	gen `var'_w_f3=`var'  if time==2 & inf_1_5==1
	}
	
    gen  dm2_aindex_w_bl=dm_aindex_bl  if time==1 & inf_1_5==1
	gen  dm2_aindex_w_f3=dm_aindex_f3  if time==2 & inf_1_5==1
	gen  proweia2_aindex_w_f3=proweia_aindex  if time==2 & inf_1_5==1	

	
	* Drop winsor variables because those are wins at the panel level 
	drop  w_current_value_*        w_cash_savings
	ren  current_value_animals     value_animals
	ren  current_value_farmassets  value_farmassets
	ren  current_value_hhassets    value_hhassets
    gen  school_mother_bl_w=school_mother if inf_1_5==1
    gen  school_mother_bl_h=school_mother if inf_1_5==2
	
	
	/** Time in farming and other activities
	This was moved to be done before opening the dataset to allow the data to be shared in an unidentifiable form
	gen      farming_work_bl_w = 1 if labor_12_1_bl==1 & fam_name1_bl==female_name
	replace  farming_work_bl_w = 1 if labor_12_2_bl==1 & fam_name2_bl==female_name
	replace  farming_work_bl_w = 1 if labor_13_1_bl==1 & fam_name1_bl==female_name & farming_work_bl_w==.
	replace  farming_work_bl_w = 1 if labor_13_2_bl==1 & fam_name2_bl==female_name & farming_work_bl_w==.
	recode   farming_work_bl_w  (.=0)*/
	
	**Worked in a farm business at baseline MEN?
	gen     farming_work_bl_m = 1 if labor_12_1_bl==1 & labor_1_1_bl==male_respondent_bl
	replace farming_work_bl_m = 1 if labor_12_2_bl==1 & labor_1_2_bl==male_respondent_bl
	replace farming_work_bl_m = 1 if labor_13_1_bl==1 & labor_1_1_bl==male_respondent_bl & farming_work_bl_m==.
	replace farming_work_bl_m = 1 if labor_13_2_bl==1 & labor_1_2_bl==male_respondent_bl & farming_work_bl_m==.

	bys hhid: egen farming_work_bl_h = max(farming_work_bl_m)
	recode farming_work_bl_h (.=0)
	la var farming_work_bl_h  "Male reported farming activity in past 30days BL"
    drop   farming_work_bl_m 
	tab    farm_size_bl, gen(d_farm_size_bl_)
	
	gen    noland_bl_t=noland_bl if inf_1_5==2
	bys    hhid: egen d_hhnoland_bl=max(noland_bl_t)
	la var d_hhnoland_bl "Household reported no land at baseline"	
	
   // time_1 time_9_bl		
   la var time_1  "Time spend asleep"
   la var time_2  "Time spend on care for others (children, ill household members)"
   la var time_3  "Time spend on domestic tasks"
   la var time_4  "Time spend onasks on non-farm business activities"
   la var time_5  "Paid (remunerated) work or activities outside of household"
   la var time_6  "Tasks on family farm, home garden, cattle herding"
   la var time_7  "hopping or getting services (including health services)" 
   la var time_8  "Prayer"
   la var time_9  "Leisure (includes self-care and hobbies)"
   la var time_10  "In the last 24 hours, did you do any work"
   
  * Checking variables to analyze 
	foreach var of varlist time_? time_??{
	gen `var'_f3_w=`var'  if time==2 & inf_1_5==1
	gen `var'_f3_h=`var'  if time==2 & inf_1_5==2
	 }
 
  * Checking variables to analyze 
	foreach var of varlist w_number_anim* w_number_farm*  value_* WeightedVar* ///
                           farming_work{
	gen `var'_fup2_w=`var'  if time==1 & inf_1_5==1
	gen `var'_fup3_w=`var'  if time==2 & inf_1_5==1
	
	gen `var'_fup2_h=`var'  if time==1 & inf_1_5==2
	gen `var'_fup3_h=`var'  if time==2 & inf_1_5==2
	 }

  * Generating availability var of women and men per wave. 
	recode inf_1_1b (2=0)
	gen     d_wavail_f2=(inf_1_1b==1) if inf_1_5==1 & time==1
	replace d_wavail_f2=0 if d_wavail_f2==. & inf_1_5==1 
	gen     d_mavail_f2=(inf_1_1b==1) if inf_1_5==2 & time==1
	replace d_mavail_f2=0 if d_mavail_f2==. & inf_1_5==2
	
	gen     d_wavail_f3=(inf_1_1b==1) if inf_1_5==1 & time==2
	replace d_wavail_f3=0 if d_wavail_f3==. & inf_1_5==1 
	
	gen     d_mavail_f3=(inf_1_1b==1) if inf_1_5==2 & time==2	
	replace d_mavail_f3=0 if d_mavail_f3==. & inf_1_5==2
	

	foreach var of varlist daily_adulteq_expenses      ///
						   HDDS emo_vio phys_vio sex_vio                      ///
						   daily_percapita_expenses daily_hh_expenses {
	bysort hhid: egen `var'_f2=max(`var') if time==1 & inf_1_5==1
	bysort hhid: egen `var'_f3=max(`var') if time==2 & inf_1_5==1
    }
    drop w_daily_adulteq_expenses       w_daily_adulteq_expenses_2 

	
  * Decision Making 
  	foreach var of varlist $ds_var{
    bysort hhid: egen `var'_f3=max(`var') if time==2 & inf_1_5==1
    }
	foreach var of varlist just_viol_pub just_viol_priv ///
	                       jviol_* ///
						   d_asp_daug_1-womenleaves ///
						   d_sharemoney2_? d_sharemoney4_? ///
						   happ_12_1 happ_12_2 ///
						   happ_12_7 happ_12_8 happ_12_9 happ_12_10   ///
						   happ_12_13 happ_12_14 happ_12_15 ///
						   happ_12_16 happ_12_17 happ_12_19 {
    bysort hhid: egen `var'_w_f3=max(`var') if time==2 & inf_1_5==1
	bysort hhid: egen `var'_h_f3=max(`var') if time==2 & inf_1_5==2
    }
	

    * Generating some real expenditures
	 /*Note: To change to real prices we are going to use CPI prices from
	   https://tradingeconomics.com/nigeria/consumer-price-index-cpi
	   Baseline 2015  173.2
	   April 2017 226.3 --> 1.307
	   May 2018 257.3   --> 1.486
	   */
	  gen daily_ae_expreal_bl=daily_adulteq_expenses_bl
	  gen daily_ae_expreal_f2=daily_adulteq_expenses_f2/1.307  
	  gen daily_ae_expreal_f3=daily_adulteq_expenses_f3/1.486
	  
 
      foreach var of varlist exp_ttlnonfood_7dae_f2  exp_ttlfood_7dae_f2 /// 
	                         exp_ttlconfood_7dae_f2 {
		 gen r_`var'=`var'/1.307	
		
	  } 
	  
	  
	  foreach var of varlist  exp_ttlnonfood_7dae_f3  exp_ttlfood_7dae_f3    ///
							  exp_ttlconfood_7dae_f3{
	  gen r_`var'=`var'/1.486
	  }

	  * We dont change to real terms the baseline 
	  gen r_exp_ttlconfood_7dae_bl=exp_ttlconfood_7dae	  
	  gen r_exp_ttlfood_7dae_bl=exp_ttlfood_7dae_bl
	  gen r_exp_ttlnonfood_7dae_bl=exp_ttlnonfood_7dae_bl	  
	  
	  gen  daily_hh_realexp_f2=daily_hh_expenses_f2/1.307
	  gen  daily_hh_realexp_f3=daily_hh_expenses_f3/1.486
      gen  daily_hh_realexp_bl=daily_hh_expenses_bl
	  
    * Winsoring variables 
	foreach var of varlist daily_ae_expreal_* ///
	                       daily_hh_expenses_*  daily_percapita_expenses_* ///
						   daily_adulteq_expenses_*   exp_ttlnonfood_7dae_* ///
						   exp_ttlfood_7dae_*	  exp_ttlconfood_7dae_* ///
						   r_exp_ttlnonfood_7dae_* ///
						   r_exp_ttlfood_7dae_*	   r_exp_ttlconfood_7dae_* ///
                           daily_hh_realexp_*{ 
	winsor `var', gen (w_`var') p (0.05)
	ihstrans `var'
	}

	
   * Prices of main animals 
	gen goat_price_f2 = anim_5_9_501/anim_5_8_501    if time==1 
	gen chicken_price_f2 = anim_5_9_502/anim_5_8_502 if time==1 
	gen sheep_price_f2 = anim_5_9_503/anim_5_8_503   if time==1
	
	gen goat_price_f3 = anim_5_9_501/anim_5_8_501    if time==2
	gen chicken_price_f3 = anim_5_9_502/anim_5_8_502 if time==2 
	gen sheep_price_f3 = anim_5_9_503/anim_5_8_503   if time==2
	
	egen ttl_food_exp_f2=rowtotal(fs_3_3_*) if time==1 
	egen ttl_food_exp_f3=rowtotal(fs_3_3_*) if time==2
	
	foreach var of varlist goat_price_f2 chicken_price_f2 sheep_price_f2     ///
						   goat_price_f3 chicken_price_f3 sheep_price_f3     ///
						   ttl_food_exp_f2 ttl_food_exp_f3{
	winsor `var', gen(w_`var') p(0.01)
	}	
	
	* Generating variables related to business
	split new_act_1_19b,  gen(d_sourcmtemp_)
	destring d_sourcmtemp_*, replace
	forval source=1/6{
	egen d_sourcemonbuss_`source'=anymatch (d_sourcmtemp_*), value(`source')
	}
    
	drop d_sourcmtemp_*
	
	egen    num_sourcemonbuss=rowtotal(d_sourcemonbuss_*)
	la var  num_sourcemonbuss "Number of source use to start a business"
	sum     num_sourcemonbuss
	
	gen    bus_years_f2_w=2018-year_bus_fup2_w
	gen    bus_years_f2_h=2018-year_bus_fup2_h
	gen    bus_years_f3_w=2018-year_bus_fup3_w
	gen    bus_years_f3_h=2018-year_bus_fup3_h
	
	** Running dofiles that Clean producst classification  
	** ----------------------------------------------------------------------------
	* Initial coding of products 
	do "$dofiles/Intermediate/Individual_Sections/CodingBusinessProducts.do"

	** Categorizing products  in more general categories 
	** -----------------------------------------------------------------------------
	/*Note: First we use the primary activity that they report, then we clean 
	according to the products they produce. For the cetegories of     
	selling and other we need to be more specific */
	gen primary_act_gcat=.    

	** First we use the primary activity 
	** -----------------------------------------------------------------------------
	// If cake processing, cook or frying ankara   
	replace primary_act_gcat=1 if  inlist(new_act_non_farming, 1, 8 ,9)  
	// If oil processing    
	replace primary_act_gcat=2 if  new_act_non_farming==2
	// If Rice processing    
	replace primary_act_gcat=3 if  new_act_non_farming==5
	// If Petty trading    
	replace primary_act_gcat=4 if  new_act_non_farming==4  
	// If Tailor or builder carpinter    
	replace primary_act_gcat=5 if  inlist(new_act_non_farming, 7, 10)

	* Second,we use the grl products which are more specific & the other category
	* -----------------------------------------------------------------------------
	/* Note PG: For the moment we focus on product 1 but they can report up to 7*/
	* Replacing using second coding of products but household items 
	replace primary_act_gcat=product_cat_v2 if  primary_act_gcat==.             ///
	        & product_cat_v2!=7
	* Replacing using the second coding for specific household items 
	replace primary_act_gcat=4 if product_cat_v2==7 & new_act_non_farming!=7	
	replace primary_act_gcat=5 if product_cat_v2==7 & new_act_non_farming==7    ///
									 | new_act_non_farming==10 
	* Cook  
	replace primary_act_gcat=1                                                  ///
	if inlist(product_cat_1,"bean cake (akara)", "cake (general)", 				///
		 "food", "fura (millet drink)", "groundnut cake (kuli kuli)",   		///
		 "rice cake (masa)", "soybean cake (awara)") & 	primary_act_gcat==.	 
	* Oil Proccesing 					 
	replace primary_act_gcat=2 if inlist(product_cat_1, "groundnut", "oil") 	///
	        & primary_act_gcat==.	 	
	* Crops Processing		   
	replace primary_act_gcat=3                                                  ///
	if  inlist(product_cat_1,"beans","crops (processing)",        				///
			"locust bean seeds (dadawa)",  "millet",            				///
			"rice", "maize/guinea corn (sorghum)") & 	primary_act_gcat==.	 
	* Trader								  
	replace primary_act_gcat=4                                                  ///
	if inlist(product_cat_1, "animal feed", "colanut",            				///
		   "dairy", "maggi (seasoning)/salt", "meat",           				///
		   "spices", "firewood","produce (vegetables/fruit)")   				///
		   & 	primary_act_gcat==.	 
	replace primary_act_gcat=4                                                  ///
			if new_act_non_farming==6 & product_cat_1=="" &						///
			primary_act_gcat==.	 
	replace primary_act_gcat=4 if new_act_non_farming==11 & product_cat_1=="" & ///
	        primary_act_gcat==.	 
	* Services 	
	replace primary_act_gcat=5                                                  ///
			if inlist(product_cat_1,"carpentry/building", "clothes",            ///
			"electrical","livestock","mat", "money","transportation", 			///
			"tailoring")  & 	primary_act_gcat==.	  	
	* Other: We can still re code some of this 
	// Replacing by other category if we are still missing classification but
	// they report an economic activity 
	replace primary_act_gcat=6 if primary_act_gcat==. & new_act_non_farming!=. 
	replace primary_act_gcat=6 if primary_act_gcat==. & business_work_new_bl==1
	replace primary_act_gcat=6 if new_act_non_farming==13 & business_work_new_bl==1
	// We replace by nothing if they did not report activity at all 
	replace primary_act_gcat=0 if business_work==0
	replace primary_act_gcat=0 if new_act_non_farming==13 & business_work_new_bl==0 &  ///
			primary_act_gcat==.
	la def primary_act_gcat 1 "Cook"    2 "Oil processing"  3 "Crops processing" ///  
			4 "Trader"  5 "Services"        0 "None"             ///
			6 "Other", modify 
	la val primary_act_gcat primary_act_gcat

	tab primary_act_gcat if new_act_non_farming!=., m 

	forval i=1/7{   
	gen temp`i'=1 if product_cat_`i'!=""
	}
	egen     num_products=rowtotal(temp1-temp7)
	la var   num_products "Number of products"
	drop temp*
    
	gl buss_var d_sourcemonbuss_* num_sourcemonbuss d_locationbuss_* ///
	              rawmats_business
	foreach var of varlist $buss_var{
	gen `var'_fup2_w=`var' if time==1 & inf_1_5==1
	gen `var'_fup2_h=`var' if time==1 & inf_1_5==2	
	gen `var'_fup3_w=`var' if time==2 & inf_1_5==1
	gen `var'_fup3_h=`var' if time==2 & inf_1_5==2		
	}

	gen  hh_income_w_f2=hh_income_w if time==1
	gen  hh_income_h_f2=hh_income_h if time==1
	gen  hh_income_w_f3=hh_income_w if time==2
	gen  hh_income_h_f3=hh_income_h if time==2
	
	gen  dm_index_bl_new_w=decisionmaking_index_bl_new if inf_1_5==1
	gen  dm_index_fup3_w=decisionmaking_index if inf_1_5==1	
	gen  proweai_sum_ind_w=proweai_sum_indicators if inf_1_5==1		
	gen  weai_new_bl_w=weai_new_bl if inf_1_5==1
	
	
	** Generating New variables per round:
	** ----------------------------------------------------------------------------
	gen      primary_act_fup2=primary_act_gcat   if time==1 & inf_1_5==1
	gen      primary_act_fup3=primary_act_gcat   if time==2 & inf_1_5==1
	gen      primary_act_fup2_h=primary_act_gcat if time==1 & inf_1_5==2
	gen      primary_act_fup3_h=primary_act_gcat if time==2 & inf_1_5==2
	gen      comm_norm_worsewife = 1 if gen_22==1 & gen_22!=.
	recode   comm_norm_worsewife (.=0) if gen_22!=.
	gen      comm_norm_worseindf = 1 if gen_22==2 & gen_22!=.
	recode   comm_norm_worseindf (.=0) if gen_22!=.
	
	 ren selfesteem   selfest
	 ren conformist   conf
	 ren independence indep
	 ren underweight_bmi_resp underw_bmi
	 ren w_bmi_resp	 w_bmi
	
	gl weia  aggregate_prod jv_any selfeff female_plotown female_own_assets 	///
			 fem_assetsale fem_borrow aggregate_income aggregate_time 			///
			 speakpublic_any groupmember_any dm_index_fup3_w ///
			 proweai_sum_ind_w 
			 
	gl norms norms_women_not_go_work      comm_norm_woman_fields 				///
			 comm_norm_male_bad_provider  comm_norm_woman_travelsout 			///
			 comm_norm_worsehusband       comm_norm_worsewife                   ///
			 comm_norm_worseindf          gender_equity_norm      				///
			 jv_any selfeff 			  aggregate_income						///
			 aggregate_time
			 
	gl other selfest conf indep	 w_bmi underw_bmi
			 
	foreach var of varlist $weia{
	replace `var'=. if time!=2
	}
	foreach var of varlist $norms  {
	gen w_`var'=`var' if inf_1_5==1
	gen h_`var'=`var' if inf_1_5==2
	}

	
	foreach var of varlist $other{
	gen `var'_w=`var' if inf_1_5==1
	gen `var'_h=`var' if inf_1_5==2
	}
	

	
	
	gen     mother_worked_w=mother_worked if inf_1_5==1
	gen     mother_workedent_w=(mother_occ==3) 
	replace mother_workedent_w=. if  inf_1_5==0
	replace mother_workedent_w=. if  mother_occ>=.
	replace econ_fem_activity_bl=. if inf_1_5==2
	
	
	ren ttl_hh_loans_fup2_w ttl_hh_loans_w_f2 
	ren ttl_hh_loans_fup2_h ttl_hh_loans_h_f2 
	ren ttl_hh_loans_fup3_w ttl_hh_loans_w_f3
	ren ttl_hh_loans_fup3_h ttl_hh_loans_h_f3 
	
** GPS information Cleaning
** ---------------------------------------------------------------------------------
	bysort hhid: egen gps_latitudemax_t0=max(gpslatitude_bl) if time==1
	bysort hhid: egen gps_latitudemax_t1=max(gps_startlatitude) if time==1
	bysort hhid: egen gps_latitudemax_t2=max(gps_startlatitude) if time==2
	
	bysort hhid: egen gps_longitudemax_t0=max(gpslongitude_bl) if time==1	
	bysort hhid: egen gps_longitudemax_t1=max(gps_startlongitude) if time==1
	bysort hhid: egen gps_longitudemax_t2=max(gps_startlongitude) if time==2		
	gl coordinates gps_latitudemax_* gps_longitudemax_*

    gen     no_gps=. 
	replace no_gps=1 if gps_latitudemax_t1!=. & gps_latitudemax_t2==.
	replace no_gps=2 if gps_latitudemax_t1==. & gps_latitudemax_t2!=.
	replace no_gps=3 if gps_latitudemax_t1!=. & gps_latitudemax_t2!=.
	replace no_gps=4 if gps_latitudemax_t1==. & gps_latitudemax_t2==.
	
	
    gen     diff_gps_blmid=. 
	replace diff_gps_blmid=(gps_latitudemax_t0!=gps_latitudemax_t1  & gps_longitudemax_t0!=gps_longitudemax_t1)
	replace diff_gps_blmid=. if gps_latitudemax_t0==. | gps_latitudemax_t1==. 
	
	gen     diff_gps_midend=. 
	replace diff_gps_midend=2 if gps_latitudemax_t1!=gps_latitudemax_t2  & gps_longitudemax_t1!=gps_longitudemax_t2
	replace diff_gps_midend=. if gps_latitudemax_t1==. | gps_latitudemax_t2==.
}
	
* 4. Collapsing so we have a crossection and Saving Processed Data 
* -----------------------------------------------------------------------------*
if 1{	
** Getting variables ready to collapse 
** ---------------------------------------------------------------------------------	
  # d ;
	gl controls1  	age_hhhead_bl    marital_status_bl_?       literacy_hhhead_bl  
					hhtype_bl               miss_*_bl           
					econ_fem_activity_bl 
					num_hh_members_bl num_enterprises_bl
					num_hh_members_15_bl d_farm_size_bl_? d_hhnoland_bl;
				  

    gl educ_health    ttl_educ_exp_hh_* ttl_health_exp_hh_*
					  ttl_healthv2_exp_hh_*
					  num_bmem_*_610_f3    num_gmem_*_610_f3 
					  num_bmem_*_1115_f3   num_gmem_*_1115_f3
				  
					  share_bmem_*_610_f3  share_bmem_*_1115_f3 
					  share_gmem_*_610_f3  share_gmem_*_1115_f3 
					  
					  num_bmem_*_616_f3     num_gmem_*_616_f3 
					  share_bmem_*_616_f3   share_gmem_*_616_f3
					  num_fem_*_f3          num_mal_*_f3
					  share_Fmem_*_15_f3    share_Mmem_*_15_f3
					  haz* waz* whz* MUAC*;

  	gl sav_loans  d_any_loan_bl 
	              d_any_account_bl 
	              ttl_loan_bl 
	              d_loan_?_f? 
				  d_anycash_?_f?
				  cash_savings_?_f?
				  d_loan_f? 
				  d_anycash_f? 
				  cash_savings_f?
				  ttl_hh_loans_* 
				  d_moneyfriend_w_f?  d_moneySILC_w_f?
	              d_moneyfriend_h_f?  d_moneySILC_h_f?	 
				  sav_1_4_dum_1_w-chop_money_rs_dum_9_h;			  
				  
	gl norms_var   w_norms_women_not_go_work      w_comm_norm_woman_fields 		
				   w_comm_norm_male_bad_provider  w_comm_norm_woman_travelsout 	
				   w_comm_norm_worsehusband 	   w_comm_norm_worsewife 			
			       w_comm_norm_worseindf          w_gender_equity_norm 			
				   overestimate_norm_w_w          overestimate_norm_w_m                               
			       h_norms_women_not_go_work      h_comm_norm_woman_fields 		
				   h_comm_norm_male_bad_provider  h_comm_norm_woman_travelsout 	
				   h_comm_norm_worsehusband 	   h_comm_norm_worsewife 			
				   h_comm_norm_worseindf          h_gender_equity_norm 	        
				   overestimate_norm_m_m          overestimate_norm_m_w            
				   empowered_new_bl 												
				   school_mother_bl_w             school_mother_bl_h				
				   mother_worked_w mother_workedent_w;               
	
	gl dsweia_var  adequate_prod_5_f3      adequate_income_5_f3 adequate_income_1_f3              
				   female_plotown_f3       fem_borrow_f3 
				   adequate_prod_6_f3      fem_assetsale_f3  female_own_assets
				   dm_index_fup3_w 	      proweai_sum_ind_w
				   dm_index_bl_new_w  	  weai_new_bl_w 
				   d_sharemoney2_?_?_f3   d_sharemoney4_?_?_f3
				   just_viol_pub_w_f3-womenleaves_h_f3
				   aggregate_prod   *_jv_any   *_selfeff									
				   speakpublic_any 
				   groupmember_any *_aggregate_income *_aggregate_time
				   fem_plotdecisions_w_bl       fem_earningsdecisions_w_bl 
	               fem_enterprisedecisions_w_bl fem_landrentdecisions_w_bl 
				   fem_borrowdecisions_w_bl     fem_cropusedecisions_w_bl 
				   fem_assetsale_w_bl
				   
				   adequacy_input_prod_w_f3  adequacy_input_income_w_f3 
				   adequacy_own_assets_w_f3      fem_assetsale_w_f3  
				   fem_borrow_w_f3  groupmember_any_w_f3
				   adequacy_workload_w_f3        adequacy_inc_satisfaction_w_f3 
				   adequacy_attitude_viol_w_f3   adequacy_autonomy_inc_w_f3 
				   adequacy_selfeff_w_f3         adequacy_respect_w_f3
				   decisionmaking_index_bl_new
				   dm2_aindex_w_bl
				   dm2_aindex_w_f3
				   proweia2_aindex_w_f3;

	gl lifesatis   happ_12_1_* happ_12_2_*
	               happ_12_7_* happ_12_8_* happ_12_9_* happ_12_10_* 
	               happ_12_13_* happ_12_14_* happ_12_15_*
	               happ_12_16_* happ_12_17_* happ_12_19_*
				   selfest_w conf_w indep_w	 w_bmi_w underw_bmi_w
				   selfest_h conf_h indep_h	 w_bmi_h underw_bmi_h;
	
	gl violence   emo_vio_f* phys_vio_f* sex_vio_f*;
  
	gl consumption w_daily_adulteq_expenses_*  
	               ihs_daily_adulteq_expenses_*   
				   HDDS_f3                     
				   w_daily_hh_expenses_*    w_daily_percapita_expenses_* 
				   w_daily_ae_expreal_*		ihs_daily_ae_expreal_* 		   
				   ihs_daily_hh_expenses_*  ihs_daily_percapita_expenses_*
				   w_exp_ttlnonfood_7dae_*   w_exp_ttlfood_7dae_* 
				   w_exp_ttlconfood_7dae_*
				   ihs_exp_ttlnonfood_7dae_*   ihs_exp_ttlfood_7dae_* 
				   ihs_exp_ttlconfood_7dae_*
				   w_r_exp_ttlnonfood_7dae_* 
				   w_r_exp_ttlfood_7dae_*	   w_r_exp_ttlconfood_7dae_*
				   ihs_r_exp_ttlnonfood_7dae_* 
				   ihs_r_exp_ttlfood_7dae_*	   ihs_r_exp_ttlconfood_7dae_* *_daily_hh_realexp_*;
				   
	gl nowins     daily_ae_expreal_*       daily_hh_expenses_* 
	              daily_percapita_expenses_* daily_adulteq_expenses_*
				  daily_hh_realexp_* ;
				  
	gl foodsec    foody*_bl foody*_f2   foody*_f3  
	              num_daymeals_adults_* num_daymeals_child_* dietdiv_score_*; 
	
	gl buss_relat business_work_bl_w  business_work_bl_h 
	              weai_6a_bl_w 
	              business_work_fup* primary_act_fup2*    primary_act_fup3* 
				  d_sourcemonbuss_1_fup2_w-rawmats_business_fup3_h 
	              location_buss_fup*  rawmats_business_bl_? profits_business_* 
				  bus_years_* source_rawmat_dum_* new_act_non_farming;
	
	gl timeuse    time_?_bl 
	              time_?_f3_w time_??_f3_w
				  time_?_f3_h time_??_f3_h;

	gl assets_w   w_number_*_fup2_w   value_*_fup2_w 
			      w_number_*_fup3_w   value_*_fup3_w 
			      WeightedVar_NonLandAssets_*_w;


	gl assets_h   w_number_*_fup2_h   value_*_fup2_h 
				  w_number_*_fup3_h   value_*_fup3_h 
				  WeightedVar_NonLandAssets_*_h; 
				 
	gl ag_var    yield_millet_bl_w-w_yield_soybean_bl_h
	             num_plots_bl       num_crops_cult_bl
				 ttl_area_cult_bl_? ttl_valharv_crops_bl_?
	             num_plots_f3_w-ttl_wagehlabor_f3_h 
				 farming_work_* 
				 ttl_solharv_f3_w-ttl_postharv_ha_f3_h;	
	
	gl inc_var   hh_income_* tr_4_w_dum_*  wage_emp_* 
			     daily_pc_income_bl;	
			   
	gl prices    w_goat_price_f* w_chicken_price_f* w_sheep_price_f* 
	             w_ttl_food_exp_f?;		   
				 
	gl ct_sharing share_myself     share_spouse share_children
	              share_friends_in share_friends_out
				  share_*_ngo_? share_*_relative_?; 			 
				 
	# d cr;

*  Collapse and save
* -------------------------------------------------------------
	# d;
	collapse  (max) village_ineligible_ct  village_new_bl  
	                d_wavail_f* d_mavail_f* 
	                $coordinates            $buss_relat    
					$educ_health			$assets_w       
					$assets_h 		        $dsweia_var 
				    $controls1              $norms_var  
					adequacy_all_domains_bl    
				    $consumption 	        $foodsec
					$lifesatis              $timeuse 
					$ag_var                 $violence
					fem_assetsale_adequate_bl 
				    $inc_var                $nowins 
					$prices					$sav_loans
					$ct_sharing
				    vulnerability_category_ward_bl cashreceived, by (hhid);
	# d cr; 		   
    
	tostring  hhid, replace 
	la val new_act_non_farming new_act_non_farming
	tab new_act_non_farming

  * Save tempdataset  
	tempfile  databusiness
	save 	 `databusiness' 
} 

}

** =============================================================================
*  A2. USING DATA WITH KEY INFORMATION OF THE PROGRAM (TREATMENT, HHID, ETC)
** =============================================================================
if `part_A2'{
* 1. Load Household-Level Treatment Dataset
* -----------------------------------------------------------------------------*
	use "$data\Raw\FNLP_Treatment.dta", clear

* 2. Constructing Treatment Variables
* ------------------------------------------------------------------------------
	gen      cash_treatment=1 if cashtransferassignment_bl=="Lump Sum"
	replace  cash_treatment=2 if cashtransferassignment_bl=="Monthly"
	replace  cash_treatment=0 if cashtransferassignment_bl=="NO CT1"
	replace  cash_treatment=0 if cashtransferassignment_bl=="NO CT2"
	la def   cash_treatment 1 "Lump Sum" 2 "Monthly" 0 "No CAT", modify 
	la val   cash_treatment cash_treatment
	tab      cash_treatment

	clonevar FNLP_treatment=treatment_bl 
	la var   FNLP_treatment "FNLP treatment"
	tab      FNLP_treatment

	clonevar caseworker_treatment=caseworker_bl
	la var   caseworker_treatment "Case worker treatment"
	tab      caseworker_treatment

	drop     cashtransferassignment_bl  caseworker_bl treatment_bl 

	gen      mul_treatment=0 if  cash_treatment==0 & FNLP_treatment==0
	replace  mul_treatment=1 if  cash_treatment==1 & FNLP_treatment==0
	replace  mul_treatment=2 if  cash_treatment==2 & FNLP_treatment==0
	replace  mul_treatment=3 if  cash_treatment==0 & FNLP_treatment==1
	replace  mul_treatment=4 if  cash_treatment==1 & FNLP_treatment==1
	replace  mul_treatment=5 if  cash_treatment==2 & FNLP_treatment==1
	la def   mul_treatment 0 "NCT/ No FNLP"       1 "Lump Sum/No FNLP"  ///
					       2 "Monthly / No FNLP"  3  "NCT FNLP"         ///
					       4 "Lump Sum/FNLP"      5 "Monthly/FNLP", modify
	la val  mul_treatment mul_treatment	
	la var  mul_treatment "Multiple Treatments"
	tab     mul_treatment

* 3. Merging with HH Dataset that includes variables constructed (from part_a1)
* ------------------------------------------------------------------------------
	merge 1:1 hhid using `databusiness', nogenerate
	
* 4. Cleaning GPS Variables
* ------------------------------------------------------------------------------	
  * Dropping  observations for which we do not have gps information
    gen     gps_latitude_final=gps_latitudemax_t1 
	replace gps_latitude_final=gps_latitudemax_t2 if gps_latitude_final==.
	//replace gps_latitude_final=gps_latitudemax_t0 if gps_latitude_final==.
	
	gen gps_longitude_final=gps_longitudemax_t1
	replace gps_longitude_final=gps_longitudemax_t2 if gps_longitude_final==.
	//replace gps_longitude_final=gps_longitudemax_t0 if gps_longitude_final==.

	drop gps_latitudemax_* gps_longitudemax_*
    
	drop if gps_latitude_final==.
	drop if gps_longitude_final==.
	drop if hhid=="123456"
	la var cash_treatment "Cash treatment"

* 5. Creating Binary Treatment Indicators
* ------------------------------------------------------------------------------	
	
  * Cleaning and adding some labels 
	gen     d_cash_treatment=cash_treatment
	recode  d_cash_treatment (2=1)
	la var  d_cash_treatment "Cash treatment Dummy"
	la def  cash 1 "Cash Transfer" 0 "No Cash Transfer", modify 
	la val  d_cash_treatment cash
	tab 	  d_cash_treatment
	
	gen       d_ct_lumpsum=(cash_treatment==1)
	gen       d_ct_monthly=(cash_treatment==2)	
    la var    d_ct_lumpsum "Lumpsum CT"
	la var    d_ct_monthly "Monthly CT"
	
	la def  business_work 0 "No business" 1 "Business", modify
	la val  business_work_fup* business_work

* 6. Business Variables
* ------------------------------------------------------------------------------
	gen     bus_CT_2=0 if business_work_fup2_w==1 & d_cash_treatment==1
	replace bus_CT_2=1 if business_work_fup2_w==1 & d_cash_treatment==0
	replace bus_CT_2=2 if business_work_fup2_w==0 & d_cash_treatment==1
	replace bus_CT_2=3 if business_work_fup2_w==0 & d_cash_treatment==0

	gen     bus_CT_3=0 if business_work_fup3_w==1 & d_cash_treatment==1
	replace bus_CT_3=1 if business_work_fup3_w==1 & d_cash_treatment==0
	replace bus_CT_3=2 if business_work_fup3_w==0 & d_cash_treatment==1
	replace bus_CT_3=3 if business_work_fup3_w==0 & d_cash_treatment==0
	la def  bus_CT 0 "Business & CT"  1  "Business & NCT"  ///
		2  "NB & CT"       3    "NB & NCT", modify 			 
	la val  bus_CT_* bus_CT


   * Working with products and categories:
   * ------------------------------------------------------------------------------
	 gen 	  d_newbus_fup2=(business_work_bl_w==0 & business_work_fup2_w==1)
	 replace  d_newbus_fup2=. if business_work_bl_w==. | business_work_fup2_w==.
	 replace  d_newbus_fup2=0 if business_work_fup2_w==0
	 
	 gen 	  d_newbus_fup3=(business_work_fup2_w==0 & business_work_fup3_w==1)
	 replace  d_newbus_fup3=. if business_work_fup2_w==. | business_work_fup3_w==.	 
	 replace  d_newbus_fup3=0 if business_work_fup3_w==0
	 
	 gen 	  d_oldbus_fup2=(business_work_bl_w==1 & business_work_fup2_w==1)
	 replace  d_oldbus_fup2=. if business_work_bl_w==. | business_work_fup2_w==.
     replace  d_oldbus_fup2=0 if business_work_fup2_w==0
	 
	 gen 	  d_oldbus_fup3=(business_work_fup2_w==1 & business_work_fup3_w==1)
	 replace  d_oldbus_fup3=. if business_work_fup2_w==. | business_work_fup3_w==.	
     replace  d_oldbus_fup3=0 if business_work_fup3_w==0
	 
	 gen 	  d_newbus_h_fup2=(business_work_bl_h==0 & business_work_fup2_h==1)
	 replace  d_newbus_h_fup2=. if business_work_bl_h==. | business_work_fup2_h==.
	 replace  d_newbus_h_fup2=0 if  business_work_fup2_h==0
	 
	 gen 	  d_newbus_h_fup3=(business_work_fup2_h==0 & business_work_fup3_h==1)
	 replace  d_newbus_h_fup3=. if business_work_fup2_h==. | business_work_fup3_h==.	 
	 replace  d_newbus_h_fup3=0 if  business_work_fup3_h==0
	 
	 gen 	  d_oldbus_h_fup2=(business_work_bl_h==1 & business_work_fup2_h==1)
	 replace  d_oldbus_h_fup2=. if business_work_bl_h==. | business_work_fup2_h==.
	 replace  d_oldbus_h_fup2=0 if business_work_fup2_h==0

	 gen 	  d_oldbus_h_fup3=(business_work_fup2_h==1 & business_work_fup3_h==1)
	 replace  d_oldbus_h_fup3=. if business_work_fup2_h==. | business_work_fup3_h==.		 
	 replace  d_oldbus_h_fup3=0 if business_work_fup3_h==0
	 

	 la var d_newbus_fup2    "Midline:New business(Wife)"
	 la var d_newbus_fup3    "Endline:New business(Wife)"
	 la var d_oldbus_fup2    "Midline:Old business(Wife)"
	 la var d_oldbus_fup3    "Endline:Old business(Wife)"
	 la var d_newbus_h_fup2  "Midline:New business(Husband)"
	 la var d_newbus_h_fup3  "Endline:New business(Husband)"
	 la var d_oldbus_h_fup2  "Midline:Old business(Husband)"
	 la var d_oldbus_h_fup3  "Endline:Old business(Husband)"
	 	 	 
	 
	la def primary_act_gcat 1 "Cook"    2 "Oil processing"  3 "Crops processing"  ///  
				            4 "Trader"  5 "Services"        0 "None"              ///
				            6 "Other", modify 
	la val primary_act_fup2* primary_act_gcat
	la val primary_act_fup3* primary_act_gcat

	gen     d_primary_act_fup2=(primary_act_fup2>0 & primary_act_fup2<.)
	la var  d_primary_act_fup2 "Primary Activity FUP2"
	gen     d_primary_act_fup3=(primary_act_fup3>0 & primary_act_fup3<.)
	la var  d_primary_act_fup3 "Primary Activity FUP3"

	gen     d_primary_act_fup2_h=(primary_act_fup2_h>0 & primary_act_fup2_h<.)
	la var  d_primary_act_fup2_h "Primary Activity FUP2 (Husband)"
	gen     d_primary_act_fup3_h=(primary_act_fup3_h>0 & primary_act_fup3_h<.)
	la var  d_primary_act_fup3_h "Primary Activity FUP3 (Husband)"

	forval i=0/6{
	foreach round in fup2 fup3{
	gen     d_primary_act_`round'_c`i'=(primary_act_`round'==`i')
	gen     d_primary_act_`round'_h_c`i'=(primary_act_`round'_h==`i')
	}
	}

* 7. Winsorizing Key Variables
* ------------------------------------------------------------------------------
   	replace profits_business_bl=.     if business_work_bl_w>=.
    replace profits_business_fup2=.   if business_work_fup2_w>=. 
    replace profits_business_fup3=.   if business_work_fup3_w>=. 
	replace rawmats_business_fup2_w=. if business_work_fup2_w>=. 
	replace rawmats_business_fup3_w=. if business_work_fup3_w>=. 
	
	replace profits_business_bl=0     if business_work_bl_w==0 
    replace profits_business_fup2=0   if business_work_fup2_w==0 
    replace profits_business_fup3=0   if business_work_fup3_w==0 
	replace rawmats_business_fup2_w=0 if business_work_fup2_w==0 
	replace rawmats_business_fup3_w=0 if business_work_fup3_w==0 	
	
   	replace profits_business_bl_h=.   if business_work_bl_h>=.
    replace profits_business_fup2_h=. if business_work_fup2_h>=. 
    replace profits_business_fup3_h=. if business_work_fup3_h>=. 
	replace rawmats_business_fup2_h=. if business_work_fup2_h>=. 
	replace rawmats_business_fup3_h=. if business_work_fup3_h>=. 

	replace profits_business_bl_h=0     if business_work_bl_h==0 
    replace profits_business_fup2_h=0   if business_work_fup2_h==0 
    replace profits_business_fup3_h=0   if business_work_fup3_h==0 
	replace rawmats_business_fup2_h=0   if business_work_fup2_h==0 
	replace rawmats_business_fup3_h=0   if business_work_fup3_h==0 	
	
	
  * Set of variables to winsor and transform 
	ren WeightedVar_NonLandAssets_fup2_w NonLandAssets_fup2_w
	ren WeightedVar_NonLandAssets_fup3_w NonLandAssets_fup3_w

	ren yield_soybean_ha_f3_w  r_yield_soybean_ha_f3_w
	ren yield_soybean_ha_f3_h  r_yield_soybean_ha_f3_h
	ren quant_soybean_ha_f3_w  r_quant_soybean_ha_f3_w
	ren quant_soybean_ha_f3_h  r_quant_soybean_ha_f3_h
	
  # d ;
  gl business_out   rawmats_business_bl_*
                    rawmats_business_fup2_* rawmats_business_fup3_* 
	                profits_business_bl*
					profits_business_fup2* profits_business_fup3*   
	                value_*_fup2_w value_*_fup3_w 					
					value_*_fup2_h value_*_fup3_h cash_savings_*
					NonLandAssets_fup2_w NonLandAssets_fup3_w;
					
  gl ag_out	    yield_*_ha_*          ttl_yields_ha*   
                ttl_qtyields_ha*  	  ttl_valharv_crops_*
                ttl_area_cult*        quant_*        
				ttl_spend_*
				ttl_hrs_week*       ttl_hrs_month*
				ttl_solharv_*       ttl_consharv_*
				ttl_paymharv_*      ttl_storharv_* 
				ttl_postharv_*;
				
  gl ag_lab  	ttl_daysseas_hhmem* 
				ttl_hhhdaysseas*    ttl_spodaysseas* 
				ttl_daymen_hired*   ttl_seassal_hmen*
				ttl_daywomen_hired* ttl_seassal_hwomen*
				ttl_daychild_hired* ttl_seassal_hchild* 
				ttl_wagehlabor*;			
  # d cr; 				
	
	foreach var of varlist $business_out $ag_out{
     winsor `var', gen(w_`var') p(0.05)
	 ihstrans `var'
	 }
	 
	
	foreach var of varlist $ag_lab ttl_healthv2_exp_hh_* ttl_health_exp_hh_* ///
						   ttl_educ_exp_hh_* silc_savings_w silc_savings_h{
     winsor `var', gen(w_`var') p(0.01)
	 ihstrans `var'
	 }
	 
	 
	 ** Renaming back soybeans 
	ren r_yield_soybean_ha_f3_w  yield_soybean_ha_f3_w
	ren r_yield_soybean_ha_f3_h  yield_soybean_ha_f3_h
	ren r_quant_soybean_ha_f3_w  quant_soybean_ha_f3_w
	ren r_quant_soybean_ha_f3_h  quant_soybean_ha_f3_h	 
	    
	gl soybean_var yield_soybean_ha_f3_w yield_soybean_ha_f3_h ///
	               quant_soybean_ha_f3_w quant_soybean_ha_f3_h   
	
	foreach var of varlist $soybean_var{
	clonevar w_`var'=`var'
	ihstrans `var'
	}
		
  *  Consolidating the responses of husbands anf wifes in one single variables
  *  We do this mostly for the ag outcomes since husband is the one that work the most on it.
  ** Generating unique output 
  	foreach cropName in millet rice maize sorghum groundnut cowpea soybean{
	gen     d_cult_`cropName'_f3=d_cult_`cropName'_f3_h
	replace d_cult_`cropName'_f3=d_cult_`cropName'_f3_w if d_cult_`cropName'_f3==. 
	
	gen     w_yield_`cropName'_ha_f3=w_yield_`cropName'_ha_f3_h 
	replace w_yield_`cropName'_ha_f3=w_yield_`cropName'_ha_f3_w if w_yield_`cropName'_ha_f3==. 	
	la var 	w_yield_`cropName'_ha_f3 "Value harvested of `cropName'/ha (`x')"
	replace w_yield_`cropName'_ha_f3=0 if w_yield_`cropName'_ha_f3>=.
	
	gen     w_quant_`cropName'_ha_f3=w_quant_`cropName'_ha_f3_h 
	replace w_quant_`cropName'_ha_f3=w_quant_`cropName'_ha_f3_w if w_quant_`cropName'_ha_f3==. 	
	la var  w_quant_`cropName'_ha_f3 "Qt harvested of `cropName' /ha (`x')"
    
	gen     ihs_yield_`cropName'_ha_f3=ihs_yield_`cropName'_ha_f3_h 
	replace ihs_yield_`cropName'_ha_f3=ihs_yield_`cropName'_ha_f3_w if ihs_yield_`cropName'_ha_f3==. 	
	la var 	ihs_yield_`cropName'_ha_f3 "(Ihs)Value harvested of `cropName'/ha (`x')"
	replace	ihs_yield_`cropName'_ha_f3=0 if ihs_yield_`cropName'_ha_f3>=. 
	
	gen     ihs_quant_`cropName'_ha_f3=ihs_quant_`cropName'_ha_f3_h 
	replace ihs_quant_`cropName'_ha_f3=ihs_quant_`cropName'_ha_f3_w if ihs_quant_`cropName'_ha_f3==. 	
	la var  ihs_quant_`cropName'_ha_f3 "(Ihs)Qt harvested of `cropName' /ha (`x')"

	gen     yield_`cropName'_bl=yield_`cropName'_bl_h 
	replace yield_`cropName'_bl=yield_`cropName'_bl_w if yield_`cropName'_bl==. 	
	la var 	yield_`cropName'_bl "/Baseline: Value harvested of `cropName'/ha"
	replace yield_`cropName'_bl=0 if 	yield_`cropName'_bl>=.	
	
	drop    yield_`cropName'_bl_h  yield_`cropName'_bl_w
	
	gen     yield_`cropName'_end=yield_`cropName'_end_f3_h
	replace yield_`cropName'_end=yield_`cropName'_end_f3_w if yield_`cropName'_end==. 	
	la var 	yield_`cropName'_end "Endline: Value harvested of `cropName'/ha"
	replace yield_`cropName'_end=0 if 	yield_`cropName'_end>=.	
	
	drop    yield_`cropName'_end_f3_h yield_`cropName'_end_f3_w

	gen     w_yield_`cropName'_bl=w_yield_`cropName'_bl_h 
	replace w_yield_`cropName'_bl=w_yield_`cropName'_bl_w if w_yield_`cropName'_bl==. 	
	la var 	w_yield_`cropName'_bl "/Baseline: Value harvested of `cropName'/ha"
	replace w_yield_`cropName'_bl=0 if 	w_yield_`cropName'_bl>=.	
	
	drop    w_yield_`cropName'_bl_h  w_yield_`cropName'_bl_w
	
	gen     w_yield_`cropName'_end=w_yield_`cropName'_end_f3_h
	replace w_yield_`cropName'_end=w_yield_`cropName'_end_f3_w if w_yield_`cropName'_end==. 	
	la var 	w_yield_`cropName'_end "Endline: Value harvested of `cropName'/ha"
	replace w_yield_`cropName'_end=0 if 	w_yield_`cropName'_end>=.	
	
	drop    w_yield_`cropName'_end_f3_h w_yield_`cropName'_end_f3_w
	
	}
	
   * Yields 	
	egen    agyields_bl=rowtotal(yield_*_bl)	
	la var  agyields_bl  "Agriculture Yields (Baseline)"

	egen    agyields_end=rowtotal(yield_*_end)		
	la var  agyields_end  "Agriculture Yields (Endline)"	
	
	egen    w_agyields_bl=rowtotal(w_yield_*_bl)	
	la var  w_agyields_bl  "Agriculture Yields w/95(Baseline)"

	egen    w_agyields_end=rowtotal(w_yield_*_end)		
	la var  w_agyields_end  "Agriculture Yields w/95 (Endline)"
		
	gen     num_crops_cult_f3=num_crops_cult_f3_h
	replace num_crops_cult_f3=num_crops_cult_f3_w if num_crops_cult_f3==. 
	la var  num_crops_cult_f3 "Endline: Number of crops cultivated"
		
	gen     ttl_area_cult_bl=ttl_area_cult_bl_h
	replace ttl_area_cult_bl=ttl_area_cult_bl_w if ttl_area_cult_bl==. 
	replace ttl_area_cult_bl=0 if ttl_area_cult_bl==. 
		
	gen     w_ttl_area_cult_bl=w_ttl_area_cult_bl_h
	replace w_ttl_area_cult_bl=w_ttl_area_cult_bl_w if w_ttl_area_cult_bl==. 
	replace w_ttl_area_cult_bl=0 if w_ttl_area_cult_bl==. 
	
	ihstrans agyields_bl  agyields_end ttl_area_cult_bl 
		
	# d; 	
	gl var_uniq ttl_area_cult         ttl_yields_ha    
	            ttl_valharv_crops    
				ttl_spend_orgfert     ttl_spend_inorgfert 
				ttl_spend_seeds	      ttl_hrs_week 
				ttl_hrs_month         ttl_daysseas_hhmem 
				ttl_hhhdaysseas       ttl_spodaysseas 
				ttl_daymen_hired      ttl_seassal_hmen
				ttl_daywomen_hired    ttl_seassal_hwomen
				ttl_daychild_hired    ttl_seassal_hchild  
				ttl_wagehlabor        ttl_solharv
				ttl_consharv  		  ttl_paymharv
				ttl_storharv		  ttl_postharv
				ttl_solharv_ha
				ttl_consharv_ha  		  ttl_paymharv_ha
				ttl_storharv_ha		  ttl_postharv_ha;
	# d cr;			
					
	foreach var in $var_uniq{
	gen     w_`var'_f3=w_`var'_f3_h
	replace w_`var'_f3=w_`var'_f3_w if w_`var'_f3==. 
	replace w_`var'_f3=0 if w_`var'_f3==. 
	
	gen     `var'_f3=`var'_f3_h
	replace `var'_f3=`var'_f3_w if `var'_f3==. 
	replace `var'_f3=0 if `var'_f3==. 	
	
    gen ihs_`var'_f3=ihs_`var'_f3_h
	replace ihs_`var'_f3=ihs_`var'_f3_w if ihs_`var'_f3==. 
	replace ihs_`var'_f3=0 if ihs_`var'_f3==.
	}
	
	gl var_uniq  ttl_valharv_crops
	foreach var in $var_uniq{
	gen w_`var'_bl=w_`var'_bl_h
	replace w_`var'_bl=w_`var'_bl_w if w_`var'_bl==. 
	replace w_`var'_bl=0 if w_`var'_bl==. 
	
	gen  `var'_bl=`var'_bl_h
	replace `var'_bl=`var'_bl_w if w_`var'_bl==. 
	replace `var'_bl=0 if `var'_bl==. 	
	
    gen ihs_`var'_bl=ihs_`var'_bl_h
	replace ihs_`var'_bl=ihs_`var'_bl_w if ihs_`var'_bl==. 
	replace ihs_`var'_bl=0 if ihs_`var'_bl==.
	}
	

	gen    d_resp_agwif=(ttl_area_cult_f3_h==. & ttl_area_cult_f3_w!=.)
	la var d_resp_agwif "Respondent of ag outcomes is wife"

  * Generating some labor over hectar variables 
    # d;
	gl var_uniq ttl_hrs_week 
				ttl_hrs_month      ttl_daysseas_hhmem 
				ttl_hhhdaysseas    ttl_spodaysseas 
				ttl_daymen_hired   ttl_seassal_hmen
				ttl_daywomen_hired ttl_seassal_hwomen
				ttl_daychild_hired ttl_seassal_hchild  
				ttl_wagehlabor 
				ttl_spend_orgfert  ttl_spend_inorgfert
				ttl_spend_seeds;
    # d cr;
  
   foreach var in $var_uniq{
    gen w_`var'_ha_f3=w_`var'_f3/w_ttl_area_cult_f3
	replace w_`var'_ha_f3=0 if w_`var'_ha_f3==. 
    gen `var'_ha_f3=`var'_f3/ttl_area_cult_f3
	replace `var'_ha_f3=0 if `var'_ha_f3==. 	
	} 
	
 * Total Inputs 
	egen     ttl_inputs_plot=rowtotal(ttl_spend_orgfert_f3 ttl_wagehlabor_f3 ///
							          ttl_spend_inorgfert_f3 ttl_spend_seeds_f3)

	gen      ttl_inputs_plot_ha=ttl_inputs_plot/ttl_area_cult_f3
	replace  ttl_inputs_plot_ha=0 if ttl_inputs_plot_ha==.
	winsor   ttl_inputs_plot_ha, gen(w_ttl_inputs_plot_ha) p(0.05)
	
	ihstrans ttl_inputs_plot_ha	ttl_wagehlabor_ha_f3     ///
	         ttl_spend_orgfert_ha_f3  ///
		     ttl_spend_inorgfert_ha_f3 ttl_spend_seeds_ha_f3

	* Intensive versus extensive 	
	gen     anyfamlab=(ttl_daysseas_hhmem_f3>0 & ttl_daysseas_hhmem_f3<.)
	gen     anyhhhlab=(ttl_hhhdaysseas_f3>0 & ttl_hhhdaysseas_f3<.)	
	gen     anyspoulab=(ttl_spodaysseas_f3>0 & ttl_spodaysseas_f3<.)	 

	gen     anyhirelab=(ttl_daymen_hired_f3>0 & ttl_daymen_hired_f3<.)
	replace anyhirelab=1 if ttl_daywomen_hired_f3>0 & ttl_daywomen_hired_f3<.
	replace anyhirelab=1 if ttl_daychild_hired_f3>0 & ttl_daychild_hired_f3<.

	drop tr_4_w_dum_dk tr_4_w_dum_refuse tr_4_w_dum_na tr_4_w_dum_other 

	
	** New marital status variable 
	gen marital_status2_bl_1=(marital_status_bl_1==1) 
	gen marital_status2_bl_2=(marital_status_bl_2==1) 
	gen marital_status2_bl_3=(marital_status_bl_3==1 | marital_status_bl_4==1 | marital_status_bl_5==1)
	gen marital_status2_bl_4=(marital_status_bl_6==1)
	

	* Replace attrition that were missing to 0
	replace d_wavail_f2=0 if d_wavail_f2==. 
	replace d_wavail_f3=0 if d_wavail_f3==. 
	replace d_mavail_f2=0 if d_mavail_f2==. 
	replace d_mavail_f3=0 if d_mavail_f3==. 	
	
* 8. Saving the Cleaned Data for Analysis
* ------------------------------------------------------------------------------

	saveold  "$data/Intermediate\FNLP_Cleaned_Intermediate.dta", replace
} 

********************************************************************************
//  END OF PART A DOFILE
********************************************************************************