********************************************************************************
*  PART B: Constructing Data from R Matrix
*  Nigeria Feed the Future - ENDLINE 2025
********************************************************************************

* Define processing steps
local part_B1  1 // Processing Census Data
local part_B2  1 // Proccesing Neighbors Data 

********************************************************************************
* B1. Preparing Census Data
********************************************************************************
if `part_B1'{
    * 1. Load Raw Census Data
    use "$data/Raw/FNLP_PPI_CensusData.dta", clear
    tostring hhid, replace

    * 2. Generate Village-Level Variables
    bysort villagename_clean: gen temp = _n
    bysort villagename_clean: egen num_vul_village = max(temp)
    bysort villagename_clean: egen ppi_mean = mean(ppi_score)

    * 3. Merge with FNLP Cleaned Dataset
    merge 1:1 hhid using "$data/Intermediate/FNLP_Cleaned_Intermediate.dta", ///
        keepusing(gps_startlatitude gps_startlongitude gps_startaltitude ///
                  gps_longitude_final gps_latitude_final ///
                  villagecode_bl village_new_bl)

    * Check merge results
    tab _merge
    drop if _merge == 2   // Keep only matched observations and those from the master dataset

    * 4. Fill Missing GPS Data
    replace gpslatitude = gps_latitude_final if _merge == 3 & !missing(gps_latitude_final)
    replace gpslongitude = gps_longitude_final if _merge == 3 & !missing(gps_longitude_final)
    replace gpsaltitude = gps_startaltitude if _merge == 3

    drop gps_startlatitude gps_startlongitude gps_startaltitude _merge *_final

    * Check and drop missing GPS
    gen missing_gps = (missing(gpslatitude) | missing(gpslongitude))
    tab missing_gps
    drop if missing_gps == 1

    * 5. Save Census Vulnerability Data to be use in part c
    preserve
    keep hhid num_vul_village ppi_mean ppi_score
    save "$data/Raw/CensusData_VulnertableHH.dta", replace
    restore

	
    * 6. Save Cleaned Census Data
    save "$data/Intermediate/FNLP_PPI_CensusCleanedData.dta", replace
}

******************************************************************************
* B2. Preparing Matrix of Neighbors Created in R Studio
******************************************************************************
if `part_B2'{

/* Before running this section make sure you ahve Run the Rscripts 
	ConstructionNeighboorsMatrixFNLPData.R
	ConstructionPovertyMatrixCensusData.R
*/	
	
** Neighbors Matrix: Number of EVs and Categories of business around hh 
** -----------------------------------------------------------------------------
* Load Dataset
  use "$data/Raw/HHSpatialWideData.dta", clear
  duplicates report hhid
  codebook   hhid //3,973 
  * Respective Rscript: ConstructionNeighboorsMatrixFNLPData
  
** Poverty Matrix: Number of vulnerables around household 
** -----------------------------------------------------------------------------
* Load Dataset 
  use  "$data/Raw/VulnerablesMatrixDatafromR.dta", clear 
  *Respective Rscript: ConstructionPovertyMatrixCensusData.R

* Checking duplicates   
  duplicates report hhid
  duplicates drop hhid, force // No duplciates
  codebook   hhid //3,973 
  
* Adding all "Poor people around"
  foreach number in   100 150 200 250 300 350 400 450 500 550 ///
					 600 650 700 750 800 850 900 950 1000{ 
  gen    b`number'pov=b`number'evall+b`number'vvall+b`number'mlall		
  la var b`number'pov "Number of poor hh around ratio `number'"
  }
  
* Save dataset 	
  saveold "$data/Intermediate/VulnerablesNeighborsMatrixData.dta", replace 
 } 


********************************************************************************
//  END OF PART A DOFILE
********************************************************************************