********************************************************************************
*  PART D: Construction of Data For Panel Analysis 
*  Nigeria Feed the Future - ENDLINE 2025
********************************************************************************


* Load data 
  use  "$data/Final/FNLPDataWideAnalysis.dta", replace 

** =============================================================================
** Defining variables we need for panel analysis 
** =============================================================================
if 1{
   # d; 
	 gl controls   age_hhhead_bl 	  marital_status_bl     literacy_hhhead_bl  
				   num_plots_bl       hhtype_bl   hhid  
				   gps_latitude_final gps_longitude_final    
				   d_amean_distma     d_amean_popsize 
				   ipw  d0_deltapov*;
				   
	gl lga_dummies d_lgacode_bl_1 village_new_bl village_group 
	               village_ineligible_ct num_vul_village;
   
			 
	gl treat d_ct_nct_inel_1 d_ct_nct_inel_2 
	         d_ct_nct_inel_3 d_cash_treatment_unc ct_lumpsum  
			 ct_month FNLP_treatment CT_hhtreat;
			 
	gl spill b*ct b*pov b*ct_lp b*ct_m d_ct_nct_inel_2_m* b*ct_tp50
	         b*ct_tmean pet*    pEV*  no_limpet*  CT_PET* CT_PEV*  CT_HH*
			 VVML_PET* b*pa2 b*pa3 max_distance;

	# d cr; 		 
}
** =============================================================================
** Keeping just variables you need in each round  
** =============================================================================
** 1) Baseline 
** -----------------------------------------------------------------------------
if 1{ 
  preserve 
  * Generating wave specific variables
    gen d_wavail_f1=1
    gen d_mavail_f1=1
  
  * Keeping variables we need 
    # d;
    keep $controls $lga_dummies $treat $spill 
	     business_work_w_bl business_work_h_bl  any_business_bl
         d_wavail_f1 d_mavail_f1 w_daily_percapita_expenses_bl 
		 w_daily_adulteq_expenses_bl ihs_daily_adulteq_expenses_bl
		 ihs_daily_percapita_expenses_bl  ihs_profits_business_bl 
		 ihs_rawmats_business_bl_w   
		 profits_business_bl
		 w_profits_business_bl 
		 rawmats_business_w_bl d_vuln_cat_* foodins_index_bl
		 profits_business_bl_h  w_rawmats_business_w_bl  
	     w_profits_business_bl_h 
		 ihs_profits_business_bl_h  
		 w_rawmats_business_h_bl 
		 ihs_rawmats_business_bl_h 
		 WeightedVar_food_bl dietdiv_score_bl
		 w_daily_ae_expreal_bl  
		 daily_ae_expreal_bl 
		 ihs_daily_ae_expreal_bl
		 w_r_exp_ttlnonfood_7dae_bl  
		 ihs_r_exp_ttlnonfood_7dae_bl
		 w_r_exp_ttlfood_7dae_bl    
		 ihs_r_exp_ttlfood_7dae_bl
		 w_r_exp_ttlconfood_7dae_bl 
		 ihs_r_exp_ttlconfood_7dae_bl
		 farming_work_w_bl 
		 farming_work_h_bl 
		 w_daily_hh_expenses_bl 
		 ihs_daily_hh_expenses_bl 
		 w_daily_hh_realexp_bl
		 ihs_daily_hh_realexp_bl
		 ihs_rexp_allfood_bl 
		 ihs_expen_7dae_bl
		 w_expen_7dae_bl
		 any_farm_hh_bl 
		 ragyields_bl  
		 agyields_bl
		 ttl_valharv_crops_bl   
		 ttl_area_cult_bl
		 w_ttl_area_cult_bl
		 lab_dyn_bl 
		 lab_dyn_w_bl
		 lab_dyn_h_bl
		 d_work_w_bl      
		 d_work_h_bl    
		 d_work_hh_bl
		 d_intr_lab_bl_*
	     d_intr_buslab_bl_* 
		 d_intr_aglab_bl_*
		 foodaindex_bl;
    # d cr; 		 
		   
  * Rename variables do they match in the panel level 	 
    ren  d_wavail_f1 d_wavail
    ren  d_mavail_f1 d_mavail 
	ren  any_business_bl    any_business
    ren  w_daily_percapita_expenses_bl w_daily_percapita_expenses
	ren  ihs_daily_percapita_expenses_bl ihs_daily_percapita_expenses 
    ren  ihs_daily_adulteq_expenses_bl ihs_daily_adulteq_expenses
    ren  w_daily_adulteq_expenses_bl w_daily_adulteq_expenses	
	ren  ihs_profits_business_bl ihs_profits_business
	ren  ihs_rawmats_business_bl_w ihs_rawmats_business
	ren  profits_business_bl profits_business
	ren  w_profits_business_bl w_profits_business
	ren  w_rawmats_business_w_bl w_rawmats_business
	ren  rawmats_business_w_bl rawmats_business_w
	ren  foodaindex_bl     foodaindex
	ren  foodins_index_bl  foodins_index
	ren  WeightedVar_food_bl WeightedVar_food
	ren  dietdiv_score_bl    dietdiv_score
	ren  w_daily_ae_expreal_bl        w_daily_ae_expreal
    ren  ihs_daily_ae_expreal_bl      ihs_daily_ae_expreal
	ren  w_r_exp_ttlnonfood_7dae_bl   w_r_exp_ttlnonfood_7dae
	ren  ihs_r_exp_ttlnonfood_7dae_bl ihs_r_exp_ttlnonfood_7dae
	ren  w_r_exp_ttlfood_7dae_bl      w_r_exp_ttlfood_7dae
	ren  ihs_r_exp_ttlfood_7dae_bl    ihs_r_exp_ttlfood_7dae
    ren  business_work_w_bl           business_work	
	ren  farming_work_w_bl            farming_work_w
	ren  farming_work_h_bl            farming_work_h
	ren  business_work_h_bl           business_work_h
	ren  w_daily_hh_expenses_bl       w_daily_hh_expenses
	ren  ihs_daily_hh_expenses_bl     ihs_daily_hh_expenses
	ren  w_daily_hh_realexp_bl        w_daily_hh_realexp
	ren  ihs_daily_hh_realexp_bl      ihs_daily_hh_realexp
	ren  w_r_exp_ttlconfood_7dae_bl   w_r_exp_ttlconfood_7dae
	ren  ihs_r_exp_ttlconfood_7dae_bl  ihs_r_exp_ttlconfood_7dae
	ren  ihs_rexp_allfood_bl          ihs_rexp_allfood
	ren  ihs_expen_7dae_bl            ihs_expen_7dae
	ren  w_expen_7dae_bl              w_expen_7dae
	ren  w_profits_business_bl_h      w_profits_business_h
	ren  ihs_profits_business_bl_h    ihs_profits_business_h
	ren  w_rawmats_business_h_bl      w_rawmats_business_h 
	ren  ihs_rawmats_business_bl_h    ihs_rawmats_business_h
	ren  profits_business_bl_h        profits_business_h
    ren  any_farm_hh_bl               any_farm_hh 
	ren  ragyields_bl                 ragyields
	ren  ttl_area_cult_bl             ttl_area_cult
	ren  ttl_valharv_crops_bl         ttl_valharv_crops
	ren  w_ttl_area_cult_bl           w_ttl_area_cult
	ren  lab_dyn_bl                   lab_dyn   
	ren  lab_dyn_w_bl                 lab_dyn_w
	ren  lab_dyn_h_bl                 lab_dyn_h
	ren  d_work_w_bl                  d_work_w
	ren  d_work_h_bl                  d_work_h
	ren  d_work_hh_bl                 d_work_hh
	ren  d_intr_lab_bl_?              d_intr_lab_?
	ren  d_intr_buslab_bl_?           d_intr_buslab_?
	ren  d_intr_aglab_bl_?            d_intr_aglab_?
	ren  daily_ae_expreal_bl          daily_ae_expreal
	
  * Generating year variable and saving wave data
    gen year=2015
    tempfile baseline 
    save `baseline'
  restore 
}  
** 2) Midline 
** -----------------------------------------------------------------------------
if 1{
  preserve 
  * Keep just variables we need to transfor to panel 
   # d;
    keep $controls $lga_dummies $treat $spill
	    business_work_w_f2 
	    profits_business_fup2          
		business_work_h_f2
		any_business_f2
		w_profits_business_fup2         
		d_wavail_f2 d_mavail_f2 
		w_daily_percapita_expenses_f2   
		w_value_farmassets_fup2_w 
		w_value_hhassets_fup2_w  	     
		w_value_animals_fup2_w    
		w_number_animals_fup2_w  	     
		w_number_farmassets_fup2_w
		w_daily_adulteq_expenses_f2 
		ihs_daily_percapita_expenses_f2 
		ihs_daily_adulteq_expenses_f2 
		ihs_profits_business_fup2        
		ihs_rawmats_business_fup2_w 
		w_profits_business_fup2         
		w_rawmats_business_w_f2
		rawmats_business_w_f2
		profits_business_fup2_h
		w_profits_business_fup2_h 
		ihs_profits_business_fup2_h  
		w_rawmats_business_h_f2 
	    ihs_rawmats_business_fup2_h 		
		d_vuln_cat_* 
		foodins_index_f2
		WeightedVar_food_f2 
		dietdiv_score_f2
		w_daily_ae_expreal_f2  
		daily_ae_expreal_f2 
		ihs_daily_ae_expreal_f2
		w_r_exp_ttlnonfood_7dae_f2 
		ihs_r_exp_ttlnonfood_7dae_f2
		w_r_exp_ttlfood_7dae_f2    
		ihs_r_exp_ttlfood_7dae_f2
		w_r_exp_ttlconfood_7dae_f2
		ihs_r_exp_ttlconfood_7dae_f2
		farming_work_w_f2 
		farming_work_h_f2
		any_farm_hh_f2
		w_daily_hh_expenses_f2
		ihs_daily_hh_expenses_f2 
		w_daily_hh_realexp_f2
		ihs_daily_hh_realexp_f2
		ihs_rexp_allfood_f2 
		ihs_expen_7dae_f2 
		w_expen_7dae_f2
		value_animals_fup2_w  
		value_farmassets_fup2_w 
	    value_hhassets_fup2_w  
		assetsind_f2 
		ttl_healthv2_exp_hh_f2 
		ttl_educ_exp_hh_f2
		ihsassetsind_f2
		lab_dyn_f2 lab_dyn_w_f2 lab_dyn_h_f2
		d_work_w_f2      d_work_h_f2      d_work_hh_f2
		d_intr_lab_f2_*
	    d_intr_buslab_f2_* d_intr_aglab_f2_*
		foodaindex_f2;
   # d cr;		
		
  * Rename variables do they match in the panel level 
    ren d_wavail_f2 d_wavail
    ren d_mavail_f2 d_mavail 
    ren business_work_w_f2            business_work
	ren any_business_f2               any_business
    ren w_daily_percapita_expenses_f2 w_daily_percapita_expenses
    ren w_number_animals_fup2_w       w_number_animals_w
    ren w_number_farmassets_fup2_w    w_number_farmassets_w
    ren ihs_daily_percapita_expenses_f2 ihs_daily_percapita_expenses	
	ren ihs_daily_adulteq_expenses_f2  ihs_daily_adulteq_expenses
	ren ihs_profits_business_fup2    ihs_profits_business
	ren ihs_rawmats_business_fup2_w  ihs_rawmats_business
	ren profits_business_fup2        profits_business
    ren w_profits_business_fup2      w_profits_business
	ren w_rawmats_business_w_f2      w_rawmats_business
	ren rawmats_business_w_f2        rawmats_business_w
	
	
	ren foodaindex_f2                foodaindex
    ren w_daily_adulteq_expenses_f2  w_daily_adulteq_expenses
    ren foodins_index_f2  foodins_index
	ren WeightedVar_food_f2 WeightedVar_food
	ren dietdiv_score_f2    dietdiv_score
	ren w_daily_ae_expreal_f2        w_daily_ae_expreal
    ren ihs_daily_ae_expreal_f2      ihs_daily_ae_expreal
	ren w_r_exp_ttlnonfood_7dae_f2   w_r_exp_ttlnonfood_7dae
	ren ihs_r_exp_ttlnonfood_7dae_f2 ihs_r_exp_ttlnonfood_7dae
	ren w_r_exp_ttlfood_7dae_f2      w_r_exp_ttlfood_7dae
	ren ihs_r_exp_ttlfood_7dae_f2    ihs_r_exp_ttlfood_7dae
	ren ihs_r_exp_ttlconfood_7dae_f2  ihs_r_exp_ttlconfood_7dae	
	ren w_r_exp_ttlconfood_7dae_f2    w_r_exp_ttlconfood_7dae		
	ren farming_work_w_f2          farming_work_w
	ren farming_work_h_f2          farming_work_h
    ren any_farm_hh_f2               any_farm_hh 	
	ren w_daily_hh_expenses_f2       w_daily_hh_expenses
	ren ihs_daily_hh_expenses_f2       ihs_daily_hh_expenses
	ren w_daily_hh_realexp_f2          w_daily_hh_realexp
	ren ihs_daily_hh_realexp_f2        ihs_daily_hh_realexp
    ren ihs_rexp_allfood_f2            ihs_rexp_allfood
	ren ihs_expen_7dae_f2              ihs_expen_7dae
	ren business_work_h_f2           business_work_h
	ren w_expen_7dae_f2                w_expen_7dae
	ren w_profits_business_fup2_h      w_profits_business_h
	ren ihs_profits_business_fup2_h    ihs_profits_business_h
	ren w_rawmats_business_h_f2      w_rawmats_business_h 
	ren ihs_rawmats_business_fup2_h    ihs_rawmats_business_h	
	ren profits_business_fup2_h        profits_business_h
	ren value_animals_fup2_w         value_animals_w 
	ren value_farmassets_fup2_w      value_farmassets_w 
	ren value_hhassets_fup2_w        value_hhassets_w	
	ren ttl_healthv2_exp_hh_f2       ttl_healthexp
	ren ttl_educ_exp_hh_f2           ttl_educexp
	ren ihsassetsind_f2              ihsassetsind
	ren assetsind_f2                 assetsind
	ren lab_dyn_f2                   lab_dyn   
	ren lab_dyn_w_f2                 lab_dyn_w
	ren lab_dyn_h_f2                 lab_dyn_h	
	ren d_work_w_f2                  d_work_w
	ren d_work_h_f2                  d_work_h
	ren d_work_hh_f2                 d_work_hh
	ren d_intr_lab_f2_?              d_intr_lab_?	
	ren d_intr_buslab_f2_?           d_intr_buslab_?
	ren d_intr_aglab_f2_?            d_intr_aglab_?	
	ren daily_ae_expreal_f2             daily_ae_expreal
	
  * Gen year variable and saving sample for wave
   gen year=2017
   tempfile midline
   save `midline'
  restore 
  }
** 3) Endline
** -----------------------------------------------------------------------------
if 1{ 
  preserve 
  * Keep just variables we need to transfor to panel 
  # d;
  keep $controls $lga_dummies $treat $spill 
        business_work_w_f3 
		w_profits_business_fup3        
		d_wavail_f3 d_mavail_f3 
		profits_business_fup3        
		business_work_h_f3 
		any_business_f3
		w_daily_percapita_expenses_f3  
		w_value_farmassets_fup3_w 
		w_value_hhassets_fup3_w  	  
		w_value_animals_fup3_w    
		w_number_animals_fup3_w      
		w_number_farmassets_fup3_w  
		w_value_animals_fup3_w        
		ihs_daily_percapita_expenses_f3 
	    profits_business_fup3_h       
		w_profits_business_fup3_h 
		ihs_profits_business_fup3_h  
		w_rawmats_business_h_f3 
	    ihs_rawmats_business_fup3_h 		
		ihs_daily_adulteq_expenses_f3 
		daily_ae_expreal_f3
		ihs_profits_business_fup3      
		ihs_rawmats_business_fup3_w 
		w_profits_business_fup3        
		w_rawmats_business_w_f3
		rawmats_business_w_f3
		w_daily_adulteq_expenses_f3
		d_vuln_cat_* foodins_index_f3
		WeightedVar_food_f3        
		dietdiv_score_f3
		w_daily_ae_expreal_f3      
		ihs_daily_ae_expreal_f3
		w_r_exp_ttlnonfood_7dae_f3  
		ihs_r_exp_ttlnonfood_7dae_f3
		w_r_exp_ttlfood_7dae_f3     
		ihs_r_exp_ttlfood_7dae_f3
		w_r_exp_ttlconfood_7dae_f3 
		ihs_r_exp_ttlconfood_7dae_f3
		farming_work_w_f3         
		farming_work_h_f3
	    w_daily_hh_expenses_f3      
		ihs_daily_hh_expenses_f3 
		w_daily_hh_realexp_f3       
		ihs_daily_hh_realexp_f3
		ihs_rexp_allfood_f3         
		ihs_expen_7dae_f3
		w_expen_7dae_f3
		any_farm_hh_f3           
		ragyields_f3 
		value_animals_fup3_w  
	    value_farmassets_fup3_w 
	    value_hhassets_fup3_w       
		assetsind_f3
	    ttl_healthv2_exp_hh_f3
	    ttl_educ_exp_hh_f3
		ttl_valharv_crops_f3
		ihsassetsind_f3            
		agyields_f3
		ttl_area_cult_f3            
		w_ttl_area_cult_f3
		lab_dyn_f3                  
		lab_dyn_w_f3            
		lab_dyn_h_f3
		d_work_w_f3                
		d_work_h_f3            
		d_work_hh_f3
		d_intr_lab_f3_*
	    d_intr_buslab_f3_*         
		d_intr_aglab_f3_*
		foodaindex_f3;		
   # d cr;		
  
  * Rename variables do they match in the panel level
    ren d_wavail_f3 d_wavail
    ren d_mavail_f3 d_mavail 
    ren business_work_w_f3   business_work
	ren any_business_f3      any_business
    ren w_daily_percapita_expenses_f3 w_daily_percapita_expenses
    ren w_number_animals_fup3_w      w_number_animals_w
    ren w_number_farmassets_fup3_w   w_number_farmassets_w
    ren ihs_daily_percapita_expenses_f3 ihs_daily_percapita_expenses	
    ren ihs_daily_adulteq_expenses_f3  ihs_daily_adulteq_expenses
	ren ihs_profits_business_fup3    ihs_profits_business
	ren ihs_rawmats_business_fup3_w  ihs_rawmats_business
    ren w_profits_business_fup3      w_profits_business
	ren w_rawmats_business_w_f3      w_rawmats_business
	ren rawmats_business_w_f3        rawmats_business_w	
    ren w_daily_adulteq_expenses_f3  w_daily_adulteq_expenses
	ren foodaindex_f3                foodaindex	
	ren foodins_index_f3             foodins_index
	ren WeightedVar_food_f3          WeightedVar_food
	ren dietdiv_score_f3             dietdiv_score
	ren w_daily_ae_expreal_f3        w_daily_ae_expreal
    ren ihs_daily_ae_expreal_f3      ihs_daily_ae_expreal
	ren w_r_exp_ttlnonfood_7dae_f3   w_r_exp_ttlnonfood_7dae
	ren ihs_r_exp_ttlnonfood_7dae_f3 ihs_r_exp_ttlnonfood_7dae
	ren w_r_exp_ttlfood_7dae_f3      w_r_exp_ttlfood_7dae
	ren ihs_r_exp_ttlfood_7dae_f3    ihs_r_exp_ttlfood_7dae
	ren ihs_r_exp_ttlconfood_7dae_f3 ihs_r_exp_ttlconfood_7dae	
	ren w_r_exp_ttlconfood_7dae_f3   w_r_exp_ttlconfood_7dae		
	ren farming_work_w_f3            farming_work_w
	ren farming_work_h_f3            farming_work_h
	ren w_daily_hh_expenses_f3       w_daily_hh_expenses
	ren ihs_daily_hh_expenses_f3     ihs_daily_hh_expenses
	ren w_daily_hh_realexp_f3        w_daily_hh_realexp
	ren ihs_daily_hh_realexp_f3      ihs_daily_hh_realexp
    ren ihs_rexp_allfood_f3          ihs_rexp_allfood
	ren ihs_expen_7dae_f3            ihs_expen_7dae
    ren profits_business_fup3        profits_business
	ren business_work_h_f3           business_work_h
	ren w_expen_7dae_f3              w_expen_7dae
	ren w_profits_business_fup3_h    w_profits_business_h
	ren ihs_profits_business_fup3_h  ihs_profits_business_h
	ren w_rawmats_business_h_f3      w_rawmats_business_h 
	ren ihs_rawmats_business_fup3_h  ihs_rawmats_business_h	
	ren profits_business_fup3_h      profits_business_h
    ren any_farm_hh_f3               any_farm_hh 
	ren ttl_valharv_crops_f3         ttl_valharv_crops
	ren ragyields_f3                 ragyields	
	ren agyields_f3                  agyields
	ren value_animals_fup3_w         value_animals_w 
	ren value_farmassets_fup3_w      value_farmassets_w 
	ren value_hhassets_fup3_w        value_hhassets_w
	ren ttl_healthv2_exp_hh_f3       ttl_healthexp
	ren ttl_educ_exp_hh_f3           ttl_educexp
	ren ihsassetsind_f3              ihsassetsind
	ren assetsind_f3                 assetsind
	ren ttl_area_cult_f3             ttl_area_cult
	ren w_ttl_area_cult_f3           w_ttl_area_cult
	ren lab_dyn_f3                   lab_dyn   
	ren lab_dyn_w_f3                 lab_dyn_w
	ren lab_dyn_h_f3                 lab_dyn_h	
	ren  d_work_w_f3                 d_work_w
	ren  d_work_h_f3                 d_work_h
	ren  d_work_hh_f3                d_work_hh
	ren  d_intr_lab_f3_?             d_intr_lab_?	
	ren  d_intr_buslab_f3_?          d_intr_buslab_?
	ren  d_intr_aglab_f3_?           d_intr_aglab_?
	ren daily_ae_expreal_f3          daily_ae_expreal
	
* Gen year variable and saving sample for wave
  gen year=2018
  tempfile endline 
  save `endline'
  restore     
}  

** Appending Wave datasets to create Panel 
** -----------------------------------------------------------------------------  
if 1{
   use `baseline', clear 
   append using `midline'
   append using  `endline'
 * Verify that hhid classifies as an ID variable
   gen long hhid_panel=real(hhid)
   assert hhid_panel!=.
   drop hhid 	
 * Step 5: Generating spatial dependence matrix  
  // spmatrix create idistance W_panel_new if year==2015
   tab year, gen(d_year_)
  
   gen     d_vuln_other=(d_vuln_cat_2==1 | d_vuln_cat_3==1)
   replace d_vuln_other=0 if village_ineligible_ct==1
   la var  d_vuln_other "Other vulnerables"
   
   gen    CTvill=(village_ineligible_ct==0)
   la var CTvill "CT village"
   la def CTvill 1 "Cash Transfer Program Villages"  0 "Non-Program Villages", modify
   la val CTvill CTvill
   
   gen ctquart_year2=ct_lumpsum*d_year_2
   gen ctquart_year3=ct_lumpsum*d_year_3
   
   gl var_panel d_ct_nct_inel_1 d_ct_nct_inel_2 d_ct_nct_inel_3 ///
                b???ct  b????ct  b*ct_lp b*ct_m         ///
				b???pov b????pov ct_lumpsum ct_month   ///
				b*ct_tp50 b*ct_tmean pet*  CTvill pEV* ///
				CT_PET* CT_PEV*  CT_HH* VVML_PET*
				 
   foreach var of varlist $var_panel{
   gen `var'_year1=`var'*d_year_1
   gen `var'_year2=`var'*d_year_2
   gen `var'_year3=`var'*d_year_3
     
   } 
   
   gen wave=. 
   replace wave=0 if year==2015
   replace wave=1 if year==2017
   replace wave=2 if year==2018
   
   la def wave 0 "Baseline" 1 "Midline" 2 "Endline", modify 
   la val wave wave
   
   gen d_vv_year2=d_vuln_cat_2*d_year_2
   la var d_vv_year2 "VV*Midline"
   gen d_vv_year3=d_vuln_cat_2*d_year_3
   la var d_vv_year3 "VV*Endline"
   
   gen d_ml_year2=d_vuln_cat_3*d_year_2
   la var d_ml_year2 "ML*Midline"
   gen d_ml_year3=d_vuln_cat_3*d_year_3
   la var d_ml_year3 "ML*Endline"
   
   gl var2  b???ct b????ct b*ct_tp50 b*ct_tmean pet*
   
   foreach var of varlist $var2{   
   gen CT_`var'_year1=d_ct_nct_inel_2*`var'*d_year_1
   la var CT_`var'_year1 "CT*#CT*Baseline (`var')"
   gen CT_`var'_year2=d_ct_nct_inel_2*`var'*d_year_2
   la var CT_`var'_year2 "CT*#CT*Midline (`var')"
   gen CT_`var'_year3=d_ct_nct_inel_2*`var'*d_year_3
   la var CT_`var'_year3 "CT*#CT*Endline (`var')"
   gen CTLS_`var'_year2=ct_lumpsum*`var'*d_year_2
   la var CTLS_`var'_year2 "CTLumpSum*#CT*Midline (`var')"
   gen CTLS_`var'_year3=ct_lumpsum*`var'*d_year_3
   la var CTLS_`var'_year3 "CTLumpSum*#CT*Endline (`var')"
   gen d_vvml_`var'_year2=d_vuln_other*`var'*d_year_2
   la var d_vvml_`var'_year2 "VVML*#CT*Midline(`var')"
   gen d_vvml_`var'_year3=d_vuln_other*`var'*d_year_3
   la var d_vvml_`var'_year3 "VVML*#CT*Endline(`var')"
   gen d_vv_`var'_year2=d_vuln_cat_2*`var'*d_year_2
   la var d_vv_`var'_year2 "VV*#CT*Midline(`var')"
   gen d_vv_`var'_year3=d_vuln_cat_3*`var'*d_year_3
   la var d_vv_`var'_year3 "VV*#CT*Endline(`var')"    
   gen d_ml_`var'_year2=d_vuln_cat_2*`var'*d_year_2
   la var d_ml_`var'_year2 "ML*#CT*Midline(`var')"
   gen d_ml_`var'_year3=d_vuln_cat_3*`var'*d_year_3
   la var d_ml_`var'_year3 "ML*#CT*Endline(`var')"   
   }
   
   gl var3  b*ct_lp 
   foreach var of varlist $var3{   
   gen    CT_`var'_year1=d_ct_nct_inel_2*`var'*d_year_1
   la var CT_`var'_year1 "CT*#CT(LumpSum)*Baseline"
   gen    CT_`var'_year2=d_ct_nct_inel_2*`var'*d_year_2
   la var CT_`var'_year2 "CT*#CT(LumpSum)*Midline"
   gen    CT_`var'_year3=d_ct_nct_inel_2*`var'*d_year_3
   la var CT_`var'_year3 "CT*#CT(LumpSum)*Endline"
   gen    CTLS_`var'_year1=ct_lumpsum*`var'*d_year_1
   la var CTLS_`var'_year1 "CT(LumpSum)*#CT(LumpSum)*Baseline"
   gen    CTLS_`var'_year2=ct_lumpsum*`var'*d_year_2
   la var CTLS_`var'_year2 "CT(LumpSum)*#CT(LumpSum)*Midline"
   gen    CTLS_`var'_year3=ct_lumpsum*`var'*d_year_3
   la var CTLS_`var'_year3 "CT(LumpSum)*#CT(LumpSum)*Endline"   
   }
  
   gl var4  b*ct_m
   foreach var of varlist $var4{   
   gen    CT_`var'_year1=d_ct_nct_inel_2*`var'*d_year_1
   la var CT_`var'_year1 "CT*#CT(Monthly)*Baseline"
   gen    CT_`var'_year2=d_ct_nct_inel_2*`var'*d_year_2
   la var CT_`var'_year2 "CT*#CT(Monthly)*Midline"
   gen    CT_`var'_year3=d_ct_nct_inel_2*`var'*d_year_3
   la var CT_`var'_year3 "CT*#CT(Monthly)*Endline"
   gen    CTLS_`var'_year1=ct_lumpsum*`var'*d_year_1
   la var CTLS_`var'_year1 "CT(LumpSum)*#CT(Monthly)*Baseline"
   gen    CTLS_`var'_year2=ct_lumpsum*`var'*d_year_2
   la var CTLS_`var'_year2 "CT(LumpSum)*#CT(Monthly)*Midline"
   gen    CTLS_`var'_year3=ct_lumpsum*`var'*d_year_3
   la var CTLS_`var'_year3 "CT(LumpSum)*#CT(Monthly)*Endline"   
   }
   
   
 * Conditional profits and raw materials 
   gen w_profits_business_con=w_profits_business if business_work==1
   gen ihs_profits_business_con=ihs_profits_business if business_work==1  
   gen ihs_rawmats_business_con=ihs_rawmats_business if business_work==1 
   la var ihs_rawmats_business_con "Raw materials Conditional (IHS)"
   gen w_rawmats_business_con=w_rawmats_business if business_work==1
   la var w_rawmats_business_con "Raw materials Conditional (Winsor)"
   
   egen     w_rexp_allfood=rowtotal(w_r_exp_ttlfood_7dae  w_r_exp_ttlconfood_7dae)	 
   la var   w_rexp_allfood  "Real Food Consumption (Expenditures+OwnConsumption Adult Eq)"
   
 * Winsor variables 
   winsor ragyields, gen (w_ragyields) p (0.05)
   la var w_ragyields "Agriculture Yields Real"
   
   winsor ttl_healthexp, gen (w_ttl_healthexp) p (0.02) 
   winsor ttl_educexp, gen (w_ttl_educexp) p (0.02) 
   
 * Gen cash transfers at the village level 
   bysort village_new_bl: egen num_CT_village_bl=total(d_ct_nct_inel_2) if d_year_1==1 
   bysort village_new_bl: egen num_CT_village=max(num_CT_village_bl)
   la var num_CT_village "Number of CT in the village"
   
   foreach var of varlist d_ct_nct_inel_1 d_ct_nct_inel_2 d_ct_nct_inel_3{
   gen `var'_CTV=`var'*num_CT_village
   gen `var'_CTV_y1=`var'_CTV*d_year_1
   gen `var'_CTV_y2=`var'_CTV*d_year_2
   gen `var'_CTV_y3=`var'_CTV*d_year_3
   }
   
   gen num_CT_village_y2=num_CT_village*d_year_2
   gen num_CT_village_y3=num_CT_village*d_year_3
   gen num_vul_village_y2=num_vul_village*d_year_2
   gen num_vul_village_y3=num_vul_village*d_year_3   
   
** Real variables 
   gen realvalanimal=value_animals_w
   gen realvalfarm=value_farmassets_w 
   gen realvalhh=value_hhassets_w 
   foreach var of varlist realvalanimal realvalfarm realvalhh{
   replace `var'=. if wave==0
   replace `var'=`var'/1.307 
   replace `var'=`var'/1.486
   winsor  `var', gen (w_`var') p (0.05)
   }
 
 * Labels 
 	la var year 				 "Year"
 	la var d_year_1   		     "Baseline" 
	la var d_year_2   		     "Midline"
	la var d_year_3   			 "Endline"
    la var ct_month_year2   	 "MonthlyCT in CT villages*Midline"
    la var ct_month_year3  		 "MonthlyCT in CT villages*Endline"
    la var ct_lumpsum_year2 	 "LumpSumCT in CT villages*Midline"
    la var ct_lumpsum_year3 	 "LumpSumCT in CT villages*Endline"	
    la var d_ct_nct_inel_1_year1 "NCT in CT villages * BL"
    la var d_ct_nct_inel_1_year2 "NCT in CT villages * Midline"   
    la var d_ct_nct_inel_1_year3 "NCT in CT villages * Endline"	
    la var d_ct_nct_inel_2_year1 "CT in CT villages * BL"
    la var d_ct_nct_inel_2_year2 "CT in CT villages * Midline"   
    la var d_ct_nct_inel_2_year3 "CT in CT villages * Endline"	
    la var d_ct_nct_inel_3_year1 "Ineligible * BL"
    la var d_ct_nct_inel_3_year2 "Ineligible * Midline"   
    la var d_ct_nct_inel_3_year3 "Ineligible * Endline"	
	la var age_hhhead_bl         "HHH Age"
	la var marital_status_bl     "Married"
	la var literacy_hhhead_bl    "HHH Literacy"
	la var num_plots_bl          "Number of plots at baseline"
	la var hhtype_bl             "HH type"
	la var d_lgacode_bl_1        "Birnin"
	la var w_daily_percapita_expenses "Consumption (Daily expenditures)" 
	la var value_farmassets_w    "Current value of farming assets"
	la var value_hhassets_w      "Current value of household assets" 
	la var value_animals_w       "Current value of animals (Wife)"
	la var d_ct_nct_inel_1       "No CT (in CT villages)"
    la var d_ct_nct_inel_2       "CT (in CT villages)"
	la var business_work              "Non-Farm Enterprise(Wife)"
	la var business_work_h            "Non-Farm enterprise(Husband)"
	la var any_business               "Non-Farm enterprise(Household)"
	la var ihs_daily_adulteq_expenses "Daily adult eq expenditures (IHS)"
    la var ihs_rawmats_business       "Raw materials (IHS)"
	la var ihs_profits_business       "Profits (IHS)"
    la var ihs_profits_business_con   "Conditional Profits (IHS)"
	la var ihs_profits_business_h     "Profits (IHS)"
	la var w_daily_adulteq_expenses   "Daily adult eq expenditures (Winsor)"
    la var w_rawmats_business         "Raw materials (Winsor)"
	la var w_profits_business         "Profits (Winsor)"	
    la var w_profits_business_con     "Conditional Profits (Winsor)"	
	la var w_daily_hh_expenses        "Daily HH expenses (Winsor 0.1)"
	la var ihs_daily_hh_expenses      "Daily HH expenses (IHS)"
	la var w_daily_hh_realexp         "Daily HH real expenses (Winsor 0.1)"
	la var ihs_daily_hh_realexp       "Daily HH real expenses (IHS)"
	la var ihs_daily_percapita_expenses "Daily per capita expenses (IHS)"
	la var w_r_exp_ttlconfood_7dae     "Real Food consumption total last 7d (Adult Eq)"
	la var ihs_r_exp_ttlconfood_7dae   "Real Food consumption total last 7d (Adult Eq)(IHS)"
	la var ihs_r_exp_ttlnonfood_7dae   "Real Non-Food expenditures total last 7d (Adult Eq)(IHS)"
	la var ihs_r_exp_ttlfood_7dae      "Real Food expenditures total last 7d (Adult Eq)(IHS)"
	la var w_r_exp_ttlconfood_7dae     "Real Food consumption total last 7d (Adult Eq)(Winsor)"
	la var w_r_exp_ttlnonfood_7dae     "Real Non-Food expenditures total last 7d (Adult Eq)(Winsor)"
	la var w_r_exp_ttlfood_7dae        "Real Food expenditures total last 7d (Adult Eq)(Winsor)"
	la var ihs_rexp_allfood            "Real Food Consumption (Expenditures+OwnConsumption Adult Eq) (IHS)"
	la var ihs_expen_7dae              "Real Expenditures Adult Equivalent 7days (IHS)"
	la var w_expen_7dae                "Real Expenditures Adult Equivalent 7days (Winsor)"
	la var d_work_w                    "Any work (Wife)"
	la var d_work_h                    "Any work (Husband)"	
	la var d_intr_lab_1                "No one worked"
	la var d_intr_lab_2                "Only husband worked"
	la var d_intr_lab_3                "Only wife worked"
	la var d_intr_lab_4                "Wife and husband worked"
    la var d_intr_buslab_1             "No Business"
	la var d_intr_buslab_2             "Only husband business"
	la var d_intr_buslab_3             "Only wife business"
	la var d_intr_buslab_4             "Both business"
    la var d_intr_aglab_1              "No Farming"
	la var d_intr_aglab_2              "Only husband farms"
	la var d_intr_aglab_3              "Only wife farms"
	la var d_intr_aglab_4              "Both farm"



	foreach meters in 100 200 300 400 500 600 700 800 900 1000{
	la var b`meters'ct_year1      "Number of cash transfers (`meters'mts) * BL"
	la var b`meters'ct_year2      "Number of cash transfers (`meters'mts) * Midline"
	la var b`meters'ct_year3      "Number of cash transfers (`meters'mts) * Endline"
	la var b`meters'pov_year1     "Number of poor (`meters'mts) * BL"
	la var b`meters'pov_year2     "Number of poor (`meters'mts) * Midline"
	la var b`meters'pov_year3     "Number of poor (`meters'mts) * Endline"
	}
   

    la var d_ct_nct_inel_1_CTV    "No CT*#CT in village"
    la var d_ct_nct_inel_2_CTV    "CT*#CT in village"
	la var d_ct_nct_inel_3_CTV    "Pure Control*#CT in village"
	la var d_ct_nct_inel_1_CTV_y1 "No CT*#CT in village*Baseline"
	la var d_ct_nct_inel_2_CTV_y1 "CT*#CT in village*Baseline"
	la var d_ct_nct_inel_3_CTV_y1 "Pure Control*#CT in village*Baseline"  
	la var d_ct_nct_inel_1_CTV_y2 "No CT*#CT in village*Midline"
	la var d_ct_nct_inel_2_CTV_y2 "CT*#CT in village*Midline"
	la var d_ct_nct_inel_3_CTV_y2 "Pure Control*#CT in village*Midline"     
	la var d_ct_nct_inel_1_CTV_y3 "No CT*#CT in village*Endline"
	la var d_ct_nct_inel_2_CTV_y3 "CT*#CT in village*Endline"
	la var d_ct_nct_inel_3_CTV_y3 "Pure Control*#CT in village*Endline"        
    la var num_CT_village_y2      "Number CT in the vilalge*Midline"
    la var num_CT_village_y3      "Number CT in the vilalge*Endline"
	la var num_vul_village_y2     "Number of vulnerables*Midline"
	la var num_vul_village_y3     "Number of vulnerables*Endline"	
	la var farming_work_w         "Farming Work (Wife)"
	la var farming_work_h         "Farming Work (Husband)"	
	la var ihs_daily_ae_expreal   "Daily Adult Equivalent Expenditures Real (IHS)"
	la var w_daily_ae_expreal     "Daily Adult Equivalent Expenditures Real (Winsor)"
	la var foodins_index          "Household Food Security Scale"
	la var WeightedVar_food       "Anderson Index"
	la var dietdiv_score          "Dietary diversity Score for 7 food groups"
	la var CTvill_year2           "CT village*Midline"
	la var CTvill_year3           "CT village*Endline"	
    la var ragyields              "Agriculture Yields (Real-Prices from Market Survey)"
    la var w_ragyields            "Agriculture Yields (Real-W/95)"
	la var ttl_area_cult          "Total Area Cultivated (Hectares)"
	la var w_ttl_area_cult        "Total Area Cultivated (Hectares-W/95)"
	la var foodaindex             "Household Food Security (Anderson Index)"

	
	
	gen const=1
	la var const "Constant"

	foreach var of varlist d_ct_nct_inel_1_year2 d_ct_nct_inel_1_year3 ///
	                       d_ct_nct_inel_2_year2 d_ct_nct_inel_2_year3{
	replace `var'=0 if `var'==. 					   	
						   } 
	 
	
	
 * Defining sample 
   keep if d_wavail==1 | d_mavail==1
   drop if business_work==. 
   drop if b500pov==.
  	 
   bysort hhid_panel: gen temp=_n 
   bysort hhid_panel: egen   num_wave_bus=max(temp)
   la var num_wave_bus "Number of waves hh"
   tab num_wave_bus
   
   
   gen nct_control=(d_ct_nct_inel_1==1 | d_ct_nct_inel_3==1)
   gen ct_control=(d_ct_nct_inel_2==1 | d_ct_nct_inel_3==1)   
   gen anyVVML=(d_vuln_cat_2==1 | d_vuln_cat_3==1)
   
   gen    d_vvml_year1=(anyVVML*d_year_1)
   la var d_vvml_year1 "VVML*Baseline"  
   gen    d_vvml_year2=(anyVVML*d_year_2)
   la var d_vvml_year2 "VVML*Midline"
   gen    d_vvml_year3=(anyVVML*d_year_3)
   la var d_vvml_year3 "VVML*Endline" 
   
   gen    d_vvml_CT_year2=(anyVVML*d_year_2*CTvill)
   gen    d_vvml_CT_year3=(anyVVML*d_year_3*CTvill)
   
   gen    panel_sample=(num_wave_bus==3)
   la var panel_sample "Sample for Panel Anaylsis"

   foreach var of varlist age_hhhead_bl marital_status_bl num_plots_bl{
	gen `var'_ct_y2=`var'*d_ct_nct_inel_2_year2
	gen `var'_ct_y3=`var'*d_ct_nct_inel_2_year3		
	gen `var'_nct_y2=`var'*d_ct_nct_inel_1_year2
	gen `var'_nct_y3=`var'*d_ct_nct_inel_1_year3			
	} 
	
	la var age_hhhead_bl_ct_y2      "Age of hhh*CT(Year 2)"
	la var age_hhhead_bl_ct_y3      "Age of hhh*CT(Year 3)"
	
	la var age_hhhead_bl_nct_y2     "Age of hhh*NCT(Year 2)"
	la var age_hhhead_bl_nct_y3     "Age of hhh*NCT(Year 3)"
	
	la var marital_status_bl_ct_y2  "Marital Status*CT(Year 2)"
	la var marital_status_bl_ct_y3  "Marital Status*CT(Year 3)"
	la var marital_status_bl_nct_y2 "Marital Status*NCT(Year 2)"
	la var marital_status_bl_nct_y3 "Marital Status*NCT(Year 3)"
	
	la var num_plots_bl_ct_y2       "Number of plots*CT(Year 2)"
	la var num_plots_bl_nct_y2      "Number of plots*NCT(Year 2)"
	la var num_plots_bl_ct_y3       "Number of plots*CT(Year 3)"
	la var num_plots_bl_nct_y3      "Number of plots*NCT(Year 3)"	
     
  * Real 
    gen     realprofits_w=profits_business
    replace realprofits_w=profits_business/1.307 if wave==1
    replace realprofits_w=profits_business/1.486  if wave==2

    gen     realprofits_h=profits_business_h
    replace realprofits_h=profits_business_h/1.307 if wave==1
    replace realprofits_h=profits_business_h/1.486  if wave==2 
    
    gen     realrawmat_w=rawmats_business_w
    replace realrawmat_w=rawmats_business_w/1.307 if wave==1
    replace realrawmat_w=rawmats_business_w/1.486  if wave==2
	
	
	
	
  * Conditional 
    gen     conrealprofits_w=realprofits_w 
	replace conrealprofits_w=. if  conrealprofits_w==0 | conrealprofits_w==.
	
    gen     conrealprofits_h=realprofits_h 
	replace conrealprofits_h=. if  conrealprofits_h==0 | conrealprofits_h==.	
	
	
	gen      w_conrawmats_bus=w_rawmats_business
	replace  w_conrawmats_bus=. if  w_conrawmats_bus==0
	la var   w_conrawmats_bus "Raw materials (Conditional)"
	
	gen  conrealexp_dae=daily_ae_expreal
	
	ihstrans realprofits_w realprofits_h conrealprofits_w  conrealprofits_h
	foreach var of varlist realprofits_w realprofits_h conrealprofits_w  ///
	                       conrealprofits_h  realrawmat_w conrealexp_dae{
	winsor `var', gen (w_`var') p(0.05)
	winsor `var', gen (w2_`var') p(0.01)			
	gen  l_`var'= log(`var' + 1)	
	}
	
	foreach var of varlist realprofits_w realprofits_h conrealprofits_w  ///
	                       conrealprofits_h  realrawmat_w conrealexp_dae{
	gen    `var'T1=`var' if wave==0
	gen    `var'T2=`var' if wave==1
	gen    `var'T3=`var' if wave==2
	winsor `var'T1, gen (w_`var'T1) p(0.01)
	winsor `var'T2, gen (w_`var'T2) p(0.01)
	winsor `var'T3, gen (w_`var'T3) p(0.01)
	
	gen     w3_`var'=. 
	replace w3_`var'=w_`var'T1 if wave==0
	replace w3_`var'=w_`var'T2 if wave==1
	replace w3_`var'=w_`var'T3 if wave==2
	
	drop  `var'T? w_`var'T?
	}
		
	winsor realprofits_w, gen (w90_realprofits_w) p (0.10) highonly
	winsor realprofits_w, gen (w80_realprofits_w) p (0.20) highonly
	winsor realprofits_w, gen (w70_realprofits_w) p (0.30) highonly	
	winsor realprofits_h, gen (w90_realprofits_h) p (0.10) highonly		
	winsor realprofits_h, gen (w80_realprofits_h) p (0.20) highonly

	
  foreach var of varlist conrealprofits_w  conrealprofits_h conrealexp_dae {
 	winsor `var', gen(w95_`var') p(0.05) highonly  	
	winsor `var', gen(w90_`var') p(0.10) highonly	
	winsor `var', gen(w80_`var') p(0.20) highonly		
	
	}

	
	ihstrans conrealexp_dae

	la var w95_conrealprofits_w "Conditional Real Profits Wife (w95)"	
	la var w90_conrealprofits_w "Conditional Real Profits Wife (w90)"
	la var w80_conrealprofits_w "Conditional Real Profits Wife (w80)"	
	la var w95_conrealprofits_h "Conditional Real Profits Husband (w95)"	
	la var w90_conrealprofits_h "Conditional Real Profits Husband (w90)"
	la var w80_conrealprofits_h "Conditional Real Profits Husband (w80)"	
	
	la var w80_conrealexp_dae  "Daily Adult Equivalent Real Conditional (w80)"		
	la var w90_conrealexp_dae  "Daily Adult Equivalent Real Conditional (w90)"		
	la var w95_conrealexp_dae  "Daily Adult Equivalent Real Conditional (w95)"	
	la var l_conrealexp_dae    "Daily Adult Equivalent Real Conditional (Log)"	
	la var ihs_conrealexp_dae  "Daily Adult Equivalent Real Conditional (IHS)"	
	
	
	la var w_conrealprofits_w     "Real Profits Conditional Wife (W/95)"
	la var ihs_conrealprofits_w   "Real Profits Conditional Wife (IHS)"
	la var w_conrealprofits_h     "Real Profits Conditional Husband (W/95)"
	la var ihs_conrealprofits_h   "Real Profits Conditional Husband (IHS)"	
	la var w_realprofits_w        "Real Profits Wife (W/95)"	
	la var w3_realprofits_w       "Real Profits Wife (W/99 by wave)"	
	la var w_realprofits_h        "Real Profits Husband (W/95)"	
	la var l_realprofits_w        "Real Profits Wife (LOG)"	
	la var w2_realprofits_w        "Real Profits Wife (W/99)"	
	la var w2_realprofits_h        "Real Profits Husband (W/99)"		
	la var ihs_realprofits_w      "Real Profits Wife (IHS)"	
	la var ihs_realprofits_h      "Real Profits Husband (IHS)"
	la var w_realrawmat_w         "Real Raw material (W95)"
	la var w2_realrawmat_w        "Real Raw material (W99)"	 
	la var w3_realrawmat_w        "Real Raw material (W99 by wave)"		
	la var l_realrawmat_w         "Real Raw material (LOG)"	 
	
   * Generating positive income generating activity 
     gen     d_posagyields=(ragyields>0 & ragyields<.)
	 la var  d_posagyields "Positive Yields"
	 replace d_posagyields=. if wave==1
	 
	 gen     d_posprofits_w=(profits_business>0 & profits_business<.)
	 gen     d_posprofits_h=(profits_business_h>0 & profits_business_h<.)	 
	 la var  d_posprofits_w "Positive Business Profits (Wife)"	 
	 la var  d_posprofits_h "Positive Business Profits (Husband)"
	 
  * Labor dynamics 
	foreach var of varlist lab_dyn lab_dyn_w lab_dyn_h{
	tab `var', gen (d_`var'_)	
	}

	la var d_lab_dyn_1    "No activity (Household)"
	la var d_lab_dyn_2    "Only farming (Household)"
	la var d_lab_dyn_3    "Only non-farming business(Household)"
	la var d_lab_dyn_4    "Farming and non-farming business(Household)"
	la var d_lab_dyn_w_1  "No activity (Wife)"
	la var d_lab_dyn_w_2  "Only farming (Wife)"
	la var d_lab_dyn_w_3  "Only non-farming business (Wife)"
	la var d_lab_dyn_w_4  "Farming and non-farming business (Wife)"
	la var d_lab_dyn_h_1  "No activity (Husband)"
	la var d_lab_dyn_h_2  "Only farming (Husband)"
	la var d_lab_dyn_h_3  "Only non-farming business (Husband)"
	la var d_lab_dyn_h_4  "Farming and non-farming business (Husband)"
	  	 
	 
 ** Generating RDD sample 
 ** ------------------------------------------------------------
	/*Defining the different bandwidths = +/- bandwidth number of EVs within 
	 the village above and below the 18 EVs per village cutoff. 
	 For example RDD_13 includes all villages with 5 EVs to 31 EVs within the village. 
	 RDD_10 includes all villages with 8 EVs to 28 EVs within the village*/
		gen RDD = 1
		gen RDD_13 = .
		gen RDD_12 = .
		gen RDD_10 = . 
		gen RDD_18 = . 
		gen RDD_15 = .

		***The bandwidth selected from local randomization methods 
		***RDD_13
		local villages 103 110 111 114 115 126	135	144	151	157	207	209 216 220	///
					   227	231	233	235 243	252	256	259 263	264 273
		local num_villages : list sizeof villages
		forvalues i = 1/`num_villages' {
		local rdd_villages: word `i' of `villages'
		replace RDD_13 = 1 if village_new_bl==`rdd_villages'
		}

		***RDD_12
		local villages 103 110 111 114 115 126	135	151	207	209 216 220	227	231	///
		               233	235 252	256	259 263	264 273
		local num_villages : list sizeof villages
		forvalues i = 1/`num_villages' {
		local rdd_villages: word `i' of `villages'
		replace RDD_12 = 1 if village_new_bl==`rdd_villages'
		}


		**RDD_10
		local villages 115 126 135 151 207 209 220 227	231	233	235	252	256	259	264	
		local num_villages : list sizeof villages
		forvalues i = 1/`num_villages' {
		local rdd_villages: word `i' of `villages'
		replace RDD_10 = 1 if village_new_bl==`rdd_villages'
		}

		**RDD_18
		local villages 110 111 114 129 131 132 133 134 135 151 209 221 227 231 ///
		               233 235 256 259 273 115 207 220 252 264 273 272 271 263 ///
					   257 255 252 247 246 243 238 234 230 222 220 219 218 216 ///
					   215 214 212 207 203 159 158 157 156 155 154 153 151 150 ///
					   144 143 142 135 134 133 131 129 128 126 117 113 109 108 ///
					   107 106 103 223 217 104 229 125 265 139 118 260 210
		local num_villages : list sizeof villages
		forvalues i = 1/`num_villages' {
		local rdd_villages: word `i' of `villages'
		replace RDD_18 = 1 if village_new_bl==`rdd_villages'
		}

		***RDD_15
		local villages 110 111 114 129 131 132 133 134 135 151 209 221 227 231 ///
		               233 235 256 259 273 115 207 220 252 264 273 272 271 263 ///
					   257 255 252 247 246 243 238 234 230 222 220 219 218 216 ///
					   215 214 212 207 203 159 158 157 156 155 154 153 151 150 ///
					   144 143 142 135 134 133 131 129 128 126 117 113 109 108 107 106 103
		local num_villages : list sizeof villages
		forvalues i = 1/`num_villages' {
		local rdd_villages: word `i' of `villages'
		replace RDD_15 = 1 if village_new_bl==`rdd_villages'
		}

 ** Generating treatment groups for FNLP Main Analysis 
	* Generating treatment variable with all possible categories 
	  gen      treat_group=.
	  replace  treat_group=0 if CT_hhtreat==0 & FNLP_treatment==0
	  replace  treat_group=1 if CT_hhtreat==0 & FNLP_treatment==1
	  replace  treat_group=2 if CT_hhtreat==1 & FNLP_treatment==0
	  replace  treat_group=3 if CT_hhtreat==1 & FNLP_treatment==1  
	  replace  treat_group=4 if CT_hhtreat==2 & FNLP_treatment==0
	  replace  treat_group=5 if CT_hhtreat==2 & FNLP_treatment==1
	 
   * Treatment group label 
     la def treat_group 0 "Pure Control (CT village=0/FNLP=0)"                    ///
                      1 "Control in FNLP village (CT village=0/FNLP=1)"         ///
					  2 "NCT in non-FNLP Village (CT village=1/FNLP=0)"         ///
                      3 "NCT in FNLP Village (CT village=1/FNLP=1)"             ///
                      4 "CT in non-FNLP Village (CT village=1/FNLP=1)"          ///					  
					  5 "CT in FNLP Village (CT village=1/FNLP=1)"              ///
					  , modify 
     la val treat_group treat_group	
	 la var treat_group  "Treatment Groups (Pure control, NCT recepients, CT recepients, FNLP treatment)"	 
	 
	* Generating treatment variable with all possible categories for VVML
	  gen      treat_groupOV=.
	  replace  treat_groupOV=0 if CTvill==0 & FNLP_treatment==0
	  replace  treat_groupOV=1 if CTvill==0 & FNLP_treatment==1
	  replace  treat_groupOV=2 if CTvill==1 & FNLP_treatment==0
	  replace  treat_groupOV=3 if CTvill==1 & FNLP_treatment==1  

	  # d;
	  la def   treat_groupOV 
	                   1  "CT control village & non-FNLP control village"
		               2  "CT control village & FNLP village"
				       3  "CT village & non-FNLP control village"
				       4  "CT village & FNLP  village", modify; 
	  # d cr;
	  la val  treat_groupOV treat_groupOV
 	  la var treat_groupOV  "Treatment Groups (Pure control, NCT recepients, CT recepients, FNLP treatment)"
	  
	* Treatment different EV and VV 
	  gen      treat_spill=.
	  replace  treat_spill=0 if CT_hhtreat==0 
	  replace  treat_spill=1 if CT_hhtreat==1 
	  replace  treat_spill=2 if CT_hhtreat==2 
	  replace  treat_spill=3 if anyVVML==1 &  CTvill==0
	  replace  treat_spill=4 if anyVVML==1 &  CTvill==1

   * Treatment group label 
     la def treat_spill 0 "Pure Control"                 ///
                        1 "NCT in CT village"            ///
                        2 "CT in CT village"             ///
                        3 "VVML in non-CT Village"          ///					  
					    4 "VVML in CT Village", modify 
     la val treat_spill treat_spill
	 la var treat_spill "Treatment Groups (Pure control, NCT recepients, CT recepients)"	 	
	
	
	
  foreach var of varlist d_work_h      farming_work_h business_work_h ///
					 d_lab_dyn_h_?{
  replace `var'=. if d_mavail==0
					 }	


  bysort village_group: egen mean_dist=mean(max_distance)
  
* Saving final data for analysis
  save "$data/Final/FNLPDataLongAnalysis.dta", replace 
 
}


  
********************************************************************************
//  END OF PART A DOFILE
********************************************************************************
	