********************************************************************************
* Cash Is Queen                                                                *
* Local Economy Effects of Cash Transfers to Women in West Africa              *
* Replication File                                                             *
* Author: Paula Gonzalez                                                       
* Date: Jan 2025                                                               
* Last Reviewed: Jan 2025                                                      
* Version: 1.0                                                                 
********************************************************************************

/*
* Datasets Required: [List the required datasets here, if applicable]
*
* Unique Identificator: [Specify if there's any unique identifier for the datasets]
*
* Outline: 
*  1. Preparation and Main Settings
*      - Installs required packages (if needed)
*      - Defines global paths and standard settings for reproducibility
*      - Specifies sections of the analysis to be executed
*
*  2. Data Cleaning and Construction
*      - Executes dofiles responsible for cleaning and preparing datasets
*      - Includes scripts for household data, census/spatial data, and panel data
*
*  3. Data Analysis
*      - Runs scripts that generate descriptive statistics
*      - Produces regression tables and graphical representations
*
*  4. End of Master Dofile
*      - Closes log settings and ensures clean execution
*/

********************************************************************************
*                          PREPARATION AND MAIN SETTINGS                        
********************************************************************************

* ------------------------------------------------------------------------------ 
* Install Required Packages (Change to 1 to install on first-time setup)
* ------------------------------------------------------------------------------ 
sysdir set PLUS "./ado"
/*
if 0{
   ssc install ietoolkit, replace
   ssc install outreg2, replace
   ssc install estout, replace
   ssc install coefplot, replace
   ssc install schemepack, replace 
   ssc install colrspace, replace 
   ssc install swindex, replace
   
   ssc install winsor, replace 
   ssc install destring, replace  
   ssc install split, replace  
   ssc install clonevar, replace  
   ssc install moransi, replace 
   ssc install acreg, replace 
   findit rdwinselect  //(st0435.pkg)
   

}
*/
* ------------------------------------------------------------------------------ 
* Standardizing Settings Across Users
* ------------------------------------------------------------------------------ 
ieboilstart, version(12.1) matsize(11000)
`r(version)' 

* ------------------------------------------------------------------------------ 
* Define Root Folder gls
* ------------------------------------------------------------------------------ 

* Define Project Folder gls
* change path 
	gl main_folder   "C:/Temp/RR_NGA_2025_291/Reproducibility package" 
	gl data          "$main_folder/Data"
	gl dofiles       "$main_folder/Do files"
	gl outputs_raw   "$main_folder/Outputs/Raw" 
	gl outputs_final "$main_folder/Outputs/Final" 

* ------------------------------------------------------------------------------ 
*  Define Sections to Execute
* ------------------------------------------------------------------------------ 
	local DataCleaningConstruction 1
	local DataAnalysis             1

  
********************************************************************************
*                  DATA CLEANING AND CONSTRUCTION                               *
******************************************************************************** 
if (`DataCleaningConstruction' == 1) { 
    di "Running Data Cleaning and Construction Scripts..."
    do "$dofiles/Intermediate/Main_Parts/PartA_HouseholdDataMainEffects.do"
    do "$dofiles/Intermediate/Main_Parts/PartB_CensusAndSpatialData.do" 
    do "$dofiles/Intermediate/Main_Parts/PartC_FNLPWideData.do"
    do "$dofiles/Intermediate/Main_Parts/PartD_FNLPLongData.do"
}  

 
********************************************************************************
*                            DATA ANALYSIS                                      *
********************************************************************************
if (`DataAnalysis' == 1) { 

    * -------------------------------------------------------------------------*
    *                     MAIN ANALYSIS: PAPER RESULTS                         *
    * -------------------------------------------------------------------------*
    di "Running Main Data Analysis Scripts..."
    
    do "$dofiles/Analysis/MainAnalysis/RandomizationBalance.do"
    do "$dofiles/Analysis/MainAnalysis/RegressionAnalysis.do"
	
    * -------------------------------------------------------------------------*
    *                     APPENDIX ANALYSIS                                    *
    * -------------------------------------------------------------------------*
    di "Running Appendix Data Analysis Scripts..."
    
    local appendices "A B C D E F"
    foreach a in `appendices' {
        do "$dofiles/Analysis/AppendixAnalysis/Appendix`a'.do"
    }

	
}

********************************************************************************
*                            END OF MASTER DOFILE                              *
********************************************************************************
