********************************************************************************
*  PART D: Construction of Data For CrossSection Analysis 
*  Using household, census and neighborhood matrix data 
*  Nigeria Feed the Future - ENDLINE 2025
********************************************************************************
  * Load parts 
  gl part_a    1
  gl part_b    1
  gl part_c    1
  gl part_d    1 
  gl part_e    1 
  
** A. Load Dataset that includes main variables for analysis, cleaned GPS
** and is in a crossection format (no panel)
** ----------------------------------------------------------------------------- 
if $part_a{
	** Load Dataset generated at one level (no panel)
	   use  "$data/Intermediate\FNLP_Cleaned_Intermediate.dta", clear 
	  
	** Generating a group variable   
		clonevar village_group=village_new_bl
		replace village_group=274 if village_group==107 | village_group==108 | village_group==109
		replace village_group=275 if village_group==110 | village_group==111 | village_group==114
		replace village_group=276 if village_group==129 | village_group==131 | village_group==132
		replace village_group=277 if village_group==133 | village_group==134 
		replace village_group=278 if village_group==202 | village_group==221
		replace village_group=279 if village_group==222 | village_group==234  
		la def  villagenames  274 "Group 5" 275 "Group 6" 276 "Group 4" ///
							  277 "Group 3" 278 "Group 2" 279 "Group 1", add 
		
	** Merge with spillover data generated in R 
	 /* Note: This dataset includes all variables related with distances and radios
	 * using number of EVs, Types of business around you 
	 * R script where this was created is call:
	   R scripts/Spillovers Dataset Construction*/
	   merge 1:1 hhid using "$data/Raw/HHSpatialWideData.dta", ///
	   keepusing (b*ct b*ct_* b*ev b*pa2 b*pa3 b*_c? b100newb2-b1000oldb3) ///
	   keep(master matched) nogenerate
	  
	** Merging with the vulnerable sin the census data 
	   merge 1:1 hhid using "$data/Raw/CensusData_VulnertableHH.dta", nogenerate       ///
	   keep (master matched)
	   la var num_vul_village "#Vulnerables by village"
	   la var ppi_mean "Mean PPi Score"
	   la var ppi_score "PPI Score"
	   bysort village_group vulnerability_category_ward_bl: egen mean_temp=mean(ppi_score)
	   replace ppi_score=mean_temp if ppi_score==. 
	   drop mean_temp
	   // replacing ppi score with mean for 112 obs maybe do mean of category in village 
	   
	** Merging with second dataset that includes number of poors around you
	   merge 1:1   hhid using "$data/Intermediate/VulnerablesNeighborsMatrixData.dta",   ///
	   keepusing(b*pov b*evall b*vvall b*mlall)
	   keep if _merge==1 | _merge==3 
	   gen merge_evall=(_merge==3) 
	   drop _merge 
	   format b*pov  %12.0g
	  //Missing poverty data for 112 households 
	   gen    misscensusdata=(b400evall==.)
	   la var misscensusdata "Missing census data"
	   
	** Mergin with data of distance to market 
	   * Dataset generated in "ConstructionDistancesMarket.do" however, we provide the 
	   * data ready for analuysis since it includes sensitive information 
		 merge 1:1 hhid  using "$data/Raw/DistancesMarketData.dta", ///
		       keepusing (min_distance_market)
		 keep if _merge==1 | _merge==3    
		 gen  market_inf=1 if _merge==3
		 drop _merge 
		 
	** Mergin with data of distance to FNLP AND CT villages 
	  * Dataset generated in "ConstructionDistancesMarket.do"	   
		 merge 1:1 hhid using "$data/Raw/DistancesHHtoVillageType.dta",   ////
						nogenerate keep (master matched)
		
	** Mergin with distances datasets within village 
	  merge 1:1 hhid using "$data/Raw/DistancesWithinVillage.dta", nogenerate keep (master matched)
		
	** Merging with instensity/poverty variables at the village level 
	* This dataset was originated by implementing partner to asses poverty and 
	* intensity datasets at the village level 
	   merge m:1 village_new_bl using ///
	  "$data/Raw/VillagePovertyIntensityData.dta", ///
	   keepusing(est_ttl_pop_size est_ttl_pop_size_gr) nogenerate
	   
	   
	** Interaction  with distance to villages (HH level)
	   gen    temp=(village_ineligible_ct==0)
	   gen    min_distance_vCT_FNLP=min_distance_vCT*FNLP_treatment
	   gen    min_distance_vFNLP_FNLP=min_distance_vFNLP*FNLP_treatment
	   gen    min_distance_vCT_vCT=min_distance_vCT*temp
	   gen    min_distance_vFNLP_vCT=min_distance_vFNLP*temp
	
	   la var min_distance_vCT_FNLP   "Distance to CT*FNLP treatment (Minimun)"
	   la var min_distance_vFNLP_FNLP "Distance to FNLP*FNLP treatment (Minimun)"   
	   la var min_distance_vCT_vCT    "Distance to CT*CT Program Village (Minimun)"
	   la var min_distance_vFNLP_vCT  "Distance to FNLP*CT Program Village (Minimun)"     	   
	   drop  temp
	
	** Generating a mean for the minimun distance by village 
	  /* We want to generate a proxy for remoteness using the average distance of the 
	   households   within a village to a market. Some of the villages that were 
	   close to each other were added in groups, we are going to be using those 
	   in groups*/
	  bysort village_group: egen mean_dist_villmark=mean(min_distance_market)
	  la var mean_dist_villmark "Village distance to the closest market KM (average across hh)"
	      
	   
	   
	** Generating mean but accounting by some villages are larger 
	  preserve 
		  collapse mean_dist_villmark est_ttl_pop_size_gr  ///
				   (max) FNLP_treatment, by(village_group)
		  
		  * Checking meanc distance 		   
		  sum mean_dist_villmark if FNLP_treatment==0
		  local 	mean_0 =round(r(mean), .01) 
		  sum mean_dist_villmark if FNLP_treatment==0,d
		  local 	median_0 =round(r(p50)) 
		  
		  sum mean_dist_villmark if FNLP_treatment==1
		  local 	mean_1 =round(r(mean), .01)
		  sum mean_dist_villmark if FNLP_treatment==1,d 
		  local 	median_1 =round(r(p50)) 
		  
		  * Checking mean of population size 
		  sum est_ttl_pop_size_gr if FNLP_treatment==0
		  local 	meanX_0 =round(r(mean), .01) 
		  sum est_ttl_pop_size_gr if FNLP_treatment==0,d
		  local 	medianX_0 =round(r(p50)) 
		  
		  sum est_ttl_pop_size_gr if FNLP_treatment==1
		  local 	meanX_1 =round(r(mean), .01)
		  sum est_ttl_pop_size_gr if FNLP_treatment==1,d 
		  local 	medianX_1 =round(r(p50)) 
	  restore

	  gen     d_amean_distma_0=(mean_dist_villmark>`mean_0')
	  gen     d_amed_distma_0=(mean_dist_villmark>`median_0')  
	  gen     d_amean_distma_1=(mean_dist_villmark>`mean_1')
	  gen     d_amed_distma_1=(mean_dist_villmark>`median_1')  
	  
	  gen     d_amean_distma=d_amean_distma_0 if FNLP_treatment==0
	  replace d_amean_distma=d_amean_distma_1 if FNLP_treatment==1
	  gen     d_amed_distma=d_amed_distma_0 if FNLP_treatment==0
	  replace d_amed_distma=d_amed_distma_1 if FNLP_treatment==1
	  
	  gen     d_amean_popsize_0=(est_ttl_pop_size_gr>`meanX_0')
	  gen     d_amed_popsize_0=(est_ttl_pop_size_gr>`medianX_0')  
	  gen     d_amean_popsize_1=(est_ttl_pop_size_gr>`meanX_1')
	  gen     d_amed_popsize_1=(est_ttl_pop_size_gr>`medianX_1')  
	  
	  gen     d_amean_popsize=d_amean_popsize_0 if FNLP_treatment==0
	  replace d_amean_popsize=d_amean_popsize_1 if FNLP_treatment==1
	  gen     d_amed_popsize=d_amed_popsize_0   if FNLP_treatment==0
	  replace d_amed_popsize=d_amed_popsize_1   if FNLP_treatment==1	  
	  
	  
	  drop   d_amean_distma_? d_amed_distma_? d_amean_popsize_? d_amean_popsize_?
	  
	  la var d_amean_distma  "Village is above the mean distance to a market"
	  la var d_amed_distma   "Village is above the median distance to a market"
	  la var d_amean_popsize "Village is above the mean population of sample"
	  la var d_amed_popsize  "Village is above the median population of sample"	  


   
}  
   
** B. Generating new variables   
** -----------------------------------------------------------------------------
if $part_b{
  * We need to susbtract from variables we generated 1 
  * if household i is part of group
   gen      d_cash_treatment_unc=(d_cash_treatment==1)  
   tab vulnerability_category_ward_bl, gen (d_vuln_cat_)
   
   foreach var of varlist b*ct{
   replace `var'=`var'-d_cash_treatment_unc
   replace `var'=0 if `var'<0 
   }
   
   foreach var of varlist b*ev{
   replace `var'=`var'-d_vuln_cat_1
   replace `var'=0 if `var'<0 
   }
   
   * substranting 1 if household has a business in same category 
   foreach category in c1 c2 c3 c4 c5 c6 {
   foreach var of varlist b*pa2_`category'{
   replace `var'=`var'-d_primary_act_fup2_`category'
   replace `var'=0 if `var'<0
   }
   }
   
   foreach category in c1 c2 c3 c4 c5 c6{
   foreach var of varlist b*pa3_`category'{
   replace `var'=`var'-d_primary_act_fup3_`category'
   replace `var'=0 if `var'<0
   }
   }
   
   * I need to substract 1 also if household has a business at all 
   foreach var of varlist b*pa2{
   replace `var'=`var'-business_work_fup2_w
   replace `var'=0 if `var'<0
   }
   
   foreach var of varlist b*pa3{
   replace `var'=`var'-business_work_fup3_w
   replace `var'=0 if `var'<0
   }
   
   * Generating a same type of business variabel    
   egen     median_adequacy=median(adequacy_all_domains_bl)
   egen     mean_adequacy=mean(adequacy_all_domains_bl)	
   gen      d_above_mean_adeq=(adequacy_all_domains_bl>mean_adequacy)
   replace  d_above_mean_adeq=. if adequacy_all_domains_bl==. 
   gen      d_above_median_adeq=(adequacy_all_domains_bl>median_adequacy)
   replace  d_above_median_adeq=. if adequacy_all_domains_bl==. 
   gen      no_business_work_bl_w=(business_work_bl_w==0)
   replace  no_business_work_bl_w=. if business_work_bl_w==. 
   gen      no_business_work_fup2_w=(business_work_fup2_w==0)
   replace  no_business_work_fup2_w=. if business_work_fup2_w==. 			
   egen     mean_dm=mean(dm_index_bl_new_w) 
   gen      above_dm_index=(dm_index_bl_new_w>mean_dm)
   egen     median_dm=median(dm_index_bl_new_w) 
   gen      above_dm_index2=(dm_index_bl_new_w> median_dm) 

** Loops of variables 		
   foreach number in 100 200 300 400 500  600 700 800 900 1000{
   * We miss census data for 112 households so I am going to replace the HH size 
   * around using the mean around    
   bysort village_new_bl: egen b`number'pov_meanv=mean(b`number'pov)
   la var  b`number'pov_meanv "Average # poors around hh in village (`number'mts)"
   replace b`number'pov=b`number'pov_meanv if misscensusdata==1  

  * Our main radius variable is going to come from census and replace by survey 
  * if no census information or in those cases where EVs in our data are larger. 
  * this is because we are using the number of household around you when we went 
  * collecting baseline information which was after census 
  
   gen      b`number'evcen=b`number'evall
   la var   b`number'evcen "Original number of EVs in census data (`number'mts)"
   replace 	b`number'evall=b`number'ev if misscensusdata==1  
   //replace  b`number'evall=b`number'ev if  b`number'ev>b`number'evall
   
   gen      pet`number'=b`number'ct/b`number'ev
   replace  pet`number'=0 if b`number'ct==0 & b`number'ev==0
   la var   pet`number' "Proportion CT/EV in your neighborhood(`number'mts)" 
   
   gen      pEV`number'=. 
   replace  pEV`number'=b`number'evall/b`number'pov
   replace  pEV`number'=0 if b`number'evall==0 & b`number'pov==0
   la var   pEV`number' "Proportion EV in your neighborhood(`number'mts)" 	  
	  
   gen      EV_pet`number'=d_vuln_cat_1*pet`number'
   la var   EV_pet`number' "EV x PET `number'"
   
   gen      VV_pet`number'=d_vuln_cat_2*pet`number'
   la var   VV_pet`number' "VV x PET `number'"  
   
   gen      ML_pet`number'=d_vuln_cat_3*pet`number'
   la var   ML_pet`number' "ML x PET `number'"

   gen      numct`number'_ct=d_cash_treatment_unc*b`number'ct
   la var   numct`number'_ct "Num CT x CT"

   gen      numev`number'_ct=d_cash_treatment_unc*b`number'ev
   la var   numev`number'_ct "Num CT x CT" 
   
   gen      numct`number'_VV=d_vuln_cat_2*b`number'ct
   la var   numct`number'_VV "Num CT x VV"
 
   gen      numev`number'_VV=d_vuln_cat_2*b`number'ev
   la var   numev`number'_VV "Num EV x VV" 
   
   gen      numct`number'_ML=d_vuln_cat_3*b`number'ct
   la var   numct`number'_ML "Num CT x ML"
 
   gen      numev`number'_ML=d_vuln_cat_3*b`number'ev
   la var   numev`number'_ML "Num EV x ML" 
   
   gen      numct`number'_nbussbl=no_business_work_bl_w*b`number'ct
   la var   numct`number'_nbussbl "Num CT x no business at baseline "
 
   gen      numev`number'_nbussbl=no_business_work_bl_w*b`number'ev
   la var   numev`number'_nbussbl "Num EV x Business"   
   
   gen      numct`number'_empow=above_dm_index2*b`number'ct
   la var   numct`number'_empow "Num CT x No business at midline"

   sum b`number'ct
   gen b`number'ct_valmean=`r(mean)' 
   sum b`number'ct, detail
   gen b`number'ct_valp50=`r(p50)'    
   
   gen b`number'ct_mean=(b`number'ct>b`number'ct_valmean)
   gen b`number'ct_p50=(b`number'ct>b`number'ct_valp50)   
   
   gen b`number'ct_tmean=b`number'ct_mean*b`number'ct
   gen b`number'ct_tp50=b`number'ct_p50*b`number'ct   
   
   la var b`number'ct_mean "#CT above mean (400mts)"
   la var b`number'ct_p50 "#CT above median (400mts)"   
   la var b`number'ct_tmean "#CT*#CT above mean (400mts)"
   la var b`number'ct_tp50 "#CT* #CT above median (400mts)"      

   replace b`number'pov=b`number'pov/100
    
   gen     no_limpet`number'=. 
   replace no_limpet`number'=1 if pet`number'==0 & village_ineligible_ct==0
   replace no_limpet`number'=1 if pet`number'==1 & village_ineligible_ct==0
   la var  no_limpet`number' "Proportion of CT around is 0 or 1"
 
   }

   foreach number in 100 200 300 400 500  600 700 800 900 1000{   
   gen pa2_same`number'=.
   gen pa2_diff`number'=.
   gen pa2_psame`number'=.
   gen pa3_same`number'=.
   gen pa3_diff`number'=.
   gen pa3_psame`number'=.
   gen pa2pa3_same`number'=.
   gen pa2pa3_diff`number'=.
   
   forval i=1/6{
   replace pa2_same`number'=b`number'pa2_c`i' if d_primary_act_fup2_c`i'==1
   replace pa2_diff`number'=b`number'pa2-b`number'pa2_c`i' if d_primary_act_fup2_c`i'==1
  
   replace pa3_same`number'=b`number'pa3_c`i' if d_primary_act_fup3_c`i'==1
   replace pa3_diff`number'=b`number'pa3-b`number'pa3_c`i' if d_primary_act_fup3_c`i'==1
   
   replace pa2pa3_same`number'=b`number'pa2_c`i' if d_primary_act_fup3_c`i'==1  
   replace pa2pa3_diff`number'=b`number'pa2-b`number'pa2_c`i' if d_primary_act_fup3_c`i'==1

   replace pa2_psame`number'=pa2_same`number'/b`number'pa2
   replace pa2_psame`number'=0 if pa2_same`number'==0 & b`number'pa2==0
   replace pa3_psame`number'=pa3_same`number'/b`number'pa3  
   replace pa3_psame`number'=0 if pa3_same`number'==0 & b`number'pa3==0   


   }
   }

   gen    ct_emp=d_cash_treatment_unc*fem_assetsale_adequate_bl
   la var ct_emp "Cash transfers times empowerment proxy"

   gen    CT_nbussbl=no_business_work_bl_w*d_cash_treatment_unc
   la var CT_nbussbl "CT x no business at baseline"
   
   
   gen    CT_empow=above_dm_index2*d_cash_treatment_unc
   la var CT_empow "CT treament x empowerment"  
   
   
   gen    CT_nbussfup2=no_business_work_fup2_w*d_cash_treatment_unc
   la var CT_nbussfup2 "CT x no business at midline"
   
   gen    ML_emp=d_vuln_cat_3*fem_assetsale_adequate_bl
   la var ML_emp "ML times empowerment proxy"
   
   gen    VV_emp=d_vuln_cat_2*fem_assetsale_adequate_bl
   la var VV_emp "VV times empowerment proxy"
   
   foreach j in 100 150 200 250 300 350 400 450 500 550 ///
					 600 650 700 750 800 850 900 950 1000{
   gen b`j'pa2_CT=b`j'pa2*d_cash_treatment_unc	
   gen b`j'pa3_CT=b`j'pa3*d_cash_treatment_unc	
   la var b`j'pa2_CT "Midline:Number of business around*CT(`j' mts)"
   la var b`j'pa3_CT "Endline:Number of business around*CT(`j' mts)"
   la var b`j'ct "Number of Cash transfer households around hh i (ratio:`j' meters)"
   la var b`j'ev "Number of EV households around i (ratio: `j' meters)"
   }

   gen     EV_CT=d_cash_treatment_unc*d_vuln_cat_1
   la var  EV_CT "EV x CT" 
  
   /*gen     VV_ICP=intensity_cash_pop*d_vuln_cat_2
   la var  VV_ICP "ICP x VV"
   gen     ML_ICP=intensity_cash_pop*d_vuln_cat_3
   la var  ML_ICP "ICP x VV"    
   gen     CT_ICP=d_cash_treatment_unc*intensity_cash_pop
   la var  CT_ICP "Interaction cash treatment with icp"  
   */
   
 * Business opening 
   gen      business_fup2_nobl_w=(business_work_fup2_w==1 & business_work_bl_w==0)
   la var   business_fup2_nobl_w "Business in fup2 but not bl (wife)"
   
   gen      business_fup2_nofup3_w=(business_work_fup2_w==1 & business_work_fup3_w==0)
   la var   business_fup2_nofup3_w "Business in fup2 but not fup3 (wife)"
	 
   gen      business_fup3_nofup2_w=(business_work_fup3_w==1 & business_work_fup2_w==0)
   la var   business_fup3_nofup2_w "Business in fup3 but not fup2 (wife)"
	 
   gen      business_fup3_nobl_w=(business_work_fup3_w==1 & business_work_bl_w==0)
   la var   business_fup3_nobl_w "Business in fup3 but not b1 (wife)"
	 
   gen      business_fup2_fup3_w=(business_work_fup3_w==1 & business_work_fup2_w==1 & business_work_bl_w==0)
   la var   business_fup2_fup3_w "New business in fup 2 and fup3 (wife)"
	 
   la var   business_work_fup2_w "Business at midline (wife)"
   la var   business_work_fup3_w "Business at endline (wife)"
   
   gen      business_fup2_nobl_h=(business_work_fup2_h==1 & business_work_bl_h==0)
   la var   business_fup2_nobl_h "Business in fup2 but not bl (husband)"
   
   gen      business_fup2_nofup3_h=(business_work_fup2_h==1 & business_work_fup3_h==0)
   la var   business_fup2_nofup3_h "Business in fup2 but not fup3(husband)"
	 
   gen      business_fup3_nofup2_h=(business_work_fup3_h==1 & business_work_fup2_h==0)
   la var   business_fup3_nofup2_h "Business in fup3 but not fup2(husband)"
	 
   gen      business_fup3_nobl_h=(business_work_fup3_h==1 & business_work_bl_h==0)
   la var   business_fup3_nobl_h "Business in fup3 but not b1(husband)"
	 
   gen      business_fup2_fup3_h=(business_work_fup3_h==1 & business_work_fup2_h==1 & business_work_bl_h==0)
   la var   business_fup2_fup3_h "New business in fup 2 and fup3(husband)"
   la var   business_work_fup2_h "Business at midline(husband)"
   la var   business_work_fup3_h "Business at endline(husband)"
   

   
   
   foreach category in 1 2 3 4 5 6{
   foreach number   in 100 150 200 250 300 350 400 450 500 550 ///
					 600 650 700 750 800 850 900 950 1000{
   gen      pb`number'_c`category'_fup2=b`number'pa2_c`category'/b`number'pa2
   replace  pb`number'_c`category'_fup2=0 if pb`number'_c`category'_fup2==.
   gen      pb`number'_c`category'_fup3=b`number'pa3_c`category'/b`number'pa3
   replace  pb`number'_c`category'_fup3=0 if pb`number'_c`category'_fup3==.

   la var pb`number'_c`category'_fup2 "Proportion of business Category `category' in midline(`number'mts)"
   la var pb`number'_c`category'_fup3 "Proportion of business Category `category' in endline(`number'mts)"
   }
   }
   
   * Interaction of proportions with CT   
  foreach round in fup2 fup3{	
    forval categorie=1/6{
	  foreach meters in 100 150 200 250 300 350 400 450 500 550 ///
					 600 650 700 750 800 850 900 950 1000{
     gen    pb`meters'_c`categorie'_ct_`round'=d_cash_treatment_unc*pb`meters'_c`categorie'_`round'
     la var pb`meters'_c`categorie'_ct_`round' "PB Category `categorie' x CT (`meters')"
   	 }
    }
   }
	
  forval i=1/6{	
  replace d_primary_act_fup2_c`i'=. if business_work_fup2_w==.
  replace d_primary_act_fup3_c`i'=. if business_work_fup3_w==.
  }
  
 ** Ancova variables: Are we copying business?
 ** -------------------------------------------------------------------
  ** Generating variables that indicate the type of business was the most likely
     foreach meters in 100 150 200 250 300 350 400 450 500 550 ///
					 600 650 700 750 800 850 900 950 1000{	
  * First we identify which one is the max proportion 
	egen     max_prop`meters'_bfup2=rowmax(pb`meters'_c?_fup2)
	replace  max_prop`meters'_bfup2=. if max_prop`meters'_bfup2==0
	egen     max_prop`meters'_bfup3=rowmax(pb`meters'_c?_fup3)
	replace  max_prop`meters'_bfup3=. if max_prop`meters'_bfup3==0
	
  * Now we generate a dummy if the max 
	forval  category=1/6{
	 gen    d_pb`meters'max_fup2_c`category'=(pb`meters'_c`category'_fup2==max_prop`meters'_bfup2)
	 gen    d_pb`meters'max_fup3_c`category'=(pb`meters'_c`category'_fup3==max_prop`meters'_bfup3)
	 }
	 }
	 
  ** Generating variables to know if we are copying variables	 
   	forval  category=1/6{ 
	foreach meters in 100 150 200 250 300 350 400 450 500 550 ///
					 600 650 700 750 800 850 900 950 1000{	  
  * Generating dummy equal to 1 if there is at least one business on same type aorund me 
	gen      d_copbuss_c`category'_f2f2_`meters'_w=(d_primary_act_fup2_c`category'==1 & ///
	                                  (pb`meters'_c`category'_fup2>0 &          ///
									   pb`meters'_c`category'_fup2<.))
	replace  d_copbuss_c`category'_f2f2_`meters'_w=. if business_work_fup2_w==. 
  
    gen      d_copbuss_c`category'_f3f2_`meters'_w=(d_primary_act_fup3_c`category'==1 & ///
	                                                (pb`meters'_c`category'_fup2>0 & ///
													 pb`meters'_c`category'_fup2<1))
	replace  d_copbuss_c`category'_f3f2_`meters'_w=. if business_work_fup2_w==. | ///
	                                                    business_work_fup3_w==.
										  
	gen      d_copbuss_c`category'_f3f3_`meters'_w=(d_primary_act_fup3_c`category'==1 & ///
	                                                (pb`meters'_c`category'_fup3>0 &  ///
													pb`meters'_c`category'_fup3<.))
	replace  d_copbuss_c`category'_f3f3_`meters'_w=. if business_work_fup3_w==. 	
	
  * Generating dummy equal to 1 if mayority of business on same type aorund me 
	gen      d_copmbuss_c`category'_f2f2_`meters'_w=(d_primary_act_fup2_c`category'==1 & ///
	                                                 d_pb`meters'max_fup2_c`category'==1)
	replace  d_copmbuss_c`category'_f2f2_`meters'_w=. if business_work_fup2_w==. 
  
    gen      d_copmbuss_c`category'_f3f2_`meters'_w=(d_primary_act_fup3_c`category'==1 & ///
	                                                 d_pb`meters'max_fup2_c`category'==1)
	replace  d_copmbuss_c`category'_f3f2_`meters'_w=. if business_work_fup2_w==. | ///
	                                                     business_work_fup3_w==.
										  
	gen      d_copmbuss_c`category'_f3f3_`meters'_w=(d_primary_act_fup3_c`category'==1 & ///
	                                                 d_pb`meters'max_fup3_c`category'==1)
	replace  d_copmbuss_c`category'_f3f3_`meters'_w=. if business_work_fup3_w==. 	
	}
	}
	drop max_prop*_bfup2 max_prop*_bfup3
	
 * Changing names so it is clearear in the dofile for someone else that wants to take over
	clonevar d_EV=d_vuln_cat_1
	clonevar d_VV=d_vuln_cat_2 
	clonevar d_ML=d_vuln_cat_3 
	gen default=1

	
	gen same_business=.
	forval category=1/6{
	replace same_business=1  if same_business==. & ///
	d_primary_act_fup2_c`category'==1 & d_primary_act_fup3_c`category'==1
	}
	replace same_business=0 if same_business==. 
	replace same_business=. if d_wavail_f2==0 | d_wavail_f3==0
	tab     same_business
	
	gen diff_business=.
	replace diff_business=1  if d_primary_act_fup3_c1==1 & d_primary_act_fup2_c2==1
	replace diff_business=1  if d_primary_act_fup3_c1==1 & d_primary_act_fup2_c3==1
	replace diff_business=1  if d_primary_act_fup3_c1==1 & d_primary_act_fup2_c4==1	
	replace diff_business=1  if d_primary_act_fup3_c1==1 & d_primary_act_fup2_c5==1
	replace diff_business=1  if d_primary_act_fup3_c1==1 & d_primary_act_fup2_c6==1		
	replace diff_business=1  if d_primary_act_fup3_c2==1 & d_primary_act_fup2_c1==1
	replace diff_business=1  if d_primary_act_fup3_c2==1 & d_primary_act_fup2_c3==1
	replace diff_business=1  if d_primary_act_fup3_c2==1 & d_primary_act_fup2_c4==1	
	replace diff_business=1  if d_primary_act_fup3_c2==1 & d_primary_act_fup2_c5==1
	replace diff_business=1  if d_primary_act_fup3_c2==1 & d_primary_act_fup2_c6==1	
	replace diff_business=1  if d_primary_act_fup3_c3==1 & d_primary_act_fup2_c1==1
	replace diff_business=1  if d_primary_act_fup3_c3==1 & d_primary_act_fup2_c2==1
	replace diff_business=1  if d_primary_act_fup3_c3==1 & d_primary_act_fup2_c4==1	
	replace diff_business=1  if d_primary_act_fup3_c3==1 & d_primary_act_fup2_c5==1
	replace diff_business=1  if d_primary_act_fup3_c3==1 & d_primary_act_fup2_c6==1	
	replace diff_business=1  if d_primary_act_fup3_c4==1 & d_primary_act_fup2_c1==1
	replace diff_business=1  if d_primary_act_fup3_c4==1 & d_primary_act_fup2_c2==1
	replace diff_business=1  if d_primary_act_fup3_c4==1 & d_primary_act_fup2_c3==1	
	replace diff_business=1  if d_primary_act_fup3_c4==1 & d_primary_act_fup2_c5==1
	replace diff_business=1  if d_primary_act_fup3_c4==1 & d_primary_act_fup2_c6==1		
	replace diff_business=1  if d_primary_act_fup3_c5==1 & d_primary_act_fup2_c1==1
	replace diff_business=1  if d_primary_act_fup3_c5==1 & d_primary_act_fup2_c2==1
	replace diff_business=1  if d_primary_act_fup3_c5==1 & d_primary_act_fup2_c3==1	
	replace diff_business=1  if d_primary_act_fup3_c5==1 & d_primary_act_fup2_c4==1
	replace diff_business=1  if d_primary_act_fup3_c5==1 & d_primary_act_fup2_c6==1	
	replace diff_business=1  if d_primary_act_fup3_c6==1 & d_primary_act_fup2_c1==1
	replace diff_business=1  if d_primary_act_fup3_c6==1 & d_primary_act_fup2_c2==1
	replace diff_business=1  if d_primary_act_fup3_c6==1 & d_primary_act_fup2_c3==1	
	replace diff_business=1  if d_primary_act_fup3_c6==1 & d_primary_act_fup2_c4==1
	replace diff_business=1  if d_primary_act_fup3_c6==1 & d_primary_act_fup2_c5==1	
	replace diff_business=0 if diff_business==. 
	replace diff_business=. if d_wavail_f2==0 | d_wavail_f3==0
	tab diff_business
	
    gen CT_dist=d_cash_treatment_unc*min_distance_market
	la var CT_dist "CT * Distance to closest market"

	foreach meters in 100 200 300 400 500 600 700 800 900 1000{
	gen ct_dist`meters'=b`meters'ct*min_distance_market
	gen ev_dist`meters'=b`meters'ev*min_distance_market
	gen b`meters'pa2_mindis=b`meters'pa2*min_distance_market
    gen b`meters'pa3_mindis=b`meters'pa2*min_distance_market
	}
	
	/*gen d_entryexit_bus_me_3b=d_entryexit_bus_me_3
	replace d_entryexit_bus_me_3b=. if d_entryexit_bus_me_1==1
	la var  d_entryexit_bus_me_3b "Different Business vs Same Business"
	replace d_entryexit_bus_me_2=. if d_entryexit_bus_me_3==1
	la var  d_entryexit_bus_me_2 "Same Business vs Exit"
	replace d_entryexit_bus_me_3=. if d_entryexit_bus_me_2==1
	la var  d_entryexit_bus_me_3 "Different Business vs Exit"
*/
  	
	foreach var of varlist  d_locationbuss_*_fup2_w{
	gen `var'_unc=`var'
	replace `var'_unc=0 if `var'==. & business_work_fup2_w!=.
	}
	
	foreach var of varlist  d_locationbuss_*_fup3_w{
	gen `var'_unc=`var'
	replace `var'_unc=0 if `var'==. & business_work_fup3_w!=.
	}
	
	foreach var of varlist  d_locationbuss_*_fup2_h{
	gen `var'_unc=`var'
	replace `var'_unc=0 if `var'==. & business_work_fup2_h!=.
	}
	
	foreach var of varlist  d_locationbuss_*_fup3_h{
	gen `var'_unc=`var'
	replace `var'_unc=0 if `var'==. & business_work_fup3_h!=.
	}	

    forval i=1/5{				   
	gen ihs_profits_fup2_c`i'= ihs_profits_business_fup2 ///
	         if d_primary_act_fup2_c`i'==1	
	replace  ihs_profits_fup2_c`i'=0 if ihs_profits_fup2_c`i'==. 
	replace  ihs_profits_fup2_c`i'=. if  business_work_fup2_w ==.
	gen      ihs_profits_fup3_c`i'= ihs_profits_business_fup2 ///
	         if d_primary_act_fup3_c`i'==1		
	replace  ihs_profits_fup3_c`i'=0 if ihs_profits_fup3_c`i'==. 
	replace  ihs_profits_fup3_c`i'=. if  business_work_fup3_w ==.
	}
	
	
	la var d_locationbuss_1_fup2_w_unc "Midline location business Home (Wife)"
	la var d_locationbuss_2_fup2_w_unc "Midline location business Market place(Wife)"
	la var d_locationbuss_3_fup2_w_unc "Midline location business form shop(Wife)"
	la var d_locationbuss_4_fup2_w_unc "Midline location business travelling door to door(Wife)"
	la var d_locationbuss_5_fup2_w_unc "Midline location business other(Wife)"
	la var d_locationbuss_1_fup3_w_unc "Endline location business Home (Wife)"
	la var d_locationbuss_2_fup3_w_unc "Endline location business Market place(Wife)"
	la var d_locationbuss_3_fup3_w_unc "Endline location business form shop(Wife)"
	la var d_locationbuss_4_fup3_w_unc "Endline location business travelling door to door(Wife)"
	la var d_locationbuss_5_fup3_w_unc "Endline location business other(Wife)"

	la var d_locationbuss_1_fup2_h_unc "Midline location business Home (Husband)"
	la var d_locationbuss_2_fup2_h_unc "Midline location business Market place(Husband)"
	la var d_locationbuss_3_fup2_h_unc "Midline location business form shop(Husband)"
	la var d_locationbuss_4_fup2_h_unc "Midline location business travelling door to door(Husband)"
	la var d_locationbuss_5_fup2_h_unc "Midline location business other(Husband)"
	la var d_locationbuss_1_fup3_h_unc "Endline location business Home (Husband)"
	la var d_locationbuss_2_fup3_h_unc "Endline location business Market place(Husband)"
	la var d_locationbuss_3_fup3_h_unc "Endline location business form shop(Husband)"
	la var d_locationbuss_4_fup3_h_unc "Endline location business travelling door to door(Husband)"
	la var d_locationbuss_5_fup3_h_unc "Endline location business other(Husband)"	
	
	
   * Raw materias by category 
	 forval i=1/6{
	  gen w_rawmat_w_f2_c`i'=w_rawmats_business_fup2_w  if d_primary_act_fup2_c`i'==1
	  gen w_rawmat_w_f3_c`i'=w_rawmats_business_fup3_w  if d_primary_act_fup3_c`i'==1
	 }

	  la var w_rawmat_w_f2_c1 "Midline:Raw Materials Cook"
	  la var w_rawmat_w_f2_c2 "Midline:Raw Materials Oil Processing"
	  la var w_rawmat_w_f2_c3 "Midline:Raw Materials Crop Processing"
	  la var w_rawmat_w_f2_c4 "Midline:Raw Materials Trading"
	  la var w_rawmat_w_f2_c5 "Midline:Raw Materials Services"
	  la var w_rawmat_w_f2_c6 "Midline:Raw Materials Other"

	  
	  la var w_rawmat_w_f3_c1 "Endline:Raw Materials Cook"
	  la var w_rawmat_w_f3_c2 "Endline:Raw Materials Oil Processing"
	  la var w_rawmat_w_f3_c3 "Endline:Raw Materials Crop Processing"
	  la var w_rawmat_w_f3_c4 "Endline:Raw Materials Trading"
	  la var w_rawmat_w_f3_c5 "Endline:Raw Materials Services"
	  la var w_rawmat_w_f3_c6 "Endline:Raw Materials Other"
	  
	  sum w_rawmats_business_fup2_w
      local mean_f2 = r(mean)
	  di `mean_f2'
	  
	  sum w_rawmats_business_fup3_w
      local mean_f3 = r(mean)
	  di `mean_f3'
	  
	  gen     d_buss_exp_f2=. 
	  replace d_buss_exp_f2=1 if (primary_act_fup2==2 | primary_act_fup2==3)
	  replace d_buss_exp_f2=0 if (primary_act_fup2==1 | primary_act_fup2==4  |  ///
	                              primary_act_fup2==5 | primary_act_fup2==6)
								  
	  gen     d_buss_exp_f3=. 
	  replace d_buss_exp_f3=1 if (primary_act_fup3==2 | primary_act_fup3==3)
	  replace d_buss_exp_f3=0 if (primary_act_fup3==1 | primary_act_fup3==4  |  ///
	                              primary_act_fup3==5 | primary_act_fup3==6)								  
								  
	  clonevar 	d_buss_exp_con_f2=d_buss_exp_f2						  
	  clonevar 	d_buss_exp_con_f3=d_buss_exp_f3
	  replace   d_buss_exp_f2=0 if d_buss_exp_f2==.
	  replace   d_buss_exp_f3=0 if d_buss_exp_f3==.
	  
	  la var d_buss_exp_f2     "Midline: NonFarm Enterprise High Cost"
	  la var d_buss_exp_f3     "Endline: NonFarm Enterprise High Cost"	  
	  la var d_buss_exp_con_f2 "Midline: NonFarm Enterprise High Cost (Conditional)"
	  la var d_buss_exp_con_f3 "Endline: NonFarm Enterprise High Cost (Conditional)"	  
	   
	  
	* Conditional Ag variables 
	** -------------------------------------------------------------------------
      ren ihs_ttl_spend_inorgfert_ha_f3 ihs_ttl_spend_infert_ha_f3
	  
	* Generating some conditional variables 
	 foreach var of varlist	ihs_ttl_yields_ha_f3              ///
	                        ihs_ttl_inputs_plot_ha            ///
	                        ihs_ttl_spend_orgfert_ha_f3       ///
	                        ihs_ttl_spend_infert_ha_f3        ///
					        ihs_ttl_spend_seeds_ha_f3         ///
					        ihs_ttl_wagehlabor_ha_f3{
	  gen     `var'_con=`var'
	  replace `var'_con=. if `var'==0
								}  
     gen      ttl_agprofit_ha=ttl_yields_ha_f3-ttl_inputs_plot_ha 								
	 ihstrans ttl_agprofit_ha
	 winsor ttl_agprofit_ha, gen(w_ttl_agprofit_ha) p (0.01)
	 la var w_ttl_agprofit_ha "Agriculture Profits per hectare(Winsor)"
	 la var ihs_ttl_agprofit_ha "Agriculture Profits per hectare(IHS)"	 
	 
    gen     perc_aginputs=ttl_inputs_plot_ha/ttl_agprofit_ha
	replace perc_aginputs=. if perc_aginputs<0
    la var perc_aginputs "% of profits that is revenues" 
	 
	* Interactions of number of business and characteristics of business
	** -------------------------------------------------------------------------
	foreach meters in 100 200 300 400  500  600 700 800 900 1000{	
	* Interaction with home 
	gen    b`meters'pa2_l1=b`meters'pa2*d_locationbuss_1_fup2_w
	gen    pa2_psame`meters'_l1=pa2_psame`meters'*d_locationbuss_1_fup2_w
	la var b`meters'pa2_l1 "Midline:Location home*# business in `meters'mts"
	la var pa2_psame`meters'_l1 "Midline:Location home* % same business in `meters'mts"	
	gen    b`meters'pa3_l1=b`meters'pa3*d_locationbuss_1_fup3_w
	gen    pa3_psame`meters'_l1=pa3_psame`meters'*d_locationbuss_1_fup3_w
	la var b`meters'pa3_l1 "Endline:Location home*# business in `meters'mts"
	la var pa3_psame`meters'_l1 "Endline:Location home* % same business in `meters'mts"	
	
	* Interaction with market place 
	gen    b`meters'pa2_l2=b`meters'pa2*d_locationbuss_2_fup2_w
	gen    pa2_psame`meters'_l2=pa2_psame`meters'*d_locationbuss_2_fup2_w
	la var b`meters'pa2_l2 "Midline:Location market*# business in `meters'mts"
	la var pa2_psame`meters'_l2 "Midline:Location market* % same business in `meters'mts"	
	gen    b`meters'pa3_l2=b`meters'pa3*d_locationbuss_1_fup3_w
	gen    pa3_psame`meters'_l2=pa3_psame`meters'*d_locationbuss_1_fup3_w
	la var b`meters'pa3_l2 "Endline:Location market*# business in `meters'mts"
	la var pa3_psame`meters'_l2 "Endline:Location market* % same business in `meters'mts"		
	}
	
	
* Generating new variables for spillover analysis
  * Additional Treatment 
    gen      ct_nct_inel=0 if  d_cash_treatment==0
	replace  ct_nct_inel=1 if  d_cash_treatment==1
	replace  ct_nct_inel=2 if  village_ineligible_ct==1
	la def   ct_nct_inel 0 "No CT" 1 "CT" 2 "INELIGIBLE", modify
	la val   ct_nct_inel ct_nct_inel
	tab      ct_nct_inel
	tab      ct_nct_inel, gen (d_ct_nct_inel_)
	sum d_ct_nct_inel_*
	
	foreach j in 100 150 200 250 300 350 400 450 500 550 ///
				 600 650 700 750 800 850 900 950 1000{
	gen d_ct_nct_inel_2_m`j'=b`j'ct*d_ct_nct_inel_2	
	}
	
	foreach j in 100 200 300 400 500 600 700 800 900 1000{
	gen d_ct_nct_inel_2_`j'lp=b`j'ct_lp*d_ct_nct_inel_2	
	la var d_ct_nct_inel_2_`j'lp "CT*#CashTransfers(LumpSum)"
	gen d_ct_nct_inel_2_`j'm=b`j'ct_m*d_ct_nct_inel_2	
	la var d_ct_nct_inel_2_`j'm "CT*#CashTransfers(Monthly)"	
	}	
   	
	// We are missing the years of a few obs business so replacing by the mean in 
	// their treatment group 
	gen     tempyears2=bus_years_f2_w
	replace tempyears2=. if  business_work_fup2_w==0
	bysort  lgacode_bl ct_nct_inel: egen temp_2=mean(tempyears2)
	replace bus_years_f2_w=temp_2 if bus_years_f2_w==. & business_work_fup2_w==1
	
	gen     tempyears3=bus_years_f3_w
	replace tempyears3=. if  business_work_fup3_w==0
	bysort  lgacode_bl ct_nct_inel: egen temp_3=mean(tempyears3)
	replace bus_years_f3_w=temp_3 if bus_years_f3_w==. & business_work_fup3_w==1	
	drop tempyears? temp_? 
	 
	* Women 
	gen      mul_bus_bme=0 if business_work_bl_w==0 & business_work_fup2_w==0 & business_work_fup3_w==0 
	replace  mul_bus_bme=1 if business_work_bl_w==0 & business_work_fup2_w==1 & business_work_fup3_w==0 
	replace  mul_bus_bme=2 if business_work_bl_w==0 & business_work_fup2_w==1 & business_work_fup3_w==1
	replace  mul_bus_bme=3 if business_work_bl_w==0 & business_work_fup2_w==0 & business_work_fup3_w==1
	replace  mul_bus_bme=4 if business_work_bl_w==1 & business_work_fup2_w==0 & business_work_fup3_w==0
	replace  mul_bus_bme=5 if business_work_bl_w==1 & business_work_fup2_w==1 & business_work_fup3_w==0
	replace  mul_bus_bme=6 if business_work_bl_w==1 & business_work_fup2_w==1 & business_work_fup3_w==1
	replace  mul_bus_bme=7 if business_work_bl_w==1 & business_work_fup2_w==0 & business_work_fup3_w==1 
	# d;
	la def   mul_bus_bme 0 "Never had business" 
				   1 "New Business at ml closed at el"
				   2 "New business at md and kept it at endline"
				   3 "New business at endline"
				   4 "Business at bl but closed"
				   5 "Business at bl and ml but closed at el"
				   6 "Business at bl, ml and el"
				   7 "Business at bl, not at ml, business at el", modify;
	la val mul_bus_bme mul_bus_bme;
	# d cr; 
		
	gen      mul_bus_me=0 if business_work_fup2_w==0 & business_work_fup3_w==0
	replace  mul_bus_me=1 if business_work_fup2_w==1 & business_work_fup3_w==0
	replace  mul_bus_me=2 if business_work_fup2_w==1 & business_work_fup3_w==1
	replace  mul_bus_me=3 if business_work_fup2_w==0 & business_work_fup3_w==1 
	la def   mul_bus_me 0 "No business at ml or el" 1 "Business at ml not at el"  ///
	                    2 "Business at ml and el" 3 "No business at ml but at el", modify 
	la val   mul_bus_me mul_bus_me
	tab mul_bus_bme, gen (d_mul_bus_bme_)
	
	* Men
	gen      mul_bus_bme_h=0 if business_work_bl_h==0 & business_work_fup2_h==0 & business_work_fup3_h==0 
	replace  mul_bus_bme_h=1 if business_work_bl_h==0 & business_work_fup2_h==1 & business_work_fup3_h==0 
	replace  mul_bus_bme_h=2 if business_work_bl_h==0 & business_work_fup2_h==1 & business_work_fup3_h==1
	replace  mul_bus_bme_h=3 if business_work_bl_h==0 & business_work_fup2_h==0 & business_work_fup3_h==1
	replace  mul_bus_bme_h=4 if business_work_bl_h==1 & business_work_fup2_h==0 & business_work_fup3_h==0
	replace  mul_bus_bme_h=5 if business_work_bl_h==1 & business_work_fup2_h==1 & business_work_fup3_h==0
	replace  mul_bus_bme_h=6 if business_work_bl_h==1 & business_work_fup2_h==1 & business_work_fup3_h==1
	replace  mul_bus_bme_h=7 if business_work_bl_h==1 & business_work_fup2_h==0 & business_work_fup3_h==1 
	# d;
	la def   mul_bus_bme 0 "Never had business" 
				   1 "New Business at ml closed at el"
				   2 "New business at md and kept it at endline"
				   3 "New business at endline"
				   4 "Business at bl but closed"
				   5 "Business at bl and ml but closed at el"
				   6 "Business at bl, ml and el"
				   7 "Business at bl, not at ml, business at el", modify;
	la val mul_bus_bme mul_bus_bme_h;
	# d cr; 
		
	gen      mul_bus_me_h=0 if business_work_fup2_h==0 & business_work_fup3_h==0
	replace  mul_bus_me_h=1 if business_work_fup2_h==1 & business_work_fup3_h==0
	replace  mul_bus_me_h=2 if business_work_fup2_h==1 & business_work_fup3_h==1
	replace  mul_bus_me_h=3 if business_work_fup2_h==0 & business_work_fup3_h==1 
	la def   mul_bus_me_h 0 "No business at ml or el" 1 "Business at ml not at el"  ///
	                    2 "Business at ml and el" 3 "No business at ml but at el", modify 
	la val   mul_bus_me_h mul_bus_me_h
	tab mul_bus_bme_h, gen (d_mul_bus_bme_h_)	
	
	
    tab lgacode_bl, gen (d_lgacode_bl_)
	la var 	d_mul_bus_bme_1 "Never had business"	
	la var 	d_mul_bus_bme_2	"New Business at midline closed at endline"	
	la var 	d_mul_bus_bme_3	"New business at midline and still open at endline"	
	la var 	d_mul_bus_bme_4	"New business at endline"	
	la var 	d_mul_bus_bme_5	"Business at baseline but closed after baseline"	
	la var 	d_mul_bus_bme_6	"Business at baseline, active at midline but closed at endline"	
	la var 	d_mul_bus_bme_7	"Business at baseline, active at midline and endline"	
	la var 	d_mul_bus_bme_8	"Business at baseline, closed at midline, active at endline"	

	la var 	d_mul_bus_bme_h_1   "Never had business"	
	la var 	d_mul_bus_bme_h_2	"New Business at midline closed at endline"	
	la var 	d_mul_bus_bme_h_3	"New business at midline and still open at endline"	
	la var 	d_mul_bus_bme_h_4	"New business at endline"	
	la var 	d_mul_bus_bme_h_5	"Business at baseline but closed after baseline"	
	la var 	d_mul_bus_bme_h_6	"Business at baseline, active at midline but closed at endline"	
	la var 	d_mul_bus_bme_h_7	"Business at baseline, active at midline and endline"	
	la var 	d_mul_bus_bme_h_8	"Business at baseline, closed at midline, active at endline"	
	
    gen      entryexit_bus_me=0 if   business_work_fup2_w==1 & business_work_fup3_w==0
    replace  entryexit_bus_me=1 if business_work_fup2_w==1 & business_work_fup3_w==1 ///
                            & same_business==1 
    replace  entryexit_bus_me=2 if business_work_fup2_w==1 & business_work_fup3_w==1 ///
                            & same_business==0
    la def   entryexit 0 "Exit" 1 "Same Business" 2 "Different Business" 
    la val   entryexit_bus_me entryexit
    replace  entryexit_bus_me=. if business_work_fup2_w==0
	tab entryexit_bus_me, gen (d_entryexit_bus_me_)
    
	gen    emp_bl_ct=d_ct_nct_inel_2*d_above_mean_adeq
	la var emp_bl_ct "Empowerment at baseline interacted with CT"
	gen    emp2_bl_ct=d_ct_nct_inel_2*adequacy_all_domains_bl
	la var emp2_bl_ct "Empowerment at baseline interacted with CT"

	gen    d_ct_nct_inel_2_dist=min_distance_market*d_ct_nct_inel_2
	gen    d_ct_nct_inel_1_dist=min_distance_market*d_ct_nct_inel_1
	la var d_ct_nct_inel_1_dist "NCT*Distance to market"
	la var d_ct_nct_inel_2_dist "CT*Distance to market"

	
   gen    ct_motwork=d_cash_treatment_unc*mother_worked_w
   la var ct_motwork "CT * Mother worked when you were a child"
   
   gen    nct_motwork=d_ct_nct_inel_1*mother_worked_w
   la var nct_motwork "NCT * Mother worked when you were a child"	
		
   gen    ct_motworkent=d_cash_treatment_unc*mother_workedent_w
   la var ct_motworkent "CT * Mother worked business when you were a child"
   
   gen    nct_motworkent=d_ct_nct_inel_1*mother_workedent_w
   la var nct_motworkent "NCT * Mother worked business when you were a child"		
	
	la var mother_workedent_w "Mother worked when you were a child"
	la var mother_worked_w "Mother worked when you were a child"
	
	* Generating unconditional var 
	  foreach var of varlist   w_profits_business_fup2 ihs_profits_business_fup2{
	  gen     u_`var'=`var'
	  replace u_`var'=. if business_work_fup2_w==0
	  }
	  foreach var of varlist w_profits_business_fup3 ihs_profits_business_fup3{
	  gen u_`var'=`var'
	  replace u_`var'=. if business_work_fup3_w==0
	  }
	
	 forval i=1/5{
	 replace ihs_profits_fup2_c`i'=. if d_primary_act_fup2_c`i'==0
	 replace ihs_profits_fup3_c`i'=. if d_primary_act_fup3_c`i'==0
	 }
	 ren u_ihs_profits_business_fup2 ihs_profits_business_fup2_c
	 ren u_w_profits_business_fup2   w_profits_business_fup2_c
	 ren u_w_profits_business_fup3   w_profits_business_fup3_c
     ren u_ihs_profits_business_fup3 ihs_profits_business_fup3_c
	 
	* Gender rankings 
	# d;
	  egen gen_equ_dis_w=rowmean(shame_husbhhwork_w_f3 tol_viol_w_f3 
				   obey_husb_w_f3 menwom_rights_w_f3 
				   womreso_w_f3 viol_priv_w_f3 womenleaves_w_f3);
	# d cr; 
	
	# d;
	  egen gen_equ_dis_h=rowmean(shame_husbhhwork_h_f3 tol_viol_h_f3 
				   obey_husb_h_f3 menwom_rights_h_f3 
				   womreso_h_f3 viol_priv_h_f3 womenleaves_h_f3);
	# d cr; 	
	 
	 
  ** Generating Index Variables out of set of categorical variables 
	* Setting up variables to be included
	# d;
	gl opt_var_w   happ_12_7_w_f3  happ_12_9_w_f3 happ_12_10_w_f3 
	               happ_12_13_w_f3 happ_12_14_w_f3  happ_12_15_w_f3 
				   happ_12_16_w_f3 happ_12_17_w_f3 happ_12_19_w_f3;

	gl opt_var_h   happ_12_7_h_f3 happ_12_9_h_f3 happ_12_10_h_f3 
	               happ_12_13_h_f3 happ_12_14_h_f3  happ_12_15_h_f3 
				   happ_12_16_h_f3 happ_12_17_h_f3 happ_12_19_h_f3;
	# d cr;
	
	* Code for index
	swindex $opt_var_w if FNLP_treatment==0, generate(opt_index_w_0) displayw ///
	                                         normby(d_ct_nct_inel_3)
	swindex $opt_var_h if FNLP_treatment==0, generate(opt_index_h_0) displayw ///
	                                         normby(d_ct_nct_inel_3)
	
	swindex $opt_var_w if FNLP_treatment==1, generate(opt_index_w_1) displayw  ///
	                                         normby(d_ct_nct_inel_3)
	swindex $opt_var_h if FNLP_treatment==1, generate(opt_index_h_1) displayw   ///
											 normby(d_ct_nct_inel_3)
	
	
	foreach var in opt_index_w opt_index_h{
	gen `var'=. 
	replace `var'=`var'_0 if FNLP_treatment==0
	replace `var'=`var'_1 if FNLP_treatment==1	
    drop `var'_0  `var'_1
	}
	
	la var opt_index_w "Optimist index (Wife)"
	la var opt_index_h "Optimist index (Husband)"	
	
	egen opt_index_w_v2=rowtotal($opt_var_w)
	egen opt_index_h_v2=rowtotal($opt_var_h)
	
	la var opt_index_w_v2 "Optimist index (Scheier) (Wife)"
	la var opt_index_h_v2 "Optimist index (Scheier) (Husband)"	
		
	
	
	gl ge_var_w  shame_husbhhwork_w_f3   tol_viol_w_f3    ///
				 obey_husb_w_f3          menwom_rights_w_f3    ///
				 menwom_rights_w_f3      womreso_w_f3    ///
				 viol_priv_w_f3         womenleaves_w_f3
						   
						   
	gl ge_var_h    shame_husbhhwork_h_f3   tol_viol_h_f3  ///
				   obey_husb_h_f3          menwom_rights_h_f3 ///
				   menwom_rights_h_f3      womreso_h_f3 ///
				   viol_priv_h_f3         womenleaves_h_f3
				   
	swindex $ge_var_w if FNLP_treatment==0, generate(ge_index_w_0) displayw     ///
											normby(d_ct_nct_inel_3)
	swindex $ge_var_h if FNLP_treatment==0, generate(ge_index_h_0) displayw     ///
											normby(d_ct_nct_inel_3)
	swindex $ge_var_w if FNLP_treatment==1, generate(ge_index_w_1) displayw     ///
											normby(d_ct_nct_inel_3)
	swindex $ge_var_h if FNLP_treatment==1, generate(ge_index_h_1) displayw	     ///
											normby(d_ct_nct_inel_3)
	
	foreach var in ge_index_w ge_index_h{
	gen `var'=. 
	replace `var'=`var'_0 if FNLP_treatment==0
	replace `var'=`var'_1 if FNLP_treatment==1	
	drop `var'_0  `var'_1
	} 
	
	la var ge_index_w "Gender Equitable Attitudes(Wife)"
	la var ge_index_h "Gender Equitable Attitudes(Husband)"							   
	
	egen   ge_index_w_v2=rowtotal($ge_var_w)
	egen   ge_index_h_v2=rowtotal($ge_var_h)
    la var ge_index_w_v2 "Gender Equitable Attitudes v2(Wife)"
	la var ge_index_h_v2 "Gender Equitable Attitudes v2(Husband)"	
	
	
	
 * Decision Making and Empowerment index
   replace fem_borrowdecisions_w_bl=0 if fem_borrowdecisions_w_bl ==.
   
 * Renaming so we can generate mean variables, these names are too long! 
   ren fem_plotdecisions_w_bl        fem_plotdec_w_bl  
   ren fem_earningsdecisions_w_bl    fem_earningsdec_w_bl 
   ren fem_enterprisedecisions_w_bl  fem_enterprisedec_w_bl
   ren fem_landrentdecisions_w_bl    fem_landrentdec_w_bl
   ren fem_borrowdecisions_w_bl      fem_borrowdec_w_bl
   ren fem_cropusedecisions_w_bl     fem_cropusedec_w_bl 

  ren adequacy_input_prod_w_f3       adq_input_prod_w_f3     
  ren adequacy_input_income_w_f3     adq_input_income_w_f3
  ren adequacy_own_assets_w_f3       adq_own_assets_w_f3
  ren groupmember_any_w_f3           groupmem_any_w_f3      
  ren adequacy_workload_w_f3         adq_workload_w_f3
  ren adequacy_inc_satisfaction_w_f3 adq_inc_sat_w_f3
  ren adequacy_attitude_viol_w_f3    adq_att_viol_w_f3
  ren adequacy_autonomy_inc_w_f3     adq_aut_inc_w_f3 
  ren adequacy_selfeff_w_f3          adq_selfeff_w_f3
  ren adequacy_respect_w_f3          adq_respect_w_f3
   
   
  # d ;
	gl dm_var_w_bl   fem_plotdec_w_bl       fem_earningsdec_w_bl 
	                 fem_enterprisedec_w_bl fem_landrentdec_w_bl 
					 fem_cropusedec_w_bl   fem_assetsale_w_bl; 

	gl dm_var_w_f3   adequate_prod_5_f3     adequate_income_5_f3
	                 adequate_income_1_f3   female_plotown_f3 
					 fem_borrow_f3          adequate_prod_6_f3   
				     fem_assetsale_f3;
				 
    gl proweia_ind adq_input_prod_w_f3        adq_input_income_w_f3
	               adq_own_assets_w_f3 
	               fem_assetsale_w_f3        fem_borrow_w_f3
				   groupmem_any_w_f3         adq_workload_w_f3
				   adq_inc_sat_w_f3          adq_att_viol_w_f3 
				   adq_aut_inc_w_f3          adq_selfeff_w_f3
				   adq_respect_w_f3;
					  
  # d cr;

 * EV		 
 * Decision Making At Baseline
   swindex $dm_var_w_bl if FNLP_treatment==0 & d_wavail_f3==1 & d_vuln_cat_1==1, ///
                                          generate(dm_aindex_w_bl_0_1v)   normby(d_ct_nct_inel_3)  
                                          
										  
   swindex $dm_var_w_bl if FNLP_treatment==1 & d_wavail_f3==1 & d_vuln_cat_1==1,  ///
                                          generate(dm_aindex_w_bl_1_1v)  normby(d_ct_nct_inel_3) 	
										  
  * Decision Making At Endline
   swindex $dm_var_w_f3 if FNLP_treatment==0 & d_wavail_f3==1 & d_vuln_cat_1==1,   ///    
                                           generate(dm_aindex_w_f3_0_1v)  normby(d_ct_nct_inel_3)   
										   
   swindex $dm_var_w_f3 if FNLP_treatment==1  & d_wavail_f3==1 & d_vuln_cat_1==1,   ///        
                                             generate(dm_aindex_w_f3_1_1v) normby(d_ct_nct_inel_3)       
	
  * ProWeia At Endline 
   swindex $proweia_ind if FNLP_treatment==0 & d_wavail_f3==1 & d_vuln_cat_1==1,  ///
                                             generate(proweia_aindex_w_f3_0_1v)  normby(d_ct_nct_inel_3)
											 
   swindex $proweia_ind if FNLP_treatment==1 & d_wavail_f3==1 & d_vuln_cat_1==1,   ///
                                             generate(proweia_aindex_w_f3_1_1v)  normby(d_ct_nct_inel_3) 
	
  	
	
	
  /* VV	
   swindex $dm_var_w_bl if FNLP_treatment==0 & d_wavail_f3==1 & d_vuln_cat_2==1, 
                                          generate(dm_aindex_w_bl_0_2v) displayw  
                                          normby(d_ct_nct_inel_3);
										  
   swindex $dm_var_w_bl if FNLP_treatment==1 & d_wavail_f3==1 & d_vuln_cat_2==1, 
                                             generate(dm_aindex_w_bl_1_2v) displayw   
                                              normby(d_ct_nct_inel_3); 	
	
   swindex $dm_var_w_f3 if FNLP_treatment==0 & d_wavail_f3==1 & d_vuln_cat_2==1,     
                                           generate(dm_aindex_w_f3_0_2v) displayw     
                                           normby(d_ct_nct_inel_3);
										   
   swindex $dm_var_w_f3 if FNLP_treatment==1  & d_wavail_f3==1 & d_vuln_cat_2==1,          
                                             generate(dm_aindex_w_f3_1_2v) displayw      
                                             normby(d_ct_nct_inel_3);										   
										   
   swindex $proweia_ind if FNLP_treatment==0 & d_wavail_f3==1 & d_vuln_cat_2==1,
                                             generate(proweia_aindex_w_f3_0_2v) displayw    
                                             normby(d_ct_nct_inel_3);
											 
   swindex $proweia_ind if FNLP_treatment==1 & d_wavail_f3==1 & d_vuln_cat_2==1, 
                                             generate(proweia_aindex_w_f3_1_2v) displayw     
                                             normby(d_ct_nct_inel_3);	
											 
* ML	
   swindex $dm_var_w_bl if FNLP_treatment==0 & d_wavail_f3==1 & d_vuln_cat_3==1, 
                                          generate(dm_aindex_w_bl_0_3v) displayw  
                                          normby(d_ct_nct_inel_3);
										  
   swindex $dm_var_w_bl if FNLP_treatment==1 & d_wavail_f3==1 & d_vuln_cat_3==1, 
                                             generate(dm_aindex_w_bl_1_3v) displayw   
                                              normby(d_ct_nct_inel_3); 	
	
   swindex $dm_var_w_f3 if FNLP_treatment==0 & d_wavail_f3==1 & d_vuln_cat_3==1,     
                                           generate(dm_aindex_w_f3_0_3v) displayw     
                                           normby(d_ct_nct_inel_3);
										   
   swindex $dm_var_w_f3 if FNLP_treatment==1  & d_wavail_f3==1 & d_vuln_cat_3==1,          
                                             generate(dm_aindex_w_f3_1_3v) displayw      
                                             normby(d_ct_nct_inel_3);										   
										   
   swindex $proweia_ind if FNLP_treatment==0 & d_wavail_f3==1 & d_vuln_cat_3==1,
                                             generate(proweia_aindex_w_f3_0_3v) displayw    
                                             normby(d_ct_nct_inel_3);
											 
   swindex $proweia_ind if FNLP_treatment==1 & d_wavail_f3==1 & d_vuln_cat_3==1, 
                                             generate(proweia_aindex_w_f3_1_3v) displayw     
                                             normby(d_ct_nct_inel_3);*/												 
											 
											 

		
	foreach var in  dm_aindex_w_bl dm_aindex_w_f3 proweia_aindex_w_f3{
	gen `var'=. 
	replace `var'=`var'_0_1v if FNLP_treatment==0 & d_vuln_cat_1==1
	replace `var'=`var'_1_1v if FNLP_treatment==1 & d_vuln_cat_1==1	
	
	/*replace `var'=`var'_0_2v if FNLP_treatment==0 & d_vuln_cat_2==1
	replace `var'=`var'_1_2v if FNLP_treatment==1 & d_vuln_cat_2==1	
	
	
	replace `var'=`var'_0_3v if FNLP_treatment==0 & d_vuln_cat_3==1
	replace `var'=`var'_1_3v if FNLP_treatment==1 & d_vuln_cat_3==1		*/
	} 	

	
	
	
	gl viol_w   jviol_9_w_f3 jviol_10_w_f3 jviol_11_w_f3 jviol_12_w_f3          ///
	            jviol_13_w_f3 jviol_14_w_f3
	gl viol_h   jviol_9_h_f3 jviol_10_h_f3 jviol_11_h_f3 jviol_12_h_f3          ///
	            jviol_13_h_f3 jviol_14_h_f3
	
	egen   viol_index_w=rowtotal($viol_w)
	egen   viol_index_h=rowtotal($viol_h)	
	la var viol_index_w "Views on violence Index (Wife)"
	la var viol_index_h "Views on violence Index (Husband)"							   
	
    la var jviol_9_w_f3 "If she goes out withouth telling him (Wife)"
    la var jviol_10_w_f3 "If she neglects the children (Wife)"
	la var jviol_11_w_f3 "If she burns the food (Wife)"
	la var jviol_12_w_f3 "If she refuses to have sex with him (Wife)"
	la var jviol_13_w_f3 "If she argues with him? (Wife)"
	la var jviol_14_w_f3 "If she disobeys him? (Wife)"
	
    la var jviol_9_h_f3 "If she goes out withouth telling him (Husband)"
    la var jviol_10_h_f3 "If she neglects the children (Husband)"
	la var jviol_11_h_f3 "If she burns the food (Husband)"
	la var jviol_12_h_f3 "If she refuses to have sex with him (Husband)"
	la var jviol_13_h_f3 "If she argues with him? (Husband)"
	la var jviol_14_h_f3 "If she disobeys him? (Husband)"	
	
	
	** Food security 	
	egen   foodins_index_f2=rowtotal(foody1_f2-foody6_f2)
	la var foodins_index_f2 "Midline:HH Food Security Access Scale"
	egen   foodins_index_f3=rowtotal(foody1_f3-foody6_f3)
	la var foodins_index_f3 "Endline:HH Food Security Access Scale"
	egen   foodins_index_bl=rowtotal(foody1_bl-foody6_bl)
	la var foodins_index_bl "Baseline:HH Food Security Access Scale"
	
	foreach var of varlist  foody1_bl-foody6_bl foody1_f2-foody6_f2 foody1_f3-foody6_f3{
	replace `var'=0 if `var'==. 	
	}
	
	
	swindex foody1_bl-foody6_bl if FNLP_treatment==0, gen(foodaindex_bl_0)      ///
								   displayw 
								 
	swindex foody1_bl-foody6_bl if FNLP_treatment==1, gen(foodaindex_bl_1)      ///
								   displayw 	 							 
								 
								 
	swindex foody1_f2-foody6_f2  if FNLP_treatment==0, gen(foodaindex_f2_0)	    ///
								 displayw 
								 
	swindex foody1_f2-foody6_f2  if FNLP_treatment==1, gen(foodaindex_f2_1)	    ///
								 displayw 	 							 
								 
	swindex foody1_f3-foody6_f3 if FNLP_treatment==0, gen(foodaindex_f3_0)	    ///
								 displayw 
						
	swindex foody1_f3-foody6_f3 if FNLP_treatment==1, gen(foodaindex_f3_1)	    ///
								  displayw 
							
	foreach var in  foodaindex_bl foodaindex_f2 foodaindex_f3{
	gen `var'=. 
	replace `var'=`var'_0 if FNLP_treatment==0
	replace `var'=`var'_1 if FNLP_treatment==1	
	drop `var'_0  `var'_1
	} 							
	
	la var foodaindex_bl "Baseline:HH Food Security Anderson Index"
	la var foodaindex_f2 "Midline:HH Food Security Anderson Index"
	la var foodaindex_f3 "Endline:HH Food Security Anderson Index"
	
	
	
		
	* Aspirations 			
	egen    d_asp_daug_anyjob_w_f3=anymatch(d_asp_daug_1_w_f3 d_asp_daug_2_w_f3 ///
									     d_asp_daug_3_w_f3 d_asp_daug_6_w_f3), value(1)
	replace d_asp_daug_anyjob_w_f3=. if 	d_asp_daug_1_w_f3>=.						  
	egen    d_asp_son_anyjob_w_f3=anymatch(d_asp_son_1_w_f3 d_asp_son_2_w_f3 ///
									  d_asp_son_3_w_f3 d_asp_son_6_w_f3), value(1)	
	replace d_asp_son_anyjob_w_f3 =. if 	d_asp_son_1_w_f3>=.
	
	egen    d_asp_daug_anyjob_h_f3=anymatch(d_asp_daug_1_h_f3 d_asp_daug_2_h_f3 ///
									  d_asp_daug_3_h_f3 d_asp_daug_6_h_f3), value(1)
	replace d_asp_daug_anyjob_h_f3=. if 	d_asp_daug_1_h_f3>=.										  
	
	egen    d_asp_son_anyjob_h_f3=anymatch(d_asp_son_1_h_f3 d_asp_son_2_h_f3 ///
									  d_asp_son_3_h_f3 d_asp_son_6_h_f3), value(1)					  
	replace d_asp_son_anyjob_h_f3 =. if 	d_asp_son_1_h_f3>=.
	
	
	** Food Security based on Anderson Index*****
   * First, I switch signs (but this is already done).
   * Second, I convert to z scores using the control group.
   foreach wave in bl f2 f3{
   forval count = 1/9 {
     zscore foody`count'_`wave' /*, stub (y`count'_z)*/
          }
		 
   * Third, I calculate the covariance matrix and the weights...
     correl z_foody*_`wave', covar
     matrix MyCovar_food  = r(C)    
     matrix CovarInv_food = syminv(MyCovar_food)
     matrix MyOnes_food   = J(rowsof(CovarInv_food), 1, 1)
     matrix MyWeights_food= syminv(MyOnes_food'*CovarInv_food*MyOnes_food)*(MyOnes_food' * CovarInv_food)

* Finally create weighted variables from matrix weights
  svmat MyWeights_food, names(weight_food`wave'_)
  forval count = 1/4 {
   gen weighted_food_`wave'_`count'= z_foody`count'_`wave'*weight_food`wave'_`count'[1]
           }
			  
   egen WeightedVar_food_`wave'= rsum(weighted_food_`wave'_*)
   recode WeightedVar_food_`wave' (0=.) if foody7_`wave'==.
   drop weighted_food_`wave'_* z_foody*_`wave'  weight_food`wave'_*
   eststo clear	
   }
   

 ** Decision Making 
   foreach x in w h {
   egen d_dm_cultany_1_`x'=anymatch(d_dm_cult_*1_f3_`x'), value(1)
   egen d_dm_cultany_2_`x'=anymatch(d_dm_cult_*2_f3_`x'), value(1)
   egen d_dm_cultany_3_`x'=anymatch(d_dm_cult_*3_f3_`x'), value(1)
   egen d_dm_cultany_4_`x'=anymatch(d_dm_cult_*4_f3_`x'), value(1)
   foreach var of varlist d_dm_cultany_?_`x'{
   replace `var'=. if num_crops_cult_f3_`x'>=. | num_crops_cult_f3_`x'==0
   }
   }

   * Consumption and loans 
	gen  w_exp_ttlconfood_7dae_bl=w_exp_ttlfood_7dae_bl
	gen  ihs_exp_ttlconfood_7dae_bl=ihs_exp_ttlfood_7dae_bl 
	replace ttl_hh_loans_w_f2=0 if ttl_hh_loans_w_f2==. 
	replace ttl_hh_loans_h_f2=0 if ttl_hh_loans_h_f2==.  
	replace ttl_hh_loans_w_f3=0 if ttl_hh_loans_w_f3==. 
	replace ttl_hh_loans_h_f3=0 if ttl_hh_loans_h_f3==.  	
	
	gen     ttl_hh_loans_f2=ttl_hh_loans_h_f2
	replace ttl_hh_loans_f2=ttl_hh_loans_w_f2 if ttl_hh_loans_f2==. 
	
	gen     ttl_hh_loans_f3=ttl_hh_loans_h_f3
	replace ttl_hh_loans_f3=ttl_hh_loans_w_f3 if ttl_hh_loans_f3==. 
	
	gen     d_loan_bl=(ttl_loan_bl>0 & ttl_loan_bl<.)  

	* Savings 
    foreach var of varlist cash_savings_h_f2 w_cash_savings_h_f2 ///
						   ihs_cash_savings_h_f2 {
	replace `var'=. if d_mavail_f2==0  					  	
						  }
						  
    foreach var of varlist cash_savings_h_f3 w_cash_savings_h_f3 ///
						   ihs_cash_savings_h_f3{
	replace `var'=. if d_mavail_f3==0  					  	
						  }
	

	* Winsor and ihs 
	gl   wins_var ttl_loan_bl     hh_income_w_f3  hh_income_h_f3     ///
	              ttl_hh_loans_f2 ttl_hh_loans_f3 ttl_hh_loans_w_*   ///
				  ttl_hh_loans_h_* 
				  
	foreach var of varlist $wins_var{
	winsor `var', gen (w_`var') p(0.05)
	}
	ihstrans ttl_loan_bl     hh_income_w_f3   hh_income_h_f3 ///
	         ttl_hh_loans_f2 ttl_hh_loans_f3 ttl_hh_loans_w_* ttl_hh_loans_h_*

	
	
	
   * Ag variables 
	drop frac_*_qt_f3_* // dropping these which were compute using quantitites to not 
				   // generate confusion
	egen ttl_temp=rowtotal(ttl_solharv_f3   ttl_consharv_f3 ///
						   ttl_paymharv_f3  ttl_storharv_f3 ///
						   ttl_postharv_f3)

	foreach var in solharv consharv paymharv storharv postharv{
	gen      frac_`var'_f3=ttl_`var'_f3/ttl_temp   
	replace  frac_`var'_f3=0 if ttl_`var'_f3==. 
	}
	drop ttl_temp 

   
* Cleaning time use at baseline. Replacing by 0 if not reported.   
	foreach var of varlist time_?_bl{
	replace `var'=0 if `var'==. & time_6_bl<.
	replace `var'=. if time_6_bl==.
	}


   drop w_profits_business_bl 	
   clonevar w_profits_business_bl=profits_business_bl



* Labeling all the variables that are missing labels
* ------------------------------------------------------------------------------ 
la var polygamy_bl 					 "Poligamous at baseline"
la var both_male_fem_bl 			 "Interviwed both female and male"
la var female_adult_only_bl 		 "Female adult only"
la var povertylinebelow_125_bl 		 "Poverty line low 125 at baseline"
la var povertylinebelow_190_bl 		 "Poverty line low 190 at baseline" 
la var noland_bl  					 "No land at baseline"
la var farm_lessthan1hectare_bl 	 "Farming less than 1 hectare at baseline"
la var farm_greaterthan1hectare_bl 	 "Farming greater than 1 hectare at baseline"
la var Monthly_fnlp_bl  			 "Monthly treatment & FNLP treatment"
la var Monthly_nonfnlp_bl 			 "Monthly treatment & No FNLP treatment"
la var Lump_Sum_fnlp_bl  			 "Lump sum & FNLP treatment"
la var Lump_Sum_nonfnlp_bl  		 "Lump sum & No FNLP treatment"
la var Cash_Transfer_fnlp_bl  		 "Cash transfer treatment & FNLP treatment"
la var Cash_Transfer_nonfnlp_bl 	 "Cash transfer treatment & No FNLP treatment"
la var treatment_ct_bl  			 "Cash transfer treatment"
la var farming_woman_bl  			 "Farming women at baseline"
la var empowered_new_bl  			 "Empowered at Baseline (A-WEAI)"
la var widowed_bl  					 "Widowed at baseline"
la var ward_vulnerable_bl  			 "Ward vulnerable at baselin"
la var Stratification_Dummies_bl 	 "Stratification Dummy at baseline" 
la var bus_CT_2 					 "Business in wave 2"
la var bus_CT_3 					 "Business in wave 3"
la var w_norms_women_not_go_work     "Women should not go out to work (Wife)"
la var w_comm_norm_woman_fields      "Fraction who speak badly woman who works in the fields? (Wife)"
la var w_comm_norm_male_bad_provider "Fraction believe man is a bad provider if wife working for pay (Wife)"
la var w_comm_norm_woman_travelsout  "Fraction who speak badly woman who travels out village (Wife)"
la var w_comm_norm_worsehusband      "People in neighborhood speak more badly of husband if wife works (Wife)"
la var w_gender_equity_norm          "Gender Equitable Norm Scale (Wife)"
la var primary_act_fup2              "Primary Non-farm activity at midline"
la var primary_act_fup3              "Primary Non-farm activity at endline"
la var w_profits_business_fup2       "Midline:Business Profits"
la var w_profits_business_fup3       "Endline:Business Profits"
la var d_locationbuss_1_fup2_w       "Midline:location business Home (Wife)"
la var d_locationbuss_2_fup2_w       "Midline:location business Market place(Wife)"
la var d_locationbuss_3_fup2_w       "Midline:location business form shop(Wife)"
la var d_locationbuss_4_fup2_w       "Midline:location business travelling door to door(Wife)"
la var d_locationbuss_5_fup2_w       "Midline:location business other(Wife)"
la var d_locationbuss_1_fup2_h       "Midline:location business Home (Husband)"
la var d_locationbuss_2_fup2_h       "Midline:location business Market place (Husband)"
la var d_locationbuss_3_fup2_h       "Midline:location business form shop (Husband)"
la var d_locationbuss_4_fup2_h       "Midline:location business travelling door to door (Husband)"
la var d_locationbuss_5_fup2_h       "Midline:location business other (Husband)"	
la var num_sourcemonbuss_fup2_w      "Midline:Number of money sources used to start a business (Wife)"
la var num_sourcemonbuss_fup2_h      "Midline:Number of money sources used to start a business (Husband)"
la var d_sourcemonbuss_1_fup2_w      "Midline:Source of money Cash transfer payment (Wife)"
la var d_sourcemonbuss_2_fup2_w      "Midline:Source of money Savings (Wife)"	
la var d_sourcemonbuss_3_fup2_w      "Midline:Source of money Loan from Bank/ Microcredit (Wife)"	
la var d_sourcemonbuss_4_fup2_w      "Midline:Source of money Loan from a family/friend/neighbor (Wife)"
la var d_sourcemonbuss_5_fup2_w      "Midline:Source of money Gift (Wife)"
la var d_sourcemonbuss_6_fup2_w      "Midline:Source of money Other (Wife)"
la var d_sourcemonbuss_1_fup2_h      "Midline:Source of money Cash transfer payment (Husband)"
la var d_sourcemonbuss_2_fup2_h      "Midline:Source of money Savings (Husband)"	
la var d_sourcemonbuss_3_fup2_h      "Midline:Source of money Loan from Bank/ Microcredit (Husband)"	
la var d_sourcemonbuss_4_fup2_h      "Midline:Source of money Loan from a family/friend/neighbor (Husband)"
la var d_sourcemonbuss_5_fup2_h      "Midline:Source of money Gift (Husband)"
la var d_sourcemonbuss_6_fup2_h      "Midline:Source of money Other(Husband)"
la var w_rawmats_business_fup2_w     "Midline:Total value spent on raw materials in last 30 days (Wife)"
la var w_rawmats_business_fup2_h     "Midline:Total value spent on raw materials in last 30 days (Husband)"
la var d_locationbuss_1_fup3_w       "Endline:location business Home (Wife)"
la var d_locationbuss_2_fup3_w       "Endline:location business Market place(Wife)"
la var d_locationbuss_3_fup3_w       "Endline:location business form shop(Wife)"
la var d_locationbuss_4_fup3_w       "Endline:location business travelling door to door(Wife)"
la var d_locationbuss_5_fup3_w       "Endline:location business other(Wife)"
la var d_locationbuss_1_fup3_h       "Endline:location business Home (Husband)"
la var d_locationbuss_2_fup3_h       "Endline:location business Market place (Husband)"
la var d_locationbuss_3_fup3_h       "Endline:location business form shop (Husband)"
la var d_locationbuss_4_fup3_h       "Endline:location business travelling door to door (Husband)"
la var d_locationbuss_5_fup3_h       "Endline:location business other (Husband)"
la var num_sourcemonbuss_fup3_w      "Endline:Number of money sources used to start a business (Wife)"
la var num_sourcemonbuss_fup3_h      "Endline:Number of money sources used to start a business (Husband)"
la var d_sourcemonbuss_1_fup3_w      "Endline:Source of money Cash transfer payment (Wife)"
la var d_sourcemonbuss_2_fup3_w      "Endline:Source of money Savings (Wife)"	
la var d_sourcemonbuss_3_fup3_w      "Endline:Source of money Loan from Bank/ Microcredit (Wife)"	
la var d_sourcemonbuss_4_fup3_w      "Endline:Source of money Loan from a family/friend/neighbor (Wife)"
la var d_sourcemonbuss_5_fup3_w      "Endline:Source of money Gift (Wife)"
la var d_sourcemonbuss_6_fup3_w      "Endline:Source of money Other (Wife)"
la var d_sourcemonbuss_1_fup3_h      "Endline:Source of money Cash transfer payment (Husband)"
la var d_sourcemonbuss_2_fup3_h      "Endline:Source of money Savings (Husband)"	
la var d_sourcemonbuss_3_fup3_h      "Endline:Source of money Loan from Bank/ Microcredit (Husband)"	
la var d_sourcemonbuss_4_fup3_h      "Endline:Source of money Loan from a family/friend/neighbor (Husband)"
la var d_sourcemonbuss_5_fup3_h      "Endline:Source of money Gift (Husband)"
la var d_sourcemonbuss_6_fup3_h      "Endline:Source of money Other(Husband)"
la var w_rawmats_business_fup3_w     "Endline:Total value spent on raw materials in last 30 days (Wife)"
la var w_rawmats_business_fup3_h     "Endline:Total value spent on raw materials in last 30 days (Husband)"	
la var school_mother_bl_w            "Mother of wife had formal schooling"
la var school_mother_bl_h            "Mother of husband had formal schooling"	
la var w_value_animals_fup2_w        "Midline:Total value of animals"
la var w_value_farmassets_fup2_w     "Midline:Total value farming assets"
la var w_value_hhassets_fup2_w       "Midline:Total value housing assets"
la var w_value_animals_fup3_w        "Endline:Total value of animals"
la var w_value_farmassets_fup3_w     "Endline:Total value farming assets"
la var w_value_hhassets_fup3_w       "Endline:Total value housing assets"	
la var ihs_rawmats_business_fup2_w   "Midline:(IHS) Raw materials in last 30 days (Wife)"
la var ihs_rawmats_business_fup2_h   "Midline:(IHS) Raw materials in last 30 days (Husband)"	
la var ihs_rawmats_business_fup3_w   "Endline:(IHS) Raw materials in last 30 days (Wife)"
la var ihs_rawmats_business_fup3_h   "Endline:(IHS) Raw materials in last 30 days (Husband)"	
la var ihs_profits_business_fup2     "Midline:(IHS) Business Profits (Wife)"
la var ihs_profits_business_fup2_h   "Midline:(IHS) Business Profits (Husband)"
la var ihs_profits_business_fup3     "Endline:(IHS) Business Profits (Wife)"
la var ihs_profits_business_fup3_h   "Endline:(IHS) Business Profits (Husband)"
la var gps_latitude_final            "Latitude"
la var gps_longitude_final           "Longitude"
la var ihs_daily_adulteq_expenses_f2 "Midline:(IHS) Daily Expenditures AdultE (Wife)"
la var ihs_daily_adulteq_expenses_f3 "Endline:(IHS) Daily Expenditures AdultE (Wife)"
la var w_daily_adulteq_expenses_bl   "Baseline:Daily adult eq expenditures"
la var w_daily_adulteq_expenses_f2   "Midline:Daily adult eq expenditures"
la var w_daily_adulteq_expenses_f3   "Endline:Daily adult eq expenditures"	
la var ihs_daily_adulteq_expenses_bl "Baseline:Daily adult eq expenditures(IHS)"
la var ihs_daily_adulteq_expenses_f2 "Midline:Daily adult eq expenditures(IHS)"
la var ihs_daily_adulteq_expenses_f3 "Endline:Daily adult eq expenditures(IHS)"	
la var w_daily_hh_expenses_bl        "Baseline:(Levels) Daily hh expenditures"
la var w_daily_hh_expenses_f2        "Midline:(Levels) Daily hh expenditures"
la var w_daily_hh_expenses_f3        "Endline:(Levels) Daily hh expenditures"
la var ihs_daily_hh_expenses_bl      "Baseline:(IHS) Daily hh expenditures"
la var ihs_daily_hh_expenses_f2      "Midline:(IHS) Daily hh expenditures"
la var ihs_daily_hh_expenses_f3      "Endline:(IHS) Daily hh expenditures"
la var w_daily_percapita_expenses_bl "Baseline:(Levels) Daily per capita expenditures"
la var w_daily_percapita_expenses_f2 "Midline:(Levels) Daily per capita expenditures"
la var w_daily_percapita_expenses_f3 "Endline:(Levels) Daily per capita expenditures"
la var w_daily_percapita_expenses_bl "Baseline:(Winsor) Daily per capita expenditures"
la var w_daily_percapita_expenses_f2 "Midline:(Winsor) Daily per capita expenditures"
la var w_daily_percapita_expenses_f3 "Endline:(Winsor) Daily per capita expenditures"
la var profits_business_bl           "Baseline: Profits (Wife)"
la var rawmats_business_bl_w         "Baseline: Raw Materials (Wife)"
la var profits_business_bl_h         "Baseline: Profits(Husband)"
la var rawmats_business_bl_h         "Baseline: Raw Materials(Husband)"
la var w_profits_business_fup2_c     "Midline:(Winsor) Uncoditional profits"
la var ihs_profits_business_fup2_c	 "Midline:(IHS) Uncoditional profits"
la var w_profits_business_fup3_c     "Endline:(Winsor) Uncoditional profits"
la var ihs_profits_business_fup3_c	 "Endline:(IHS) Uncoditional profits"	
la var w_daily_adulteq_expenses_f2   "Midline:Daily Expenditures"
la var dietdiv_score_bl              "Baseline: Dietary diversity for 7 food groups"	
la var dietdiv_score_f2              "Midline:Dietary diversity for 7 food groups"
la var w_daily_adulteq_expenses_f3   "Endline:Daily Expenditures"
la var dietdiv_score_f3              "Endline:Dietary diversity for 7 food groups"
la var HDDS_f3					     "Endline:Dietary diversity for 12 food groups"
la var w_norms_women_not_go_work     "Women should not go out to work (Wife)"
la var w_comm_norm_woman_fields      "Fraction who speak badly woman who works in the fields? (Wife)"
la var w_comm_norm_male_bad_provider "Fraction believe man is a bad provider if wife working for pay (Wife)"
la var w_comm_norm_woman_travelsout  "Fraction who speak badly woman who travels out village (Wife)"
la var w_comm_norm_worsehusband      "People in neighborhood speak more badly of husband if wife works (Wife)"
la var w_comm_norm_worsewife         "People in neighborhood speak more badly of wife if wife works (Wife)"
la var w_comm_norm_worseindf         "People in neighborhood indiffirent if wife works (Wife)"
la var w_gender_equity_norm          "Gender Equitable Norm Scale (Wife)"
la var h_norms_women_not_go_work     "Women should not go out to work (Husband)"
la var h_comm_norm_woman_fields      "Fraction who speak badly woman who works in the fields? (Husband)"
la var h_comm_norm_male_bad_provider "Fraction believe man is a bad provider if wife working for pay (Husband)"
la var h_comm_norm_woman_travelsout  "Fraction who speak badly woman who travels out village (Husband)"
la var h_comm_norm_worsehusband      "People in neighborhood speak more badly of husband if wife works (Husband)"
la var h_comm_norm_worsewife         "People in neighborhood speak more badly of wife if wife works (Husband)"
la var h_comm_norm_worseindf         "People in neighborhood indiffirent if wife works (Husband)"
la var h_gender_equity_norm          "Gender Equitable Norm Scale (Husband)"
la var aggregate_prod     			 "Input into productive decisions"
la var w_jv_any          			 "Justify Violence (Wife)"
la var h_jv_any           			 "Justify Violence (Husband)"
la var w_selfeff          			 "Self Efficacy (Wife)"
la var h_selfeff          			 "Self Efficacy (Husband)"
la var female_own_assets 			 "Female own assets?"
la var w_aggregate_income 			 "Total time spent daily on work related activities (Wife)"
la var w_aggregate_time   			 "Total time spent daily on work related activities (Husband)"
la var speakpublic_any   			 "Comfortable speaking in public in AT LEAST ONE context"
la var groupmember_any   		     "Female is part of AT LEAST ONE group"
la var d_primary_act_fup2_c1   		 "Midline:Cook"
la var d_primary_act_fup2_c2   		 "Midline:Oil Processing(Wife)"
la var d_primary_act_fup2_c3   		 "Midline:Crop Proccesing(Wife)"
la var d_primary_act_fup2_c4   		 "Midline:Trading(Wife)"
la var d_primary_act_fup2_c5         "Midline:Services(Wife)"
la var d_primary_act_fup2_c6         "Midline:Other(Wife)"
la var d_primary_act_fup3_c6         "Endline:Other(Wife)"	
la var d_primary_act_fup3_c1         "Endline:Cook(Wife)"
la var d_primary_act_fup3_c2         "Endline:Oil Processing(Wife)"
la var d_primary_act_fup3_c3         "Endline:Crop Proccesing(Wife)"
la var d_primary_act_fup3_c4         "Endline:Trading(Wife)"
la var d_primary_act_fup3_c5         "Endline:Services(Wife)"
la var d_primary_act_fup3_c6         "Endline:Other(Wife)"
la var d_primary_act_fup2_h_c1   	 "Midline:Cook (Husband)"
la var d_primary_act_fup2_h_c2   	 "Midline:Oil Processing (Husband)"
la var d_primary_act_fup2_h_c3   	 "Midline:Crop Proccesing (Husband)"
la var d_primary_act_fup2_h_c4   	 "Midline:Trading (Husband)"
la var d_primary_act_fup2_h_c5       "Midline:Services (Husband)"
la var d_primary_act_fup2_h_c6       "Midline:Other (Husband)" 
la var d_primary_act_fup3_h_c6       "Endline:Other (Husband)"	
la var d_primary_act_fup3_h_c1       "Endline:Cook (Husband)"
la var d_primary_act_fup3_h_c2       "Endline:Oil Processing (Husband)"
la var d_primary_act_fup3_h_c3       "Endline:Crop Proccesing (Husband)"
la var d_primary_act_fup3_h_c4       "Endline:Trading (Husband)"
la var d_primary_act_fup3_h_c5       "Endline:Services (Husband)"
la var d_primary_act_fup3_h_c6       "Endline:Other (Husband)"

la var emo_vio_f2                    "Midline:Emotional Violence"
la var phys_vio_f2  				 "Midline:Physical Violence"
la var sex_vio_f2					 "Midline:Sexual Violence"
la var emo_vio_f3                    "Endline:Emotional Violence"
la var phys_vio_f3  				 "Endline:Physical Violence"
la var sex_vio_f3					 "Endline:Sexual Violence"
la var business_work_fup2_w    		 "Midline:Non-Farm Enterprise (Wife)"
la var business_fup2_nobl_w   		 "Midline not baseline: New Business (Wife)"
la var business_work_fup3_w    		 "Endline:Non-Farm Enterprise (Wife)"
la var business_work_fup2_h    		 "Midline:Non-Farm Enterprise (Husband)"
la var business_work_fup3_h    		 "Endline:Non-Farm Enterprise (Husband)"
la var business_fup3_nofup2_w 		 "Endline not Midline:New Business (Wife)"
la var business_fup3_nobl_w    		 "Endline not baseline: Business (Wife)"
la var business_fup2_fup3_w          "Business at midline and still open endline"
la var business_fup2_nofup3_w        "Business at midline and closed endline"
la var overestimate_norm_w_w         "Women who overestimate comm norm of share of women in village judging female"
la var overestimate_norm_m_m         "Men who overestimate comm norm of share of men in village judging female"
la var overestimate_norm_w_m         "Women who overestimate comm norm of share of men in village judging female"
la var overestimate_norm_m_w         "Men who overestimate comm norm of share of women in village judging female"
la var w_number_animals_fup2_w       "Midline:Number of animals (Wife)"
la var w_number_animals_fup2_h       "Midline:Number of animals (Husband)"
la var w_number_farmassets_fup2_w    "Midline:Number of farm assets (Wife)"
la var w_number_farmassets_fup2_h    "Midline:Number of farm assets (Husband)"
la var w_value_animals_fup2_w        "Midline Current value of animals (Wife)"
la var w_value_farmassets_fup2_w     "Midline Current value of farming assets (Wife)"
la var w_value_hhassets_fup2_w       "Midline Current value of household assets (Wife)"
la var w_value_animals_fup2_h        "Midline Current value of animals (Husband)"
la var w_value_farmassets_fup2_h     "Midline Current value of farming assets (Husband)"
la var w_value_hhassets_fup2_h       "Midline Current value of housing assets (Husband)"
la var w_number_animals_fup3_w       "Endline:Number of animals (Wife)"
la var w_number_animals_fup3_h       "Endline:Number of animals (Husband)"
la var w_number_farmassets_fup3_w    "Endline:Number of farm assets (Wife)"
la var w_number_farmassets_fup3_h    "Endline:Number of farm assets (Husband)"
la var w_value_animals_fup3_w        "Endline:Current value of animals (Wife)"
la var w_value_farmassets_fup3_w     "Endline:Current value of farming assets (Wife)"
la var w_value_hhassets_fup3_w       "Endline:Current value of household assets (Wife)"
la var w_value_animals_fup3_h        "Endline:Current value of animals (Husband)"
la var w_value_farmassets_fup3_h     "Endline:Current value of farming assets (Husband)"
la var w_value_hhassets_fup3_h       "Endline:Current value of housing assets (Husband)"
la var same_business   				 "Same business"
la var diff_business				 "Different business"
la var d_cash_treatment_unc          "Cash Transfer Treatment"
la var business_work_bl_w            "Business at baseline"	
la var rawmats_business_bl_w         "Baseline:Raw materials (Wife)"
la var rawmats_business_bl_h         "Baseline:Raw materials (Husband)"
la var w_rawmats_business_fup2_w     "Midline:Raw materials(Winsor)"
la var w_rawmats_business_fup3_w     "Endline:Raw materials(Winsor)"	
la var ihs_rawmats_business_fup2_w   "Midline:Raw materials(IHS) "
la var ihs_rawmats_business_fup3_w   "Endline:Raw materials(IHS)"		
la var w_profits_business_fup2       "Midline:Business Profits(Winsor)"
la var w_profits_business_fup3       "Endline:Business Profits(Winsor)"	
la var ihs_profits_business_fup2     "Midline:Business Profits(IHS) "
la var ihs_profits_business_fup3     "Endline:Business Profits(IHS) "
la var ihs_profits_fup2_c1   	   "Midline:Profits Cook"
la var ihs_profits_fup2_c2   	   "Midline:Profits Oil Processing"
la var ihs_profits_fup2_c3   	   "Midline:Profits Crop Proccesing"
la var ihs_profits_fup2_c4   	   "Midline:Profits Trading"
la var ihs_profits_fup2_c5         "Midline:Profits Services"
la var ihs_profits_fup3_c1         "Endline:Profits Cook"
la var ihs_profits_fup3_c2         "Endline:Profits Oil Processing"
la var ihs_profits_fup3_c3         "Endline:Profits Crop Proccesing"
la var ihs_profits_fup3_c4         "Endline:Profits Trading"
la var ihs_profits_fup3_c5         "Endline:Profits Services"
la var ihs_value_animals_fup2_w     "Midline:Current value of animals (IHS)"
la var ihs_value_farmassets_fup2_w  "Midline:Current value of farming assets (IHS)"
la var ihs_value_hhassets_fup2_w    "Midline:Current value of household assets (IHS)"
la var ihs_value_animals_fup3_w      "Endline:(IHS)Current value of animals (Wife)"
la var ihs_value_farmassets_fup3_w   "Endline:(IHS)Current value of farming assets (Wife)"
la var ihs_value_hhassets_fup3_w     "Endline:(IHS)Current value of household assets (Wife)"
la var  w_daily_hh_expenses_bl       "Baseline: Daily hh expenses (Winsor 0.1)"
la var  w_daily_hh_expenses_f2       "Midline: Daily hh expenses (Winsor 0.1)"
la var  w_daily_hh_expenses_f3       "Endline: Daily hh expenses (Winsor 0.1)"
la var  ihs_daily_hh_expenses_bl       "Baseline: Daily hh expenses (IHS)"
la var  ihs_daily_hh_expenses_f2       "Midline: Daily hh expenses (IHS)"
la var  ihs_daily_hh_expenses_f3       "Endline: Daily hh expenses (IHS)"
la var  w_daily_hh_realexp_bl         "Baseline: Daily hh real expenses (Winsor 0.1)"
la var  w_daily_hh_realexp_f2         "Midline: Daily hh real expenses (Winsor 0.1)"
la var  w_daily_hh_realexp_f3         "Endline: Daily hh real expenses (Winsor 0.1)"
la var  ihs_daily_hh_realexp_bl       "Baseline: Daily hh real expenses (IHS)"
la var  ihs_daily_hh_realexp_f2       "Midline: Daily hh real expenses (IHS)"
la var  ihs_daily_hh_realexp_f3       "Endline: Daily hh real expenses ((IHS)"
la var  profits_business_bl           "Baseline: Business Profits (Wife)"
la var  profits_business_fup2         "Midline:Business Profits(Wife)"
la var  profits_business_fup3         "Endline:Business Profits(Wife)"
la var  profits_business_bl_h         "Baseline: Business Profits (Husband)"
la var  profits_business_fup2_h       "Midline:Business Profits(Husband)"
la var  profits_business_fup3_h       "Endline:Business Profits(Husband)"
la var  w_profits_business_bl         "Baseline:(Winsor)Business Profits(Wife)"
la var  w_profits_business_fup2       "Midline:(Winsor)Business Profits(Wife)"
la var  w_profits_business_fup3       "Endline:(Winsor)Business Profits(Wife)"
la var  w_profits_business_bl_h       "Baseline:(Winsor)Business Profits (Husband)"
la var  w_profits_business_fup2_h     "Midline:(Winsor)Business Profits(Husband)"
la var  w_profits_business_fup3_h     "Endline:(Winsor)Business Profits(Husband)"
la var  ihs_profits_business_bl       "Baseline:(IHS)Business Profits(Wife)"
la var  ihs_profits_business_fup2     "Midline:(IHS)Business Profits(Wife)"
la var  ihs_profits_business_fup3     "Endline:(IHS)Business Profits(Wife)"
la var  ihs_profits_business_bl_h     "Baseline:(IHS)Business Profits (Husband)"
la var  ihs_profits_business_fup2_h   "Midline:(IHS)Business Profits(Husband)"
la var  ihs_profits_business_fup3_h   "Endline:(IHS)Business Profits(Husband)"
la var  daily_percapita_expenses_bl   "Baseline:Daily per capita expenditures (No winsor)"
la var  daily_percapita_expenses_f2   "Midline:Daily per capita expenditures (No winsor)"
la var  daily_percapita_expenses_f3   "Endline:Daily per capita expenditures (No winsor)"
la var  w_NonLandAssets_fup2_w        "Midline:Non-Land Assets"
la var  w_NonLandAssets_fup3_w        "Endline:Non-Land Assets"	
la var  ihs_NonLandAssets_fup2_w      "Midline:(IHS) Non-Land Assets"
la var  ihs_NonLandAssets_fup3_w      "Endline:(IHS) Non-Land Assets"
la var  market_inf                    "Market Information"
la var  age_hhhead_bl                 "Age (Years)"
la var  marital_status2_bl_1           "Marital Status (Married Monogamous=1)"
la var  marital_status2_bl_2           "Marital Status (Married Polygamous=1)"
la var  marital_status2_bl_3           "Marital Status (Divorced/Widowed=1)"
la var  marital_status2_bl_4           "Marital Status (Never married=1)"

la var  marital_status_bl_1           "Marital Status (Married Monogamous=1)"
la var  marital_status_bl_2           "Marital Status (Married Polygamous=1)"
la var  marital_status_bl_3           "Marital Status (Divorced=1)"
la var  marital_status_bl_4           "Marital Status (Separated=1)"
la var  marital_status_bl_5           "Marital Status (Widowed=1)"
la var  marital_status_bl_6           "Marital Status (Never married=1)"


la var  literacy_hhhead_bl            "Literacy (Can you read or write in any language=1)"
la var  num_hh_members_bl             "Number of household members"
la var  num_hh_members_15_bl          "Number of HH members(Age under 15)"
la var  num_plots_bl                  "Number of agriculture plots (0-7)"
la var  d_farm_size_bl_1              "Farm size less than 1 hectare(=1)"
la var  d_farm_size_bl_2              "Farm size greater or equal to 1 hectare(=1)"
la var  w_daily_adulteq_expenses_bl   "Daily adult equivalent expentitures (Naira)*"
la var  num_enterprises_bl            "Number of enterprises own by the household (0-5)"
la var  empowered_new_bl              "Empowered (=1 if adequacy in modified A-WEIA)"
la var  weai_new_bl_w                 "Modified A-WEAI Score (0-1)"
la var  dm_index_bl_new_w             "Decision Making Index (0-6)"
la var  proweai_sum_ind_w 			  "Proweai Ind"	
la var  proweia_aindex_w_f3           "Pro-WEAI Anderson Index"
la var  dm_aindex_w_f3                "Decision Making Anderson Index"
la var  dm_aindex_w_bl                "Decision Making Anderson Index (Baseline)"

la var  hhtype_bl                     "Household type"
la var  econ_fem_activity_bl          "Economic female activity"
la var  dm_index_bl_new_w             "Baseline:Decision Making Index"
la var  dm_index_fup3_w               "Endline:Decision Making Index"
la var  business_work_bl_w            "Females owns a non-farm enterprise (Yes=1)"
la var  econ_fem_activity_bl          "Female any economic activity in past year(Yes=1)"
la var  adequate_prod_5_f3            "Female makes the most decisions on any plots"
la var  adequate_income_5_f3          "Female Self Non-farm Enterprise Decisions act_1_13"
la var  adequate_income_1_f3          "Non-farm economic activities (from WEAI in last 12 months)"
la var  female_plotown_f3             "Female named as owning any of the plots"
la var  fem_borrow_f3                 "Female named as making the decision to borrow"
la var  adequate_prod_6_f3            "Female decided to cultivate this crop (7 top crops)"
la var  fem_assetsale_f3              "Female named as having the final say over the purchase of assets"
la var  d_sharemoney2_1_w_f3          "Final say over NGO money: Self" 
la var  d_sharemoney2_2_w_f3          "Final say over NGO money: Spouse" 	
la var  d_sharemoney2_3_w_f3          "Final say over NGO money: Joint" 
la var  d_sharemoney2_4_w_f3          "Final say over NGO money: Other" 	
la var  d_sharemoney4_1_w_f3          "Final say over relative money: Self" 
la var  d_sharemoney4_2_w_f3          "Final say over relative money: Spouse" 	
la var  d_sharemoney4_3_w_f3          "Final say over relative money: Joint" 
la var  d_sharemoney4_4_w_f3          "Final say over relative money: Other" 	
la var  just_viol_pub_w_f3            "Justify violence Public goods (wife)"
la var  just_viol_priv_w_f3           "Justify violence Private goods (wife)"
la var  d_asp_daug_1_w_f3             "Aspirations daughter:Family farming"
la var  d_asp_daug_2_w_f3             "Aspirations daughter:Run family business"
la var  d_asp_daug_3_w_f3             "Aspirations daughter:Any other job (Proffesional,Army,etc)"
la var  d_asp_daug_4_w_f3             "Aspirations daughter:Dont work outside home"
la var  d_asp_daug_5_w_f3             "Aspirations daughter:Married"
la var  d_asp_daug_6_w_f3             "Aspirations daughter:Other"
la var  d_asp_daug_anyjob_w_f3        "Aspiration  daughter:Any Job at all" 
la var  d_asp_son_1_w_f3              "Aspirations son:Family farming"
la var  d_asp_son_2_w_f3              "Aspirations son:Run family business"
la var  d_asp_son_3_w_f3              "Aspirations son:Any other job (Proffesional,Army,etc)"
la var  d_asp_son_4_w_f3              "Aspirations son:Dont work outside home"
la var  d_asp_son_5_w_f3              "Aspirations son:Married"
la var  d_asp_son_6_w_f3              "Aspirations son:Other"
la var  d_asp_son_anyjob_w_f3        "Aspiration  son:Any Job at all" 
la var  shame_husbhhwork_w_f3         "Shameful for a woman if her husband cooks or does housework"
la var  tol_viol_w_f3                 "Woman should tolerate violence to keep her family together"
la var  obey_husb_w_f3                "Woman should obey her husband even if she does not agree with him"
la var  menwom_rights_w_f3            "Men and women have the same rights, men will lose their authority"
la var  womreso_w_f3                  "Woman is the one who provides resources for the family, she will control the man" 
la var  viol_priv_w_f3                "Violence between husband and wife is a private matter and others should not intervene"
la var womenleaves_w_f3              "If a woman leaves her marriage, it reflects badly on her family"
la var d_sharemoney2_1_h_f3          "Final say over NGO money: Self" 
la var d_sharemoney2_2_h_f3          "Final say over NGO money: Spouse" 	
la var d_sharemoney2_3_h_f3          "Final say over NGO money: Joint" 
la var d_sharemoney2_4_h_f3          "Final say over NGO money: Other" 	
la var d_sharemoney4_1_h_f3          "Final say over relative money: Self" 
la var d_sharemoney4_2_h_f3          "Final say over relative money: Spouse" 	
la var d_sharemoney4_3_h_f3          "Final say over relative money: Joint" 
la var d_sharemoney4_4_h_f3          "Final say over relative money: Other" 	
la var just_viol_pub_h_f3            "Justify violence Public goods (wife)"
la var just_viol_priv_h_f3           "Justify violence Private goods (wife)"
la var d_asp_daug_1_h_f3             "Aspirations daughter:Family farming"
la var d_asp_daug_2_h_f3             "Aspirations daughter:Run family business"
la var d_asp_daug_3_h_f3             "Aspirations daughter:Any other job (Proffesional,Army,etc)"
la var d_asp_daug_4_h_f3             "Aspirations daughter:Dont work outside home"
la var d_asp_daug_5_h_f3             "Aspirations daughter:Married"
la var d_asp_daug_6_h_f3             "Aspirations daughter:Other"
la var d_asp_daug_anyjob_h_f3        "Aspiration  daughter:Any Job at all" 	
la var d_asp_son_1_h_f3              "Aspirations son:Family farming"
la var d_asp_son_2_h_f3              "Aspirations son:Run family business"
la var d_asp_son_3_h_f3              "Aspirations son:Any job (Proffesional,Army,etc)"
la var d_asp_son_4_h_f3              "Aspirations son:Dont work outside home"
la var d_asp_son_5_h_f3              "Aspirations son:Married"
la var d_asp_son_6_h_f3              "Aspirations son:Other"
la var d_asp_son_anyjob_h_f3         "Aspirations  son:Any Job at all" 	
la var shame_husbhhwork_h_f3         "Shameful for a woman if her husband cooks or does housework"
la var tol_viol_h_f3                 "Woman should tolerate violence to keep her family together"
la var obey_husb_h_f3                "Woman should obey her husband even if she does not agree with him"
la var menwom_rights_h_f3            "Men and women have the same rights, men will lose their authority"
la var womreso_h_f3                  "Woman is the one who provides resources for the family, she will control the man" 
la var viol_priv_h_f3                "Violence between husband and wife is a private matter and others should not intervene"
la var womenleaves_h_f3              "If a woman leaves her marriage, it reflects badly on her family"
la var ihs_value_animals_fup2_w     "Midline:Current value of animals (IHS)"
la var ihs_value_farmassets_fup2_w  "Midline:Current value of farming assets (IHS)"
la var ihs_value_hhassets_fup2_w    "Midline:Current value of household assets (IHS)"
la var ihs_daily_percapita_expenses_f2 "Midline:Daily Percapita Expenditures(IHS)"	
la var ihs_daily_percapita_expenses_f3 "Endline:Daily Percapita Expenditures(IHS)"	
la var happ_12_1_w_f3  "Happiness Level"
la var happ_12_2_w_f3  "Wellbeing satisfaction"
la var happ_12_7_w_f3   "I'm optimistic about my future" 
la var happ_12_8_w_f3   "I expect things to go my way"
la var happ_12_9_w_f3   "I count on good things happening to me"
la var happ_12_10_w_f3  "I expect more good things to happen to me than bad"
la var happ_12_13_w_f3 "All in all I am inclined to feel that I am a failure"
la var happ_12_14_w_f3 "I am able to do things as well as most other people."
la var happ_12_15_w_f3 "I feel I do not have much to be proud of"
la var happ_12_16_w_f3 "I take a positive attitude toward myself"
la var happ_12_17_w_f3 "On the whole, I am satisfied with myself"
la var happ_12_19_w_f3 "I certainly feel useless at times"
la var happ_12_1_h_f3  "Happiness Level"
la var happ_12_2_h_f3  "Wellbeing satisfaction"	
la var happ_12_7_h_f3   "I'm optimistic about my future" 
la var happ_12_8_h_f3   "I expect things to go my way"
la var happ_12_9_h_f3 "I count on good things happening to me"
la var happ_12_10_h_f3 "I expect more good things to happen to me than bad"
la var happ_12_13_h_f3 "All in all I am inclined to feel that I am a failure"
la var happ_12_14_h_f3 "I am able to do things as well as most other people."
la var happ_12_15_h_f3 "I feel I do not have much to be proud of."
la var happ_12_16_h_f3 "I take a positive attitude toward myself."
la var happ_12_17_h_f3 "On the whole, I am satisfied with myself."
la var happ_12_19_h_f3 "I certainly feel useless at times."	

la var foody1_bl "Did not go a whole day and night without eating anything?"
la var foody2_bl "Did not go to sleep at night hungry because there is not enough food?"
la var foody3_bl "Did not have no food or any kind in your household?"
la var foody4_bl "Did not borrow food, or rely on help from a friend or relative?"
la var foody5_bl "Did not reduce number of meals eaten in a day?"
la var foody6_bl "Did not restrict consumption by adults in order for small children to eat?"
la var foody7_bl "In the last 7 days hh did not face situation not enough food" 
la var foody8_bl "Ate meat or fish in the alst 7 days"
la var foody9_bl "Adults eat more than 2 meals per day"
la var num_daymeals_adults_bl "Baseline: Number of daily meals take by adults"
la var num_daymeals_child_bl  "Baseline: Number of daily meals take by children"
la var foody1_f2 "Midline:not go a whole day and night without eating anything?"
la var foody2_f2 "Midline:not go to sleep at night hungry because there is not enough food?"
la var foody3_f2 "Midline:not have no food or any kind in your household?"
la var foody4_f2 "Midline:not borrow food, or rely on help from a friend or relative?"
la var foody5_f2 "Midline:not reduce number of meals eaten in a day?"
la var foody6_f2 "Midline:not restrict consumption by adults in order for small children to eat?"
la var foody7_f2 "Midline:In the last 7 days hh did not face situation not enough food" 
la var foody8_f2 "Midline:Ate meat or fish in the alst 7 days"
la var foody9_f2 "Midline:Adults eat more than 2 meals per day"
la var num_daymeals_adults_f2 "Midline:Number of daily meals take by adults"
la var num_daymeals_child_f2 "Midline:Number of daily meals take by children"
la var foody1_f3 "Endline:not go a whole day and night without eating anything?"
la var foody2_f3 "Endline:not go to sleep at night hungry because there is not enough food?"
la var foody3_f3 "Endline:not have no food or any kind in your household?"
la var foody4_f3 "Endline:not borrow food, or rely on help from a friend or relative?"
la var foody5_f3 "Endline:not reduce number of meals eaten in a day?"
la var foody6_f3 "Endline:not restrict consumption by adults in order for small children to eat?"
la var foody7_f3 "Endline:In the last 7 days hh did not face situation not enough food" 
la var foody8_f3 "Endline:Ate meat or fish in the alst 7 days"
la var foody9_f3 "Endline:Adults eat more than 2 meals per day"
la var num_daymeals_adults_f3 "Endline:Number of daily meals take by adults"
la var num_daymeals_child_f3 "Endline:Number of daily meals take by children"  

la var  w_exp_ttlnonfood_7dae_bl "Baseline:(Winsor) Non-Food expenditures total last 7d (Adult Eq)"	
la var  w_exp_ttlfood_7dae_bl    "Baseline:(Winsor) Food expenditures total last 7d (Adult Eq)" 
la var  w_exp_ttlconfood_7dae_bl "Baseline:(Winsor) Food consumption total last 7d (Adult Eq)"   

la var  w_exp_ttlnonfood_7dae_f2 "Midline:(Winsor) Non-Food expenditures total last 7d (Adult Eq)"
la var  w_exp_ttlfood_7dae_f2    "Midline:(Winsor) Food expenditures last 7d (Adult Eq)"
la var  w_exp_ttlconfood_7dae_f2 "Midline:(Winsor) Food consumption total last 7d (Adult Eq)"	

la var  w_exp_ttlnonfood_7dae_f3 "Endline:(Winsor) Non-Food expenditures total last 7d (Adult Eq)"
la var  w_exp_ttlfood_7dae_f3    "Endline:(Winsor) Food expenditures total last 7d (Adult Eq)"	
la var  w_exp_ttlconfood_7dae_f3 "Endline:(Winsor) Food consumption  total last 7d (Adult Eq)"

la var  ihs_exp_ttlnonfood_7dae_bl "Baseline:(IHS) Non-Food expenditures total last 7d (Adult Eq)"	
la var  ihs_exp_ttlfood_7dae_bl    "Baseline:(IHS) Food expenditures total last 7d (Adult Eq)" 
la var  ihs_exp_ttlconfood_7dae_bl "Baseline:(IHS) Food consumption total last 7d (Adult Eq)"
la var  ihs_exp_ttlnonfood_7dae_f2 "Midline:(IHS) Non-Food expenditures total last 7d (Adult Eq)"
la var  ihs_exp_ttlfood_7dae_f2    "Midline:(IHS) Food expenditures total last 7d (Adult Eq)"	
la var  ihs_exp_ttlconfood_7dae_f2 "Midline:(IHS) Food consumption total last 7d (Adult Eq)"	
la var  ihs_exp_ttlnonfood_7dae_f3 "Endline:(IHS) Non-Food expenditures total last 7d (Adult Eq)"
la var  ihs_exp_ttlfood_7dae_f3    "Endline:(IHS) Food expenditures total last 7d (Adult Eq)"	
la var  ihs_exp_ttlconfood_7dae_f3 "Endline:(IHS) Food consumption total last 7d (Adult Eq)"		


la var  w_r_exp_ttlnonfood_7dae_bl   "Baseline:(Winsor)Real Non-Food expenditures total last 7d (Adult Eq)"
la var  w_r_exp_ttlfood_7dae_bl      "Baseline:(Winsor)Real Food expenditures total last 7d (Adult Eq)"	
la var  w_r_exp_ttlconfood_7dae_bl   "Baseline:(Winsor)Real Food consumption total last 7d (Adult Eq)"

la var  w_r_exp_ttlnonfood_7dae_f2   "Midline:(Winsor)Real Non-Food expenditures total last 7d (Adult Eq)"
la var  w_r_exp_ttlfood_7dae_f2      "Midline:(Winsor)Real Food expenditures total last 7d (Adult Eq)"	
la var  w_r_exp_ttlconfood_7dae_f2   "Midline:(Winsor)Real Food consumption total last 7d (Adult Eq)"	

la var  w_r_exp_ttlnonfood_7dae_f3   "Endline:(Winsor)Real Non-Food expenditures total last 7d (Adult Eq)"
la var  w_r_exp_ttlfood_7dae_f3      "Endline:(Winsor)Real Food expenditures total last 7d (Adult Eq)"	
la var  w_r_exp_ttlconfood_7dae_f3   "Endline:(Winsor)Real Food consumption total last 7d (Adult Eq)"	

la var  ihs_r_exp_ttlnonfood_7dae_bl "Baseline:(IHS)Real Non-Food expenditures total last 7d (Adult Eq)"
la var  ihs_r_exp_ttlfood_7dae_bl    "Baseline:(IHS)Real Food expenditures total last 7d (Adult Eq)"	
la var  ihs_r_exp_ttlconfood_7dae_bl "Baseline:(IHS)Real Food consumption total last 7d (Adult Eq)"	

la var  ihs_r_exp_ttlnonfood_7dae_f2 "Midline:(IHS)Real Non-Food expenditures total last 7d (Adult Eq)"
la var  ihs_r_exp_ttlfood_7dae_f2    "Midline:(IHS)Real Food expenditures total last 7d (Adult Eq)"	
la var  ihs_r_exp_ttlconfood_7dae_f2 "Midline:(IHS)Real Food consumption total last 7d (Adult Eq)"	
la var  ihs_r_exp_ttlnonfood_7dae_f3 "Endline:(IHS)Real Non-Food expenditures total last 7d (Adult Eq)"
la var  ihs_r_exp_ttlfood_7dae_f3    "Endline:(IHS)Real Food expenditures total last 7d (Adult Eq)"	
la var  ihs_r_exp_ttlconfood_7dae_f3 "Endline:(IHS)Real Food consumption total last 7d (Adult Eq)"	  
la var  num_bmem_illi_610_f3 "Illiterate number of boys in the household (6 and 10 yrs)"
la var  num_gmem_illi_610_f3 "Illiterate number of girls in the household (6 and 10 yrs)"
la var  num_bmem_illi_1115_f3 "Illiterate number of boys in the household (11 and 15 yrs)"	 	 
la var  num_gmem_illi_1115_f3 "Illiterate number of girls in the household (11 and 15 yrs)"	 
la var  num_bmem_illi_616_f3 "Number of illiterate boys in the household (6 to 16 yrs)"	 	 
la var  num_gmem_illi_616_f3 "Number of illiterate girls in the household (6 to 16 yrs)"	
la var  num_bmem_attsch_616_f3  "Number of boys attending school(6 and 18 yrs)"	 
la var  num_gmem_attsch_616_f3  "Number of girls attending school(6 and 18 yrs)"	
	 
la var  share_bmem_illi_610_f3  "Proportion illiterate boys in the hh (6 and 10 yrs)"
la var  share_bmem_illi_1115_f3 "Proportion illiterate boys in the hh (11 and 15 yrs)"	 
la var  share_gmem_illi_610_f3  "Proportion illiterate girls in the hh (6 and 10 yrs)"	 
la var  share_gmem_illi_1115_f3 "Proportion illiterate girls in the hh (11 and 15 yrs)"
la var  share_bmem_illi_616_f3  "Proportion illiterate boys in the household(6 and 16 yrs)"	 
la var  share_gmem_illi_616_f3  "Proportion illiterate girls in the household(6 and 16 yrs)"	
la var  share_bmem_attsch_616_f3  "Proportion of boys attending school(6 and 16 yrs)"	 
la var  share_gmem_attsch_616_f3  "Proportion of girls attending school(6 and 16 yrs)"	

la var  d_any_loan_bl           "Baseline:Household has any loan"
la var  d_any_account_bl        "Baseline:Household has any bank account"
la var  w_ttl_loan_bl           "Baseline: Amount of loans in the households (W/95)"
la var  d_loan_bl               "Baseline: Any loan (Household)"
la var  d_loan_w_f2             "Midline: Any loan (Wife)"
la var  d_loan_h_f2             "Midline: Any loan (Husband)"
la var  d_loan_f2               "Midline: Any loan"
la var  d_anycash_w_f2          "Midline: Any cash savings (Wife)" 
la var  d_anycash_h_f2          "Midline: Any cash savings (Husband)" 
la var  d_anycash_f2            "Midline: Any cash savings (Household)" 
la var  w_cash_savings_w_f2     "Midline: Cash savings (Wife) (W/95)" 
la var  w_cash_savings_h_f2     "Midline: Cash savings (Husband) (W/95)" 
la var  w_cash_savings_f2       "Midline: Cash savings (Household) (W/95)" 
la var  ihs_cash_savings_w_f2   "Midline: Cash savings (Wife) (IHS)" 
la var  ihs_cash_savings_h_f2   "Midline: Cash savings (Husband) (IHS)" 
la var  ihs_cash_savings_f2     "Midline: Cash savings (Household) (IHS)" 
la var  d_loan_w_f3             "Endline: Any loan (Wife)"
la var  d_loan_h_f3             "Endline: Any loan (Husband)"
la var  d_loan_f3               "Endline: Any loan"
la var  d_anycash_w_f3          "Endline: Any cash savings (Wife)" 
la var  d_anycash_h_f3          "Endline: Any cash savings (Husband)" 
la var  d_anycash_f3            "Endline: Any cash savings (Household)" 
la var  w_cash_savings_w_f3     "Endline: Cash savings (Wife) (W/95)" 
la var  w_cash_savings_h_f3     "Endline: Cash savings (Husband) (W/95)" 
la var  w_cash_savings_f3       "Endline: Cash savings (Household) (W/95)" 
la var  ihs_cash_savings_w_f3   "Endline: Cash savings (Wife) (IHS)" 
la var  ihs_cash_savings_h_f3   "Endline: Cash savings (Husband) (IHS)" 
la var  ihs_cash_savings_f3     "Endline: Cash savings (Household) (IHS)" 
la var  num_fem_illi_f3         "Number of illiterate females in the household"	 
la var  num_mal_illi_f3         "Number of illiterate males in the household"
la var  share_Fmem_illi_15_f3   "Proportion illiterate females in hh(15 & older)"
la var  share_Mmem_illi_15_f3   "Proportion illiterate males in hh(15 & older)"  
la var  w_ttl_health_exp_hh_f3  "Endline:(Winsor) Total Health Expenditures"
la var  w_ttl_health_exp_hh_f2  "Midline:(Winsor) Total Health Expenditures"
la var  num_crops_cult_bl  		"Number of cultivated crops"
la var  farming_work_fup2_w 	"Midline:Farming Work Wife"
la var  farming_work_fup3_w     "Endline:Farming Work Wife"
la var  frac_solharv_f3     	"Fraction of harvested that was sold (%)"
la var  frac_consharv_f3 	    "Fraction of harvested that was consumed (%)" 
la var  frac_paymharv_f3 	    "Fraction of harvested that was used as payment for labor(%)" 
la var  frac_postharv_f3        "Fraction of harvested that was post-harvest lost(%)" 
la var  frac_storharv_f3       "Fraction of harvested that was stored for next season (%)"
la var  w_ttl_solharv_f3        "Harvested value that was sold (W/95)"
la var  w_ttl_consharv_f3       "Harvested value that was consumed (W/95)"
la var  w_ttl_paymharv_f3       "Harvested value that was used as payment for labor(W/95)"
la var  w_ttl_storharv_f3       "Harvested value that was stored for next season (W/95)"
la var  w_ttl_postharv_f3       "Harvested value that was post-harvest lost(W/95)" 
la var  ihs_ttl_solharv_f3      "Harvested value that was sold (IHS)"
la var  ihs_ttl_consharv_f3     "Harvested value that was consumed (IHS)"
la var  ihs_ttl_paymharv_f3     "Harvested value that was used as payment for labor(IHS)"
la var  ihs_ttl_storharv_f3     "Harvested value that was stored for next season (IHS)"
la var  ihs_ttl_postharv_f3     "Harvested value that was post-harvest lost(IHS)" 
la var  w_ttl_solharv_ha_f3     "Harvested value that was sold per hectare (W/95)"
la var  w_ttl_consharv_ha_f3    "Harvested value that was consumed per hectare (W/95)"
la var  w_ttl_paymharv_ha_f3    "Harvested value that was used as payment for labor per hectare (W/95)"
la var  w_ttl_storharv_ha_f3    "Harvested value that was stored for next season per hectare (W/95)"
la var  w_ttl_postharv_ha_f3    "Harvested value that was post-harvest lost per hectare (W/95)" 
la var  ihs_ttl_solharv_ha_f3   "Harvested value that was sold per hectare (IHS)"
la var  ihs_ttl_consharv_ha_f3  "Harvested value that was consumed per hectare (IHS)"
la var  ihs_ttl_paymharv_ha_f3  "Harvested value that was used as payment for labor per hectare (IHS)"
la var  ihs_ttl_storharv_ha_f3  "Harvested value that was stored for next season per hectare (IHS)"
la var  ihs_ttl_postharv_ha_f3  "Harvested value that was post-harvest lost per hectare(IHS)" 
la var  dm_index_bl_new_w       "Decision Making Index (0-6)"
la var  business_work_bl_w      "NonFarm Enterprise (=1 Yes)"
la var  widowed_bl              "Marital Status (Widowed=1)"
la var  foodins_index_bl        "Food Insecurity Index (0-6)"
la var  w_bmi_w                 "BMI (Wife)"
la var  underw_bmi_w            "Underweight (=1) (Wife)"
la var  selfest_w               "Self-esteem(Wife)"
la var  conf_w                  "Conformist (Wife)"
la var  indep_w	                "Independence (Wife)"
la var  w_bmi_h                 "BMI (Husband)"
la var  underw_bmi_h            "Underweight (=1) (Husband)"
la var  selfest_h               "Self-esteem(Husband)"
la var  conf_h                  "Conformist (Husband)"
la var  indep_h	                "Independence (Husband)"


gen d_dm_cult_soybean4_f3_w=.
gen d_dm_cult_soybean4_f3_h=. 
ren time_?_bl time_?_bl_w
ren dm_index_fup3_w    dm_index_w_f3
ren dm_index_bl_new_w  dm_index_w_bl
foreach cropName in millet rice maize sorghum groundnut cowpea soybean{
gen d_cult_`cropName'_bl=d_cult_`cropName'_bl_f3_h
replace d_cult_`cropName'_bl=d_cult_`cropName'_bl_f3_w if d_cult_`cropName'_bl==. 
}

foreach x in w h {
la var num_plots_f3_`x'     "Endline:Numbr of plots (`x')"
la var num_crops_cult_f3_`x' "Endline:Number of cultivated crops (`x')"
foreach cropName in millet rice maize sorghum groundnut cowpea soybean{
replace w_yield_`cropName'_ha_f3_`x'=. if  num_crops_cult_f3_`x'==0 | num_crops_cult_f3_`x'>=. 
la var  w_yield_`cropName'_ha_f3_`x' "Value harvested of `cropName'/ha (`x')"
la var  w_quant_`cropName'_ha_f3_`x' "Qt harvested of `cropName' /ha (`x')"
replace w_quant_`cropName'_ha_f3_`x'=. if  num_crops_cult_f3_`x'==0 | num_crops_cult_f3_`x'>=. 
replace ihs_yield_`cropName'_ha_f3_`x'=. if  num_crops_cult_f3_`x'==0 | num_crops_cult_f3_`x'>=. 
la var  ihs_yield_`cropName'_ha_f3_`x' "(Ihs)Value harvested of `cropName'/ha (`x')"
la var  ihs_quant_`cropName'_ha_f3_`x' "(Ihs)Qt harvested of `cropName' /ha (`x')"
replace ihs_quant_`cropName'_ha_f3_`x'=. if  num_crops_cult_f3_`x'==0 | num_crops_cult_f3_`x'>=. 
la var  d_dm_cult_`cropName'1_f3_`x' "Decision Making on `cropName':Self (`x')"
la var  d_dm_cult_`cropName'2_f3_`x' "Decision Making on `cropName':Spouse (`x')"
la var  d_dm_cult_`cropName'3_f3_`x' "Decision Making on `cropName':Joint (`x')"
la var  d_dm_cult_`cropName'4_f3_`x' "Decision Making on `cropName':Other (`x')"
la var  d_cult_`cropName'_f3 "Cultivate `cropName'"

la var  d_cult_`cropName'_bl "Baseline:Cultivate `cropName'"	
}
la var d_dm_cultany_1_`x' "Decision Making on crop cult:Self (`x')"
la var d_dm_cultany_2_`x' "Decision Making on crop cult:Spouse (`x')"
la var d_dm_cultany_3_`x' "Decision Making on crop cult:Joint (`x')"
la var d_dm_cultany_4_`x' "Decision Making on crop cult:Other (`x')"

la var w_ttl_qtyields_ha_f3_`x'      "Endline:Total quantity harvest/ha(`x')"
la var w_ttl_yields_ha_f3_`x'        "Endline:Total value harvested/ha(`x')"
replace w_ttl_qtyields_ha_f3_`x'=. if num_crops_cult_f3_`x'==0 | num_crops_cult_f3_`x'>=. 
replace w_ttl_yields_ha_f3_`x'=. if num_crops_cult_f3_`x'==0 | num_crops_cult_f3_`x'>=. 
la var w_ttl_hrs_week_f3_`x'   "Endline:Average #hrs worked per week by members of hh (`x')"
la var w_ttl_hrs_month_f3_`x'    "Endline:Average #hrs worked per month by members of hh (`x')"

la var ihs_ttl_qtyields_ha_f3_`x'      "Endline:(Ihs)Total quantity harvest/ha(`x')"
la var ihs_ttl_yields_ha_f3_`x'        "Endline:(Ihs)Total value harvested/ha(`x')"
replace ihs_ttl_qtyields_ha_f3_`x'=. if num_crops_cult_f3_`x'==0 | num_crops_cult_f3_`x'>=. 
replace ihs_ttl_yields_ha_f3_`x'=. if num_crops_cult_f3_`x'==0 | num_crops_cult_f3_`x'>=. 
la var ihs_ttl_hrs_week_f3_`x'   "Endline:(Ihs)Average #hrs worked per week by members of hh (`x')"
la var ihs_ttl_hrs_month_f3_`x'    "Endline:(Ihs)Average #hrs worked per month by members of hh (`x')"   

}	
  
	egen  w_ttl_dayhired_ha=rowtotal(w_ttl_daymen_hired_ha_f3  ///
									   w_ttl_daywomen_hired_ha_f3  ///
									   w_ttl_daychild_hired_ha_f3)
									   
	la var  w_ttl_dayhired_ha	         "Hired Labor (days/HA)"							 
	la var  w_ttl_daysseas_hhmem_ha_f3 "Family Labor (days/HA)"
	  
	egen    w_ttl_laborplots_ha=rowtotal(w_ttl_dayhired_ha w_ttl_daysseas_hhmem_ha_f3)
	la var  w_ttl_laborplots_ha "Total labor on all household plots (Days/HA)"
	  
	la var w_ttl_area_cult_bl        "Baseline:Ttl area cultivated (W/95)"
	la var ihs_ttl_area_cult_bl      "Baseline:Ttl area cultivated (IHS)"
	la var w_ttl_area_cult_f3        "Endline:Ttl area cultivated (W/95)"
	la var ihs_ttl_area_cult_f3      "Endline:Ttl area cultivated (IHS)"
	la var num_crops_cult_f3         "Number of crops cultivated"
	la var w_ttl_yields_ha_f3        "Yields (Winsor)"
	la var ihs_ttl_yields_ha_f3      "Yields (IHS)"
	la var w_ttl_spend_orgfert_f3     "Ttl spend organic fertilizer"
	la var w_ttl_spend_inorgfert_f3   "Ttl spend inorganic fertilizer"
	la var w_ttl_spend_seeds_f3       "Ttl spend seeds"
	la var w_ttl_spend_orgfert_ha_f3     "Ttl spend organic fertilizer/ha (winsor)"
	la var w_ttl_spend_inorgfert_ha_f3   "Ttl spend inorganic fertilizer/ha (winsor)"
	la var w_ttl_spend_seeds_ha_f3       "Ttl spend seeds/ha (winsor)"
	la var w_ttl_daysseas_hhmem_f3    "Ttl days worked by hmem in plots in the last season" 
	la var w_ttl_daysseas_hhmem_ha_f3 "Ttl days worked by hmem/ha in the last season" 
	la var w_ttl_hhhdaysseas_f3       "Ttl days worked by hhh in plots in the last season" 
	la var w_ttl_hhhdaysseas_ha_f3    "Ttl days worked by hhh/ha in the last season" 
	la var w_ttl_spodaysseas_f3       "Ttl days worked by spouse in plots in the last season" 
	la var w_ttl_spodaysseas_ha_f3    "Ttl days worked by spouse/ha in plots in the last season" 
	la var w_ttl_daymen_hired_f3       "Ttl number of days/men hired (winsor)"
	la var w_ttl_daymen_hired_ha_f3    "Ttl number of days/men hired/ha (winsor)"
	la var w_ttl_daywomen_hired_f3     "Ttl number of days/women hired (winsor)"
	la var w_ttl_daywomen_hired_ha_f3  "Ttl number of days/women hired/ha (winsor)"
	la var w_ttl_daychild_hired_f3     "Ttl number of days/child hired (winsor)"
	la var w_ttl_daychild_hired_ha_f3  "Ttl number of days/child hired/ha (winsor)"  
	la var w_ttl_wagehlabor_f3         "Ttl wage pay to hired workers (winsor)"          
	la var w_ttl_wagehlabor_ha_f3      "Ttl wage pay to hired workers/ha (winsor)"  
	la var anyfamlab 					   "Any family labor in the plot"
	la var anyhhhlab 					   "Any hhh labor in the plot"	  
	la var anyspoulab					   "Any spouse labor in the plot"	  	  
	la var anyhirelab  					   "Any hired labor in the plot"
	la var w_ttl_inputs_plot_ha            "Total spend on inputs in the plot/ha (Winsor)"
	la var ihs_ttl_inputs_plot_ha          "Total spend on inputs in the plot/ha (IHS)"	
	la var ihs_ttl_spend_orgfert_ha_f3     "Total  spend organic fertilizer/ha (IHS)"
	la var ihs_ttl_spend_infert_ha_f3      "Total  spend inorganic fertilizer/ha (IHS)"
	la var ihs_ttl_spend_seeds_ha_f3       "Total  spend seed fertilizer/ha (IHS)"
	la var ihs_ttl_wagehlabor_ha_f3        "Total  wage pay to hired workers/ha (IHS)"  

	la var ihs_ttl_yields_ha_f3_con            "Conditional:Yields (IHS)"
	la var ihs_ttl_inputs_plot_ha_con          "Conditional:Total spend on inputs in the plot/ha (IHS)"	
	la var ihs_ttl_spend_orgfert_ha_f3_con     "Conditional:Total spend organic fertilizer/ha (IHS)"
	la var ihs_ttl_spend_infert_ha_f3_con      "Conditional:Total spend inorganic fertilizer/ha (IHS)"
	la var ihs_ttl_spend_seeds_ha_f3_con       "Conditional:Total spend seed fertilizer/ha (IHS)"
	la var ihs_ttl_wagehlabor_ha_f3_con        "Conditional:Total wage pay to hired workers/ha (IHS)"  

	la var time_1_f3_w  "Time spend on: Sleeping (Wife)"
	la var time_2_f3_w  "Time spend on: Care (children, ill household members)(Wife)"
	la var time_3_f3_w  "Time spend on: Domestic tasks (Wife)"
	la var time_4_f3_w  "Time spend on: Non-farm business activities(Wife)"
	la var time_5_f3_w  "Time spend on: Paid work or activities outside of household(Wife)"
	la var time_6_f3_w  "Time spend on: Tasks on family farm, home garden, cattle herding(Wife)"
	la var time_7_f3_w  "Time spend on: Getting services (including health services)(Wife)" 
	la var time_8_f3_w  "Time spend on: Prayer(Wife)"
	la var time_9_f3_w  "Time spend on: Leisure (includes self-care and hobbies)(Wife)"
	la var time_10_f3_w  "In the last 24 hours, did you do any work(Wife)"

	la var time_1_bl_w  "Baseline time spend on:Sleeping (Wife)"
	la var time_2_bl_w  "Baseline time spend on:Care (children, ill household members)(Wife)"
	la var time_3_bl_w  "Baseline time spend on:Domestic tasks (Wife)"
	la var time_4_bl_w  "Baseline time spend on:Non-farm business activities(Wife)"
	la var time_5_bl_w  "Baseline time spend on:Paid work or activities outside of household(Wife)"
	la var time_6_bl_w  "Baseline time spend on:Tasks on family farm, home garden, cattle herding(Wife)"
	la var time_7_bl_w  "Baseline time spend on:Getting services (including health services)(Wife)" 
	la var time_8_bl_w  "Baseline time spend on:Prayer(Wife)"
	la var time_9_bl_w  "Baseline time spend on:Leisure (includes self-care and hobbies)(Wife)"
	la var time_1_f3_h  "Time spend on: Sleeping (Husb)"
	la var time_2_f3_h  "Time spend on: Care (children, ill household members)(Husb)"
	la var time_3_f3_h  "Time spend on: Domestic tasks (Husb)"
	la var time_4_f3_h  "Time spend on: Non-farm business activities(Husb)"
	la var time_5_f3_h  "Time spend on: Paid work or activities outside of household(Husb)"
	la var time_6_f3_h  "Time spend on: Tasks on family farm, home garden, cattle herding(Husb)"
	la var time_7_f3_h  "Time spend on: Getting services (including health services)(Husb)" 
	la var time_8_f3_h  "Time spend on: Prayer(Husb)"
	la var time_9_f3_h  "Time spend on: Leisure (includes self-care and hobbies)(Husb)"
	la var time_10_f3_h "In the last 24 hours, did you do any work(Husb)"
	la var w_hh_income_w_f3  "Endline:Household income (Wife)"	
	la var w_hh_income_h_f3  "Endline:Household income (Husband)"		
	la var ihs_hh_income_w_f3  "Endline:Household income (Wife)(IHS)"	
	la var ihs_hh_income_h_f3  "Endline:Household income (Husband)(IHS)"		
	la var tr_4_w_dum_1 "Reason Chop Money: Daily Composition"	
	la var tr_4_w_dum_2 "Reason Chop Money: Housing"	
	la var tr_4_w_dum_3 "Reason Chop Money:Business"	
	la var tr_4_w_dum_4 "Reason Chop Money:Education"	
	la var tr_4_w_dum_5 "Reason Chop Money: Health"	
	la var tr_4_w_dum_6 "Reason Chop Money:Funerals"	
	la var tr_4_w_dum_7 "Reason Chop Money:Ceremonies"	
	la var tr_4_w_dum_8 "Reason Chop Money:Savings"	
	la var tr_4_w_dum_9 "Reason Chop Money:Other"	
	la var bus_years_f2_w "Midline:Years of business(Wife)"	
	la var bus_years_f2_h "Midline:Years of business(Husband)"	
	la var bus_years_f3_w "Endline:Years of business(Wife)"	
	la var bus_years_f3_h "Endline:Years of business(Husband)"	
	la var ttl_hh_loans_f2 "Midline:Total amount in loans (Household)"	
	la var ttl_hh_loans_f3 "Endline:Total amount in loans (Household)"	
	la var w_ttl_hh_loans_f2 "Midline:Total amount in loans (Household)(W/95)"	
	la var w_ttl_hh_loans_f3 "Endline:Total amount in loans (Household)(W/95)"	
	la var ihs_ttl_hh_loans_f2 "Midline:Total amount in loans (Household)(IHS)"	
	la var ihs_ttl_hh_loans_f3 "Endline:Total amount in loans (Household)(IHS)"		
	la var ttl_hh_loans_w_f2 "Midline:Total amount in loans (Wife)"	
	la var ttl_hh_loans_h_f2 "Midline:Total amount in loans (Husband)"	
	la var ttl_hh_loans_w_f3 "Endline:Total amount in loans (Wife)"	
	la var ttl_hh_loans_h_f3 "Endline:Total amount in loans (Husband)"	
	la var ttl_loan_bl         "Baseline: Total amount of loans"
	la var w_ttl_loan_bl       "Baseline: Total amount of loans"
	la var ihs_ttl_loan_bl     "Baseline: Total amount of loans(IHS)"
	la var w_ttl_hh_loans_w_f2 "Midline:Total amount in loans (Wife) (W/95)"	
	la var w_ttl_hh_loans_h_f2 "Midline:Total amount in loans (Husband)(W/95)"	
	la var w_ttl_hh_loans_w_f3 "Endline:Total amount in loans (Wife)(W/95)"	
	la var w_ttl_hh_loans_h_f3 "Endline:Total amount in loans (Husband)(W/95)"		
	la var ihs_ttl_hh_loans_w_f2 "Midline:Total amount in loans (Wife) (IHS)"	
	la var ihs_ttl_hh_loans_h_f2 "Midline:Total amount in loans (Husband)(IHS)"	
	la var ihs_ttl_hh_loans_w_f3 "Endline:Total amount in loans (Wife)(IHS)"	
	la var ihs_ttl_hh_loans_h_f3 "Endline:Total amount in loans (Husband)(IHS)"		
	la var source_rawmat_dum_1_fup2_w "Midline:Source Raw materials:Cash transfer payment (Wife)"
	la var source_rawmat_dum_2_fup2_w "Midline:Savings (Wife)"
	la var source_rawmat_dum_3_fup2_w "Midline:Loan from Bank/ Microcredit (Wife)"
	la var source_rawmat_dum_4_fup2_w "Midline:Loan from a family/friend/neighbor(Wife)"
	la var source_rawmat_dum_5_fup2_w "Midline:Gift.(Wife)"
	la var source_rawmat_dum_6_fup2_w "Midline:Other (Wife)"
	la var source_rawmat_dum_1_fup2_h "Midline:Source Raw materials:Cash transfer payment (Husband)"
	la var source_rawmat_dum_2_fup2_h "Midline:Savings (Husband)"
	la var source_rawmat_dum_3_fup2_h "Midline:Loan from Bank/ Microcredit (Husband)"
	la var source_rawmat_dum_4_fup2_h "Midline:Loan from a family/friend/neighbor(Husband)"
	la var source_rawmat_dum_5_fup2_h "Midline:Gift.(Husband)"
	la var source_rawmat_dum_6_fup2_h "Midline:Other (Husband)"
	la var source_rawmat_dum_1_fup3_w "Endline:Source Raw materials:Cash transfer payment (Wife)"
	la var source_rawmat_dum_2_fup3_w "Endline:Savings (Wife)"
	la var source_rawmat_dum_3_fup3_w "Endline:Loan from Bank/ Microcredit (Wife)"
	la var source_rawmat_dum_4_fup3_w "Endline:Loan from a family/friend/neighbor(Wife)"
	la var source_rawmat_dum_5_fup3_w "Endline:Gift.(Wife)"
	la var source_rawmat_dum_6_fup3_w "Endline:Other (Wife)"
	la var source_rawmat_dum_1_fup3_h "Endline:Source Raw materials:Cash transfer payment (Husband)"
	la var source_rawmat_dum_2_fup3_h "Endline:Savings (Husband)"
	la var source_rawmat_dum_3_fup3_h "Endline:Loan from Bank/ Microcredit (Husband)"
	la var source_rawmat_dum_4_fup3_h "Endline:Loan from a family/friend/neighbor(Husband)"
	la var source_rawmat_dum_5_fup3_h "Endline:Gift.(Husband)"
	la var source_rawmat_dum_6_fup3_h "Endline:Other (Husband)"
	la var wage_emp_fup2_w 			  "Midline:Wage-employment (Wife)"
	la var wage_emp_fup2_h 			  "Midline:Wage-employment (Husband)"
	la var wage_emp_fup3_w 			  "Endline:Wage-employment (Wife)"
	la var wage_emp_fup3_h 			  "Endline:Wage-employment (Husband)"
	la var daily_pc_income_bl 		  "Daily per capita income "
	la var w_ttl_health_exp_hh_f2 	  "Midline:Health Expenditures(Winsor 0.01)"
	la var w_ttl_health_exp_hh_f3     "Endline:Health Expenditures(Winsor 0.01)"
	la var ihs_ttl_health_exp_hh_f2   "Midline:Health Expenditures(IHS)"
	la var ihs_ttl_health_exp_hh_f3   "Endline:Health Expenditures(IHS)"
	la var w_ttl_educ_exp_hh_f2 	  "Midline:Education Expenditures(Winsor 0.01)"
	la var w_ttl_educ_exp_hh_f3       "Endline:Education Expenditures(Winsor 0.01)"
	la var ihs_ttl_educ_exp_hh_f2     "Midline:Education Expenditures(IHS)"
	la var ihs_ttl_educ_exp_hh_f3     "Endline:Education Expenditures(IHS)"
	la var num_bmem_attsch_610_f3     "#Boys attending school (6-10)"
	la var num_gmem_attsch_610_f3     "#Girls attending school (6-10)"
	la var num_bmem_attsch_1115_f3    "#Boys attending school (11-15)"
	la var num_gmem_attsch_1115_f3    "#Girls attending school (11-15)"
	la var share_bmem_attsch_610_f3   "Share Boys attending school (6-10)"
	la var share_bmem_attsch_1115_f3  "Share Boys attending school (11-15)" 
	la var share_gmem_attsch_610_f3   "Share Girls attending school (6-10)"
	la var share_gmem_attsch_1115_f3  "Share Girls attending school (11-15)"
	la var w_daily_ae_expreal_bl      "Baseline:Daily Adult Equivalent Real(Winsor)"
	la var ihs_daily_ae_expreal_bl    "Baseline:Daily Adult Equivalent Real(IHS)"
	la var ihs_daily_percapita_expenses_bl "Baseline: Daily per capita expenses (IHS)"
	la var w_daily_ae_expreal_f2       "Midline:Daily Adult Equivalent Real(Winsor)"
	la var ihs_daily_ae_expreal_f2     "Midline:Daily Adult Equivalent Real(IHS)"
	la var w_daily_ae_expreal_f3       "Endline:Daily Adult Equivalent Real(Winsor)"
	la var ihs_daily_ae_expreal_f3     "Endline:Daily Adult Equivalent Real(IHS)"
	la var daily_ae_expreal_bl 		   "Baseline:Daily Adult Equivalent Real (No winsor)"
	la var daily_ae_expreal_f2		   "Midline:Daily Adult Equivalent Real (No winsor)"
	la var daily_ae_expreal_f3 		   "Endline:Daily Adult Equivalent Real(No winsor)"
	la var daily_hh_realexp_bl         "Endline:Daily hh Real expenses(No winsor)"
	la var daily_hh_realexp_f2         "Midline:Daily hh Real expenses(No winsor)"
	la var daily_hh_realexp_f3         "Endline:Daily hh Real expenses(No winsor)"
	la var daily_adulteq_expenses_bl "Baseline:Daily Adult Equivalent(No Winsor)"
	la var daily_adulteq_expenses_f2 "Midline:Daily Adult Equivalent(No Winsor)"
	la var daily_adulteq_expenses_f3 "Endline:Daily Adult Equivalent(No Winsor)"
	la var daily_hh_expenses_bl      "Baseline:Daily HH expenditures(No winsor)"
	la var daily_hh_expenses_f2      "Midline:Daily HH expenditures(No winsor)"
	la var daily_hh_expenses_f3      "Endline:Daily HH expenditures(No winsor)"
	la var rawmats_business_fup2_w   "Midline:Raw materials in last 30 days (Wife)"
	la var rawmats_business_fup2_h   "Midline:Raw materials in last 30 days (Husband)"	
	la var rawmats_business_fup3_w   "Endline:Raw materials in last 30 days (Wife)"
	la var rawmats_business_fup3_h   "Endline:Raw materials in last 30 days (Husband)"	
	la var w_rawmats_business_bl_w   "Baseline:(Winsor)Raw materials (Wife)"
	la var ihs_rawmats_business_bl_w "Baseline:(IHS)Raw materials (Wife)"
	la var w_rawmats_business_bl_h   "Baseline:(Winsor)Raw materials (Husband)"
	la var ihs_rawmats_business_bl_h "Baseline:(IHS)Raw materials (Husband)"
	la var haz_b	    "Boys Height-for-age (z-score)"
	la var waz_b	    "Boys Weight-for-age (z-score)"
	la var whz_b	    "Boys Weight-for-height (z-score)"
	la var MUAC_z_b	    "Boys Middle and upper arm Circumference (z-score)"
	la var haz_tot_b	"Boys Moderate Stunting: Height-for-age (2sd)"
	la var waz_tot_b	"Boys Underweight: Weight-for-age (2sd)"
	la var whz_tot_b	"Boys Wasting: Weight-for-height (2sd)"
	la var MUAC_tot_b	"Boys Middle and upper arm Circumference (2sd)"
	la var haz_3sd_b	"Boys Severe Stunting: Height-for-age (3sd)"
	la var waz_3sd_b	"Boys Severe Underweight: Weight-for-age (3sd)"
	la var whz_3sd_b	"Boys Severe Wasting: Weight-for-height (3sd)"
	la var haz	    "Height-for-age (z-score)"
	la var waz	    "Weight-for-age (z-score)"
	la var whz	    "Weight-for-height (z-score)"
	la var MUAC_z	    "Middle and upper arm Circumference (z-score)"
	la var haz_tot	"Moderate Stunting: Height-for-age (2sd)"
	la var waz_tot	"Underweight: Weight-for-age (2sd)"
	la var whz_tot	"Wasting: Weight-for-height (2sd)"
	la var MUAC_tot	"Middle and upper arm Circumference (2sd)"
	la var haz_3sd	"Severe Stunting: Height-for-age (3sd)"
	la var waz_3sd	"Severe Underweight: Weight-for-age (3sd)"
	la var whz_3sd	"Severe Wasting: Weight-for-height (3sd)"
	la var MUAC_under3sd_b	"Boys Middle and upper arm Circumference (3sd)"
	la var haz_g	    "Girls Height-for-age (z-score)"
	la var waz_g	    "Girls Weight-for-age (z-score)"
	la var whz_g	    "Girls Weight-for-height (z-score)"
	la var MUAC_z_g	    "Girls Middle and upper arm Circumference (z-score)"
	la var haz_tot_g	"Girls Moderate Stunting: Height-for-age (2sd)"
	la var waz_tot_g	"Girls Underweight: Weight-for-age (2sd)"
	la var whz_tot_g	"Girls Wasting: Weight-for-height (2sd)"
	la var MUAC_tot_g	"Girls Middle and upper arm Circumference (2sd)"
	la var haz_3sd_g	"Girls Severe Stunting: Height-for-age (3sd)"
	la var waz_3sd_g	"Girls Severe Underweight: Weight-for-age (3sd)"
	la var whz_3sd_g	"Girls Severe Wasting: Weight-for-height (3sd)"
	la var MUAC_under3sd_g	"Girls Middle and upper arm Circumference (3sd)"
	la var business_work_bl_h  "Baseline:NonFarm Enterprise (Husband)"
	la var ihs_ttl_healthv2_exp_hh_f2 "Midline: Health Expenditures(IHS)"
	la var ihs_ttl_healthv2_exp_hh_f3 "Endline: Health Expenditures(IHS)"
	la var w_goat_price_f2         "Goat Individual Price (Midline)"
	la var w_chicken_price_f2      "Chicken Individual Price (Midline)"
	la var w_sheep_price_f2        "Sheep Individual Price (Midline)"
	la var w_goat_price_f3         "Goat Individual Price (Endline)"
	la var w_chicken_price_f3      "Chicken Individual Price (Endline)"
	la var w_sheep_price_f3        "Sheep Individual Price (Endline)"
	la var 	sav_1_4_dum_1_w	"Reason loan:Agricultural Activity (Wife)"
	la var 	sav_1_4_dum_1_h	"Reason loan:Agricultural Activity (Husband)"
	la var 	sav_1_4_dum_2_w	"Reason loan:Business Expansion (Wife)"
	la var 	sav_1_4_dum_2_h	"Reason loan:Business Expansion (Husband)"
	la var 	sav_1_4_dum_3_w	"Reason loan:Paying for business expenses or procuring raw materials (Wife)"
	la var 	sav_1_4_dum_3_h	"Reason loan:Paying for business expenses or procuring raw materials (Husband)"
	la var 	sav_1_4_dum_5_w	"Reason loan:To start a new business (Wife)"
	la var 	sav_1_4_dum_5_h	"Reason loan:To start a new business (Husband)"
	la var 	sav_1_4_dum_7_w	"Reason loan:Education (Wife)"
	la var 	sav_1_4_dum_7_h	"Reason loan:Education (Husband)"
	la var 	sav_1_4_dum_8_w	"Reason loan:Household Consumption (Wife)"
	la var 	sav_1_4_dum_8_h	"Reason loan:Household Consumption (Husband)"
	la var 	sav_1_4_dum_9_w	"Reason loan:Health (Wife)"
	la var 	sav_1_4_dum_9_h	"Reason loan:Health (Husband)" 
	la var 	d_fromwho_loan_1_w	"Source loan:Formal institution	(Wife)"
	la var 	d_fromwho_loan_1_h	"Source loan:Formal institution	(Husband)"
	la var 	d_fromwho_loan_2_w	"Source loan:Informal groups (Wife)"
	la var 	d_fromwho_loan_2_h	"Source loan:Informal groups (Husband)"
	la var 	d_fromwho_loan_3_w	"Source loan:Friends and relatives (Wife)"
	la var 	d_fromwho_loan_3_h	"Source loan:Friends and relatives (Husband)"
	la var 	d_fromwho_loan_4_w	"Source loan:Other (Wife)"
	la var 	d_fromwho_loan_4_h	"Source loan:Other (Husband)"
	la var 	d_whod_loan_1_w	    "Who decided loan:Self (Wife)"
	la var 	d_whod_loan_1_h	    "Who decided loan:Self (Husband)"
	la var 	d_whod_loan_2_w	    "Who decided loan:Partner (Wife)"
	la var 	d_whod_loan_2_h	    "Who decided loan:Partner (Husband)"
	la var 	d_whod_loan_3_w	    "Who decided loan:Joint	(Wife)"
	la var 	d_whod_loan_3_h	    "Who decided loan:Joint	(Husband)"
	la var 	d_whod_loan_4_w	    "Who decided loan:Other	(Wife)"
	la var 	d_whod_loan_4_h	    "Who decided loan:Other	(Husband)"
	la var 	d_busgrant_w	    "Received any business grant (Yes==1) (Wife)"
	la var 	d_busgrant_h	    "Received any business grant (Yes==1) (Husband)"
	la var 	d_chop_money_w	    "Any chop money from husband (Wife)"
	la var 	d_chop_money_h	    "Any chop money from husband (Husband)"
    la var 	amt_chop_money_w	"Amount chop money in last 30 days (Wife)"
    la var 	amt_chop_money_h	"Amount chop money in last 30 days (Husband)"
    la var	chop_money_rs_dum_1_w	"Chop money reason:Daily consumption (Wife)"
	la var 	chop_money_rs_dum_1_h	"Chop money reason:Daily consumption (Husband)"
	la var 	chop_money_rs_dum_2_w	"Chop money reason:Housing (Wife)"
	la var 	chop_money_rs_dum_2_h	"Chop money reason:Housing (Husband)"
	la var 	chop_money_rs_dum_3_w	"Chop money reason:Business (Wife)"
	la var 	chop_money_rs_dum_3_h	"Chop money reason:Business (Husband)"
	la var 	chop_money_rs_dum_4_w	"Chop money reason:Education (Wife)"
	la var 	chop_money_rs_dum_4_h	"Chop money reason:Education (Husband)"
	la var 	chop_money_rs_dum_5_w	"Chop money reason:Health (Wife)"
	la var 	chop_money_rs_dum_5_h	"Chop money reason:Health (Husband)"
	la var 	chop_money_rs_dum_6_w	"Chop money reason:Funerals (Wife)"
	la var 	chop_money_rs_dum_6_h	"Chop money reason:Funerals (Husband)"
	la var 	chop_money_rs_dum_7_w	"Chop money reason:Ceremonies (Wife)"
	la var 	chop_money_rs_dum_7_h	"Chop money reason:Ceremonies (Husband)"
	la var 	chop_money_rs_dum_8_w	"Chop money reason:Savings (Wife)"
	la var 	chop_money_rs_dum_8_h	"Chop money reason:Savings (Husband)"
	la var 	chop_money_rs_dum_9_w	"Chop money reason:Other (Wife)"
	la var 	chop_money_rs_dum_9_h	"Chop money reason:Other (Husband)"
	la var  d_busgrant_w            "Received any business grant (Yes==1)(Wife)" 
	la var  d_busgrant_h            "Received any business grant (Yes==1)(Husband)"	
	la var  d_moneyfriend_w_f2      "Midline:Used money family member or friend (Wife)"
	la var  d_moneyfriend_h_f2      "Midline:Used money family member or friend (Husband)"
	la var  d_moneySILC_w_f2        "Midline:Used SILC (Wife)"
	la var  d_moneySILC_h_f2        "Midline:Used SILC (Husband)"

	la var  d_moneyfriend_w_f3      "Endline:Used money family member or friend (Wife)"
	la var  d_moneyfriend_h_f3      "Endline:Used money family member or friend (Husband)"
	la var  d_moneySILC_w_f3        "Endline:Used SILC (Wife)"
	la var  d_moneySILC_h_f3        "Endline:Used SILC (Husband)"	
	
    la var  num_silcm_w             "Number of SILC meetings (Wife)"
    la var  num_silcm_h             "Number of SILC meetings (Husband)"	
	la var  d_bankaccount_w         "Having a bank account (Wife)"	
	la var  d_bankaccount_h         "Having a bank account (Husband)"		
	la var  w_silc_savings_w        "SILC Savings (w/99) (Wife)"
	la var  w_silc_savings_h        "SILC Savings (w/99) (Husband)"
	
	

	la def hhtype_bl 1 "Male and Female in the household" 0 "Just Female", modify 
	la val hhtype_bl hhtype_bl
	egen    time_leisu_f3_w=rowtotal(time_1_f3_w time_8_f3_w time_9_f3_w)
	replace time_leisu_f3_w=. if time_1_f3_w==.
	la var  time_leisu_f3_w "Time spend on: Leisure (Wife)"

	egen    time_leisu_bl_w=rowtotal(time_1_bl_w time_8_bl_w time_9_bl_w)
	replace time_leisu_bl_w=. if time_1_bl_w==.
	la var  time_leisu_bl_w "Baseline: Time spend on: Leisure (Wife)"

	egen    time_leisu_f3_h=rowtotal(time_1_f3_h time_8_f3_h time_9_f3_h)
	replace time_leisu_f3_h=. if time_1_f3_h==.
	la var  time_leisu_f3_h "Time spend on: Leisure (Husb)"    

	gen     d_any_ext_f3=d_any_ext_f3_h
	replace d_any_ext_f3=d_any_ext_f3_w if d_any_ext_f3_h>=.
	la var  d_any_ext_f3 "Endline:Attended extension training"

	foreach time in bl f2 f3{
	   egen     w_rexp_allfood_`time'=rowtotal(w_r_exp_ttlfood_7dae_`time' w_r_exp_ttlconfood_7dae_`time')	 
	   ihstrans w_rexp_allfood_`time'
	   ren      ihs_w_rexp_allfood_`time' ihs_rexp_allfood_`time'
	   
	   gen      expen_7dae_`time'=daily_adulteq_expenses_`time'*7
	   ihstrans expen_7dae_`time'
	   winsor   expen_7dae_`time', gen (w_expen_7dae_`time') p(0.01)
	   }


	drop   d_dm_cult_soybean4_f3_w d_dm_cult_soybean4_f3_h


	gen lump_sum=(cash_treatment==2)  
	la var lump_sum "Lump Sum"

	gen    ct_lumpsum=d_ct_nct_inel_2*lump_sum 
	la var ct_lumpsum "CT(LumpSum)" 
	gen    ct_month=(d_ct_nct_inel_2==1 & ct_lumpsum==0)
	la var ct_month "CT(Monthly)" 

	foreach j in 100 200 300 400 500 600 700 800 900 1000{
	gen     b`j'ct_treatlp=b`j'ct*ct_lumpsum
	la var  b`j'ct_treatlp "CT(LumpSum)*#CashTransfers(LumpSum&Monthly)"	
	gen     b`j'ct_lp_treatlp=b`j'ct_lp*ct_lumpsum
	la var  b`j'ct_lp_treatlp "CT(LumpSum)*#CashTransfers(LumpSum)"
	gen     b`j'ct_m_treatlp=b`j'ct_m*ct_lumpsum
	la var  b`j'ct_m_treatlp "CT(LumpSum)*#CashTransfers(Monthly)"
	gen     b`j'ct_lp_treatm=b`j'ct_lp*ct_month
	la var  b`j'ct_lp_treatm "CT(Monthly)*#CashTransfers(LumpSum)"
	gen     b`j'ct_m_treatm=b`j'ct_m*ct_month
	la var  b`j'ct_m_treatm "CT(Monthly)*#CashTransfers(Monthly)"	
	}	
		

* Generating annualiza measures of consumption 
	foreach time in bl f2 f3{
	gen annual_expenses_`time'=w_daily_hh_expenses_`time'*360
	gen NCT_annual_expenses_`time'=annual_expenses_`time' if d_ct_nct_inel_1==1 
	gen CT_annual_expenses_`time'=annual_expenses_`time'  if d_ct_nct_inel_2==1
	gen INE_annual_expenses_`time'=annual_expenses_`time' if d_ct_nct_inel_3==1  
	bysort village_group: egen NCTvill_annual_expenses_`time'=mean(NCT_annual_expenses_`time')    
	bysort village_group: egen CTvill_annual_expenses_`time'=mean(CT_annual_expenses_`time')   
	bysort village_group: egen INEvill_annual_expenses_`time'=mean(INE_annual_expenses_`time')  
	}

	 replace annual_expenses_f2=annual_expenses_f2/1.307  
	 replace annual_expenses_f3=annual_expenses_f3/1.486

	 gen annual_expenses_blf2=annual_expenses_f2-annual_expenses_bl
	 gen annual_expenses_blf3=annual_expenses_f3-annual_expenses_bl
	 gen annual_expenses_f2f3=annual_expenses_f3-annual_expenses_f2 
	 la var annual_expenses_blf2 "Annual Expenditures Change (BL-Midline)"
	 la var annual_expenses_blf3 "Annual Expenditures Change (BL-Endline)"
	 la var annual_expenses_f2f3 "Annual Expenditures Change (Midline-Endline)"

	 gen     annual_profits_bl=profits_business_bl*12
	 gen     annual_profits_f2=w_profits_business_fup2*12
	 gen     annual_profits_f3=w_profits_business_fup3*12
	 replace annual_profits_bl=annual_profits_bl
	 replace annual_profits_f2=annual_profits_f2/1.307  
	 replace annual_profits_f3=annual_profits_f3/1.486
	 
	 gen annual_profits_blf2=annual_profits_f2-annual_profits_bl
	 gen annual_profits_blf3=annual_profits_f3-annual_profits_bl
	 gen annual_profits_f2f3=annual_profits_f3-annual_profits_f2 
	 la var annual_profits_blf2 "Annual Profits Change (BL-Midline)"
	 la var annual_profits_blf3 "Annual Profits Change (BL-Endline)"
	 la var annual_profits_f2f3 "Annual Profits Change (Midline-Endline)" 

	 gl vill_var annual_expenses_bl annual_expenses_f2 annual_expenses_f3 ///
				 annual_profits_bl annual_profits_f2 annual_profits_f3
	 foreach var of varlist $vill_var{
	 bysort village_group: egen vill_`var'=total(`var') 	

				 } 


* By vulnerable Category 
	foreach time in bl f2 f3{
	gen EV_annual_expenses_`time'=annual_expenses_`time' if d_EV==1 
	gen VV_annual_expenses_`time'=annual_expenses_`time' if d_VV==1
	gen ML_annual_expenses_`time'=annual_expenses_`time' if d_ML==1 
	 
	bysort village_group: egen EVvill_annual_expenses_`time'=total(EV_annual_expenses_`time')    
	bysort village_group: egen VVvill_annual_expenses_`time'=total(VV_annual_expenses_`time')   
	bysort village_group: egen MLvill_annual_expenses_`time'=total(ML_annual_expenses_`time')  
	la var EVvill_annual_expenses_`time'  "EV: Annual expenditures at the village(`time')"
	la var VVvill_annual_expenses_`time'  "VV: Annual expenditures at the village(`time')"
	la var MLvill_annual_expenses_`time' "ML: Annual expenditures at the village(`time')"

	bysort village_ineligible_ct FNLP_treatment: egen EVttl_annual_expenses_`time'=total(EV_annual_expenses_`time')  
	bysort village_ineligible_ct FNLP_treatment: egen VVttl_annual_expenses_`time'=total(VV_annual_expenses_`time')   
	bysort village_ineligible_ct FNLP_treatment: egen MLttl_annual_expenses_`time'=total(ML_annual_expenses_`time')  
	la var EVttl_annual_expenses_`time' "EV: Annual expenditures sample(`time')"
	la var VVttl_annual_expenses_`time' "VV: Annual expenditures sample(`time')"
	la var MLttl_annual_expenses_`time' "ML: Annual expenditures sample(`time')"

	bysort village_ineligible_ct FNLP_treatment: egen EVmean_annual_expenses_`time'=mean(EV_annual_expenses_`time')  
	bysort village_ineligible_ct FNLP_treatment: egen VVmean_annual_expenses_`time'=mean(VV_annual_expenses_`time')   
	bysort village_ineligible_ct FNLP_treatment: egen MLmean_annual_expenses_`time'=mean(ML_annual_expenses_`time')  
	la var EVttl_annual_expenses_`time' "EV: Annual expenditures sample(`time')"
	la var VVttl_annual_expenses_`time' "VV: Annual expenditures sample(`time')"
	la var MLttl_annual_expenses_`time' "ML: Annual expenditures sample(`time')"
	}
	drop EV_annual_expenses_* VV_annual_expenses_* ML_annual_expenses_*

* Change in expenditures 
	gen pch_vill_annualexp_blf2=(vill_annual_expenses_f2-vill_annual_expenses_bl)/vill_annual_expenses_bl
	gen pch_vill_annualexp_blf3=(vill_annual_expenses_f3-vill_annual_expenses_bl)/vill_annual_expenses_bl
	gen pch_vill_annualexp_f2f3=(vill_annual_expenses_f3-vill_annual_expenses_f2)/vill_annual_expenses_f2
	gen pch_vill_annualprof_blf2=(vill_annual_profits_f2-vill_annual_profits_bl)/vill_annual_profits_bl
	gen pch_vill_annualprof_blf3=(vill_annual_profits_f3-vill_annual_profits_bl)/vill_annual_profits_bl
	gen pch_vill_annualprof_f2f3=(vill_annual_profits_f3-vill_annual_profits_f2)/vill_annual_profits_f2

	gen pch_CTvill_annualexp_blf2=(CTvill_annual_expenses_f2-CTvill_annual_expenses_bl)/CTvill_annual_expenses_bl
	gen pch_CTvill_annualexp_f2f3=(CTvill_annual_expenses_f3-CTvill_annual_expenses_f2)/CTvill_annual_expenses_f2

	 
	la var pch_vill_annualexp_blf2 "Annual Expenditures Change (BL to Midline)" 
	la var pch_vill_annualexp_blf3 "Annual Expenditures Change (BL to Endline)"     
	la var pch_vill_annualexp_f2f3 "Annual Expenditures Change (Midline to Endline)" 
	la var pch_vill_annualprof_blf2 "Annual Profits Change (BL to Midline)" 
	la var pch_vill_annualprof_blf3 "Annual Profits Change (BL to Endline)"     
	la var pch_vill_annualprof_f2f3 "Annual Profits Change (Midline to Endline)" 

	 
	la var pch_CTvill_annualexp_blf2 "Annual CT hh Expenditures Change (BL to Midline)"   
	la var pch_CTvill_annualexp_f2f3 "Annual CT hh Expenditures Change (Midline to Endline)"   
	egen ttl_annual_expenses_bl=total(annual_expenses_bl) if  village_ineligible_ct==0
	egen ttl_annual_expenses_f2=total(annual_expenses_f2) if  village_ineligible_ct==0
	egen ttl_annual_expenses_f3=total(annual_expenses_f3) if  village_ineligible_ct==0   


 * Generating Real ag yields 
   gen    any_farm_hh_bl=(farming_work_bl_w==1 | farming_work_bl_h==1)
   la var any_farm_hh_bl   "Baseline: Any farming work"
   la var any_farm_hh_bl  "Farming work (=1 if anyone in the household)"
   
   gen    any_farm_hh_f2=(farming_work_fup2_w==1 | farming_work_fup2_h==1)
   la var any_farm_hh_f2   "Midline: Any farming work"     
   
   gen    any_farm_hh_f3=(farming_work_fup3_w==1 | farming_work_fup3_h==1)
   la var any_farm_hh_f3   "Endline: Any farming work"   
   
   gen    ragyields_bl=agyields_bl
   gen    ragyields_f3=agyields_end
   ren    agyields_end agyields_f3
   winsor ragyields_bl, gen (w_ragyields_bl) p(0.05)   
   winsor ragyields_f3, gen (w_ragyields_f3) p(0.05)
   
   ihstrans ragyields_bl ragyields_f3
   
   gen     d_posyields_bl=(ragyields_bl>0 &  ragyields_bl<.)
   gen     d_posyields_f3=(ragyields_f3>0 &  ragyields_f3<.)
   gen     w_conragyields_bl=ragyields_bl
   replace w_conragyields_bl=. if d_posyields_bl==0
   gen     w_conragyields_f3=ragyields_f3
   replace w_conragyields_f3=. if d_posyields_f3==0
   
   ihstrans w_conragyields_bl w_conragyields_f3
   ren ihs_w_conragyields_bl ihs_conragyields_bl
   ren ihs_w_conragyields_f3 ihs_conragyields_f3
   
   clonevar ihs_ttl_inputsha_f3=ihs_ttl_inputs_plot_ha  
   winsor   ttl_inputs_plot, gen (w_ttl_inputs_f3) p(0.05)
   
   gen      conttl_inputsha_f3=ttl_inputs_plot_ha
   replace  conttl_inputsha_f3=. if d_posyields_f3==0   
   gen      conttl_inputs_f3=ttl_inputs_plot
   replace  conttl_inputs_f3=. if d_posyields_f3==0  
   
   gen      w_conttl_inputsha_f3=w_ttl_inputs_plot_ha
   replace  w_conttl_inputsha_f3=. if d_posyields_f3==0   
   gen      w_conttl_inputs_f3=w_ttl_inputs_f3
   replace  w_conttl_inputs_f3=. if d_posyields_f3==0     
   
   gen      ttl_realinputsha_f3=ttl_inputs_plot_ha
   replace  ttl_realinputsha_f3=ttl_realinputsha_f3/1.486
   winsor   ttl_realinputsha_f3, gen (w_ttl_realinputsha_f3) p(0.05)
   ihstrans conttl_inputsha_f3 conttl_inputs_f3 ttl_realinputsha_f3
   	

   * Both profitable households    
   gen d_posprofitsw_bl=(profits_business_bl>0 & profits_business_bl<.)    
   gen d_posprofitsw_f2=(profits_business_fup2>0 & profits_business_fup2<.) 
   gen d_posprofitsw_f3=(profits_business_fup3>0 & profits_business_fup3<.)
   
   gen d_posprofitsh_bl=(profits_business_bl_h>0 & profits_business_bl_h<.)    
   gen d_posprofitsh_f2=(profits_business_fup2_h>0 & profits_business_fup2_h<.) 
   gen d_posprofitsh_f3=(profits_business_fup3_h>0 & profits_business_fup3_h<.)   
   
   gen     catprofw_bl=.
   replace catprofw_bl=1 if d_posprofitsw_bl==0 &  d_posyields_bl==0
   replace catprofw_bl=2 if d_posprofitsw_bl==1 &  d_posyields_bl==0   
   replace catprofw_bl=3 if d_posprofitsw_bl==0 &  d_posyields_bl==1  
   replace catprofw_bl=4 if d_posprofitsw_bl==1 &  d_posyields_bl==1   
   
   gen     catprofw_f3=.
   replace catprofw_f3=1 if d_posprofitsw_f3==0 &  d_posyields_f3==0
   replace catprofw_f3=2 if d_posprofitsw_f3==1 &  d_posyields_f3==0   
   replace catprofw_f3=3 if d_posprofitsw_f3==0 &  d_posyields_f3==1  
   replace catprofw_f3=4 if d_posprofitsw_f3==1 &  d_posyields_f3==1
   
   gen     catprofh_bl=.
   replace catprofh_bl=1 if d_posprofitsh_bl==0 &  d_posyields_bl==0
   replace catprofh_bl=2 if d_posprofitsh_bl==1 &  d_posyields_bl==0   
   replace catprofh_bl=3 if d_posprofitsh_bl==0 &  d_posyields_bl==1  
   replace catprofh_bl=4 if d_posprofitsh_bl==1 &  d_posyields_bl==1   
   
   gen     catprofh_f3=.
   replace catprofh_f3=1 if d_posprofitsh_f3==0 &  d_posyields_f3==0
   replace catprofh_f3=2 if d_posprofitsh_f3==1 &  d_posyields_f3==0   
   replace catprofh_f3=3 if d_posprofitsh_f3==0 &  d_posyields_f3==1  
   replace catprofh_f3=4 if d_posprofitsh_f3==1 &  d_posyields_f3==1   
   
   
   la var ragyields_bl            "Baseline:Agriculture Yields (Real-Prices from Market Survey)"
   la var ragyields_f3            "Endline:Agriculture Yields  (Real-Prices from Market Survey)"
   la var w_ragyields_bl          "Baseline:Agriculture Yields (W/95-Real-Prices from Market Survey)"
   la var w_ragyields_f3          "Endline:Agriculture Yields  (W/95-Real-Prices from Market Survey)"  
   la var ihs_ragyields_bl        "Baseline:Agriculture Yields (IHS-Real-Prices from Market Survey)"
   la var ihs_ragyields_f3        "Endline:Agriculture Yields  (IHS-Real-Prices from Market Survey)"  
   la var d_posyields_bl          "Baseline: Positive yields"   
   la var d_posyields_f3          "Endline: Positive yields"   
   la var w_conragyields_bl       "Baseline:Agriculture Yields Conditional(W/95-Real-Prices from Market Survey)"
   la var w_conragyields_f3       "Endline:Agriculture Yields Conditional(W/95-Real-Prices from Market Survey)"  
   la var w_ttl_inputs_f3         "Endline:Total spend on inputs (W/95)"
   la var w_ttl_realinputsha_f3   "Endline:Total spend on inputs real (W/95)"
   la var ihs_ttl_realinputsha_f3 "Endline:Total spend on inputs real (IHS)"
   la var w_conttl_inputsha_f3    "Endline:Total spend on inputs per hectare (Conditional)"
   la var w_conttl_inputs_f3      "Endline:Total spend on inputs (Conditional)"
   la var ihs_conttl_inputsha_f3  "Endline:IHS Total spend on inputs per hectare (Conditional)"
   la var ihs_conttl_inputs_f3    "Endline:IHS Total spend on inputs (Conditional)"   
   la var ihs_conragyields_f3     "Endline:Agriculture Yields Conditional(IHS)" 
   la var ihs_ragyields_f3        "Endline:Agriculture Yields (IHS)" 
   la var ihs_ttl_realinputsha_f3 "Endline:Total spend on inputs per hectare (IHS)" 

  * Generate number of CT in village before focussing on our sample of analysis  
	bysort village_group: egen ct_hh_num=total(d_ct_nct_inel_2) 
	la var ct_hh_num "Number of CT recepients in village"
	bysort village_group: gen amount_CT_village=ct_hh_num*75000

	bysort village_ineligible_ct: egen   ttl_CThh=total(d_ct_nct_inel_2)
	bysort village_ineligible_ct: gen amount_CT_total=ttl_CThh*75000

	bysort village_group: egen   vill_EVhh=total(d_EV)
	bysort village_ineligible_ct FNLP_treatment: egen   ttl_EVhh=total(d_EV)

	la def village_ineligible_ct  1 "Pure control" 0 "CT village", modify
	la val village_ineligible_ct village_ineligible_ct

 ** Assets index        
 ** ------------------------
 	clonevar ihs_farmassetsf2=ihs_value_farmassets_fup2_w
	clonevar ihs_farmassetsf3=ihs_value_farmassets_fup3_w
	clonevar ihs_hhassetsf2=ihs_value_hhassets_fup2_w
	clonevar ihs_hhassetsf3=ihs_value_hhassets_fup3_w
	
	gen realvalanimal_f2=value_animals_fup2_w
	gen realvalfarm_f2=value_farmassets_fup2_w
	gen realvalhh_f2=value_hhassets_fup2_w
	
	gen realvalanimal_f3=value_animals_fup3_w
	gen realvalfarm_f3=value_farmassets_fup3_w
	gen realvalhh_f3=value_hhassets_fup3_w	
	foreach var in realvalanimal realvalfarm realvalhh{
    replace `var'_f2=`var'_f2/1.307 
    replace `var'_f3=`var'_f3/1.486
	winsor `var'_f2, gen (w_`var'_f2) p (0.05)
	winsor `var'_f3, gen (w_`var'_f3) p (0.05)
    }
	
	ihstrans realvalanimal_?? realvalfarm_?? realvalhh_??
	

	
	gl assets_f2     realvalanimal_f2 realvalfarm_f2 realvalhh_f2
	gl assets_f3     realvalanimal_f3 realvalfarm_f3 realvalhh_f3
	gl ihs_assets_f2 ihs_realvalanimal_f2 ihs_realvalfarm_f2 ihs_realvalhh_f2
	gl ihs_assets_f3 ihs_realvalanimal_f3 ihs_realvalfarm_f3 ihs_realvalhh_f3
					 
	swindex $assets_f2 if FNLP_treatment==0, generate(assetsind_f2_0) displayw ///
											normby(d_ct_nct_inel_3)
	swindex $assets_f3 if FNLP_treatment==0, generate(assetsind_f3_0) displayw	///
											normby(d_ct_nct_inel_3) 
	swindex $ihs_assets_f2 if FNLP_treatment==0, generate(ihsassetsind_f2_0) displayw ///
											normby(d_ct_nct_inel_3) 
	swindex $ihs_assets_f3 if FNLP_treatment==0, generate(ihsassetsind_f3_0) displayw ///
											normby(d_ct_nct_inel_3) 
	
	swindex $assets_f2 if FNLP_treatment==1, generate(assetsind_f2_1) displayw  ///
											normby(d_ct_nct_inel_3) 
	swindex $assets_f3 if FNLP_treatment==1, generate(assetsind_f3_1) displayw	///
											normby(d_ct_nct_inel_3)  
	swindex $ihs_assets_f2 if FNLP_treatment==1, generate(ihsassetsind_f2_1) displayw ///
											normby(d_ct_nct_inel_3) 
	swindex $ihs_assets_f3 if FNLP_treatment==1, generate(ihsassetsind_f3_1) displayw ///
											normby(d_ct_nct_inel_3) 	
		
	swindex $assets_f2 $ihs_assets_f2 if FNLP_treatment==0, ///
			generate(allassetsind_f2) displayw normby(d_ct_nct_inel_3)
	swindex $assets_f3 $ihs_assets_f3 if FNLP_treatment==0, ///
			generate(allassetsind_f3) displayw	normby(d_ct_nct_inel_3)
					
			
	gl index_var assetsind_f2 assetsind_f3 ihsassetsind_f2 	ihsassetsind_f3 
	foreach var in $index_var{
	gen `var'=. 
	replace `var'=`var'_0 if FNLP_treatment==0
	replace `var'=`var'_1 if FNLP_treatment==1	
    drop `var'_0  `var'_1
	}
	
	drop ihs_farmassetsf? ihs_hhassetsf?
	la var assetsind_f2     "Midline:Assets Index(Winsor)"
	la var assetsind_f3     "Endline:Assets Index(Winsor)"
	la var ihsassetsind_f2  "Midline:Assets Index(IHS)"
	la var ihsassetsind_f3  "Endline:Assets Index((IHS)"
	la var allassetsind_f2  "Midline:Assets Index(all)"
	la var allassetsind_f3  "Endline:Assets Index((all)"
	
	
	** Real variables 
   gen realvalanimal_w_f2=value_animals_fup2_w
   gen realvalfarm_w_f2=value_farmassets_fup2_w 
   gen realvalhh_w_f2=value_hhassets_fup2_w
   
   gen realvalanimal_w_f3=value_animals_fup3_w
   gen realvalfarm_w_f3=value_farmassets_fup3_w 
   gen realvalhh_w_f3=value_hhassets_fup3_w  
   
   gen realvalanimal_h_f2=value_animals_fup2_h
   gen realvalfarm_h_f2=value_farmassets_fup2_h 
   gen realvalhh_h_f2=value_hhassets_fup2_h
   
   gen realvalanimal_h_f3=value_animals_fup3_h
   gen realvalfarm_h_f3=value_farmassets_fup3_h 
   gen realvalhh_h_f3=value_hhassets_fup3_h  
   
   foreach var in  realvalanimal_w realvalfarm_w realvalhh_w ///
				   realvalanimal_h realvalfarm_h realvalhh_h {
   replace `var'_f2=`var'_f2/1.307   
   replace `var'_f3=`var'_f3/1.486
   winsor  `var'_f2, gen (w_`var'_f2) p (0.05)  
   winsor  `var'_f3, gen (w_`var'_f3) p (0.05)     
   }
	
   egen w_realvalassets_f2=rowtotal(w_realvalanimal_f2 w_realvalfarm_f2 w_realvalhh_f2)
   egen w_realvalassets_f3=rowtotal(w_realvalanimal_f3 w_realvalfarm_f3 w_realvalhh_f3)
   
 ** Education and health 
    gen realeduc_hh_f2=ttl_educ_exp_hh_f2
    gen realeduc_hh_f3=ttl_educ_exp_hh_f3
    gen realhealth_hh_f2=ttl_healthv2_exp_hh_f2
    gen realhealth_hh_f3=ttl_healthv2_exp_hh_f3
	
   foreach var in  realeduc_hh realhealth_hh{
   replace `var'_f2=`var'_f2/1.307   
   replace `var'_f3=`var'_f3/1.486
   winsor  `var'_f2, gen (w_`var'_f2) p (0.05)  
   winsor  `var'_f3, gen (w_`var'_f3) p (0.05)     
   }	
	
  ** Ratio profits raw materials 
     gen income_w_bl=profits_business_bl+rawmats_business_bl_w 
	 gen income_w_f2=profits_business_fup2+rawmats_business_fup2_w 
	 gen income_w_f3=profits_business_fup3+rawmats_business_fup3_w 
	   	   
     gen income_h_bl=profits_business_bl_h+rawmats_business_bl_h
	 gen income_h_f2=profits_business_fup2_h+rawmats_business_fup2_h 
	 gen income_h_f3=profits_business_fup3_h+rawmats_business_fup3_h 	   
	   
	 foreach var of varlist  income_w_f2  income_w_f3 income_h_f2 income_h_f3{
	 winsor `var', p(0.01) gen (w_`var')  
	 }
	 
	 clonevar w_income_w_bl=income_w_bl
	 clonevar w_income_h_bl=income_h_bl
	 
	 ihstrans income_w_bl income_h_bl income_w_f2  income_w_f3 income_h_f2 income_h_f3
	 
	 
	 la var w_income_w_bl "Baseline:Business Income Wife (W/99)"
	 la var w_income_w_f2 "Midline:Business Income Wife (W/99)"	 
	 la var w_income_w_f3 "Endline:Business Income Wife (W/99)"
	 
	 la var w_income_h_bl "Baseline:Business Income Husband (W/99)"
	 la var w_income_h_f2 "Midline:Business Income Husband (W/99)"	 
	 la var w_income_h_f3 "Endline:Business Income Husband (W/99)"	 
	 
	 la var ihs_income_w_bl "Baseline:Business Income Wife (IHS)"
	 la var ihs_income_w_f2 "Midline:Business Income Wife (IHS)"	 
	 la var ihs_income_w_f3 "Endline:Business Income Wife (IHS)"
	 
	 la var ihs_income_h_bl "Baseline:Business Income Husband (IHS)"
	 la var ihs_income_h_f2 "Midline:Business Income Husband (IHS)"	 
	 la var ihs_income_h_f3 "Endline:Business Income Husband (IHS)"		 
	 
	 gen     frac_rawmat_w_bl=rawmats_business_bl_w/income_w_bl
	 replace frac_rawmat_w_bl=0 if rawmats_business_bl_w==0
	 gen     frac_rawmat_w_f2=rawmats_business_fup2_w/income_w_f2	
	 replace frac_rawmat_w_f2=0 if rawmats_business_fup2_w==0	 
	 gen     frac_rawmat_w_f3=rawmats_business_fup3_w/income_w_f3
	 replace frac_rawmat_w_f3=0 if rawmats_business_fup3_w==0	 
	 
	 gen     frac_rawmat_h_bl=rawmats_business_bl_h/income_h_bl
	 replace frac_rawmat_h_bl=0 if rawmats_business_bl_h==0	 
	 gen     frac_rawmat_h_f2=rawmats_business_fup2_h/income_h_f2	
	 replace frac_rawmat_h_f2=0 if rawmats_business_fup2_h==0	 	 
	 gen     frac_rawmat_h_f3=rawmats_business_fup3_h/income_h_f3
	 replace frac_rawmat_h_f3=0 if rawmats_business_fup3_h==0	 		 
	
	 egen     hh_income_f3=rowmean(hh_income_w_f3 hh_income_h_f3)
     replace  hh_income_f3=. if hh_income_w_f3==. & hh_income_h_f3==. 
	 ihstrans hh_income_f3
	 winsor   hh_income_f3, p (0.05) gen (w_hh_income_f3)
	 
	 la var hh_income_f3 "Household Income (average wife and husband)"
	 la var ihs_hh_income_f3 "Household Income (average wife and husband) (W/99)"
	 la var w_hh_income_f3 "Household Income (average wife and husband) (IHS)"
	
   ** Interactions with CT
    gen temp=(d_ct_nct_inel_2==1)
    foreach number in 100 200 300 400 500  600 700 800 900 1000{   
	gen    CT_PET`number'=pet`number'*temp
	gen    CT_PEV`number'=pEV`number'*temp
	gen    CT_HH`number'=b`number'pov*temp
	la var CT_PET`number' "CT*PET(`number'mts)"
	la var CT_PEV`number' "CT*PEV(`number'mts)"
	la var CT_HH`number'  "CT*HH(`number'mts)"	
	}
    drop temp 
    
	
	gen temp=(d_VV==1 | d_ML==1)
	
    foreach number in 100 200 300 400 500  600 700 800 900 1000{   
	gen    VVML_PET`number'=pet`number'*temp
	}
	drop temp 
	
	la var ttl_CThh                "Total number of CT in our sample"
	la var ttl_EVhh                "Total number of EV in village"
	la var amount_CT_village       "Total amount of CT in village"
	la var amount_CT_total         "Total amount of CT in our sample"
	  
	la var vill_annual_expenses_bl "Baseline: Annual Expenditures Village Level"
	la var vill_annual_expenses_f2 "Midline: Annual Expenditures Village Level"
	la var vill_annual_expenses_f3 "Endline: Annual Expenditures Village Level"
	la var vill_annual_profits_bl  "Baseline: Annual Profits Village Level"
	la var vill_annual_profits_f2  "Midline: Annual Profits Village Level"
	la var vill_annual_profits_f3  "Endline: Annual Profits Village Level"
	la var CTvill_annual_expenses_bl "Baseline: Annual CT hh Expenditures Village Level"
	la var CTvill_annual_expenses_f2 "Midline: Annual CT hh Expenditures Village Level"
	la var CTvill_annual_expenses_f3 "Endline: Annual CT hh Expenditures Village Level"


  ** Generating some attrition/respondent rates 
	gen    d_hhavail_f2=(d_wavail_f2==1 | d_mavail_f2==1)
	gen    d_hhavail_f3=(d_wavail_f3==1 | d_mavail_f3==1)
	la var d_hhavail_f2 "Someone in the household present at Midline"
	la var d_hhavail_f3 "Someone in the household present at Endline"
    la var d_wavail_f2  "Wife present at Midline"
	la var d_wavail_f3  "Wife present at Endline"
    la var d_mavail_f2  "Husband present at Midline"
	la var d_mavail_f3  "Husband present at Endline"
	
    gen    attrit_f2=(d_hhavail_f2==0) 
    gen    attrit_f3=(d_hhavail_f3==0) 
    gen    attrit_f2f3=(d_hhavail_f2==0 | d_hhavail_f3==0) 
	la var attrit_f2   "Attrition at Midline"
	la var attrit_f3   "Attrition at Endline"
	la var attrit_f2f3 "Attrition at Midline and Endline"
	 
    gen    attrit_w_f2=(d_wavail_f2==0) 
    gen    attrit_w_f3=(d_wavail_f3==0) 
    gen    attrit_w_f2f3=(d_wavail_f2==0 | d_wavail_f3==0) 
	la var attrit_w_f2   "Attrition at Midline (Wife)"
	la var attrit_w_f3   "Attrition at Endline (Wife)"
	la var attrit_w_f2f3 "Attrition at Midline and Endline (Wife)"	 
	 
    gen     attrit_wEv_f2=(d_wavail_f2==0) 
    gen     attrit_wEv_f3=(d_wavail_f3==0) 
    gen     attrit_wEv_f2f3=(d_wavail_f2==0 | d_wavail_f3==0)
	replace attrit_wEv_f2=.   if d_vuln_cat_1!=1
	replace attrit_wEv_f3=.   if d_vuln_cat_1!=1
	replace attrit_wEv_f2f3=. if d_vuln_cat_1!=1
	la var  attrit_wEv_f2   "Attrition at Midline (Wife EVs)"
	la var  attrit_wEv_f3   "Attrition at Endline (Wife EVs)"
	la var  attrit_wEv_f2f3 "Attrition at Midline and Endline (Wife EVs)"	 
	
	gen     panel_sample=(d_wavail_f2==1 & d_wavail_f3==1)
	la var  panel_sample "Panel Sample"
	la def  panel_sample 1 "Panel Sample" 0 "Otherwise", modify 
	la val  panel_sample panel_sample
	
	gen    atonew_sample=(d_wavail_f2==1 | d_wavail_f3==1)
	la var atonew_sample "Household Present on one wave"
	la def atonew_sample 1 "At least one Wave" 0 "Otherwise", modify 
	la val atonew_sample atonew_sample 
	
  ** Extra cleaning using response rates
  * Replace by missing if not present in the wave 	  
  * Globals of variables   
  # d;
    gl controls    age_hhhead_bl 	  marital_status_1_bl    
                   literacy_hhhead_bl  
	    		   num_plots_bl         hhtype_bl  
				   num_hh_members_bl    
				   num_hh_members_15_bl d_farm_size_bl_?
				   w_daily_adulteq_expenses_bl
			       empowered_new_bl      dm_index_bl_new_w 
				   weai_new_bl_w 
				   business_work_bl_w
			       econ_fem_activity_bl 	 num_enterprises_bl;   

    gl non_farm_f2 business_work_fup2_w          w_profits_business_fup2  	 
			       w_rawmats_business_fup2_w	d_primary_act_fup2_c*;              
			   
	gl non_farm_f3 business_work_fup3_w   
				   w_profits_business_fup3  	w_rawmats_business_fup3_w	
				   d_primary_act_fup3_c* ;      
				   
	gl assets_f2  w_value_animals_fup2_w w_value_farmassets_fup2_w 
				  w_value_hhassets_fup2_w;
				  
	gl assets_f3  w_value_animals_fup3_w w_value_farmassets_fup3_w 
				  w_value_hhassets_fup3_w;

	gl consump_f2 w_daily_adulteq_expenses_f2  foodcons_daily_f2;

	gl consump_f3 w_daily_adulteq_expenses_f3  foodcons_daily_f3;  
								
	gl norms_f3    w_norms_women_not_go_work      w_comm_norm_woman_fields 
				   w_comm_norm_male_bad_provider  w_comm_norm_woman_travelsout 
				   w_comm_norm_worsehusband 	  w_comm_norm_worsewife 
				   w_comm_norm_worseindf          w_gender_equity_norm; 
				   
	gl norms_f3_h  h_norms_women_not_go_work      h_comm_norm_woman_fields 
				   h_comm_norm_male_bad_provider  h_comm_norm_woman_travelsout 
				   h_comm_norm_worsehusband 	  h_comm_norm_worsewife 
				   h_comm_norm_worseindf          h_gender_equity_norm 
				   h_jv_any h_selfeff;						   
				   
	gl empower_f3  aggregate_prod w_jv_any w_selfeff 
				   female_own_assets 
				  
				   w_aggregate_income w_aggregate_time 
				   speakpublic_any groupmember_any;
				   
	gl viol_f3     emo_vio_f3 phys_vio_f3 sex_vio_f3;
	
	gl dist_out_f2 business_work_fup2_w    		w_profits_business_fup2  	 
			       w_rawmats_business_fup2_w
	               d_primary_act_fup2_c1             
				   d_primary_act_fup2_c2		d_primary_act_fup2_c3               
				   d_primary_act_fup2_c4 		d_primary_act_fup2_c5
				   d_locationbuss_*_fup2_w_unc;
				   
	gl dist_out_f3 business_work_fup3_w   	w_profits_business_fup3  	 
			       w_rawmats_business_fup3_w	
	               d_primary_act_fup3_c1                 
				   d_primary_act_fup3_c2 		d_primary_act_fup3_c3               
				   d_primary_act_fup3_c4		d_primary_act_fup3_c5   
				   d_locationbuss_*_fup3_w_unc;
		
	gl foodsecur_bl  num_daymeals_child_bl num_daymeals_adults_bl
	                  foody1_bl-foody6_bl 
	                  foodins_index_bl      WeightedVar_food_bl;
					   		
		
	gl foodsecur_f2  num_daymeals_child_f2 num_daymeals_adults_f2
	                  foody1_f2-foody6_f2 
	                  foodins_index_f2      WeightedVar_food_f2;
					   
	gl foodsecur_f3   num_daymeals_child_f3  num_daymeals_adults_f3
	                  foody1_f3-foody6_f3 
	                  foodins_index_f3 WeightedVar_food_f3;	
					  
	gl dm_var mother_worked_w mother_workedent_w 
	          school_mother_bl_w weai_new_bl_w  dm_index_bl_new_w;				  
 # d cr;
 
	foreach var of varlist w_rawmats_business_fup2_w ihs_profits_business_fup2 ///
						   $non_farm_f2 $assets_f2 $dist_out_f2{
	replace `var'=. if d_wavail_f2==0
	}
	foreach var of varlist w_rawmats_business_fup3_w ihs_profits_business_fup3 ///
						   $non_farm_f3 $assets_f3 ///
						   $norms_f3   $empower_f3 $viol_f3 $dist_out_f3{
	replace `var'=. if d_wavail_f3==0
	}
	foreach var of varlist $norms_f3_h{
	replace `var'=. if d_mavail_f3==0
	}

	
  ** Generating two fold trteatment variables 	 
	gen     nct_control=(d_ct_nct_inel_1==1 | d_ct_nct_inel_3==1)
	gen     ct_control=(d_ct_nct_inel_2==1 | d_ct_nct_inel_3==1)   
	la var  nct_control "NCT in Ct villages and Pure control"
	la var  ct_control  "CT in Ct villages and Pure control"
	replace d_ct_nct_inel_2=0 if d_ct_nct_inel_2==.   
	replace d_ct_nct_inel_1=0 if d_ct_nct_inel_1==.   
	gen     CTvill=(village_ineligible_ct==0)
	la var  CTvill "CT village"
	la def  CTvill 1 "Cash Transfer Program Villages"  0 "Non-Program Villages", modify
	la val  CTvill CTvill

	gen    VVML=(d_VV==1 | d_ML==1) 
	gen    VVML_CT=VVML*CTvill
	la var VVML "VVML"
	la var VVML_CT "VVML*CT"
	
	gen     nct_ct_inel=. 
	replace nct_ct_inel=1 if ct_nct_inel==1
	replace nct_ct_inel=2 if ct_nct_inel==0
    replace nct_ct_inel=3 if ct_nct_inel==2
	la def  nct_ct_inel 1 "Cash Transfer in Program Villages"             ///
	                    2 "Non-CT in Program Villages"                     ///
					    3 "Pure Control in Non-Program Villages", modify
					   
	la val nct_ct_inel nct_ct_inel
	
	gen     spill_treatment=. 
	replace spill_treatment=0 if ct_nct_inel==2
	replace spill_treatment=1 if ct_nct_inel==1
    replace spill_treatment=2 if ct_nct_inel==0
	la def  spill_treatment 0 "Pure Control in Non-Program Villages"         ///
	                        1 "Cash Transfer in Program Villages"            ///
	                        2 "Non-CT in Program Villages", modify
					   
	la val  spill_treatment  spill_treatment 
	la var  spill_treatment "Spillover Treatment"
		
	gen     CT_hhtreat=. 
	replace CT_hhtreat=0 if ct_nct_inel==2
	replace CT_hhtreat=1 if ct_nct_inel==0
    replace CT_hhtreat=2 if ct_nct_inel==1
	la def  CT_hhtreat      0 "Pure Control in Non-Program Villages"         ///
	                        1 "Non-CT in Program Villages"                   ///
							2 "Cash Transfer in Program Villages" , modify
					   
	la val  CT_hhtreat  CT_hhtreat
	la var  CT_hhtreat "Cash Transfer Program Treatment"
	
	gen     spill_treat_cat=""
	replace spill_treat_cat="Pure Control"  if spill_treatment==0
	replace spill_treat_cat="CT"            if spill_treatment==1
	replace spill_treat_cat="NCT"           if spill_treatment==2
	replace spill_treat_cat=""              if vulnerability_category_ward_bl!=1
	la var  spill_treat_cat "Spillover Treatment"
	
	* We replace by missing if no eV 
	replace ct_nct_inel=.     if vulnerability_category_ward_bl!=1
	replace nct_ct_inel=.     if vulnerability_category_ward_bl!=1
	replace num_enterprises_bl=0 if num_enterprises_bl==. 	
	
	foreach var of varlist age_hhhead_bl marital_status_bl_1 num_plots_bl{
	gen `var'_ct= `var'*d_ct_nct_inel_2	
	gen `var'_nct=`var'*d_ct_nct_inel_1			
	} 
	
	la var age_hhhead_bl_ct      "Age of hhh*CT"
	la var age_hhhead_bl_nct     "Age of hhh*NCT"
	la var marital_status_bl_1_ct  "Marital Status*CT"
	la var marital_status_bl_1_nct "Marital Status*NCT"
	la var num_plots_bl_ct       "Number of plots*CT"
	la var num_plots_bl_nct      "Number of plots*NCT"	
	
	la def FNLP_treatment 1 "FNLP Treatment" 0 "FNLP Control", modify 
	la val FNLP_treatment FNLP_treatment
	
    gen     business_work_fup2_w_c2=business_work_fup2_w*d_ct_nct_inel_2  
    gen     business_work_fup2_w_c1=business_work_fup2_w*d_ct_nct_inel_1
	la var  business_work_fup2_w_c2 "Midline Business Wife*CT in CT villages"
	la var  business_work_fup2_w_c1 "Midline Business Wife*NCT in CT villages"
	
	gen     any_business_bl=(business_work_bl_w==1 | business_work_bl_h==1)
	gen     any_business_f2=(business_work_fup2_w==1 | business_work_fup2_h==1)	
	gen     any_business_f3=(business_work_fup3_w==1 | business_work_fup3_h==1)	
	la var  any_business_bl "Baseline:Any business"
	la var  any_business_f2 "Midline:Any business"	
	la var  any_business_f3 "Endline:Any business"
	la var  business_work_bl_w "Baseline:NonFarm Enterprise (Wife)"
	
	gen d_wavail_bl=(business_work_bl_w!=.)
	gen d_mavail_bl=(business_work_bl_h!=.)	
	
  ** Labor Dynamics 

  * Wife 
    gen     lab_dyn_w_bl=. 
	replace lab_dyn_w_bl=0 if business_work_bl_w==0 & farming_work_bl_w==0
	replace lab_dyn_w_bl=1 if business_work_bl_w==0 & farming_work_bl_w==1
	replace lab_dyn_w_bl=2 if business_work_bl_w==1 & farming_work_bl_w==0
	replace lab_dyn_w_bl=3 if business_work_bl_w==1 & farming_work_bl_w==1
	replace lab_dyn_w_bl=. if d_wavail_bl==0
	
	
    gen     lab_dyn_w_f2=. 
	replace lab_dyn_w_f2=0 if business_work_fup2_w==0 & farming_work_fup2_w==0
	replace lab_dyn_w_f2=1 if business_work_fup2_w==0 & farming_work_fup2_w==1
	replace lab_dyn_w_f2=2 if business_work_fup2_w==1 & farming_work_fup2_w==0
	replace lab_dyn_w_f2=3 if business_work_fup2_w==1 & farming_work_fup2_w==1
	replace lab_dyn_w_f2=.   if d_wavail_f2==0
	
    gen     lab_dyn_w_f3=. 
	replace lab_dyn_w_f3=0 if business_work_fup3_w==0 & farming_work_fup3_w==0
	replace lab_dyn_w_f3=1 if business_work_fup3_w==0 & farming_work_fup3_w==1
	replace lab_dyn_w_f3=2 if business_work_fup3_w==1 & farming_work_fup3_w==0
	replace lab_dyn_w_f3=3 if business_work_fup3_w==1 & farming_work_fup3_w==1	
	replace lab_dyn_w_f3=.   if d_wavail_f3==0
	
  * Husband  
    gen     lab_dyn_h_bl=. 
	replace lab_dyn_h_bl=0 if business_work_bl_h==0 & farming_work_bl_h==0
	replace lab_dyn_h_bl=1 if business_work_bl_h==0 & farming_work_bl_h==1
	replace lab_dyn_h_bl=2 if business_work_bl_h==1 & farming_work_bl_h==0
	replace lab_dyn_h_bl=3 if business_work_bl_h==1 & farming_work_bl_h==1
	replace lab_dyn_h_bl=.   if d_mavail_bl==0
		
    gen     lab_dyn_h_f2=. 
	replace lab_dyn_h_f2=0 if business_work_fup2_h==0 & farming_work_fup2_h==0
	replace lab_dyn_h_f2=1 if business_work_fup2_h==0 & farming_work_fup2_h==1
	replace lab_dyn_h_f2=2 if business_work_fup2_h==1 & farming_work_fup2_h==0
	replace lab_dyn_h_f2=3 if business_work_fup2_h==1 & farming_work_fup2_h==1
	replace lab_dyn_h_f2=. if d_mavail_f2==0
	
    gen     lab_dyn_h_f3=. 
	replace lab_dyn_h_f3=0 if business_work_fup3_h==0 & farming_work_fup3_h==0
	replace lab_dyn_h_f3=1 if business_work_fup3_h==0 & farming_work_fup3_h==1
	replace lab_dyn_h_f3=2 if business_work_fup3_h==1 & farming_work_fup3_h==0
	replace lab_dyn_h_f3=3 if business_work_fup3_h==1 & farming_work_fup3_h==1	
	replace lab_dyn_h_f3=. if d_mavail_f3==0	 
	 
  * Household
    gen     lab_dyn_bl=. 
	replace lab_dyn_bl=0 if any_business_bl==0 & any_farm_hh_bl==0
	replace lab_dyn_bl=1 if any_business_bl==0 & any_farm_hh_bl==1
	replace lab_dyn_bl=2 if any_business_bl==1 & any_farm_hh_bl==0
	replace lab_dyn_bl=3 if any_business_bl==1 & any_farm_hh_bl==1
	replace lab_dyn_bl=. if d_mavail_bl==0 | d_wavail_bl==0
	
    gen     lab_dyn_f2=. 
	replace lab_dyn_f2=0 if any_business_f2==0 & any_farm_hh_f2==0
	replace lab_dyn_f2=1 if any_business_f2==0 & any_farm_hh_f2==1
	replace lab_dyn_f2=2 if any_business_f2==1 & any_farm_hh_f2==0
	replace lab_dyn_f2=3 if any_business_f2==1 & any_farm_hh_f2==1	
	replace lab_dyn_f2=. if d_mavail_f2==0 | d_wavail_f2==0
	
	
    gen     lab_dyn_f3=. 
	replace lab_dyn_f3=0 if any_business_f3==0 & any_farm_hh_f3==0
	replace lab_dyn_f3=1 if any_business_f3==0 & any_farm_hh_f3==1
	replace lab_dyn_f3=2 if any_business_f3==1 & any_farm_hh_f3==0
	replace lab_dyn_f3=3 if any_business_f3==1 & any_farm_hh_f3==1		
	replace lab_dyn_f3=. if d_mavail_f3==0 | d_wavail_f3==0
		 
	 
 ** Intrahousehold  
  * Wife
    gen      lab_bl_w=.
	replace  lab_bl_w=0 if business_work_bl_w==0 & farming_work_bl_w==0
	replace  lab_bl_w=1 if business_work_bl_w==1 
	replace  lab_bl_w=1 if farming_work_bl_w==1
	
    gen      lab_f2_w=.
	replace  lab_f2_w=0 if business_work_fup2_w==0 & farming_work_fup2_w==0
	replace  lab_f2_w=1 if business_work_fup2_w==1 
	replace  lab_f2_w=1 if farming_work_fup2_w==1	
	
    gen      lab_f3_w=.
	replace  lab_f3_w=0 if business_work_fup3_w==0 & farming_work_fup3_w==0
	replace  lab_f3_w=1 if business_work_fup3_w==1 
	replace  lab_f3_w=1 if farming_work_fup3_w==1		
	
  * Husband
    gen      lab_bl_h=.
	replace  lab_bl_h=0 if business_work_bl_h==0 &  farming_work_bl_h==0
	replace  lab_bl_h=1 if business_work_bl_h==1 
	replace  lab_bl_h=1 if farming_work_bl_h==1
	
    gen      lab_f2_h=.
	replace  lab_f2_h=0 if business_work_fup2_h==0 &  farming_work_fup2_h==0
	replace  lab_f2_h=1 if business_work_fup2_h==1 
	replace  lab_f2_h=1 if farming_work_fup2_h==1	
	
    gen      lab_f3_h=.
	replace  lab_f3_h=0 if business_work_fup3_h==0 &  farming_work_fup3_h==0
	replace  lab_f3_h=1 if business_work_fup3_h==1 
	replace  lab_f3_h=1 if farming_work_fup3_h==1		
		
	
 * Household 	
   * Any labor 
    foreach time in bl f2 f3{
    gen     lab_`time'_hh=. 
    replace lab_`time'_hh=0  if lab_`time'_w==0 & lab_`time'_h==0
	replace lab_`time'_hh=1  if lab_`time'_w==1
	replace lab_`time'_hh=1  if lab_`time'_h==1
	replace lab_`time'_hh=.  if d_wavail_`time'==0 | d_mavail_`time'==0
	}
   
   
	gen      intr_lab_bl=. 
	replace  intr_lab_bl=1 if lab_bl_h==0 & lab_bl_w==0	 	
	replace  intr_lab_bl=2 if lab_bl_h==1 & lab_bl_w==0
	replace  intr_lab_bl=3 if lab_bl_h==0 & lab_bl_w==1
	replace  intr_lab_bl=4 if lab_bl_h==1 & lab_bl_w==1
	
	gen      intr_lab_f2=. 
	replace  intr_lab_f2=1 if lab_f2_h==0 & lab_f2_w==0	 	
	replace  intr_lab_f2=2 if lab_f2_h==1 & lab_f2_w==0
	replace  intr_lab_f2=3 if lab_f2_h==0 & lab_f2_w==1
	replace  intr_lab_f2=4 if lab_f2_h==1 & lab_f2_w==1
		
	gen      intr_lab_f3=. 
	replace  intr_lab_f3=1 if lab_f3_h==0 & lab_f3_w==0	 	
	replace  intr_lab_f3=2 if lab_f3_h==1 & lab_f3_w==0
	replace  intr_lab_f3=3 if lab_f3_h==0 & lab_f3_w==1
	replace  intr_lab_f3=4 if lab_f3_h==1 & lab_f3_w==1
			
	* Business
    gen     intr_buslab_bl=. 
	replace intr_buslab_bl=1 if business_work_bl_h==0 & business_work_bl_w==0 
	replace intr_buslab_bl=2 if business_work_bl_h==1 & business_work_bl_w==0 
	replace intr_buslab_bl=3 if business_work_bl_h==0 & business_work_bl_w==1
	replace intr_buslab_bl=4 if business_work_bl_h==1 & business_work_bl_w==1
	replace intr_buslab_bl=. if d_mavail_bl==0 | d_wavail_bl==0
	
    gen     intr_buslab_f2=. 
	replace intr_buslab_f2=1 if business_work_fup2_h==0 & business_work_fup2_w==0 
	replace intr_buslab_f2=2 if business_work_fup2_h==1 & business_work_fup2_w==0 
	replace intr_buslab_f2=3 if business_work_fup2_h==0 & business_work_fup2_w==1
	replace intr_buslab_f2=4 if business_work_fup2_h==1 & business_work_fup2_w==1
	replace intr_buslab_f2=. if d_mavail_f2==0 | d_wavail_f2==0
	
    gen     intr_buslab_f3=. 
	replace intr_buslab_f3=1 if business_work_fup3_h==0 & business_work_fup3_w==0 
	replace intr_buslab_f3=2 if business_work_fup3_h==1 & business_work_fup3_w==0 
	replace intr_buslab_f3=3 if business_work_fup3_h==0 & business_work_fup3_w==1
	replace intr_buslab_f3=4 if business_work_fup3_h==1 & business_work_fup3_w==1
	replace intr_buslab_f3=. if d_mavail_f3==0 | d_wavail_f3==0
	
	* Ag
    gen     intr_aglab_bl=. 
	replace intr_aglab_bl=1 if farming_work_bl_h==0 & farming_work_bl_w==0 
	replace intr_aglab_bl=2 if farming_work_bl_h==1 & farming_work_bl_w==0 
	replace intr_aglab_bl=3 if farming_work_bl_h==0 & farming_work_bl_w==1
	replace intr_aglab_bl=4 if farming_work_bl_h==1 & farming_work_bl_w==1
	replace intr_aglab_bl=. if d_mavail_bl==0 | d_wavail_bl==0
	
    gen     intr_aglab_f2=. 
	replace intr_aglab_f2=1 if farming_work_fup2_h==0 & farming_work_fup2_w==0 
	replace intr_aglab_f2=2 if farming_work_fup2_h==1 & farming_work_fup2_w==0 
	replace intr_aglab_f2=3 if farming_work_fup2_h==0 & farming_work_fup2_w==1
	replace intr_aglab_f2=4 if farming_work_fup2_h==1 & farming_work_fup2_w==1
	replace intr_aglab_f2=. if d_mavail_f2==0 | d_wavail_f2==0
	
    gen     intr_aglab_f3=. 
	replace intr_aglab_f3=1 if farming_work_fup3_h==0 & farming_work_fup3_w==0 
	replace intr_aglab_f3=2 if farming_work_fup3_h==1 & farming_work_fup3_w==0 
	replace intr_aglab_f3=3 if farming_work_fup3_h==0 & farming_work_fup3_w==1
	replace intr_aglab_f3=4 if farming_work_fup3_h==1 & farming_work_fup3_w==1
	replace intr_aglab_f3=. if d_mavail_f3==0 | d_wavail_f3==0	
	
	
	# d; 
	la def  lab_dyn 0 "No activity"               
	                1 "Only farming"  
					2 "Only non-farming business"
					3 "Farming and non-farming business", modify;
					
	la def intr_lab 1 "None"
				    2 "Only husband"
					3 "Only wife"
					4 "Both", modify;
	
	la def lab_any 1 "Any work" 0 "No Work", modify; 
	
	la def intr_buslab 1 "No Business" 
					   2 "Only husband business"
					   3 "Only wife business"
					   4 "Both business", modify; 
					   
	la def intr_aglab 1 "No Farming" 
					   2 "Only husband farm"
					   3 "Only wife farm"
					   4 "Both farm", modify; 					   
	
	# d cr; 
	
	la val lab_dyn_* lab_dyn_w_* lab_dyn_h_* lab_dyn
	la val intr_lab_*  intr_lab 
	la val lab_*_w   lab_*_h lab_*_hh lab_any 
	la val intr_buslab_* intr_buslab
	la val intr_aglab_*  intr_aglab
	
	
	foreach time in bl f2 f3 {
	tab lab_dyn_`time',   gen (d_lab_dyn_`time'_) 
	tab lab_dyn_w_`time', gen (d_lab_dyn_w_`time'_) 
	tab lab_dyn_h_`time', gen (d_lab_dyn_h_`time'_) 
	tab lab_`time'_hh,    gen (d_lab_`time'_hh)
	tab lab_`time'_h,     gen (d_lab_h_`time'_)
	tab lab_`time'_w,     gen (d_lab_w_`time'_)	
	tab intr_lab_`time',  gen (d_intr_lab_`time'_)
	tab intr_buslab_`time', gen (d_intr_buslab_`time'_)	
	tab intr_aglab_`time', gen (d_intr_aglab_`time'_)
	}

	la var lab_dyn_bl     "Baseline:Household labor dynamics (last 30 days)"
	la var lab_dyn_f2     "Midline:Household labor dynamics (last 30 days)"	
	la var lab_dyn_f3     "Endline:Household labor dynamics (last 30 days)"	
	la var lab_dyn_w_bl   "Baseline:Wife labor dynamics (last 30 days)"
	la var lab_dyn_w_f2   "Midline:Wife labor dynamics (last 30 days)"	
	la var lab_dyn_w_f3   "Endline:Wife labor dynamics (last 30 days)"		
	la var lab_dyn_h_bl   "Baseline:Husband labor dynamics (last 30 days)"
	la var lab_dyn_h_f2   "Midline:Husband labor dynamics (last 30 days)"	
	la var lab_dyn_h_f3   "Endline:Husband labor dynamics (last 30 days)"			
	la var intr_lab_bl    "Baseline:Intrahousehold Labor"	
	la var intr_buslab_bl "Baseline:Business Labor"
	la var intr_aglab_bl  "Baseline:Agriculture Labor"	
	la var intr_lab_f2    "Midline:Intrahousehold Labor"	
	la var intr_buslab_f2 "Midline:Business Labor"
	la var intr_aglab_f2  "Midline:Agriculture Labor"		
	la var intr_lab_f3    "Endline:Intrahousehold Labor"	
	la var intr_buslab_f3 "Endline:Business Labor"
	la var intr_aglab_f3  "Endline:Agriculture Labor"		
	la var lab_bl_hh      "Baseline:Household LFP(Yes=1)"
	la var lab_f2_hh      "Midline:Household LFP(Yes=1)"
	la var lab_f3_hh      "Endline:Household LFP(Yes=1)"
	la var lab_bl_w       "Baseline:Wife LFP(Yes=1)"
	la var lab_f2_w       "Midline:Wife LFP(Yes=1)"
	la var lab_f3_w       "Endline:Wife LFP(Yes=1)"
	la var lab_bl_h       "Baseline:Husband LFP(Yes=1)"
	la var lab_f2_h       "Midline:Husband LFP(Yes=1)"
	la var lab_f3_h       "Endline:HusbandLFP(Yes=1)"

	
	* Women 
	gen      mul_lfp_w=0 if lab_bl_w==0 & lab_f2_w==0 & lab_f3_w==0 
	replace  mul_lfp_w=1 if lab_bl_w==1 & lab_f2_w==0 & lab_f3_w==0 
	replace  mul_lfp_w=2 if lab_bl_w==0 & lab_f2_w==1 & lab_f3_w==0
	replace  mul_lfp_w=3 if lab_bl_w==0 & lab_f2_w==0 & lab_f3_w==1
	replace  mul_lfp_w=4 if lab_bl_w==1 & lab_f2_w==1 & lab_f3_w==0
	replace  mul_lfp_w=5 if lab_bl_w==0 & lab_f2_w==1 & lab_f3_w==1
	replace  mul_lfp_w=6 if lab_bl_w==1 & lab_f2_w==0 & lab_f3_w==1
	replace  mul_lfp_w=7 if lab_bl_w==1 & lab_f2_w==1 & lab_f3_w==1 
	# d;
	la def   mul_lfp_w 0 "Never worked" 
				       1 "Worked just at BL "
				       2 "Worked just at ML"
				       3 "Worked just at EL"
				       4 "Worked at BL and ML"
				       5 "Worked at ML and EL"
				       6 "Worked at BL, not ML, worked EL"
				       7 "Worked at BL, ML and EL", modify;
	la val mul_lfp_w mul_lfp_w;
	# d cr; 
	tab mul_lfp_w, gen (d_mul_lfp_w_)
	
	* Husband
	gen      mul_lfp_h=0 if lab_bl_h==0 & lab_f2_h==0 & lab_f3_h==0 
	replace  mul_lfp_h=1 if lab_bl_h==1 & lab_f2_h==0 & lab_f3_h==0 
	replace  mul_lfp_h=2 if lab_bl_h==0 & lab_f2_h==1 & lab_f3_h==0
	replace  mul_lfp_h=3 if lab_bl_h==0 & lab_f2_h==0 & lab_f3_h==1
	replace  mul_lfp_h=4 if lab_bl_h==1 & lab_f2_h==1 & lab_f3_h==0
	replace  mul_lfp_h=5 if lab_bl_h==0 & lab_f2_h==1 & lab_f3_h==1
	replace  mul_lfp_h=6 if lab_bl_h==1 & lab_f2_h==0 & lab_f3_h==1
	replace  mul_lfp_h=7 if lab_bl_h==1 & lab_f2_h==1 & lab_f3_h==1 
	# d;
	la def   mul_lfp_h 0 "Never worked" 
				       1 "Worked just at BL "
				       2 "Worked just at ML"
				       3 "Worked just at EL"
				       4 "Worked at BL and ML"
				       5 "Worked at ML and EL"
				       6 "Worked at BL, not ML, worked EL"
				       7 "Worked at BL, ML and EL", modify;
	la val mul_lfp_h mul_lfp_h;
	# d cr; 
	tab mul_lfp_h, gen (d_mul_lfp_h_)			
	
 * Work 
 foreach time in bl f2 f3 {
   gen     d_work_w_`time'=(lab_dyn_w_`time'==1 | lab_dyn_w_`time'==2 | lab_dyn_w_`time'==3)
   la var  d_work_w_`time' "Working Wife (Yes==1)"
   replace d_work_w_`time'=. if d_wavail_`time'==0
 	 
   gen     d_work_h_`time'=(lab_dyn_h_`time'==1 | lab_dyn_h_`time'==2 | lab_dyn_h_`time'==3)
   la var  d_work_h_`time' "Working Husband (Yes==1)"
   replace d_work_h_`time'=. if d_mavail_`time'==0

   gen     d_work_hh_`time'=(lab_dyn_`time'==1 | lab_dyn_`time'==2 | lab_dyn_`time'==3)
   la var  d_work_hh_`time' "Any work HH (Yes==1)"  
   replace d_work_hh_`time'=. if  lab_dyn_`time'==.
 }
	
	drop w_rawmats_business_bl_w 
	gen  w_rawmats_business_bl_w=rawmats_business_bl_w
	drop w_rawmats_business_bl_h 
	gen  w_rawmats_business_bl_h=rawmats_business_bl_h	
	
 * Renamign variables so they match the code 
    ren farming_work_bl_w          farming_work_w_bl 
    ren farming_work_bl_h          farming_work_h_bl 
    ren farming_work_fup2_w        farming_work_w_f2
    ren farming_work_fup3_w        farming_work_w_f3
    ren farming_work_fup2_h        farming_work_h_f2
    ren farming_work_fup3_h        farming_work_h_f3
    ren business_work_bl_w         business_work_w_bl 
    ren business_work_bl_h         business_work_h_bl 
    ren business_work_fup2_w       business_work_w_f2 
    ren business_work_fup2_h       business_work_h_f2 
    ren business_work_fup3_w       business_work_w_f3 
    ren business_work_fup3_h       business_work_h_f3 
	ren rawmats_business_bl_w      rawmats_business_w_bl
	ren rawmats_business_fup2_w    rawmats_business_w_f2
	ren rawmats_business_fup3_w    rawmats_business_w_f3
	ren rawmats_business_bl_h      rawmats_business_h_bl
	ren rawmats_business_fup2_h    rawmats_business_h_f2
	ren rawmats_business_fup3_h    rawmats_business_h_f3	
	ren w_rawmats_business_bl_w    w_rawmats_business_w_bl 
	ren w_rawmats_business_fup2_w  w_rawmats_business_w_f2
	ren w_rawmats_business_fup3_w  w_rawmats_business_w_f3
	ren w_rawmats_business_bl_h    w_rawmats_business_h_bl
	ren w_rawmats_business_fup2_h  w_rawmats_business_h_f2
	ren w_rawmats_business_fup3_h  w_rawmats_business_h_f3	
    ren d_primary_act_fup2_c?      d_primary_act_f2_c?
	ren d_sourcemonbuss_?_fup2_w   d_sourcemonbuss_?_w_f2
	ren d_locationbuss_?_fup2_w    d_locationbuss_?_w_f2		
    ren d_primary_act_fup3_c?      d_primary_act_f3_c?
	ren d_sourcemonbuss_?_fup3_w   d_sourcemonbuss_?_w_f3
	ren d_locationbuss_?_fup3_w    d_locationbuss_?_w_f3 
    ren d_primary_act_fup2_h_c?    d_primary_act_h_f2_c?
	ren d_sourcemonbuss_?_fup2_h   d_sourcemonbuss_?_h_f2
	ren d_locationbuss_?_fup2_h    d_locationbuss_?_h_f2		
    ren d_primary_act_fup3_h_c?    d_primary_act_h_f3_c?
	ren d_sourcemonbuss_?_fup3_h   d_sourcemonbuss_?_h_f3
	ren d_locationbuss_?_fup3_h    d_locationbuss_?_h_f3 	
	ren num_sourcemonbuss_fup2_w   num_sourcemonbuss_w_f2
	ren num_sourcemonbuss_fup2_h   num_sourcemonbuss_h_f2
	ren num_sourcemonbuss_fup3_w   num_sourcemonbuss_w_f3
	ren num_sourcemonbuss_fup3_h   num_sourcemonbuss_h_f3
	 
	
    drop  d_primary_act_f2_c0    d_primary_act_f3_c0 d_primary_act_h_f2_c0  ///
	      d_primary_act_h_f3_c0
		  
		  
**  Raw materials by category 
    forval i=1/6{
     gen  rawmatbus_w_f2_c`i'=rawmats_business_w_f2 if d_primary_act_f2_c`i'==1 
	 gen  rawmatbus_h_f2_c`i'=rawmats_business_h_f2 if d_primary_act_f2_c`i'==1
	 gen  rawmatbus_w_f3_c`i'=rawmats_business_w_f3 if d_primary_act_f3_c`i'==1 
	 gen  rawmatbus_h_f3_c`i'=rawmats_business_h_f3 if d_primary_act_f3_c`i'==1	 
	}
	
    forval i=1/4{	
	 winsor rawmatbus_w_f2_c`i', gen (w_rawmatbus_w_f2_c`i') p (0.01)
	 winsor rawmatbus_w_f3_c`i', gen (w_rawmatbus_w_f3_c`i') p (0.01) 
	}
    gen w_rawmatbus_w_f2_c5=rawmatbus_w_f2_c5
    gen w_rawmatbus_w_f3_c5=rawmatbus_w_f3_c5
    gen w_rawmatbus_w_f2_c6=rawmatbus_w_f2_c6
    gen w_rawmatbus_w_f3_c6=rawmatbus_w_f3_c6	
	
	
    foreach i in 1 3 4{		
    winsor rawmatbus_h_f2_c`i', gen (w_rawmatbus_h_f2_c`i') p (0.01)
    winsor rawmatbus_h_f3_c`i', gen (w_rawmatbus_h_f3_c`i') p (0.01)
	}
	
	gen w_rawmatbus_h_f2_c2=rawmatbus_h_f2_c2
	gen w_rawmatbus_h_f2_c5=rawmatbus_h_f2_c5	
	gen w_rawmatbus_h_f2_c6=rawmatbus_h_f2_c6
	
	winsor rawmatbus_h_f3_c2, gen (w_rawmatbus_h_f3_c2) p(0.01)
	gen w_rawmatbus_h_f3_c5=rawmatbus_h_f3_c5
	gen w_rawmatbus_h_f3_c6=rawmatbus_h_f2_c6
	

	la var w_rawmatbus_w_f2_c1   "Midline:Raw Materials Cooking (Wife)"
	la var w_rawmatbus_w_f2_c2   "Midline:Raw Materials Oil Processing (Wife)"
	la var w_rawmatbus_w_f2_c3   "Midline:Raw Materials Crop Proccesing (Wife)"
	la var w_rawmatbus_w_f2_c4   "Midline:Raw Materials Tranding (Wife)"
	la var w_rawmatbus_w_f2_c5   "Midline:Raw Materials Services (Wife)"
	la var w_rawmatbus_w_f2_c6   "Midline:Raw Materials Other (Wife)"
	la var w_rawmatbus_w_f3_c1   "Endline:Raw Materials Cooking (Wife)"
	la var w_rawmatbus_w_f3_c2   "Endline:Raw Materials Oil Processing (Wife)"
	la var w_rawmatbus_w_f3_c3   "Endline:Raw Materials Crop Proccesing (Wife)"
	la var w_rawmatbus_w_f3_c4   "Endline:Raw Materials Tranding (Wife)"
	la var w_rawmatbus_w_f3_c5   "Endline:Raw Materials Services (Wife)"
	la var w_rawmatbus_w_f3_c6   "Endline:Raw Materials Other (Wife)"	
	

	la var w_rawmatbus_h_f2_c1   "Midline:Raw Materials Cooking (Husband)"
	la var w_rawmatbus_h_f2_c2   "Midline:Raw Materials Oil Processing (Husband)"
	la var w_rawmatbus_h_f2_c3   "Midline:Raw Materials Crop Proccesing (Husband)"
	la var w_rawmatbus_h_f2_c4   "Midline:Raw Materials Tranding (Husband)"
	la var w_rawmatbus_h_f2_c5   "Midline:Raw Materials Services (Husband)"
	la var w_rawmatbus_h_f2_c6   "Midline:Raw Materials Other (Husband)"
	la var w_rawmatbus_h_f3_c1   "Endline:Raw Materials Cooking (Husband)"
	la var w_rawmatbus_h_f3_c2   "Endline:Raw Materials Oil Processing (Husband)"
	la var w_rawmatbus_h_f3_c3   "Endline:Raw Materials Crop Proccesing (Husband)"
	la var w_rawmatbus_h_f3_c4   "Endline:Raw Materials Tranding (Husband)"
	la var w_rawmatbus_h_f3_c5   "Endline:Raw Materials Services (Husband)"
	la var w_rawmatbus_h_f3_c6   "Endline:Raw Materials Other (Husband)"		
	
	* When they both have business
	clonevar bothbustype_f2=primary_act_fup2 
	replace  bothbustype_f2=. if intr_buslab_f2!=4
	clonevar bothbustype_f3=primary_act_fup3 
    replace  bothbustype_f3=. if intr_buslab_f2!=4
	tab      bothbustype_f2, gen (d_bothbustype_f2_c)
	tab      bothbustype_f3, gen (d_bothbustype_f3_c)
	
    la var d_bothbustype_f2_c1        "Midline:Cook both Business"
	la var d_bothbustype_f2_c2        "Midline:Oil Processing both Business"
	la var d_bothbustype_f2_c3        "Midline:Crops Proccessing both Business"
	la var d_bothbustype_f2_c4        "Midline:Trader both Business"
	la var d_bothbustype_f2_c5        "Midline:Services both Business"
	la var d_bothbustype_f2_c6        "Midline:Other both Business"	
    la var d_bothbustype_f3_c1        "Endline:Cook both Business"
	la var d_bothbustype_f3_c2        "Endline:Oil Processing both Business"
	la var d_bothbustype_f3_c3        "Endline:Crops Proccessing both Business"
	la var d_bothbustype_f3_c4        "Endline:Trader both Business"
	la var d_bothbustype_f3_c5        "Endline:Services both Business"
	la var d_bothbustype_f3_c6        "Endline:Other both Business"
	
 ** New business characteristics 
    * Raw materials 
	gen     newbus_rawmats_w_f2=w_rawmats_business_w_f2
	replace newbus_rawmats_w_f2=. if d_newbus_fup2==0
	gen     newbus_rawmats_w_f3=w_rawmats_business_w_f3
	replace newbus_rawmats_w_f3=. if d_newbus_fup3==0	
	
	
	* Characteritics 
	clonevar newbustype_f2=primary_act_fup2 
	replace  newbustype_f2=. if d_newbus_fup2==0
	clonevar newbustype_f3=primary_act_fup3 
    replace  newbustype_f3=. if d_newbus_fup3==0
	tab      newbustype_f2, gen (d_newbustype_f2_c)
	tab      newbustype_f3, gen (d_newbustype_f3_c)
	
	gen      hc_newbustype_f2=(newbustype_f2==2 | newbustype_f2==3)
	replace  hc_newbustype_f2=. if d_newbus_fup2==0
	gen      hc_newbustype_f3=(newbustype_f3==2 | newbustype_f3==3)
	replace  hc_newbustype_f3=. if d_newbus_fup3==0
  
    * Source of business 
	gen     d_newbus_source1_w_f2=d_sourcemonbuss_1_w_f2 if d_newbus_fup2==1
	gen     d_newbus_source2_w_f2=d_sourcemonbuss_2_w_f2 if d_newbus_fup2==1	
	gen     d_newbus_source3_w_f2=d_sourcemonbuss_3_w_f2 if d_newbus_fup2==1
	gen     d_newbus_source4_w_f2=d_sourcemonbuss_4_w_f2 if d_newbus_fup2==1
	gen     d_newbus_source5_w_f2=d_sourcemonbuss_5_w_f2 if d_newbus_fup2==1
	gen     d_newbus_source6_w_f2=d_sourcemonbuss_6_w_f2 if d_newbus_fup2==1	
	
	gen     d_newbus_source1_w_f3=d_sourcemonbuss_1_w_f3 if d_newbus_fup3==1
	gen     d_newbus_source2_w_f3=d_sourcemonbuss_2_w_f3 if d_newbus_fup3==1	
	gen     d_newbus_source3_w_f3=d_sourcemonbuss_3_w_f3 if d_newbus_fup3==1
	gen     d_newbus_source4_w_f3=d_sourcemonbuss_4_w_f3 if d_newbus_fup3==1
	gen     d_newbus_source5_w_f3=d_sourcemonbuss_5_w_f3 if d_newbus_fup3==1
	gen     d_newbus_source6_w_f3=d_sourcemonbuss_6_w_f3 if d_newbus_fup3==1	 
	
	la var newbus_rawmats_w_f2       "Midline: Raw Materials New Business"
    la var d_newbustype_f2_c1        "Midline:Cook New Business"
	la var d_newbustype_f2_c2        "Midline:Oil Processing New Business"
	la var d_newbustype_f2_c3        "Midline:Crops Proccessing New Business"
	la var d_newbustype_f2_c4        "Midline:Trader New Business"
	la var d_newbustype_f2_c5        "Midline:Services New Business"
	la var d_newbustype_f2_c6        "Midline:Other New Business"
	la var d_newbus_source1_w_f2     "Midline:Source of money Cash transfer payment (Wife)"
	la var d_newbus_source2_w_f2     "Midline:Source of money Savings (Wife)"	
	la var d_newbus_source3_w_f2     "Midline:Source of money Loan from Bank/ Microcredit (Wife)"	
	la var d_newbus_source4_w_f2     "Midline:Source of money Loan from a family/friend/neighbor (Wife)"
	la var d_newbus_source5_w_f2     "Midline:Source of money Gift (Wife)"
	la var d_newbus_source6_w_f2     "Midline:Source of money Other (Wife)"
	
	
	la var newbus_rawmats_w_f3       "Endline: Raw Materials New Business"	
    la var d_newbustype_f3_c1        "Endline:Cook New Business"
	la var d_newbustype_f3_c2        "Endline:Oil Processing New Business"
	la var d_newbustype_f3_c3        "Endline:Crops Proccessing New Business"
	la var d_newbustype_f3_c4        "Endline:Trader New Business"
	la var d_newbustype_f3_c5        "Endline:Services New Business"
	la var d_newbustype_f3_c6        "Endline:Other New Business"	
	la var d_newbus_source1_w_f3     "Endline:Source of money Cash transfer payment (Wife)"
	la var d_newbus_source2_w_f3     "Endline:Source of money Savings (Wife)"	
	la var d_newbus_source3_w_f3     "Endline:Source of money Loan from Bank/ Microcredit (Wife)"	
	la var d_newbus_source4_w_f3     "Endline:Source of money Loan from a family/friend/neighbor (Wife)"
	la var d_newbus_source5_w_f3     "Endline:Source of money Gift (Wife)"
	la var d_newbus_source6_w_f3     "Endline:Source of money Other (Wife)"

	* Labels 
    la var farming_work_w_bl  "Baseline:Any farming work(Wife)"
    la var farming_work_w_f2  "Midline:Any farming work(Wife)"
    la var farming_work_w_f3  "Endline:Any farming work(Wife)"	
    la var farming_work_h_bl  "Baseline:Any farming work(Husband)"
    la var farming_work_h_f2  "Midline:Any farming work(Husband)"
    la var farming_work_h_f3  "Endline:Any farming work(husband)"	
	la var any_business_bl    "Baseline:Non-Farm Enterprise (Household)"
	la var any_business_f2    "Midline:Non-Farm Enterprise (Household)"	
	la var any_business_f3    "Endline:Non-Farm Enterprise (Household)"			
	la var d_work_w_bl        "Baseline:Any work (Wife)"
	la var d_work_w_f2        "Midline:Any work (Wife)"	
	la var d_work_w_f3        "Endline:Any work (Wife)"	
	la var d_work_h_bl        "Baseline:Any work (Husband)"
	la var d_work_h_f2        "Midline:Any work (Husband)"	
	la var d_work_h_f3        "Endline:Any work (Husband)"		
	la var d_work_hh_bl       "Baseline:Any work (Household)"
	la var d_work_hh_f2       "Midline:Any work (Household)"	
	la var d_work_hh_f3       "Endline:Any work (Household)"			
	la var frac_rawmat_w_bl   "Baseline:Fraction of profits that are raw materials(Wife)"
	la var frac_rawmat_w_f2   "Midline:Fraction of profits that are raw materials(Wife)"
	la var frac_rawmat_w_f3   "Endline:Fraction of profits that are raw materials(Wife)"
	la var frac_rawmat_h_bl   "Baseline:Fraction of profits that are raw materials(Husband)"
	la var frac_rawmat_h_f2   "Midline:Fraction of profits that are raw materials(Husband)"
	la var frac_rawmat_h_f3   "Endline:Fraction of profits that are raw materials(Husband)"
    la var hc_newbustype_f2   "Midline:High cost new business"	  
	la var hc_newbustype_f3   "Endline:High cost new business"
	
	
	la var share_myself                 "% CT kept for myself(Wife)"
	la var share_spouse                 "% CT given to spouse(Wife)"
	la var share_children               "% CT given to children(Wife)"
	la var share_friends_in             "% CT shared with friends and family same village(Wife)"
	la var share_friends_out            "% CT shared with friends and family outside village(Wife)"
	
    la var share_myself_relative_w      "% of hypothetical relative transfer kept by herself(Wife)"
    la var share_spouse_relative_w      "% of hypothetical relative transfer given to spouse(Wife)"	
    la var share_children_relative_w    "% of hypothetical relative transfer given to children(Wife)"
    la var share_friends_in_relative_w  "% of hypothetical relative transfer given to friends (in village)(Wife)"	
    la var share_friends_out_relative_w "% of hypothetical relative transfer given  to friends (outside village)(Wife)"	
	
    la var share_myself_ngo_w           "% of hypothetical ngo transfer kept by herself(Wife)"
    la var share_spouse_ngo_w           "% of hypothetical ngo transfer given to spouse(Wife)"	
    la var share_children_ngo_w         "% of hypothetical ngo transfer given to children(Wife)"
    la var share_friends_in_ngo_w       "% of hypothetical ngo transfer given to friends (in village)(Wife)"	
    la var share_friends_out_ngo_w      "% of hypothetical ngo transfer given  to friends (outside village)(Wife)"
    la var share_myself_relative_h      "% of hypothetical relative transfer kept by himself(Husband)"
    la var share_spouse_relative_h      "% of hypothetical relative transfer given to spouse(Husband)"	
    la var share_children_relative_h    "% of hypothetical relative transfer given to children(Husband)"
    la var share_friends_in_relative_h  "% of hypothetical relative transfer given to friends (in village)(Husband)"	
    la var share_friends_out_relative_h "% of hypothetical relative transfer given  to friends (outside village)(Husband)"
	
    la var share_myself_ngo_h           "% of hypothetical ngo transfer kept by himself (Husband)"
    la var share_spouse_ngo_h           "% of hypothetical ngo transfer given to spouse(Husband)"	
    la var share_children_ngo_h         "% of hypothetical ngo transfer given to children(Husband)"
    la var share_friends_in_ngo_h       "% of hypothetical ngo transfer given to friends (in village)(Husband)"	
    la var share_friends_out_ngo_h      "% of hypothetical ngo transfer given  to friends (outside village)(Husband)"		
    la var business_work_w_bl            "Female Non Farm Enterprise (Yes=1)"

    la var d_posyields_f3           "Positive Agricultural Yield (Yes=1)"
	la var ihs_ragyields_f3          "Yields (IHS)"
	la var ihs_ttl_realinputsha_f3   "Total inputs used on the plot per hectare (IHS)"
	la var proweia2_aindex_w_f3      "Pro-WEAI Empowerment Index"
	la var dm2_aindex_w_f3           "Decision Making Index"
	la var d_wavail_bl            "Wife is present at Baseline"
	la var d_mavail_bl            "Husband is present at baseline"	


** Checking variation in number of households 	
	gen    deltapet3001000=pet300-pet1000	
	gen    deltapet600700=pet600-pet700
	gen    deltapet600800=pet600-pet800
	gen    deltapet600900=pet600-pet900
	gen    deltapet6001000=pet600-pet1000
	gen    d0_deltapet3001000=(deltapet3001000==0)	
	gen    d0_deltapet600700=(deltapet600700==0)
	gen    d0_deltapet600800=(deltapet600800==0)
	gen    d0_deltapet600900=(deltapet600900==0)
	gen    d0_deltapet6001000=(deltapet6001000==0)
	la var d0_deltapet3001000  "Fraction of hh PET doesnt change (300-1000mts)"	
	la var d0_deltapet600700  "Fraction of hh PET doesnt change (600-700mts)"
	la var d0_deltapet600800  "Fraction of hh PET doesnt change (600-800mts)"
	la var d0_deltapet600900  "Fraction of hh PET doesnt change (600-900mts)"
	la var d0_deltapet6001000 "Fraction of hh PET doesnt change (600-1000mts)"
	sum    d0_*
	
	gen    deltapov300400=b300pov-b400pov	
	gen    deltapov3001000=b300pov-b1000pov	
	gen    deltapov600700=b600pov-b700pov
	gen    deltapov600800=b600pov-b700pov
	gen    deltapov600900=b600pov-b700pov
	gen    deltapov6001000=b600pov-b700pov
	gen    d0_deltapov3001000=(deltapov3001000==0)	
	gen    d0_deltapov600700=(deltapov600700==0)
	gen    d0_deltapov600800=(deltapov600800==0)
	gen    d0_deltapov600900=(deltapov600900==0)
	gen    d0_deltapov6001000=(deltapov6001000==0)
	la var d0_deltapov3001000  "Fraction of market size doesnt change(300-1000mts)"	
	la var d0_deltapov600700  "Fraction of market size doesnt change(600-700mts)"
	la var d0_deltapov600800  "Fraction of market size doesnt change(600-800mts)"
	la var d0_deltapov600900  "Fraction of market size doesnt change(600-900mts)"
	la var d0_deltapov6001000 "Fraction of market size doesnt change(600-1000mts)"	


	clonevar vulne_cat=vulnerability_category_ward_bl
	
}	


** C. Generating RDD variables 
** -----------------------------------------------------------------------------
if $part_c{
	
*Defining the different bandwidths = +/- bandwidth number of EVs within the village above and below the 18 EVs per village cutoff. For example RDD_18 includes all villages with 0 EVs to 36EVs within the village. RDD_10 includes all villages with 8 EVs to 28 EVs withing the village
gen RDD = 1
gen RDD_13 = .
gen RDD_12 = .
gen RDD_10 = . 
gen RDD_18 = . 
gen RDD_15 = .
	
**The village groups needed to be aggregated to create a "number of EVs in the
* village variable" (group 6, group 4, group 3 and group 1 are in non-FNLP sample)
/*this variable was created by Sree ask about why she excluded some villages*/ 
clonevar village_ = village_new_bl
replace village_ = 110 if village_new_bl ==111 | village_new_bl==114
replace village_ = 129 if village_new_bl ==131 | village_new_bl==132
replace village_ = 133 if village_new_bl ==134
replace village_ = 202 if village_new_bl ==221
	
// Change village group to village_ if want to run Sree's code 
bys village_: egen num_evs_village_ = total(d_vuln_cat_1)

**Number of EVs in Control Villages (not everyone got surveyed so look to original EV list)
replace num_evs_village_=	88	if village_==	102
replace num_evs_village_=	7	if village_==	103
replace num_evs_village_=	37	if village_==	106
replace num_evs_village_=	30	if village_==	110
replace num_evs_village_=	30	if village_==	110
replace num_evs_village_=	30	if village_==	110
replace num_evs_village_=	16	if village_==	115
replace num_evs_village_=	58	if village_==	119
replace num_evs_village_=	49	if village_==	120
replace num_evs_village_=	9	if village_==	126
replace num_evs_village_=	44	if village_==	129
replace num_evs_village_=	44	if village_==	129
replace num_evs_village_=	44	if village_==	129
replace num_evs_village_=	39	if village_==	133
replace num_evs_village_=	39	if village_==	133
replace num_evs_village_=	24	if village_==	135
replace num_evs_village_=	47	if village_==	141
replace num_evs_village_=	31	if village_==	144
replace num_evs_village_=	96	if village_==	147
replace num_evs_village_=	59	if village_==	148
replace num_evs_village_=	27	if village_==	151
replace num_evs_village_=	5	if village_==	157
replace num_evs_village_=	34	if village_==	158
replace num_evs_village_=	50	if village_==	201
replace num_evs_village_=	64	if village_==	202
replace num_evs_village_=	16	if village_==	207
replace num_evs_village_=	18	if village_==	209
replace num_evs_village_=	70	if village_==	210
replace num_evs_village_=	55	if village_==	211
replace num_evs_village_=	6	if village_==	216
replace num_evs_village_=	16	if village_==	220
replace num_evs_village_=	64	if village_==	202
replace num_evs_village_=	70	if village_==	224
replace num_evs_village_=	105	if village_==	226
replace num_evs_village_=	28	if village_==	227
replace num_evs_village_=	18	if village_==	231
replace num_evs_village_=	23	if village_==	233
replace num_evs_village_=	21	if village_==	235
replace num_evs_village_=	5	if village_==	243
replace num_evs_village_=	38	if village_==	250
replace num_evs_village_=	13	if village_==	252
replace num_evs_village_=	4	if village_==	255
replace num_evs_village_=	26	if village_==	256
replace num_evs_village_=	70	if village_==	258
replace num_evs_village_=	24	if village_==	259
replace num_evs_village_=	6	if village_==	263
replace num_evs_village_=	15	if village_==	264
replace num_evs_village_=	40	if village_==	265
replace num_evs_village_=	41	if village_==	266
replace num_evs_village_=	54	if village_==	267
replace num_evs_village_=	29	if village_==	273

****************Sree added 10/25/2023
**Number of EVs in FNLP Treatment Villages (not everyone got surveyed so look to original EV list for the full number)
**First I replace the code for the groups (group 5 and 2 in treatment villages)
replace village_ = 107 if village_new_bl ==108 | village_new_bl==109
replace village_ = 222 if village_new_bl ==234

replace num_evs_village_=	43	if village_==	101
replace num_evs_village_=	2	if village_==	104
replace num_evs_village_=	76	if village_==	105
replace num_evs_village_=	65	if village_==	107
replace num_evs_village_=	65	if village_==	107
replace num_evs_village_=	65	if village_==	107
replace num_evs_village_=	25	if village_==	113
replace num_evs_village_=	7	if village_==	117
replace num_evs_village_=	35	if village_==	118
replace num_evs_village_=	51	if village_==	121
replace num_evs_village_=	51	if village_==	123
replace num_evs_village_=	2	if village_==	125
replace num_evs_village_=	17	if village_==	128
replace num_evs_village_=	37	if village_==	139
replace num_evs_village_=	48	if village_==	140
replace num_evs_village_=	11	if village_==	142
replace num_evs_village_=	25	if village_==	143
replace num_evs_village_=	51	if village_==	149
replace num_evs_village_=	35	if village_==	150
replace num_evs_village_=	22	if village_==	153
replace num_evs_village_=	20	if village_==	154
replace num_evs_village_=	7	if village_==	155
replace num_evs_village_=	8	if village_==	156
replace num_evs_village_=	8	if village_==	159
replace num_evs_village_=	13	if village_==	203
replace num_evs_village_=	18	if village_==	205
replace num_evs_village_=	70	if village_==	208
replace num_evs_village_=	24	if village_==	212
replace num_evs_village_=	44	if village_==	213
replace num_evs_village_=	24	if village_==	214
replace num_evs_village_=	12	if village_==	215
replace num_evs_village_=	3	if village_==	217
replace num_evs_village_=	16	if village_==	218
replace num_evs_village_=	23	if village_==	219
replace num_evs_village_=	59	if village_==	222
replace num_evs_village_=	3	if village_==	223
replace num_evs_village_=	2	if village_==	229
replace num_evs_village_=	32	if village_==	230
replace num_evs_village_=	59	if village_==	222
replace num_evs_village_=	47	if village_==	237
replace num_evs_village_=	29	if village_==	238
replace num_evs_village_=	140	if village_==	244
replace num_evs_village_=	2	if village_==	245
replace num_evs_village_=	14	if village_==	246
replace num_evs_village_=	20	if village_==	247
replace num_evs_village_=	21	if village_==	257
replace num_evs_village_=	2	if village_==	260
replace num_evs_village_=	40	if village_==	261
replace num_evs_village_=	26	if village_==	269
replace num_evs_village_=	42	if village_==	270
replace num_evs_village_=	30	if village_==	271
replace num_evs_village_=	9	if village_==	272


**RDD_18
local villages 110 111 114 129 131 132 133 134 135 151 209 221 227 231 ///
			   233 235 256 259 273 115 207 220 252 264 273 272 271 263 ///
			   257 255 252 247 246 243 238 234 230 222 220 219 218 216 ///
			   215 214 212 207 203 159 158 157 156 155 154 153 151 150 ///
			   144 143 142 135 134 133 131 129 128 126 117 113 109 108 ///
			   107 106 103 223 217 104 229 125 265 139 118 260 210
local num_villages : list sizeof villages
forvalues i = 1/`num_villages' {
local rdd_villages: word `i' of `villages'
replace RDD_18 = 1 if village_new_bl==`rdd_villages'
}

replace RDD_18 = 0 if RDD_18==.

***RDD_15
local villages 255	157	243	216	263	103	126	252	264	220	207	115	231	/// 
			   209	235	233	259	135	256	151	227	273	114	111	110	144	/// 
			   133	134	131	129	223	217	117	155	159	156	272	142	215	///
			   203	246	218	128	205	247	154	257	153	219	212	214	143	///
			   113	269	238	271	230	234	109	108	107
local num_villages : list sizeof villages
forvalues i = 1/`num_villages' {
local rdd_villages: word `i' of `villages'
replace RDD_15 = 1 if village_new_bl==`rdd_villages'
}	

***The bandwidth selected from local randomization methods 
***RDD_13
local villages 157	243	216	263	103	126	252	264	220	207	115	231	209	/// 
               235	233	259	135	256	151	227	273	114	111	110	144	133	/// 
			   134	131	129	117	155	159	156	272	142	215	203	246	218	/// 
			   128	205	247	154	257	153	219	212	214	143	113	269	238	/// 
			   271	234	109	108	107
local num_villages : list sizeof villages
forvalues i = 1/`num_villages' {
local rdd_villages: word `i' of `villages'
replace RDD_13 = 1 if village_new_bl==`rdd_villages'
}

***RDD_12
local villages 216	263	103	126	252	264	220	207	115	231	209	235	233	/// 
               259	135	256	151	227	273	114	111	110	133	134	131	129	/// 
			   117	155	159	156	272	142	215	203	246	218	128	205	247	/// 
			   154	257	153	219	212	214	143	113	269	238	271	234	109	/// 
			   108	107   
local num_villages : list sizeof villages
forvalues i = 1/`num_villages' {
local rdd_villages: word `i' of `villages'
replace RDD_12 = 1 if village_new_bl==`rdd_villages'
}


**RDD_10
local villages 126	252	264	220	207	115	231	209	235	233	259	135	256	/// 
               151	227	114	111	110	133	134	131	129	117	155	159	156	/// 
			   272	142	215	203	246	218	128	205	247	154	257	153	219	/// 
			   212	214	143	113	269	234	109	108	107
local num_villages : list sizeof villages
forvalues i = 1/`num_villages' {
local rdd_villages: word `i' of `villages'
replace RDD_10 = 1 if village_new_bl==`rdd_villages'
}

************************************************************************************

***Creating means within the villages to use in the RD plots
bys village_: egen business_mean_vill_bl_ = mean(business_work_w_bl) if FNLP_treatment==0 & d_vuln_cat_1==1
bys village_: egen business_mean_vill_fup2_ = mean(business_work_w_f2) if FNLP_treatment==0 & d_vuln_cat_1==1
bys village_: egen business_mean_vill_fup3_ = mean(business_work_w_f3) if FNLP_treatment==0 & d_vuln_cat_1==1

bys village_: egen business_mean_vill_bl_2 = mean(business_work_w_bl) if cashreceived==0 & FNLP_treatment==0 & d_vuln_cat_1==1
bys village_: egen business_mean_vill_fup2_2 = mean(business_work_w_f2) if cashreceived==0 & FNLP_treatment==0 & d_vuln_cat_1==1
bys village_: egen business_mean_vill_fup3_2 = mean(business_work_w_f3) if cashreceived==0 & FNLP_treatment==0 & d_vuln_cat_1==1

bys village_: egen business_mean_vill_bl_all = mean(business_work_w_bl) if FNLP_treatment==0  
bys village_: egen business_mean_vill_fup2_all = mean(business_work_w_f2) if FNLP_treatment==0  
bys village_: egen business_mean_vill_fup3_all = mean(business_work_w_f3) if FNLP_treatment==0  

**Variables that were missing values are replaced with zeros where appropriate
recode farm_greaterthan1hectare_bl num_hh_members_15_bl empowered_new_bl  (.=0)
recode farm_lessthan1hectare_bl (.=1)
	
tab Stratification_Dummies_bl, gen(d_strat_)	

}


** D. Generating PS weights 
** -----------------------------------------------------------------------------
if $part_d{
  gen more_one_enterprise=(num_enterprises_bl>0)
  
** Extreme vulnerable Sample:
** -----------------------------------------------------------------------------  
* Setting up controls 	 to be included in the multinomial  
  # d;
   gl cov_pred    age_hhhead_bl
                  marital_status2_bl_2 marital_status2_bl_3 marital_status2_bl_4
				  num_plots_bl       
				  num_hh_members_bl  
				  num_plots_bl  
				  num_enterprises_bl
				  weai_new_bl_w
				  d_lgacode_bl_1;  
  # d cr; 				  

  
 * Regression on treatment status -Pure control is base caregory 
   mprobit spill_treatment $cov_pred if d_vuln_cat_1==1 & FNLP_treatment==0	& RDD_18==1
 * Predict probabilities
   predict prob0 prob1 prob2

 * Generating inverse probability weights  
	gen     ipw=1/prob0 if spill_treatment==0
	replace ipw=1/prob1 if spill_treatment==1
	replace ipw=1/prob2 if spill_treatment==2
	sum ipw
	la var ipw "Inverse Probability Weights Multinomial (RDD 18)"
    drop prob0 prob1 prob2
  
 * Regression on treatment status -Pure control is base caregory 
   mprobit spill_treatment $cov_pred if d_vuln_cat_1==1 & FNLP_treatment==0	& RDD_15==1
 * Predict probabilities
   predict prob0 prob1 prob2

 * Generating inverse probability weights  
	gen     ipw2=1/prob0 if spill_treatment==0
	replace ipw2=1/prob1 if spill_treatment==1
	replace ipw2=1/prob2 if spill_treatment==2
	sum ipw2
	la var ipw2 "Inverse Probability Weights Multinomial (RDD 15)"  
    drop prob0 prob1 prob2 
  

 
  
 
 
 
}


** E. Sampling weights 
** -----------------------------------------------------------------------------
if $part_e{
*****CREATING THE SAMPLING WEIGHTS - when doing the balance check we adjust the weight attributed to EV, VV and ML within each ward

*The sampling weights:

*The EV category was defined as the bottom 16th percentiles defined within the ward of the 16,848 with PPI data
*The VV category was the middle 69 percentiles of the PPI score distribution within each ward 
*The ML category was the top 15 percentiles of the PPI score distribution within each ward

/**Therefore to create the sampling weights we need to adjust the % assigned to EV, VV and ML within each ward with the level 
that was attributed to that category during the randomizations. i.e. 16%, 69% and 15%**/

gen sampling_weights = .

gen ward_vulnerable = 1 if vulnerability_category_ward_bl==1 & ward_new_bl==1

forvalues j = 2/8 {
replace ward_vulnerable = `j' if vulnerability_category_ward_bl==1 & ward_new_bl==`j'
}

replace ward_vulnerable = 9  if vulnerability_category_ward_bl==2 & ward_new_bl==1
replace ward_vulnerable = 10 if vulnerability_category_ward_bl==2 & ward_new_bl==2
replace ward_vulnerable = 11 if vulnerability_category_ward_bl==2 & ward_new_bl==3
replace ward_vulnerable = 12 if vulnerability_category_ward_bl==2 & ward_new_bl==4
replace ward_vulnerable = 13 if vulnerability_category_ward_bl==2 & ward_new_bl==5
replace ward_vulnerable = 14 if vulnerability_category_ward_bl==2 & ward_new_bl==6
replace ward_vulnerable = 15 if vulnerability_category_ward_bl==2 & ward_new_bl==7
replace ward_vulnerable = 16 if vulnerability_category_ward_bl==2 & ward_new_bl==8
replace ward_vulnerable = 17 if vulnerability_category_ward_bl==3 & ward_new_bl==1
replace ward_vulnerable = 18 if vulnerability_category_ward_bl==3 & ward_new_bl==2
replace ward_vulnerable = 19 if vulnerability_category_ward_bl==3 & ward_new_bl==3
replace ward_vulnerable = 20 if vulnerability_category_ward_bl==3 & ward_new_bl==4
replace ward_vulnerable = 21 if vulnerability_category_ward_bl==3 & ward_new_bl==5
replace ward_vulnerable = 22 if vulnerability_category_ward_bl==3 & ward_new_bl==6
replace ward_vulnerable = 23 if vulnerability_category_ward_bl==3 & ward_new_bl==7
replace ward_vulnerable = 24 if vulnerability_category_ward_bl==3 & ward_new_bl==8

replace sampling_weights = 0.16/0.7019 if ward_vulnerable ==1
replace sampling_weights = 0.16/0.6302 if ward_vulnerable ==2
replace sampling_weights = 0.16/0.6562 if ward_vulnerable ==3
replace sampling_weights = 0.16/0.6949 if ward_vulnerable ==4
replace sampling_weights = 0.16/0.7612 if ward_vulnerable ==5
replace sampling_weights = 0.16/0.6876 if ward_vulnerable ==6
replace sampling_weights = 0.16/0.7347 if ward_vulnerable ==7
replace sampling_weights = 0.16/0.6731 if ward_vulnerable ==8
replace sampling_weights = 0.69/0.2404 if ward_vulnerable ==9
replace sampling_weights = 0.69/0.3066 if ward_vulnerable ==10
replace sampling_weights = 0.69/0.2719 if ward_vulnerable ==11
replace sampling_weights = 0.69/0.2465 if ward_vulnerable ==12
replace sampling_weights = 0.69/0.1774 if ward_vulnerable ==13
replace sampling_weights = 0.69/0.2364 if ward_vulnerable ==14
replace sampling_weights = 0.69/0.2182 if ward_vulnerable ==15
replace sampling_weights = 0.69/0.2628 if ward_vulnerable ==16
replace sampling_weights = 0.15/0.0577 if ward_vulnerable ==17
replace sampling_weights = 0.15/0.0633 if ward_vulnerable ==18
replace sampling_weights = 0.15/0.0719 if ward_vulnerable ==19
replace sampling_weights = 0.15/0.0586 if ward_vulnerable ==20
replace sampling_weights = 0.15/0.0614 if ward_vulnerable ==21
replace sampling_weights = 0.15/0.0759 if ward_vulnerable ==22
replace sampling_weights = 0.15/0.0471 if ward_vulnerable ==23
replace sampling_weights = 0.15/0.0641 if ward_vulnerable ==24
la var  sampling_weights "Sampling weights"

tab sampling_weights vulnerability_category_ward_bl

*** Creating the sampling weight for the household level randomizations
/*The sampling frame dropped from 16,858 households to 12,000 when we randomly
selected who would go to class B assignment. Since we fixed the EV category at
approx 2,400 households we randomly selected a number of households from VV and ML
categories to go to class C assignment and drop from our experiment.  
EV has a weight of 23% in the sampling frame (treatment villages only)
VV has a weight of 61% in the sampling frame (treatment villages only)
ML has a weight of 15% in the sampling frame (treatment villages only)
EV has a weight of 67.63% in the survey (treatment villages only)
VV has a weight of 26.47% in the survey (treatment villages only)
ML has a weight of 5.89% in the survey (treatment villages only)
*/

gen     weight_hh = . 
replace weight_hh = 0.23/0.6763 if vulnerability_category_ward_bl ==1
replace weight_hh = 0.61/0.2647 if vulnerability_category_ward_bl ==2
replace weight_hh = 0.15/0.0589 if vulnerability_category_ward_bl ==3
la var  weight_hh "Households weights"


* temporary generating a baseline variable for inputs that works in the loop  
  clonevar ihs_ttl_inputsha_bl=num_crops_cult_bl
  clonevar ihs_ttl_realinputsha_bl=num_crops_cult_bl
  clonevar w_ttl_realinputsha_bl=num_crops_cult_bl

  gen    chop_money_rs_dum_other_w=(chop_money_rs_dum_6_w==1| chop_money_rs_dum_7_w==1| chop_money_rs_dum_9_w==1) 
  la var chop_money_rs_dum_other_w "Other" 	 
 
  replace 	d_chop_money_w=0 if d_chop_money_w==.
  replace  d_chop_money_w=. if marital_status2_bl_3==1 | marital_status2_bl_4==1 	
	






* Saving final data for analysis
  saveold "$data/Final/FNLPDataWideAnalysis.dta", replace 
}
  
********************************************************************************
//  END OF PART A DOFILE
********************************************************************************